import { $APP, shadow$provide } from "./shared.js";
const shadow_esm_import = function(x) { return import(x) };
var $app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$,$goog$functions$throttle$$,$module$contents$goog$array_slice$$,$module$contents$goog$array_splice$$,$cljs$tools$reader$macro_terminating_QMARK_$$,$app$common$math$sq$$,$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$,$goog$dom$getElementsByClass$$,$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$util$dom$select_target$$,$app$util$dom$get_parent_with_selector$$,$app$util$dom$valid_QMARK_$$,
$app$util$dom$set_value_BANG_$$,$app$util$dom$is_in_viewport_QMARK_$$,$rumext$v2$throttle$$,$app$common$types$color$hue__GT_rgb$$,$app$common$types$tokens_lib$get_set_names$$,$app$common$types$tokens_lib$get_sets_at_path$$,$app$common$types$tokens_lib$enable_sets$$,$app$common$types$tokens_lib$disable_sets$$,$app$common$types$tokens_lib$set_path_exists_QMARK_$$,$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$,$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$,$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$,
$app$common$types$tokens_lib$get_all_tokens$$,$app$util$keyboard$mod_event_QMARK_$$,$app$util$mouse$get_pointer_movement$$,$app$main$ui$hooks$sortable_container_STAR_$$,$app$util$text$content$to_dom$create_random_key$$,$app$util$array$normalize_to_array$$,$app$util$array$without_nils$$,$app$util$array$filter$$,$app$util$text_editor$editor_select_all$$,$app$util$text_editor$cursor_to_end$$,$app$main$data$tinycolor$__GT_string$$,$app$main$ui$css_cursors$get_dynamic$$,$cljs$tools$reader$ending_line_col_info$$,
$cljs$tools$reader$starting_line_col_info$$,$app$util$dom$left_mouse_QMARK_$$,$app$util$dom$active_QMARK_$$,$app$render_wasm$api$set_transition_tiles_complete_handler_BANG_$$,$app$render_wasm$serializers$translate_guide_axis$$,$app$main$data$workspace$colors$recent_color_equal_QMARK_$$,$app$main$data$workspace$specialized_panel$interrupt_QMARK_$$,$app$util$shape_icon$get_shape_icon_by_type$$,$app$util$mouse$mouse_click_event_QMARK_$$,$app$common$types$shape$interactions$has_offset_effect_QMARK_$$,
$app$common$types$shape$interactions$has_way_QMARK_$$,$app$main$data$workspace$notifications$finalize$$,$app$main$ui$measurements$get_edge_for_badge$$,$app$main$ui$hooks$use_ref_callback$$,$app$main$ui$hooks$use_update_ref$$,$cljs$core$partition_by$cljs$0core$0IFn$0_invoke$0arity$02$$,$cljs$core$not_every_QMARK_$$,$cljs$tools$reader$flatten_map$$,$app$common$path_names$merge_path_item_with_dot$$,$app$common$types$token$build_result$$,$promesa$impl$promise$all$$,$cljs$spec$alpha$explain_data_STAR_$$,
$app$common$data$nth_index_of_STAR_$$,$cljs$core$Namespace$$,$app$common$types$text$replace_all_case_insensitive$$,$app$common$types$color$remove_hash$$,$app$common$data$macros$truncate$$,$app$util$array$sort_BANG_$$,$app$render_wasm$api$apply_canvas_blur$$,$app$render_wasm$api$start_initial_load_transition_BANG_$$,$app$main$ui$workspace$viewport$utils$title_transform_use_width_QMARK_$$,$app$main$ui$workspace$viewport$utils$text_transform$$,$app$common$geom$shapes$intersect$on_segment_QMARK_$$,$app$common$geom$shapes$intersect$orientation$$,
$app$common$files$helpers$hidden_parent_QMARK_$$,$app$main$data$helpers$split_text_shapes$$,$app$common$files$helpers$unframed_shape_QMARK_$$,$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$versions$apply_snapshot$$,$app$main$data$workspace$tokens$library_edit$start_token_set_edition$$,$app$main$data$workspace$colors$update_colorpicker_gradient$$,
$app$main$data$workspace$common$toggle_toolbar_visibility$$,$app$main$data$modal$update_props$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_paths$$,$app$main$data$workspace$set_clipboard_style$$,$app$main$data$workspace$set_annotations_expanded$$,$app$main$data$workspace$start_rename_page_item$$,$app$main$data$workspace$set_margins_selected$$,$app$main$data$workspace$set_gap_selected$$,$app$main$data$workspace$set_paddings_selected$$,$app$main$data$workspace$show_guide_context_menu$$,
$app$main$data$workspace$show_page_item_context_menu$$,$app$main$data$workspace$set_assets_group_open$$,$app$main$data$workspace$set_assets_section_open$$,$app$main$data$workspace$workspace_focus_lost$$,$app$main$data$workspace$path$selection$update_area_selection$$,$app$main$data$workspace$path$drawing$reset_last_handler$$,$app$main$data$workspace$colors$pick_color_select$$,$app$main$data$workspace$colors$pick_color$$,$app$main$data$workspace$selection$update_selrect$$,$app$main$data$workspace$update_layers_search_scope$$,
$app$main$data$workspace$colors$select_colorpicker_gradient_stop$$,$app$common$types$file$get_base_font_size$$,$app$main$data$workspace$texts$cursor_to_end$$,$app$main$data$workspace$texts$select_all$$,$app$main$data$helpers$update_file$cljs$0core$0IFn$0_invoke$0arity$03$$,$clojure$set$superset_QMARK_$$,$app$common$files$tokens$shapes_applied_all_QMARK_$$,$cljs$tools$reader$unquote_QMARK_$$,$cljs$tools$reader$unquote_splicing_QMARK_$$,$app$main$data$workspace$set_preview_blend_mode$$,$cljs$core$js_reserved_QMARK_$$,
$app$main$data$workspace$grid_layout$editor$remove_selection$$,$app$main$data$workspace$path$selection$path_handler_leave$$,$app$main$data$workspace$path$selection$path_pointer_leave$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_creation$$,$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$,$app$main$data$workspace$tokens$library_edit$assign_token_node_context_menu$$,$app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$,$app$main$data$workspace$unset_preview_blend_mode$$,
$app$main$data$workspace$stop_rename_page_item$$,$app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing$$,$app$main$data$workspace$grid_layout$editor$clear_selection$$,$app$main$data$workspace$path$selection$clear_area_selection$$,$app$main$data$workspace$path$drawing$close_path_drag_end$$,$app$main$data$workspace$colors$activate_colorpicker_image$$,$app$main$data$workspace$colors$finalize_colorpicker$$,
$app$main$data$workspace$colors$clear_color_components$$,$app$main$data$workspace$texts$clean_text_modifier$$,$app$main$data$workspace$texts$update_editor$$,$app$main$data$workspace$specialized_panel$clear_specialized_panel$$,$app$main$data$project$finalize_project$$,$app$main$data$persistence$discard_persistence_state$$,$app$main$data$workspace$set_annotations_id_for_create$$,$app$main$ui$measurements$get_edge_points$$,$app$util$text$content$to_dom$set_dataset$$,$app$main$ui$hooks$use_rxsub$$,$app$common$geom$shapes$intersect$intersects_line_ellipse_QMARK_$$,
$app$common$types$color$hsl__GT_rgb$$,$app$common$types$color$hex__GT_hsv$$,$app$common$types$color$sort_colors$$,$rumext$v2$use_debounce$$,$app$common$types$pages_list$get_last_page$$,$app$main$data$workspace$clear_assets_section_open$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$,$app$main$data$workspace$common$initialized_QMARK_$$,$app$main$ui$workspace$viewport$utils$format_viewbox$$,$app$main$data$workspace$viewport$update_viewport_size$$,$app$main$data$workspace$drawing$set_default_size$$,
$app$main$data$workspace$transforms$fix_init_point$$,$app$main$data$workspace$tokens$library_edit$start_token_set_creation$$,$app$common$types$file$find_remote_shape$$,$app$main$data$workspace$colors$stop_picker$$,$app$main$data$workspace$colors$start_picker$$,$app$main$data$workspace$show_track_context_menu$$,$app$main$data$workspace$versions$exit_preview_cleanup$$,$app$main$data$workspace$versions$update_versions_state$$,$app$main$data$workspace$drawing$change_orientation$$,$app$common$files$variant$get_primary_component$$,
$cljs$core$TaggedLiteral$$,$cljs$tools$reader$garg$$,$app$main$data$workspace$versions$fetch_versions$$,$app$main$data$workspace$versions$unlock_version$$,$app$main$data$workspace$versions$lock_version$$,$app$main$data$workspace$versions$delete_version$$,$app$main$data$workspace$versions$rename_version$$,$app$main$data$workspace$versions$init_versions_state$$,$app$main$data$workspace$rename_file$$,$app$main$data$tinycolor$hex_without_hash_prefix_QMARK_$$,$app$main$data$workspace$pages$finalize_page$$,
$app$main$data$workspace$comments$handle_comment_layer_click$$,$app$main$data$workspace$texts$gen_name$$,$app$common$types$shape$interactions$allowed_animation_QMARK_$$,$app$common$geom$shapes$intersect$is_point_inside_nonzero_QMARK_$$,$app$common$geom$shapes$intersect$intersects_lines_QMARK_$$,$app$render_wasm$serializers$guide_frame_range$$,$app$main$data$workspace$libraries$set_file_shared$$,$app$util$clipboard$to_clipboard_multi$$,$app$main$data$workspace$versions$pin_version$$,$app$main$data$workspace$texts$save_font$$,
$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$geom$point$resize$$,$app$main$data$workspace$interactions$move_overlay_pos$$,$app$main$data$workspace$path$streams$get_angle$$,$app$render_wasm$serializers$write_guides$$,$promesa$core$all$$,$malli$error$_get$$,$app$common$types$tokens_lib$split_set_str_path_prefix$$,$app$main$data$workspace$colors$split_color_components$$,$app$common$types$color$library_color__GT_color$$,$app$main$fonts$get_node_fonts$$,$app$common$types$text$content_has_text_QMARK_$$,
$app$common$types$shape$layout$cells_in_area$$,$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$shape$layout$cells_by_column$$,$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$shape$layout$cells_by_row$$,$app$common$types$shape$layout$remove_cell_areas_after$$,$app$common$types$shape$layout$remove_cell_areas$$,$app$main$data$workspace$colors$remove_gradient_stop$cljs$0core$0IFn$0_invoke$0arity$01$$,
$cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$tokens$errors$detail_errors$$,$app$main$data$workspace$tokens$errors$humanize_errors$$,$app$main$data$workspace$show_grid_cell_context_menu$$,$app$common$types$color$offset_spread$$,$app$common$types$shape$layout$swap_track_content$$,$app$common$data$natural_sort_key$$,$app$common$data$natural_compare$$,$app$common$data$invert_map$$,$app$common$types$tokens_lib$get_json_format$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$common$types$color$hsv__GT_rgb$$,$app$util$dom$bounding_rect__GT_rect$$,$app$common$geom$shapes$text$overlaps_position_data_QMARK_$$,$app$common$types$tokens_lib$legacy_json__GT_dtcg_json$$,$app$common$types$text$replace_text_in_content$$,$cljs$spec$alpha$abbrev$$,$app$render_wasm$api$find_guide_at$$,$app$main$data$workspace$viewport_wasm$maybe_view_interaction_start_BANG_$$,$app$main$data$workspace$viewport$activate_panning$$,$app$render_wasm$api$render_blurred_snapshot_BANG_$$,$app$render_wasm$api$render_from_cache_BANG_$$,
$app$render_wasm$api$render_ui_only$$,$app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$,$app$render_wasm$text_editor$text_editor_blur$$,$app$render_wasm$text_editor$text_editor_select_word_boundary$$,$app$render_wasm$text_editor$text_editor_select_all$$,$app$render_wasm$text_editor$text_editor_move_cursor$$,$app$render_wasm$text_editor$text_editor_insert_paragraph$$,$app$render_wasm$text_editor$text_editor_delete_forward$cljs$0core$0IFn$0_invoke$0arity$01$$,
$app$render_wasm$text_editor$text_editor_delete_backward$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$render_wasm$text_editor$text_editor_pointer_up$$,$app$render_wasm$text_editor$text_editor_pointer_move$$,$app$render_wasm$text_editor$text_editor_pointer_down$$,$app$render_wasm$text_editor$text_editor_toggle_overtype_mode$$,$app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$,$app$render_wasm$text_editor$text_editor_focus$$,$app$render_wasm$mem$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$,
$app$render_wasm$text_editor$text_editor_export_selection$$,$app$render_wasm$text_editor$text_editor_encode_text_pre$$,$app$render_wasm$text_editor$text_editor_insert_text$$,$app$main$data$workspace$transforms$get_handler_resize_origin$$,$app$main$data$workspace$transforms$get_handler_multiplier$$,$app$common$types$shape$interactions$calc_overlay_pos_initial$$,$app$common$types$shape$interactions$set_destination$$,$app$common$types$shape$interactions$set_action_type$$,$app$common$geom$shapes$distance_selrect$$,
$app$common$geom$shapes$intersect$intersects_lines_ellipse_QMARK_$$,$app$common$types$path$get_handler$$,$app$common$types$path$segment$curve_closest_point$$,$app$common$types$path$segment$path__GT_lines$$,$app$common$types$path$segment$closest_point$$,$app$util$dom$get_delta_position$$,$app$common$geom$shapes$has_point_rect_QMARK_$$,$app$main$data$helpers$get_selrect$$,$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$,$app$common$geom$point$normal_right$$,$app$main$ui$measurements$selection_size_badge_STAR_$$,
$app$main$data$persistence$discard_commit$$,$app$common$types$color$interpolate_color$$,$app$common$types$color$interpolate_gradient$$,$app$main$data$workspace$colors$update_colorpicker_add_stop$$,$app$common$types$color$uniform_spread_QMARK_$$,$app$common$types$color$hsv__GT_hex$$,$cljs$tools$reader$resolve_symbol$$,$cljs$tools$reader$register_gensym$$,$cljs$tools$reader$register_arg$$,$cljs$tools$reader$check_eof_error$$,$cljs$tools$reader$read_regex$$,$cljs$tools$reader$read_token$$,$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$,
$cljs$tools$reader$read_char_STAR_$$,$cljs$tools$reader$read_unmatched_delimiter$$,$cljs$tools$reader$read_keyword$$,$cljs$tools$reader$read_symbol$$,$app$main$data$exports$assets$show_workspace_export_frames_dialog$$,$app$main$data$workspace$colors$sort_colorpicker_stops$$,$app$common$text$fix_gradients$$,$app$common$text$build_style_index$$,$app$render_wasm$text_editor$merge_exported_texts_into_content$$,$app$common$types$variant$compare_properties$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$types$color$uniform_spread$$,
$app$main$data$workspace$colors$update_colorpicker_add_auto$$,$app$common$types$tokens_lib$update_tokens_group$$,$app$util$webapi$read_file_as_text$$,$app$util$strings$matches_search$$,$app$common$types$variant$find_boolean_pair$$,$app$common$types$file$get_shape_in_copy$$,$app$util$text_editor$get_content_changes$$,$app$common$geom$shapes$intersect$overlaps_text_QMARK_$$,$app$common$geom$shapes$intersect$overlaps_QMARK_$$,$app$common$types$shape$interactions$remove_interactions$$,$app$main$data$workspace$colors$get_color_from_colorpicker_state$$,
$app$main$data$workspace$colors$colorpicker_onchange_runner$$,$app$main$data$workspace$colors$initialize_colorpicker$$,$app$main$data$workspace$colors$materialize_color_components$$,$app$main$data$workspace$colors$activate_colorpicker_gradient$$,$app$util$text$content$to_dom$get_styles_from_attrs$$,$app$main$data$persistence$merge_commit$$,$app$common$path_names$sort_by_children$$,$app$common$path_names$compact_path$$,$app$common$data$reorder$$,$cljs$core$sorted_map$$,$app$common$path_names$join_path_with_dot$$,
$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$path_names$group_by_first_segment$$,$app$common$path_names$sort_and_group_segments$$,$app$common$path_names$build_tree_root$$,$app$common$path_names$butlast_path$$,$app$common$types$token$join_font_family$$,$app$main$data$workspace$texts$generate_typography_name$$,$app$common$types$path$get_handlers$$,$app$common$types$path$segment$is_curve_QMARK_$$,$cljs$core$dedupe$cljs$0core$0IFn$0_invoke$0arity$00$$,$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$,
$app$main$data$workspace$colors$update_colorpicker_stops$$,$app$main$data$fonts$update_recent_font$$,$app$common$path_names$inside_path_QMARK_$$,$app$main$data$workspace$texts$focus_editor$$,$app$main$data$workspace$versions$create_version$$,$app$main$refs$workspace_grid_edition_id$$,$app$main$refs$workspace_thumbnail_rendered_at$$,$app$main$refs$workspace_token_in_selected_set$$,$app$main$refs$grid_layout_child_QMARK_$$,$app$main$refs$flex_layout_child_QMARK_$$,$app$main$refs$all_layout_child_QMARK_$$,
$app$main$refs$is_layout_child_QMARK_$$,$app$main$refs$shape_parents$$,$app$main$refs$objects_by_id$$,$app$main$refs$object_by_id$$,$app$main$refs$token_sets_at_path_all_active$$,$app$main$refs$workspace_token_theme$$,$app$main$data$modal$allow_click_outside_BANG_$$,$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$common$types$shape$interactions$has_direction_QMARK_$$,$app$common$types$shape$interactions$has_easing_QMARK_$$,$app$common$types$shape$interactions$has_duration_QMARK_$$,
$app$common$types$shape$interactions$has_animation_QMARK_$$,$app$common$types$shape$interactions$has_overlay_opts$$,$app$common$types$shape$interactions$destination_QMARK_$$,$app$main$data$workspace$bool$bool__GT_group$$,$app$common$types$modifiers$change_orientation_modifiers$$,$app$main$data$workspace$transforms$rotation_modifiers$$,$app$common$types$modifiers$resize_parent$cljs$0core$0IFn$0_invoke$0arity$05$$,$app$common$types$modifiers$move_parent$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$util$dom$prevent_default_context_menu$$,
$app$common$types$tokens_lib$group_by_type$$,$app$main$ui$hooks$resize$use_resize_observer$$,$app$main$data$persistence$update_file_revn$$,$app$main$data$persistence$update_status$$,$app$main$data$persistence$persist_commit$$,$app$main$data$persistence$append_commit$$,$app$main$data$persistence$initialize_persistence$$,$cljs$tools$reader$impl$utils$ReaderConditional$$,$cljs$tools$reader$impl$utils$reader_conditional$$,$cljs$tools$reader$add_meta$$,$cljs$tools$reader$syntax_quote_coll$$,$cljs$tools$reader$syntax_quote_STAR_$$,
$app$util$theme$add_color_scheme_listener_BANG_$$,$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$,$app$common$logic$tokens$toggle_token_set_group$$,$app$common$files$tokens$shapes_ids_by_applied_attributes$$,$app$main$data$workspace$select_assets$$,$app$main$data$workspace$check_in_asset$$,$app$main$data$workspace$toggle_selected_assets$$,$app$main$data$workspace$grid_layout$editor$select_track_cells$$,$app$main$data$workspace$grid_layout$editor$hover_grid_cell$$,
$app$main$data$workspace$guides$set_hover_guide$$,$app$main$data$workspace$path$selection$deselect_all$$,$app$main$data$workspace$path$selection$path_handler_enter$$,$app$main$data$workspace$path$selection$path_pointer_enter$$,$app$main$data$workspace$libraries$cleanup_unlinked_libraries$$,$app$main$data$workspace$libraries$unlink_file_from_library$$,$app$render_wasm$rulers_state$display_state$$,$app$main$refs$parents_by_ids$$,$app$main$data$workspace$path$edition$move_selected_path_point$$,$app$main$data$workspace$path$edition$modify_handler$$,
$app$main$data$workspace$path$selection$select_node_area$$,$app$main$data$workspace$path$selection$handle_area_selection$$,$app$common$geom$shapes$transforms$update_shapes_geometry$$,$app$common$geom$shapes$update_shapes_geometry$$,$app$main$data$workspace$shape_layout$copy_grid_tracks$$,$app$main$data$workspace$grid_layout$editor$add_to_selection$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$common$types$shape$layout$valid_area_cells_QMARK_$$,$app$common$types$shape$layout$duplicate_cells$$,$app$common$types$shape_tree$get_root_shapes$$,
$app$common$types$shape_tree$get_root_frames_ids$$,$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$,$app$common$geom$shapes$fit_frame$fit_frame_modifiers$$,$app$common$files$helpers$component_touched_QMARK_$$,$app$util$text$content$to_dom$get_paragraph_styles$$,$app$main$data$workspace$layout$ensure_layout$$,$app$main$data$workspace$initialize_workspace_layout$$,$app$common$types$variant$same_variant_QMARK_$$,$app$main$data$workspace$select_single_asset$$,$app$main$data$workspace$grid_layout$editor$set_selection$$,
$app$main$data$workspace$path$selection$select_node$$,$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$shape_layout$hover_layout_track$$,$app$main$data$workspace$highlight$clear_search_match_highlight$$,$app$main$data$workspace$highlight$set_search_match_highlight$$,$app$main$data$workspace$path$streams$move_handler_stream$$,$app$main$data$workspace$path$streams$move_points_stream$$,$app$common$attrs$get_text_attrs_multi$$,$app$common$types$shape$layout$duplicate_column_at$$,
$app$common$types$shape$layout$duplicate_row_at$$,$app$main$data$workspace$interactions$get_target_frame$$,$app$main$data$workspace$interactions$move_edit_interaction$$,$app$main$data$workspace$colors$update_colorpicker$$,$app$main$data$workspace$clipboard$copy_selected_text$$,$app$main$data$workspace$specialized_panel$open_specialized_panel$$,$app$main$data$workspace$modifiers$set_rotation_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$modifiers$calculate_update_modifiers$$,
$app$main$data$workspace$modifiers$update_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$texts$commit_update_text_modifier$$,$app$common$types$shape$layout$reorder_grid_tracks$$,$app$common$types$shape$layout$reorder_grid_track$$,$cljs$tools$reader$read_dispatch$$,$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$,$cljs$tools$reader$read_delimited$$,$cljs$tools$reader$read_list$$,$cljs$tools$reader$read_vector$$,$cljs$tools$reader$read_map$$,$cljs$tools$reader$read_number$$,
$cljs$tools$reader$escape_char$$,$cljs$tools$reader$read_string_STAR_$$,$cljs$tools$reader$wrapping_reader$$,$cljs$tools$reader$read_meta$$,$cljs$tools$reader$read_set$$,$cljs$tools$reader$read_discard$$,$cljs$tools$reader$read_symbolic_value$$,$cljs$tools$reader$read_suppress$$,$cljs$tools$reader$read_cond_delimited$$,$cljs$tools$reader$read_cond$$,$cljs$tools$reader$read_fn$$,$cljs$tools$reader$read_arg$$,$cljs$tools$reader$read_unquote$$,$cljs$tools$reader$read_syntax_quote$$,$cljs$tools$reader$read_namespaced_map$$,
$cljs$tools$reader$macros$$,$cljs$tools$reader$dispatch_macros$$,$cljs$tools$reader$read_tagged$$,$cljs$tools$reader$read_STAR_$$,$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$,$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$main$data$workspace$libraries$go_to_component_file$$,$app$main$data$workspace$show_component_in_assets$$,$app$main$data$common$go_to_feedback$$,$app$main$rasterizer$render_node$$,$app$util$text_editor$setup_block_styles$$,$app$common$types$fills$prepend$$,
$app$main$data$workspace$media$create_shapes_svg$$,$app$main$data$workspace$bool$group__GT_bool$$,$app$main$data$workspace$comments$handle_interrupt$$,$app$main$data$workspace$comments$initialize_comments$$,$app$main$data$workspace$selection$deselect_all$$,$app$render_wasm$api$set_focus_mode$$,$app$main$data$workspace$viewport_wasm$maybe_view_interaction_end_BANG_$$,$app$main$data$workspace$viewport$finish_panning$$,$app$main$data$workspace$zoom$finish_zooming$$,$app$main$data$workspace$viewport$start_panning$$,
$app$main$data$workspace$viewport$initialize_viewport$$,$app$main$data$workspace$viewport$sync_wasm_workspace_viewport$$,$app$main$data$workspace$grid_layout$editor$locate_board$$,$app$main$data$workspace$zoom$start_zooming$$,$app$util$text_editor$insert_text$$,$app$util$text_editor$apply_block_styles_to_content$$,$app$util$worker$ask_buffered_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$snap$get_snap_points$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$,
$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect$$,$app$main$data$workspace$selection$handle_area_selection$$,$app$common$text$parse_draft_styles$$,$app$common$text$convert_from_draft$$,$app$util$text_editor$export_content$$,$app$util$text$content$to_dom$set_styles$$,$app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$util$text$content$to_dom$create_paragraph$$,
$app$util$text$content$to_dom$create_root$$,$app$util$text$content$styles$get_style_defaults$$,$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_types$$,$app$main$data$workspace$tokens$library_edit$toggle_token_type$$,$app$main$data$workspace$tokens$library_edit$close_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$tokens$library_edit$open_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$,
$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types$$,$app$main$data$workspace$shortcuts$on_display_guides_keydown$$,$app$main$data$workspace$colors$toggle_palette$$,$app$main$data$fonts$add_recent_font$$,$app$main$ui$hooks$use_persisted_state$$,$app$main$ui$hooks$use_shared_state$$,$app$main$data$workspace$clipboard$copy_selected_css_nested$$,$app$main$data$workspace$clipboard$copy_selected_css$$,$app$main$ui$dashboard$subscription$main_menu_power_up_STAR_$$,$app$main$data$workspace$tokens$library_edit$drop_error$$,
$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$,$app$main$data$style_dictionary$resolve_tokens_with_verbose_errors$$,$app$main$data$workspace$tokens$errors$error_ex_info$$,$app$util$color$get_color_name$$,$app$main$data$workspace$clipboard$copy_as_image$$,$app$main$data$workspace$clipboard$copy_selected_svg$$,$app$main$data$workspace$modifiers$set_wasm_modifiers$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout$$,
$app$main$data$workspace$transforms$resize_text_editor$$,$app$main$data$workspace$update_nudge$$,$app$main$data$workspace$finalize_workspace$$,$malli$util$assoc_in$cljs$0core$0IFn$0_invoke$0arity$04$$,$malli$error$_resolve_direct_error$$,$malli$error$humanize$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$common$schema$valid_QMARK_$$,$app$main$data$plugins$update_plugin_permissions_peek$$,$app$main$data$plugins$update_plugins_permissions_peek$$,$app$common$types$tokens_lib$export_dtcg_multi_file$$,$app$main$data$workspace$colors$add_recent_color$$,
$app$main$data$workspace$colors$apply_color_from_colorpicker$$,$app$main$data$workspace$path$drawing$start_path_from_point$$,$app$main$data$workspace$path$drawing$close_path_drag_start$$,$app$common$schema$validation_errors$$,$app$main$data$workspace$colors$update_colorpicker_color$$,$app$main$data$workspace$colors$activate_colorpicker_color$$,$app$common$files$tokens$make_node_token_name_schema$$,$app$common$schema$assoc_key$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$types$tokens_lib$walk_sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$common$logic$tokens$calculate_move_token_set_or_set_group$$,$app$common$types$tokens_lib$sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$common$types$tokens_lib$parse_single_set_dtcg_json$$,$app$common$logic$libraries$add_shape_to_main$$,$app$common$logic$tokens$generate_toggle_token_set_group$$,$app$common$logic$tokens$generate_delete_token_set_group$$,$app$common$logic$libraries$update_grid_main_attrs$$,$app$common$logic$libraries$update_flex_child_main_attrs$$,$app$common$logic$libraries$generate_sync_shape_inverse$$,
$app$common$logic$variant_properties$generate_reorder_variant_poperties$$,$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$$,$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$tokens$library_edit$bulk_create_tokens$$,$app$main$data$workspace$tokens$library_edit$duplicate_token$$,
$app$main$data$workspace$tokens$library_edit$rename_token_set_group$$,$app$main$data$workspace$update_component_annotation$$,$app$main$data$workspace$change_pixel_grid_color$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$relocate_page$$,$app$main$data$workspace$update_page_position_data$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$variants$reorder_variant_poperties$$,$app$main$data$workspace$pages$duplicate_page$$,$app$main$data$workspace$interactions$rename_flow$$,
$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$data$workspace$interactions$add_flow_selected_frame$$,$app$main$data$workspace$guides$update_guide_color$$,$app$main$data$workspace$guides$remove_frame_guides$$,$app$main$data$workspace$path$edition$drag_selected_points$$,$app$main$data$workspace$path$edition$split_segments$$,$app$main$data$workspace$libraries$update_component$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$libraries$update_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$main$data$workspace$libraries$reset_components$$,$app$main$data$workspace$libraries$detach_components$$,$app$main$data$workspace$libraries$duplicate_typography$$,$app$main$data$workspace$libraries$delete_media$$,$app$main$data$workspace$libraries$duplicate_color$$,$app$main$data$workspace$shape_layout$merge_cells$$,$app$main$data$workspace$colors$reorder_strokes$$,$app$main$data$workspace$colors$remove_all_strokes$$,$app$main$data$workspace$colors$remove_stroke$$,$app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$04$$,
$app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$texts$replace_layer_names_in_shapes$$,$app$main$data$workspace$texts$commit_position_data$$,$app$main$data$workspace$texts$commit_resize_text$$,$app$main$data$workspace$texts$finalize_editor_state$$,$app$main$data$workspace$texts$initialize_editor_state$$,$app$main$data$workspace$texts$remove_text_modifier$$,$app$main$data$workspace$colors$remove_fill$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$main$data$workspace$colors$detach_fill$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$colors$add_fill$cljs$0core$0IFn$0_invoke$0arity$03$$,$app$main$data$workspace$colors$apply_color_from_palette$$,$app$main$data$workspace$colors$apply_color_from_assets$$,$app$main$data$workspace$texts$replace_text_in_shapes$$,$app$main$data$workspace$transforms$selected_fit_content$$,$app$main$data$workspace$tokens$application$get_token_properties$$,$app$main$data$workspace$tokens$library_edit$drop_token_set$$,
$app$main$data$workspace$tokens$library_edit$drop_token_set_group$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_group$$,$app$main$data$workspace$tokens$library_edit$import_tokens_lib$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_group$$,$app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69261$$,$app$main$data$workspace$transforms$start_resize$$,$app$main$data$workspace$start_resize$$,$app$main$data$workspace$transforms$start_rotate$$,$app$main$data$workspace$transforms$change_orientation$$,
$app$main$data$workspace$bool$change_bool_type$$,$app$main$data$workspace$bool$bool_to_group$$,$app$main$data$workspace$bool$group_to_bool$$,$app$main$data$workspace$tokens$application$unapply_multiple_tokens$$,$app$main$data$workspace$tokens$application$apply_token_on_color_selected$$,$app$main$data$workspace$tokens$application$apply_token_from_input$$,$app$main$data$workspace$set_shape_proportion_lock$$,$app$main$data$workspace$shape_layout$reorder_layout_track$$,$app$main$data$workspace$interactions$finish_move_overlay_pos$$,
$app$main$data$workspace$interactions$start_move_overlay_pos$$,$app$main$data$workspace$interactions$remove_all_interactions_nav_to$$,$app$main$data$workspace$interactions$add_new_interaction$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$interactions$finish_edit_interaction$$,$app$main$data$workspace$interactions$start_edit_interaction$$,$app$main$data$workspace$path$edition$create_node_at_position$$,$app$main$data$workspace$path$edition$start_move_handler$$,$app$main$data$workspace$path$edition$start_move_path_point$$,
$app$main$data$workspace$path$shortcuts$get_tooltip$$,$app$main$data$workspace$colors$reorder_shadows$$,$app$main$data$workspace$colors$add_shadow$$,$app$main$data$workspace$colors$change_hide_fill_on_export$$,$app$main$data$workspace$colors$reorder_fills$$,$app$main$data$workspace$texts$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$,$app$main$data$workspace$texts$update_all_attrs$$,$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$common$logic$libraries$generate_restore_component$$,
$app$main$data$workspace$libraries$restore_component$$,$app$main$data$workspace$libraries$restore_components$$,$app$main$data$workspace$libraries$component_multi_swap$$,$app$common$logic$libraries$generate_duplicate_changes$$,$app$main$data$workspace$shape_layout$paste_grid_tracks$$,$app$main$data$workspace$shape_layout$duplicate_layout_track$$,$app$common$logic$libraries$generate_duplicate_component$$,$app$main$data$workspace$media$add_shapes_and_component$$,$app$main$data$workspace$media$process_svg_component$$,
$app$main$data$workspace$media$process_img_component$$,$app$main$data$workspace$versions$exit_preview$$,$app$main$data$workspace$versions$restore_version$$,$app$main$data$workspace$versions$enter_restore$$,$app$main$data$workspace$versions$enter_preview$$,$app$common$files$shapes_helpers$prepare_create_empty_artboard$$,$app$main$data$workspace$shape_layout$create_cell_board$$,$app$main$data$workspace$libraries$add_multiple_components$$,$app$main$data$workspace$variants$combine_selected_as_variants$$,
$app$main$data$workspace$media$upload_fill_image$$,$app$main$data$workspace$media$upload_media_components$$,$app$main$data$workspace$clipboard$paste_from_event$$,$app$main$data$workspace$shortcuts$get_tooltip$$,$cljs$spec$alpha$explain_printer$$,$cljs$spec$alpha$assert_STAR_$$,$app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$,$app$main$ui$workspace$colorpicker$color_inputs$color_inputs_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$token_empty_state_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$list_item_STAR_$$,
$app$main$ui$workspace$colorpicker$color_tokens$grid_item_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$group__GT_paths$$,$app$main$ui$workspace$colorpicker$color_tokens$set_section_STAR_$$,$app$main$ui$workspace$colorpicker$color_tokens$label_group_or_set$$,$app$main$ui$workspace$colorpicker$color_tokens$filter_combined_tokens$$,$app$main$ui$workspace$colorpicker$color_tokens$sort_combined_tokens$$,$app$main$ui$workspace$colorpicker$color_tokens$token_section_STAR_$$,$instaparse$auto_flatten_seq$conj_flat$$,
$instaparse$auto_flatten_seq$delve$$,$instaparse$auto_flatten_seq$flat_seq$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$auto_flatten_seq$AutoFlattenSeq$$,$instaparse$auto_flatten_seq$hash_cat$$,$instaparse$auto_flatten_seq$auto_flatten_seq$$,$instaparse$auto_flatten_seq$afs_QMARK_$$,$instaparse$auto_flatten_seq$true_count$$,$instaparse$auto_flatten_seq$FlattenOnDemandVector$$,$JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$,$instaparse$auto_flatten_seq$convert_afs_to_vec$$,
$instaparse$print$paren_for_tags$$,$instaparse$print$regexp_replace$$,$instaparse$print$regexp__GT_str$$,$instaparse$print$number__GT_hex_padded$$,$instaparse$print$char_range__GT_str$$,$instaparse$print$combinators__GT_str$$,$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$print$rule__GT_str$$,$instaparse$print$Parser__GT_str$$,$instaparse$failure$print_reason$$,$instaparse$failure$pprint_failure$$,$instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$instaparse$util$regexp_flags$$,$instaparse$reduction$singleton_QMARK_$$,$instaparse$reduction$apply_reduction$$,$instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$combinators_source$opt$$,$instaparse$combinators_source$plus$$,$instaparse$combinators_source$star$$,$instaparse$combinators_source$rep$$,$instaparse$combinators_source$string$$,$instaparse$combinators_source$string_ci$$,
$instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$combinators_source$regexp$$,$instaparse$combinators_source$nt$$,$instaparse$combinators_source$look$$,$instaparse$combinators_source$neg$$,$instaparse$combinators_source$hide$$,$instaparse$combinators_source$hide_tag$$,$instaparse$combinators_source$unhide_all_content$$,$instaparse$combinators_source$unhide_tags$$,$instaparse$combinators_source$unhide_all$$,$instaparse$combinators_source$auto_whitespace$$,
$goog$i18n$uChar$fromCharCode$$,$goog$i18n$uChar$getCodePointAround$$,$instaparse$gll$_parse$$,$instaparse$gll$_full_parse$$,$instaparse$gll$Failure$$,$instaparse$gll$Tramp$$,$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$,$instaparse$gll$make_success$$,$instaparse$gll$total_success_QMARK_$$,$instaparse$gll$Node$$,$instaparse$gll$push_stack$$,$instaparse$gll$push_message$$,$instaparse$gll$listener_exists_QMARK_$$,$instaparse$gll$full_listener_exists_QMARK_$$,$instaparse$gll$result_exists_QMARK_$$,
$instaparse$gll$node_get$$,$instaparse$gll$safe_with_meta$$,$instaparse$gll$push_result$$,$instaparse$gll$push_listener$$,$instaparse$gll$push_full_listener$$,$instaparse$gll$push_negative_listener$$,$instaparse$gll$fail$$,$instaparse$gll$step$$,$instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$,$instaparse$gll$NodeListener$$,$instaparse$gll$LookListener$$,$instaparse$gll$TopListener$$,$instaparse$gll$string_parse$$,$instaparse$gll$string_full_parse$$,$instaparse$gll$string_case_insensitive_parse$$,
$instaparse$gll$string_case_insensitive_full_parse$$,$instaparse$gll$char_range_parse$$,$instaparse$gll$char_range_full_parse$$,$instaparse$gll$re_match_at_front$$,$instaparse$gll$regexp_parse$$,$instaparse$gll$regexp_full_parse$$,$instaparse$gll$cat_parse$$,$instaparse$gll$cat_full_parse$$,$instaparse$gll$plus_parse$$,$instaparse$gll$plus_full_parse$$,$instaparse$gll$rep_parse$$,$instaparse$gll$rep_full_parse$$,$instaparse$gll$star_parse$$,$instaparse$gll$star_full_parse$$,$instaparse$gll$alt_parse$$,
$instaparse$gll$alt_full_parse$$,$instaparse$gll$ordered_alt_parse$$,$instaparse$gll$ordered_alt_full_parse$$,$instaparse$gll$opt_parse$$,$instaparse$gll$opt_full_parse$$,$instaparse$gll$non_terminal_parse$$,$instaparse$gll$non_terminal_full_parse$$,$instaparse$gll$lookahead_parse$$,$instaparse$gll$lookahead_full_parse$$,$instaparse$gll$negative_lookahead_parse$$,$instaparse$gll$epsilon_parse$$,$instaparse$gll$epsilon_full_parse$$,$instaparse$gll$start_parser$$,$instaparse$gll$parse$$,$instaparse$gll$build_node_with_meta$$,
$instaparse$cfg$string_PLUS_$$,$instaparse$cfg$make_cfg$$,$instaparse$cfg$escape$$,$instaparse$cfg$process_string$$,$instaparse$cfg$process_regexp$$,$instaparse$cfg$check_grammar$$,$instaparse$cfg$build_parser$cljs$0core$0IFn$0_invoke$0arity$03$$,$instaparse$cfg$build_parser_from_combinators$$,$instaparse$transform$merge_meta$$,$instaparse$abnf$project$$,$instaparse$abnf$merge_core$$,$instaparse$abnf$alt_preserving_hide_tag$$,$instaparse$abnf$build_parser$$,$instaparse$viz$span$$,$instaparse$repeat$empty_result_QMARK_$$,
$instaparse$repeat$parse_from_index$$,$instaparse$repeat$select_parse$$,$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$,$instaparse$repeat$repeat_parse$cljs$0core$0IFn$0_invoke$0arity$05$$,$instaparse$repeat$repeat_parse_with_header$$,$instaparse$repeat$try_repeating_parse_strategy_with_header$$,$instaparse$repeat$try_repeating_parse_strategy$$,$instaparse$core$unhide_parser$$,$instaparse$core$Parser$$,$instaparse$core$map__GT_Parser$$,$instaparse$core$parser$$,$instaparse$core$parser$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$instaparse$core$failure_QMARK_$$,$app$util$simple_math$expr_eval$$,$app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$token__GT_dropdown_option$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$generate_dropdown_options$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_token_groups_by_name$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$sort_groups_and_tokens$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$,
$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$,$app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,$app$main$ui$workspace$sidebar$options$rows$color_row$color_token_row_STAR_$$,$app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,$app$main$ui$workspace$colorpicker$gradients$format_rgb$$,
$app$main$ui$workspace$colorpicker$gradients$gradient__GT_string$$,$app$main$ui$workspace$colorpicker$gradients$stop_input_row_STAR_$$,$app$main$ui$workspace$colorpicker$gradients$gradients_STAR_$$,$app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,$app$main$ui$workspace$colorpicker$harmony$color__GT_point$$,$app$main$ui$workspace$colorpicker$harmony$harmony_selector_STAR_$$,$app$main$ui$workspace$colorpicker$hsva$hsva_selector_STAR_$$,$app$main$ui$workspace$sidebar$assets$common$apply_filters$$,
$app$main$ui$workspace$sidebar$assets$common$add_group$$,$app$main$ui$workspace$sidebar$assets$common$rename_group$$,$app$main$ui$workspace$sidebar$assets$common$ungroup$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$,$app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,$app$main$ui$workspace$sidebar$assets$common$section_icon$$,$app$main$ui$workspace$sidebar$assets$common$should_display_asset_count_QMARK_$$,
$app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$,$app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,$app$main$ui$workspace$sidebar$assets$common$create_assets_group$$,$app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$,$app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$,$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$,$app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$,$app$main$ui$workspace$sidebar$assets$common$create_counter_element$$,
$app$main$ui$workspace$sidebar$assets$common$set_drag_image$$,$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$,$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$,$app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$,$app$main$ui$workspace$sidebar$assets$common$component_item_thumbnail_STAR_$$,$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$$,$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,
$app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$,$app$main$ui$workspace$sidebar$assets$groups$sort_groups$$,$app$main$ui$workspace$sidebar$assets$groups$group_assets$$,$app$main$ui$workspace$sidebar$assets$groups$name_group_dialog$$,$app$main$ui$workspace$colorpicker$libraries$libraries_STAR_$$,$app$main$ui$workspace$colorpicker$ramp$value_saturation_selector_STAR_$$,$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$,$app$main$ui$workspace$colorpicker$ramp$ramp_selector_STAR_$$,
$app$main$ui$workspace$colorpicker$use_color_picker_css_variables_BANG_$$,$app$main$ui$workspace$colorpicker$colorpicker_STAR_$$,$app$main$ui$workspace$colorpicker$calculate_position$$,$app$main$ui$workspace$colorpicker$group_sets$$,$app$main$ui$workspace$colorpicker$combine_groups_with_resolved$$,$app$main$ui$workspace$colorpicker$filter_non_empty_sets$$,$app$main$ui$workspace$colorpicker$add_tokens_to_sets$$,$app$main$ui$workspace$colorpicker$filter_active_sets$$,$app$main$ui$workspace$colorpicker$colorpicker_modal$$,
$app$main$ui$workspace$context_menu$prevent_default$$,$app$main$ui$workspace$context_menu$menu_entry_STAR_$$,$app$main$ui$workspace$context_menu$menu_separator_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_edit_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_layer_position_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_flip_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_thumbnail_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_rename_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_group_STAR_$$,
$app$main$ui$workspace$context_menu$context_focus_mode_menu_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_path_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_layer_options_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_prototype_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_layout_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_component_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_guides_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_delete_STAR_$$,
$app$main$ui$workspace$context_menu$page_item_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$viewport_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$grid_track_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$grid_cells_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$guide_color_context_menu_STAR_$$,$app$main$ui$workspace$context_menu$context_menu_STAR_$$,$app$main$ui$workspace$coordinates$coordinates_STAR_$$,$app$main$ui$workspace$tokens$import_from_library$import_modal_library_STAR_$$,
$app$main$ui$workspace$libraries$get_library_summary$$,$app$main$ui$workspace$libraries$adapt_backend_summary$$,$app$main$ui$workspace$libraries$describe_library$$,$app$main$ui$workspace$libraries$library_description_STAR_$$,$app$main$ui$workspace$libraries$sample_library_entry_STAR_$$,$app$main$ui$workspace$libraries$libraries_tab_STAR_$$,$app$main$ui$workspace$libraries$extract_assets$$,$app$main$ui$workspace$libraries$updates_tab_STAR_$$,$app$main$ui$workspace$libraries$libraries_dialog$$,$app$main$ui$workspace$libraries$v2_info_dialog$$,
$app$main$ui$workspace$nudge$on_keydown$$,$app$main$ui$workspace$nudge$nudge_modal$$,$app$main$ui$workspace$color_palette$recent_colors_palette_STAR_$$,$app$main$ui$workspace$color_palette$make_library_colors_ref$$,$app$main$ui$workspace$color_palette$file_color_palette_STAR_$$,$app$main$ui$workspace$color_palette_ctx_menu$extract_colors$$,$app$main$ui$workspace$color_palette_ctx_menu$color_palette_ctx_menu_STAR_$$,$app$main$ui$workspace$text_palette$typography_item_STAR_$$,$app$main$ui$workspace$text_palette$palette_STAR_$$,
$app$main$ui$workspace$text_palette_ctx_menu$text_palette_ctx_menu_STAR_$$,$app$main$ui$workspace$palette$calculate_palette_style$$,$app$main$ui$workspace$palette$palette_STAR_$$,$app$main$ui$workspace$main_menu$shortcuts_STAR_$$,$app$main$ui$workspace$main_menu$file_menu_STAR_$$,$app$main$ui$workspace$main_menu$mcp_menu_STAR_$$,$app$main$ui$workspace$main_menu$menu_STAR_$$,$app$main$ui$workspace$left_header$left_header_STAR_$$,$app$main$data$workspace$history$initialize_history$$,$app$main$ui$workspace$right_header$right_header_STAR_$$,
$app$main$ui$workspace$sidebar$assets$colors$color_item_STAR_$$,$app$main$ui$workspace$sidebar$assets$colors$colors_section_STAR_$$,$app$main$ui$components$editable_label$editable_label_STAR_$$,$app$main$ui$workspace$sidebar$assets$components$get_component_root_and_container$$,$app$main$ui$workspace$sidebar$assets$components$components_item_STAR_$$,$app$main$ui$workspace$sidebar$assets$components$components_section_STAR_$$,$app$main$ui$components$editable_select$editable_select$$,$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$,
$app$main$ui$workspace$sidebar$options$menus$typography$get_next_font$$,$app$main$ui$workspace$sidebar$options$menus$typography$get_prev_font$$,$app$main$ui$workspace$sidebar$options$menus$typography$filter_fonts$$,$app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$,$app$main$ui$workspace$sidebar$options$menus$typography$font_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$typography$spacing_options_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$typography$text_transform_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$typography$text_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$typography$typography_entry_STAR_$$,$app$main$ui$workspace$sidebar$assets$typographies$typography_item$$,$app$main$ui$workspace$sidebar$assets$typographies$typographies_section_STAR_$$,$app$main$ui$workspace$sidebar$assets$file_library$create_file_ref$$,$app$main$ui$workspace$sidebar$assets$file_library$use_library_ref$$,
$app$main$ui$workspace$sidebar$assets$file_library$use_selected$$,$app$main$ui$workspace$sidebar$assets$file_library$file_library_title_STAR_$$,$app$main$ui$workspace$sidebar$assets$file_library$extend_selected$$,$app$main$ui$workspace$sidebar$assets$file_library$file_library_content_STAR_$$,$app$main$ui$workspace$sidebar$assets$file_library$file_library_STAR_$$,$app$main$ui$workspace$sidebar$assets$assets_local_library_STAR_$$,$app$main$ui$workspace$sidebar$debug$debug_panel_STAR_$$,$app$main$ui$workspace$sidebar$debug_shape_info$get_attrs$$,
$app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$,$app$main$ui$workspace$sidebar$debug_shape_info$cells_render$$,$app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_attr$$,$app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_info_STAR_$$,$app$main$ui$workspace$sidebar$history$get_object$$,$app$main$ui$workspace$sidebar$history$extract_operation$$,$app$main$ui$workspace$sidebar$history$parse_change$$,$app$main$ui$workspace$sidebar$history$resolve_shape_types$$,$app$main$ui$workspace$sidebar$history$entry__GT_message$$,
$app$main$ui$workspace$sidebar$history$entry__GT_icon$$,$app$main$ui$workspace$sidebar$history$is_shape_QMARK_$$,$app$main$ui$workspace$sidebar$history$short_id$$,$app$main$ui$workspace$sidebar$history$safe_name$$,$app$main$ui$workspace$sidebar$history$select_entry$$,$app$main$ui$workspace$sidebar$history$parse_entries$$,$app$main$ui$workspace$sidebar$history$history_entry_details_STAR_$$,$app$main$ui$workspace$sidebar$history$history_entry_STAR_$$,$app$main$ui$workspace$sidebar$history$history_toolbox_STAR_$$,
$app$main$ui$workspace$sidebar$layers$use_selected_shapes$$,$app$main$ui$workspace$sidebar$layers$frame_wrapper_STAR_$$,$app$main$ui$workspace$sidebar$layers$layers_tree_wrapper_STAR_$$,$app$main$ui$workspace$sidebar$layers$calc_reparented_objects$$,$app$main$ui$workspace$sidebar$layers$match_filters_QMARK_$$,$app$main$ui$workspace$sidebar$layers$radio_button_STAR_$$,$app$main$ui$workspace$sidebar$layers$use_search$$,$app$main$ui$workspace$sidebar$layers$on_scroll$$,$app$main$ui$workspace$sidebar$options$common$advanced_options_STAR_$$,
$app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$,$app$main$ui$ds$controls$utilities$token_field$token_field_STAR_$$,$app$main$ui$ds$controls$numeric_input$parse_value$$,$app$main$ui$ds$controls$numeric_input$get_option_by_name$$,$app$main$ui$ds$controls$numeric_input$get_token_op$$,$app$main$ui$ds$controls$numeric_input$clean_token_name$$,$app$main$ui$ds$controls$numeric_input$focusable_option_QMARK_$$,$app$main$ui$ds$controls$numeric_input$first_focusable_id$$,$app$main$ui$ds$controls$numeric_input$next_focus_index$$,
$app$main$ui$ds$controls$numeric_input$find_token_by_name$$,$app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$border_radius$all_equal_QMARK_$$,$app$main$ui$workspace$sidebar$options$menus$measures$type__GT_options$$,$app$main$ui$workspace$sidebar$options$menus$measures$select_measure_keys$$,$app$main$ui$workspace$sidebar$options$menus$measures$fixed_decimal_value$cljs$0core$0IFn$0_invoke$0arity$02$$,
$app$main$ui$workspace$sidebar$options$menus$measures$filter_size_presets$$,$app$main$ui$workspace$sidebar$options$drawing$frame$options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$align$align_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$bool$bool_options_STAR_$$,$app$main$ui$ds$product$input_with_meta$input_with_meta_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$variants_help_modal$variants_help_modal$$,$app$main$ui$workspace$sidebar$options$menus$component$component_annotation_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$component$get_variant_malformed_warning_message$$,$app$main$ui$workspace$sidebar$options$menus$component$get_variant_duplicated_warning_message$$,$app$main$ui$workspace$sidebar$options$menus$component$get_components_with_duplicated_variant_props_and_values$$,$app$main$ui$workspace$sidebar$options$menus$component$get_main_ids_with_duplicated_variant_props_and_values$$,$app$main$ui$workspace$sidebar$options$menus$component$get_variant_options$$,$app$main$ui$workspace$sidebar$options$menus$component$component_variant_property_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_variant_copy_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_swap_item_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_swap_group_title_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$01$$,$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$03$$,
$app$main$ui$workspace$sidebar$options$menus$component$same_component_file_QMARK_$$,$app$main$ui$workspace$sidebar$options$menus$component$same_component_QMARK_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_swap_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_pill_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$component$move_empty_items_to_end$$,$app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_property_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$grid_cell$set_self_alignment$$,$app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$event_type_name$$,$app$main$ui$workspace$sidebar$options$menus$interactions$action_summary$$,$app$main$ui$workspace$sidebar$options$menus$interactions$get_frames_options$$,$app$main$ui$workspace$sidebar$options$menus$interactions$get_shared_frames_options$$,
$app$main$ui$workspace$sidebar$options$menus$interactions$prototype_pill_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$flow_item_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$interaction_item_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$page_flows_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$shape_flows_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$interactions_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$interactions$interactions_menu_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_flex$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$wrap_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$align_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$align_content_row$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$justify_content_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$simple_padding_selection_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$multiple_padding_selection_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_focus$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_grid$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_edit_mode$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$manage_values$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_track_info$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_columns_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$open_flex_help$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$open_grid_help$$,$app$main$ui$workspace$sidebar$options$menus$blur$create_blur$$,$app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_content_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$blur$get_blurs$$,
$app$main$ui$workspace$sidebar$options$menus$layer$opacity__GT_string$$,$app$main$ui$workspace$sidebar$options$menus$layer$on_change$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margin$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_simple_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_multiple_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_section_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_horizontal$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_vertical$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$align_self_row$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_size_constraints_STAR_$$,$app$main$ui$workspace$sidebar$options$rows$shadow_row$shadow_row_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$shadow$remove_shadow_by_index$$,$app$main$ui$workspace$sidebar$options$rows$stroke_row$stroke_row_STAR_$$,
$app$main$ui$workspace$sidebar$options$shapes$bool$options_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$circle$options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$color_selection$prepare_colors$$,$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$,$app$common$geom$grid$calculate_generic_grid$$,$app$common$geom$grid$calculate_column_grid$$,$app$common$geom$grid$calculate_row_grid$$,$app$common$geom$grid$calculate_square_grid$$,$app$common$geom$grid$grid_gutter$$,
$app$common$geom$grid$grid_areas$$,$app$main$data$workspace$grid$add_frame_grid$$,$app$main$data$workspace$grid$remove_frame_grid$$,$app$main$data$workspace$grid$set_frame_grid$$,$app$main$data$workspace$grid$set_default_grid$$,$app$main$ui$workspace$sidebar$options$menus$frame_grid$get_size_options$$,$app$main$ui$workspace$sidebar$options$shapes$frame$options_STAR_$$,$app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,$app$main$ui$ds$controls$shared$dropdown_navigation$use_dropdown_navigation$$,
$app$main$ui$ds$controls$shared$searchable_options_dropdown$searchable_options_dropdown_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$token_typography_row$token_typography_row_STAR_$$,$app$util$text$ui$get_element$$,$app$util$text$ui$closest_text_editor_content$$,$app$main$ui$workspace$sidebar$options$menus$text$text_align_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$text$text_direction_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$text$vertical_align_STAR_$$,
$app$main$ui$workspace$sidebar$options$menus$text$grow_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$text$text_decoration_options_STAR_$$,$app$main$ui$workspace$sidebar$options$menus$text$get_option_by_name$$,$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$,$app$main$ui$workspace$sidebar$options$menus$text$find_token_by_id$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_eq$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_sel$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_eq$$,
$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_sel$$,$app$main$ui$workspace$sidebar$options$shapes$path$options_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$rect$options_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$svg_raw$parse_color$$,$app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_fill_values$$,$app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_stroke_values$$,$app$main$ui$workspace$sidebar$options$shapes$svg_raw$options_STAR_$$,$app$main$ui$workspace$sidebar$options$shapes$text$options_STAR_$$,
$app$main$ui$workspace$sidebar$options$single_shape_options_STAR_$$,$app$main$ui$workspace$sidebar$options$specialized_panel_STAR_$$,$app$main$ui$workspace$sidebar$options$design_menu_STAR_$$,$app$main$ui$workspace$sidebar$options$inspect_tab_STAR_$$,$app$main$ui$workspace$sidebar$options$on_option_tab_change$$,$app$main$ui$workspace$sidebar$options$options_content_STAR_$$,$app$main$ui$workspace$sidebar$options$make_page_objects_ref$$,$app$main$ui$workspace$sidebar$shortcuts$converted_chars_STAR_$$,
$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts_keys_STAR_$$,$app$main$ui$workspace$sidebar$shortcuts$shortcut_row_STAR_$$,$app$main$ui$workspace$sidebar$shortcuts$section_title_STAR_$$,$app$main$ui$workspace$sidebar$shortcuts$shortcut_subsection_STAR_$$,$app$main$ui$workspace$sidebar$shortcuts$shortcut_section_STAR_$$,
$app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR_$$,$app$main$ui$workspace$sidebar$sitemap$make_page_ref$$,$app$main$ui$workspace$sidebar$sitemap$page_item$$,$app$main$ui$workspace$sidebar$sitemap$page_item_wrapper$$,$app$main$ui$workspace$sidebar$sitemap$pages_list_STAR_$$,$app$main$ui$workspace$sidebar$sitemap$sitemap_STAR_$$,$app$main$ui$ds$product$avatar$avatar_STAR_$$,$app$main$ui$ds$product$milestone$milestone_STAR_$$,$app$main$ui$ds$utilities$date$date_STAR_$$,$app$main$ui$ds$product$milestone_group$milestone_group_STAR_$$,
$app$main$ui$workspace$sidebar$versions$get_versions_stored_days$$,$app$main$ui$workspace$sidebar$versions$get_versions_warning_subtext$$,$app$main$ui$workspace$sidebar$versions$group_snapshots$$,$app$main$ui$workspace$sidebar$versions$on_name_input_focus$$,$app$main$ui$workspace$sidebar$versions$on_create_version$$,$app$main$ui$workspace$sidebar$versions$on_edit_version$$,$app$main$ui$workspace$sidebar$versions$on_cancel_version_edition$$,$app$main$ui$workspace$sidebar$versions$on_rename_version$$,
$app$main$ui$workspace$sidebar$versions$on_delete_version$$,$app$main$ui$workspace$sidebar$versions$on_pin_version$$,$app$main$ui$workspace$sidebar$versions$on_lock_version$$,$app$main$ui$workspace$sidebar$versions$on_unlock_version$$,$app$main$ui$workspace$sidebar$versions$version_entry_STAR_$$,$app$main$ui$workspace$sidebar$versions$snapshot_entry_STAR_$$,$app$main$ui$workspace$sidebar$versions$versions_toolbox_STAR_$$,$app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens$$,$app$main$data$workspace$tokens$remapping$scan_token_value_references$$,
$app$main$data$workspace$tokens$remapping$scan_workspace_token_references$$,$app$main$data$workspace$tokens$remapping$build_remap_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$tokens$remapping$remap_tokens$$,$app$main$data$workspace$tokens$remapping$remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$tokens$remapping$bulk_remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$data$workspace$tokens$remapping$count_token_references$$,
$app$main$ui$workspace$tokens$management$context_menu$key_in_map_QMARK_$$,$app$main$ui$workspace$tokens$management$context_menu$clean_separators$$,$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$,$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$,$app$main$ui$workspace$tokens$management$context_menu$layout_spacing_items$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_padding$$,
$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_margin$$,$app$main$ui$workspace$tokens$management$context_menu$spacing_attribute_actions$$,$app$main$ui$workspace$tokens$management$context_menu$sizing_attribute_actions$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_radius_for_corners$$,$app$main$ui$workspace$tokens$management$context_menu$default_actions$$,$app$main$ui$workspace$tokens$management$context_menu$allowed_shape_attributes$$,$app$main$ui$workspace$tokens$management$context_menu$menu_actions$$,
$app$main$ui$workspace$tokens$management$context_menu$selection_actions$$,$app$main$ui$workspace$tokens$management$context_menu$prevent_default$$,$app$main$ui$workspace$tokens$management$context_menu$menu_entry$$,$app$main$ui$workspace$tokens$management$context_menu$token_context_menu_tree$$,$app$main$ui$workspace$tokens$management$context_menu$token_context_menu$$,$app$main$ui$ds$layers$layer_button$layer_button_STAR_$$,$app$main$data$workspace$tokens$color$resolved_token_bullet_color$$,$app$main$ui$ds$foundations$utilities$token$token_status$token_status_icon_STAR_$$,
$app$main$ui$workspace$tokens$management$token_pill$partially_applied_attr$$,$app$main$ui$workspace$tokens$management$token_pill$translate_and_format$$,$app$main$ui$workspace$tokens$management$token_pill$contains_reference_value_QMARK_$$,$app$main$ui$workspace$tokens$management$token_pill$applied_all_attributes_QMARK_$$,$app$main$ui$workspace$tokens$management$token_pill$attributes_match_selection_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$ui$workspace$tokens$management$token_tree$token_tree_STAR_$$,
$app$main$ui$workspace$tokens$management$group$token_section_icon$$,$app$main$ui$workspace$tokens$management$group$token_group_STAR_$$,$app$main$ui$workspace$tokens$management$node_context_menu$prevent_default$$,$app$main$ui$workspace$tokens$management$node_context_menu$token_node_context_menu_STAR_$$,$app$main$ui$workspace$tokens$management$selected_set_info_STAR_$$,$app$main$ui$workspace$tokens$management$tokens_section_STAR_$$,$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set$$,$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set_group$$,
$app$main$ui$workspace$tokens$sets$helpers$on_create_token_set$$,$app$main$ui$workspace$tokens$sets$lists$on_start_creation$$,$app$main$ui$workspace$tokens$sets$lists$editing_label_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$checkbox_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$inline_add_button_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$add_button_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$sets_tree_set_group_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$sets_tree_set_STAR_$$,
$app$main$ui$workspace$tokens$sets$lists$token_sets_tree_STAR_$$,$app$main$ui$workspace$tokens$sets$lists$controlled_sets_list_STAR_$$,$app$main$ui$workspace$tokens$sets$on_select_token_set_click$$,$app$main$ui$workspace$tokens$sets$on_toggle_token_set_click$$,$app$main$ui$workspace$tokens$sets$on_toggle_token_set_group_click$$,$app$main$ui$workspace$tokens$sets$sets_list_STAR_$$,$app$main$ui$workspace$tokens$sets$context_menu$prevent_default$$,$app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,
$app$main$ui$workspace$tokens$sets$context_menu$menu_STAR_$$,$app$main$ui$workspace$tokens$sets$context_menu$token_set_context_menu_STAR_$$,$app$main$ui$workspace$tokens$themes$theme_selector$themes_list_STAR_$$,$app$main$ui$workspace$tokens$themes$theme_selector$open_tokens_theme_modal$$,$app$main$ui$workspace$tokens$themes$theme_selector$theme_options_STAR_$$,$app$main$ui$workspace$tokens$themes$theme_selector$theme_selector_STAR_$$,$app$main$ui$workspace$tokens$themes$themes_header_STAR_$$,$app$main$ui$workspace$tokens$sidebar$token_sets_list_STAR_$$,
$app$main$ui$workspace$tokens$sidebar$token_management_section_STAR_$$,$app$main$ui$workspace$tokens$sidebar$import_export_button_STAR_$$,$app$main$ui$workspace$tokens$sidebar$tokens_sidebar_tab_STAR_$$,$app$main$ui$workspace$sidebar$collapse_button_STAR_$$,$app$main$ui$workspace$sidebar$on_close_document_history$$,$app$main$ui$workspace$sidebar$right_sidebar_STAR_$$,$app$main$ui$workspace$sidebar$sidebar_STAR_$$,$app$util$zip$writer$$,$app$util$zip$add$$,$app$util$zip$read_as_text$$,$app$util$zip$close$$,
$app$main$ui$workspace$tokens$export$0$modal$export_tab_STAR_$$,$app$main$ui$workspace$tokens$export$0$modal$single_file_tab_STAR_$$,$app$main$ui$workspace$tokens$export$0$modal$download_tokens_zip_BANG_$$,$app$main$ui$workspace$tokens$export$0$modal$multi_file_tab_STAR_$$,$app$main$ui$workspace$tokens$export$0$modal$export_modal_body_STAR_$$,$app$main$ui$workspace$tokens$export$0$export_modal_STAR_$$,$app$main$data$workspace$tokens$import_export$group_by_value$$,$app$main$data$workspace$tokens$import_export$show_unknown_types_warning$$,
$app$main$data$workspace$tokens$import_export$decode_json$$,$app$main$data$workspace$tokens$import_export$parse_decoded_json$$,$app$main$data$workspace$tokens$import_export$validate_library$$,$app$main$data$workspace$tokens$import_export$import_file_stream$$,$app$main$data$workspace$tokens$import_export$import_directory_stream$$,$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$,$app$main$ui$workspace$tokens$import$0$modal$import_type_dropdown_STAR_$$,$app$main$ui$workspace$tokens$import$0$modal$has_token_files_QMARK_$$,
$app$main$ui$workspace$tokens$import$0$modal$validate_token_files$$,$app$main$ui$workspace$tokens$import$0$modal$import_modal_body_STAR_$$,$app$main$ui$workspace$tokens$import$0$import_modal_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$resolve_value$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$hex__GT_color_obj$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$ramp_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$color_input_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$controls$color_input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$indexed_color_input_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$first_focusable_id$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$next_focus_id$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$use_navigation$$,
$app$main$ui$workspace$tokens$management$forms$controls$floating_dropdown$use_floating_dropdown$$,$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$token_at_cursor$$,$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$remove_self_token$$,$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$select_option_by_id$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox$resolve_value$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox$value_combobox_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$resolve_value$$,$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$fonts_combobox_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$on_composite_combobox_token_change$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$composite_fonts_combobox_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value_tokenscript$$,
$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$,$app$main$ui$workspace$tokens$management$forms$controls$input$input_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$input$on_composite_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$,$app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,$app$main$ui$workspace$tokens$management$forms$controls$input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$,$app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$controls$select$select_indexed_STAR_$$,$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$,$app$main$ui$workspace$tokens$management$forms$validators$validate_resolve_token$$,$app$main$ui$workspace$tokens$management$forms$validators$validate_token_with$$,$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$,$app$main$ui$workspace$tokens$management$forms$validators$check_coll_self_reference$$,$app$main$ui$workspace$tokens$management$forms$generic_form$scroll_token_type_section_on_create$$,
$app$main$ui$workspace$tokens$management$forms$generic_form$get_value_for_validator$$,$app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$color$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$font_family$check_font_family_token_self_reference$$,$app$main$ui$workspace$tokens$management$forms$font_family$validate_font_family_token$$,$app$main$ui$workspace$tokens$management$forms$font_family$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$check_shadow_token_self_reference$$,
$app$main$ui$workspace$tokens$management$forms$shadow$check_empty_shadow_token$$,$app$main$ui$workspace$tokens$management$forms$shadow$validate_shadow_token$$,$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$,$app$main$ui$workspace$tokens$management$forms$shadow$shadow_formset_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$composite_form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$reference_form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$shadow$tabs_wrapper_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$shadow$make_schema$$,$app$main$ui$workspace$tokens$management$forms$shadow$make_default_value$$,$app$main$ui$workspace$tokens$management$forms$shadow$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$typography$check_typography_token_self_reference$$,$app$main$ui$workspace$tokens$management$forms$typography$check_empty_typography_token$$,$app$main$ui$workspace$tokens$management$forms$typography$validate_typography_token$$,$app$main$ui$workspace$tokens$management$forms$typography$composite_form_STAR_$$,
$app$main$ui$workspace$tokens$management$forms$typography$reference_form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$typography$tabs_wrapper_STAR_$$,$app$main$ui$workspace$tokens$management$forms$typography$make_schema$$,$app$main$ui$workspace$tokens$management$forms$typography$form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$form_container$form_container_STAR_$$,$app$main$ui$workspace$tokens$management$forms$modals$calculate_position$$,$app$main$ui$workspace$tokens$management$forms$modals$use_viewport_position_style$$,
$app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$boolean_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$border_radius_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$box_shadow_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$color_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$dimensions_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$font_familiy_modal$$,
$app$main$ui$workspace$tokens$management$forms$modals$font_size_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$font_weight_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$letter_spacing_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$number_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$opacity_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$other_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$rotation_modal$$,
$app$main$ui$workspace$tokens$management$forms$modals$sizing_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$spacing_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$string_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$stroke_width_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$text_case_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$text_decoration_modal$$,$app$main$ui$workspace$tokens$management$forms$modals$typography_modal$$,
$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_form_STAR_$$,$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_modal$$,$app$main$ui$workspace$tokens$remapping_modal$token_remapping_modal$$,$app$main$data$workspace$tokens$typography$set_base_font_size$$,$app$main$ui$workspace$tokens$settings$menu$token_settings_STAR_$$,$app$main$ui$workspace$tokens$settings$token_settings_modal_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$empty_themes$$,
$app$main$ui$workspace$tokens$themes$create_modal$themes_overview$$,$app$main$ui$workspace$tokens$themes$create_modal$theme_inputs_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$theme_modal_buttons_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$make_lib_with_theme$$,$app$main$ui$workspace$tokens$themes$create_modal$edit_create_theme_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$has_prev_view$$,$app$main$ui$workspace$tokens$themes$create_modal$edit_theme$$,$app$main$ui$workspace$tokens$themes$create_modal$create_theme$$,
$app$main$ui$workspace$tokens$themes$create_modal$themes_modal_body_STAR_$$,$app$main$ui$workspace$tokens$themes$create_modal$token_themes_modal$$,$app$main$ui$flex_controls$common$flex_display_pill$$,$app$main$ui$workspace$viewport$viewport_ref$init_observer$$,$app$main$ui$workspace$viewport$viewport_ref$on_change_bounds$$,$app$main$ui$workspace$viewport$viewport_ref$create_viewport_ref$$,$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$,$app$main$ui$flex_controls$gap$gap_display_STAR_$$,
$app$main$ui$flex_controls$gap$gap_rects_STAR_$$,$app$main$ui$flex_controls$gap$gap_control_STAR_$$,$app$main$ui$flex_controls$margin$margin_display_STAR_$$,$app$main$ui$flex_controls$margin$margin_rects_STAR_$$,$app$main$ui$flex_controls$margin$margin_control_STAR_$$,$app$main$ui$flex_controls$padding$padding_display_STAR_$$,$app$main$ui$flex_controls$padding$padding_rects_STAR_$$,$app$main$ui$flex_controls$padding$padding_control_STAR_$$,$app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$,
$app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$,$app$main$ui$workspace$shapes$path$editor$path_preview_STAR_$$,$app$main$ui$workspace$shapes$path$editor$path_snap_STAR_$$,$app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$,$app$main$ui$workspace$shapes$text$editor$block_component$$,$app$main$ui$workspace$shapes$text$editor$styles_fn$$,$app$main$ui$workspace$shapes$text$editor$get_blocks_to_setup$$,$app$main$ui$workspace$shapes$text$editor$get_blocks_to_add_styles$$,$app$main$ui$workspace$shapes$text$editor$shape__GT_justify$$,
$app$main$ui$workspace$shapes$text$editor$text_editor_svg$$,$app$main$ui$workspace$shapes$text$text_edition_outline$text_edition_outline_STAR_$$,$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$,$app$main$ui$workspace$shapes$text$v2_editor$coalesce_per_tick$$,$app$main$ui$workspace$shapes$text$v2_editor$load_fonts_BANG_$$,$app$main$ui$workspace$shapes$text$v2_editor$initialize_event_handlers$$,$app$main$ui$workspace$shapes$text$v2_editor$vertical_align_editor_classes$$,$app$main$ui$workspace$shapes$text$v2_editor$get_color_from_content$$,
$app$main$ui$workspace$shapes$text$v2_editor$get_default_text_color$$,$app$main$ui$workspace$shapes$text$v2_editor$shape__GT_justify$$,$$jscomp$scope$m743970774$0$getRangeRects$$,$app$util$text_position_data$parse_text_nodes$$,$app$util$text_svg_position$parse_text_nodes$$,$app$util$text_svg_position$resolve_font$$,$app$util$text_svg_position$process_text_node$$,$app$util$text_svg_position$calc_text_node_positions$$,$app$util$text_svg_position$calc_position_data$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$fix_position$$,
$app$main$ui$workspace$shapes$text$viewport_texts_html$update_shape_with_content$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_shape$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_modifier$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$text_properties_equal_QMARK_$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$text_changes_renderer$$,$app$main$ui$workspace$shapes$text$viewport_texts_html$text_modifiers_renderer$$,$app$main$ui$workspace$top_toolbar$mcp_indicator_STAR_$$,
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$,$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$app$main$ui$workspace$shapes$text$v3_editor$text_editor_STAR_$$,$app$main$ui$workspace$viewport$actions$on_pointer_down$$,$app$main$ui$workspace$viewport$actions$on_move_selected$$,$app$main$ui$workspace$viewport$actions$on_frame_select$$,$app$main$ui$workspace$viewport$actions$on_frame_enter$$,
$app$main$ui$workspace$viewport$actions$on_frame_leave$$,$app$main$ui$workspace$viewport$actions$on_click$$,$app$main$ui$workspace$viewport$actions$on_double_click$$,$app$main$ui$workspace$viewport$actions$on_context_menu$$,$app$main$ui$workspace$viewport$actions$on_menu_selected$$,$app$main$ui$workspace$viewport$actions$on_pointer_up$$,$app$main$ui$workspace$viewport$actions$on_pointer_enter$$,$app$main$ui$workspace$viewport$actions$on_pointer_leave$$,$app$main$ui$workspace$viewport$actions$on_key_down$$,
$app$main$ui$workspace$viewport$actions$on_key_up$$,$app$main$ui$workspace$viewport$actions$on_pointer_move$$,$app$main$ui$workspace$viewport$actions$schedule_zoom_BANG_$$,$app$main$ui$workspace$viewport$actions$schedule_scroll_BANG_$$,$app$main$ui$workspace$viewport$actions$on_mouse_wheel$$,$app$main$ui$workspace$viewport$actions$on_drag_enter$$,$app$main$ui$workspace$viewport$actions$on_drag_over$$,$app$main$ui$workspace$viewport$actions$on_drop$$,$app$main$ui$workspace$viewport$actions$on_paste$$,
$app$main$ui$workspace$viewport$comments$use_frame_position_modifier$$,$app$main$ui$workspace$viewport$comments$comment_floating_bubble_wrapper_STAR_$$,$app$main$ui$workspace$viewport$comments$comment_floating_group_wrapper_STAR_$$,$app$main$ui$workspace$viewport$comments$comment_floating_thread_wrapper_STAR_$$,$app$main$ui$workspace$viewport$debug$debug_content_bounds_STAR_$$,$app$main$ui$workspace$viewport$debug$debug_layout_lines_STAR_$$,$app$main$ui$workspace$viewport$debug$debug_parent_bounds_STAR_$$,
$app$main$ui$workspace$viewport$debug$debug_grid_layout_STAR_$$,$app$main$ui$workspace$viewport$debug$debug_text_wasm_position_data_STAR_$$,$app$main$ui$workspace$viewport$drawarea$make_edit_path_ref$$,$app$main$ui$workspace$viewport$drawarea$generic_draw_area_STAR_$$,$app$main$ui$workspace$viewport$drawarea$path_draw_area_STAR_$$,$app$main$ui$workspace$viewport$drawarea$draw_area_STAR_$$,$app$main$ui$workspace$viewport$rulers$rulers_clip_path_STAR_$$,$app$main$ui$workspace$viewport$rulers$get_ruler_params$$,
$app$main$ui$workspace$viewport$rulers$rulers_inside_path$$,$app$main$ui$workspace$viewport$rulers$rulers_text_STAR_$$,$app$main$ui$workspace$viewport$rulers$viewport_frame_STAR_$$,$app$main$ui$workspace$viewport$rulers$selection_area_STAR_$$,$app$main$ui$workspace$viewport$rulers$rulers_STAR_$$,$app$main$ui$workspace$viewport$frame_grid$square_grid_STAR_$$,$app$main$ui$workspace$viewport$frame_grid$layout_grid_STAR_$$,$app$main$ui$workspace$viewport$frame_grid$frame_clip_area$$,$app$main$ui$workspace$viewport$frame_grid$has_grid_QMARK_$$,
$app$main$ui$workspace$viewport$gradients$shadow_STAR_$$,$app$main$ui$workspace$viewport$gradients$gradient_color_handler_STAR_$$,$app$main$ui$workspace$viewport$gradients$gradient_handler_transformed_STAR_$$,$app$main$ui$workspace$viewport$gradients$gradient_handlers_impl_STAR_$$,$app$main$ui$workspace$viewport$grid_layout_editor$apply_to_point$$,$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$,$app$main$ui$workspace$viewport$grid_layout_editor$grid_edition_actions$$,$app$main$ui$workspace$viewport$grid_layout_editor$grid_editor_frame$$,
$app$main$ui$workspace$viewport$grid_layout_editor$plus_btn$$,$app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$,$app$main$ui$workspace$viewport$grid_layout_editor$resize_cell_handler$$,$app$main$ui$workspace$viewport$grid_layout_editor$grid_cell_area_label$$,$app$main$ui$workspace$viewport$grid_layout_editor$use_resize_track$$,$app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$,$app$main$ui$workspace$viewport$grid_layout_editor$marker_shape_d$$,$app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$,
$app$main$ui$workspace$viewport$guides$compute_guide_drag_position$$,$app$main$ui$workspace$viewport$guides$guide_visible_in_focus_QMARK_$$,$app$main$ui$workspace$viewport$guides$wasm_visible_guides$$,$app$main$ui$workspace$viewport$guides$use_guide$$,$app$main$ui$workspace$viewport$guides$guide_area_axis$$,$app$main$ui$workspace$viewport$guides$is_guide_inside_frame_QMARK_$$,$app$main$ui$workspace$viewport$guides$new_guide_area_STAR_$$,$app$main$ui$workspace$viewport$guides$guide_by_serialized_index$$,
$app$main$ui$workspace$viewport$guides$guide_overlay_STAR_$$,$app$main$ui$workspace$viewport$guides$use_wasm_guide_interaction$$,$app$main$ui$workspace$viewport$guides$wasm_guide_overlay_layer_STAR_$$,$app$main$data$workspace$grid_layout$shortcuts$esc_pressed$$,$app$main$ui$workspace$viewport$hooks$setup_dom_events$$,$app$main$ui$workspace$viewport$hooks$setup_viewport_size$$,$app$main$ui$workspace$viewport$hooks$setup_cursor$$,$app$main$ui$workspace$viewport$hooks$setup_keyboard$$,$app$main$ui$workspace$viewport$hooks$setup_hover_shapes$$,
$app$main$ui$workspace$viewport$hooks$setup_viewport_modifiers$$,$app$main$ui$workspace$viewport$hooks$inside_vbox$$,$app$main$ui$workspace$viewport$hooks$setup_active_frames$$,$app$main$ui$workspace$viewport$hooks$setup_shortcuts$$,$app$main$ui$workspace$viewport$outline$outline_STAR_$$,$app$main$ui$workspace$viewport$outline$shape_outlines_STAR_$$,$app$main$ui$workspace$viewport$interactions$on_pointer_down$$,$app$main$ui$workspace$viewport$interactions$connect_to_shape$$,$app$main$ui$workspace$viewport$interactions$connect_to_point$$,
$app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,$app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$,$app$main$ui$workspace$viewport$interactions$interaction_handle_STAR_$$,$app$main$ui$workspace$viewport$interactions$overlay_marker_STAR_$$,$app$main$ui$workspace$viewport$interactions$interactions_STAR_$$,$app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move$$,$app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_STAR_$$,$app$main$ui$workspace$viewport$pixel_overlay$viewport__GT_canvas_coords$$,
$app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move_wasm$$,$app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_wasm_STAR_$$,$app$main$ui$workspace$viewport$presence$active_cursors$$,$app$main$ui$workspace$viewport$selection$selection_rect$$,$app$main$ui$workspace$viewport$selection$calculate_handlers$$,$app$main$ui$workspace$viewport$selection$rotation_handler$$,$app$main$ui$workspace$viewport$selection$resize_point_handler$$,$app$main$ui$workspace$viewport$selection$resize_side_handler$$,
$app$main$ui$workspace$viewport$selection$controls_selection_STAR_$$,$app$main$ui$workspace$viewport$selection$controls_handlers_STAR_$$,$app$main$ui$workspace$viewport$selection$text_edition_selection$$,$app$main$ui$workspace$viewport$selection$multiple_handlers_STAR_$$,$app$main$ui$workspace$viewport$selection$multiple_selection_STAR_$$,$app$main$ui$workspace$viewport$selection$single_handlers_STAR_$$,$app$main$ui$workspace$viewport$selection$single_selection_STAR_$$,$app$main$ui$workspace$viewport$selection$area_STAR_$$,
$app$main$ui$workspace$viewport$selection$handlers_STAR_$$,$app$main$ui$workspace$viewport$snap_distances$half_point$$,$app$main$ui$workspace$viewport$snap_distances$shape_distance_segment_STAR_$$,$app$main$ui$workspace$viewport$snap_distances$calculate_segments$$,$app$main$ui$workspace$viewport$snap_distances$query_worker$$,$app$main$ui$workspace$viewport$snap_distances$shape_distance_STAR_$$,$app$main$ui$workspace$viewport$snap_distances$snap_distances_STAR_$$,$app$main$ui$workspace$viewport$snap_points$snap_point_STAR_$$,
$app$main$ui$workspace$viewport$snap_points$snap_line_STAR_$$,$app$main$ui$workspace$viewport$snap_points$get_snap$$,$app$main$ui$workspace$viewport$snap_points$add_point_to_snaps$$,$app$main$ui$workspace$viewport$snap_points$process_snap_lines$$,$app$main$ui$workspace$viewport$snap_points$snap_feedback_STAR_$$,$app$main$ui$workspace$viewport$path_actions$check_enabled$$,$app$main$ui$workspace$viewport$path_actions$path_actions_STAR_$$,$app$main$ui$workspace$viewport$top_bar$view_only_bar_STAR_$$,
$app$main$ui$workspace$viewport$top_bar$path_edition_bar_STAR_$$,$app$main$ui$workspace$viewport$top_bar$grid_edition_bar_STAR_$$,$app$main$ui$workspace$viewport$widgets$pixel_grid_STAR_$$,$app$main$ui$workspace$viewport$widgets$cursor_tooltip_STAR_$$,$app$main$ui$workspace$viewport$widgets$frame_flow_STAR_$$,$app$main$ui$workspace$viewport$widgets$frame_flows_STAR_$$,$app$main$ui$workspace$viewport$widgets$button_add_STAR_$$,$app$main$ui$workspace$viewport_wasm$apply_modifiers_to_objects$$,$app$main$ui$workspace$viewport_wasm$apply_wasm_modifiers_to_ids$$,
$app$main$ui$workspace$viewport_wasm$outline_wasm_source_ids$$,$app$main$ui$workspace$viewport_wasm$transition_overlay_STAR_$$,$app$main$ui$workspace$viewport_wasm$viewport_STAR_$$,$app$main$ui$workspace$viewport$apply_modifiers_to_selected$$,$app$main$ui$workspace$viewport$viewport_classic_STAR_$$,$app$main$ui$workspace$viewport$viewport_STAR_$$,$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$,$app$main$ui$workspace$webgl_unavailable_modal$webgl_unavailable_modal_STAR_$$,$app$main$ui$workspace$workspace_content_STAR_$$,
$app$main$ui$workspace$workspace_loader_STAR_$$,$app$main$ui$workspace$make_team_ref$$,$app$main$ui$workspace$make_file_ref$$,$app$main$ui$workspace$make_page_ref$$,$app$main$ui$workspace$workspace_inner_STAR_$$,$cljs$core$CHAR_MAP$$,$cljs$core$js_reserved_arr$$,$cljs$core$js_reserved$$,$cljs$core$NS_CACHE$$,$cljs$tools$reader$READ_EOF$$,$cljs$tools$reader$READ_FINISHED$$,$cljs$tools$reader$_STAR_read_delim_STAR_$$,$cljs$tools$reader$_STAR_suppress_read_STAR_$$,$cljs$tools$reader$NO_MATCH$$,$cljs$tools$reader$arg_env$$,
$cljs$tools$reader$gensym_env$$,$app$$,$app$main$$,$app$main$data$workspace$initialize_layout_71823$$,$app$main$data$workspace$update_page_position_data_71850$$,$app$main$data$workspace$finalize_workspace_71915$$,$app$main$data$workspace$rename_file_71926$$,$app$main$data$workspace$update_nudge_71939$$,$app$main$data$workspace$relocate_page_72007$$,$app$main$data$workspace$set_shape_proportion_lock_72059$$,$app$main$data$workspace$workspace_focus_lost_72081$$,$app$main$data$workspace$set_assets_section_open_72090$$,
$app$main$data$workspace$clear_assets_section_open_72095$$,$app$main$data$workspace$set_assets_group_open_72101$$,$app$main$data$workspace$toggle_selected_assets_72110$$,$app$main$data$workspace$select_single_asset_72122$$,$app$main$data$workspace$select_assets_72125$$,$app$main$data$workspace$unselect_all_assets_72130$$,$app$main$data$workspace$show_component_in_assets_72134$$,$app$main$data$workspace$show_page_item_context_menu_72151$$,$app$main$data$workspace$show_track_context_menu_72156$$,$app$main$data$workspace$show_grid_cell_context_menu_72162$$,
$app$main$data$workspace$show_guide_context_menu_72167$$,$app$main$data$workspace$change_pixel_grid_color_72219$$,$app$main$data$workspace$set_paddings_selected_72222$$,$app$main$data$workspace$set_gap_selected_72225$$,$app$main$data$workspace$set_margins_selected_72228$$,$app$main$data$workspace$start_rename_page_item_72261$$,$app$main$data$workspace$stop_rename_page_item_72264$$,$app$main$data$workspace$update_component_annotation_72267$$,$app$main$data$workspace$set_annotations_expanded_72270$$,
$app$main$data$workspace$set_annotations_id_for_create_72273$$,$app$main$data$workspace$set_preview_blend_mode_72278$$,$app$main$data$workspace$unset_preview_blend_mode_72283$$,$app$main$data$workspace$set_clipboard_style_72295$$,$app$main$data$workspace$update_layers_search_scope_72314$$,$app$main$store$$,$app$main$data$modal$update_modal_props_51549$$,$app$main$data$common$go_to_feedback_52707$$,$app$main$data$persistence$update_status_55170$$,$app$main$data$persistence$update_file_revn_55197$$,
$app$main$data$persistence$discard_commit_55244$$,$app$main$data$persistence$append_commit_55252$$,$app$main$data$persistence$discard_persistence_state_55283$$,$app$main$data$persistence$persist_commit_55318$$,$app$main$data$persistence$run_persistence_task_55403$$,$app$main$data$persistence$initialize_persistence_55455$$,$app$main$data$plugins$update_plugins_permissions_peek_66403$$,$app$main$data$fonts$add_recent_font_56067$$,$app$main$data$project$finalize_project_55829$$,$app$main$data$workspace$zoom$start_zooming_66442$$,
$app$main$data$workspace$zoom$finish_zooming_66448$$,$app$main$data$workspace$selection$update_selrect_67246$$,$app$main$data$workspace$selection$handle_area_selection_67263$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$,$app$main$data$workspace$bool$group_to_bool_67835$$,$app$main$data$workspace$bool$bool_to_group_67841$$,$app$main$data$workspace$bool$change_bool_type_67853$$,$app$main$data$workspace$media$upload_fill_image_67897$$,$app$main$data$workspace$media$process_img_component_67916$$,
$app$main$data$workspace$media$process_svg_component_67922$$,$app$main$data$workspace$layout$ensure_layout_67340$$,$app$main$data$workspace$common$toggle_toolbar_visibility_67523$$,$app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$,$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$,$app$main$data$workspace$modifiers$update_modifiers_68893$$,$app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$,$app$main$data$workspace$transforms$change_orientation_69319$$,
$app$main$data$workspace$transforms$start_rotate_69329$$,$app$main$data$workspace$transforms$selected_fit_content_69611$$,$app$main$data$workspace$transforms$resize_text_editor_69617$$,$app$main$data$workspace$libraries$duplicate_color_69667$$,$app$main$data$workspace$libraries$delete_media_69683$$,$app$main$data$workspace$libraries$duplicate_typography_69723$$,$app$main$data$workspace$libraries$add_multiple_components_69757$$,$app$main$data$workspace$libraries$duplicate_component_69769$$,$app$main$data$workspace$libraries$restore_component_69783$$,
$app$main$data$workspace$libraries$restore_components_69787$$,$app$main$data$workspace$libraries$detach_components_69836$$,$app$main$data$workspace$libraries$nav_to_component_file_69848$$,$app$main$data$workspace$libraries$reset_components_69878$$,$app$main$data$workspace$libraries$update_component_69895$$,$app$main$data$workspace$libraries$update_component_sync_69922$$,$app$main$data$workspace$libraries$component_multi_swap_69968$$,$app$main$data$workspace$libraries$set_file_shared_70119$$,$app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$,
$app$main$data$workspace$libraries$detach_library_70179$$,$app$main$data$workspace$texts$update_editor_70204$$,$app$main$data$workspace$texts$focus_editor_70212$$,$app$main$data$workspace$texts$finalize_editor_state_70223$$,$app$main$data$workspace$texts$initialize_editor_state_70249$$,$app$main$data$workspace$texts$editor_select_all_70266$$,$app$main$data$workspace$texts$cursor_to_end_70272$$,$app$main$data$workspace$texts$commit_resize_text_70368$$,$app$main$data$workspace$texts$resize_text_70418$$,
$app$main$data$workspace$texts$save_font_70429$$,$app$main$data$workspace$texts$commit_update_text_modifier_70447$$,$app$main$data$workspace$texts$update_text_modifier_70462$$,$app$main$data$workspace$texts$clean_text_modifier_70486$$,$app$main$data$workspace$texts$remove_text_modifier_70499$$,$app$main$data$workspace$texts$commit_position_data_70511$$,$app$main$data$workspace$texts$update_position_data_70522$$,$app$main$data$workspace$texts$update_all_attrs_70569$$,$app$main$data$workspace$texts$add_typography_70592$$,
$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$,$app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$,$app$main$data$workspace$texts$replace_text_in_shapes_70640$$,$app$main$data$workspace$clipboard$paste_from_event_70783$$,$app$main$data$workspace$clipboard$copy_selected_svg_70795$$,$app$main$data$workspace$clipboard$copy_selected_css_70798$$,$app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$,$app$main$data$workspace$clipboard$copy_selected_text_70811$$,
$app$main$data$workspace$clipboard$copy_as_image_71197$$,$app$main$data$workspace$colors$toggle_palette_70661$$,$app$main$data$workspace$colors$start_picker_70669$$,$app$main$data$workspace$colors$stop_picker_70672$$,$app$main$data$workspace$colors$pick_color_70686$$,$app$main$data$workspace$colors$pick_color_select_70690$$,$app$main$data$workspace$colors$reorder_fills_70731$$,$app$main$data$workspace$colors$add_fill_70807$$,$app$main$data$workspace$colors$detach_fill_70816$$,$app$main$data$workspace$colors$remove_fill_70831$$,
$app$main$data$workspace$colors$change_hide_fill_on_export_70858$$,$app$main$data$workspace$colors$change_stroke_attrs_70937$$,$app$main$data$workspace$colors$add_shadow_70972$$,$app$main$data$workspace$colors$remove_stroke_71014$$,$app$main$data$workspace$colors$remove_all_strokes_71053$$,$app$main$data$workspace$colors$reorder_shadow_71064$$,$app$main$data$workspace$colors$reorder_strokes_71091$$,$app$main$data$workspace$colors$apply_color_from_palette_71130$$,$app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$,
$app$main$data$workspace$colors$add_recent_color_71194$$,$app$main$data$workspace$colors$apply_color_from_asserts_71203$$,$app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$,$app$main$data$workspace$colors$initialize_colorpicker_71225$$,$app$main$data$workspace$colors$finalize_colorpicker_71228$$,$app$main$data$workspace$colors$update_colorpicker_71233$$,$app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$,$app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$,
$app$main$data$workspace$colors$update_colorpicker_stops_71254$$,$app$main$data$workspace$colors$sort_colorpicker_stops_71258$$,$app$main$data$workspace$colors$remove_gradient_stop_71264$$,$app$main$data$workspace$colors$update_colorpicker_color_71270$$,$app$main$data$workspace$colors$update_colorpicker_gradient_71279$$,$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$,$app$main$data$workspace$colors$activate_colorpicker_color_71289$$,$app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$,
$app$main$data$workspace$colors$activate_colorpicker_image_71301$$,$app$main$data$workspace$drawing$change_orientation_70315$$,$app$main$data$workspace$drawing$change_preset_70325$$,$app$main$data$workspace$path$drawing$close_path_drag_start_70050$$,$app$main$data$workspace$path$drawing$close_path_drag_end_70063$$,$app$main$data$workspace$path$drawing$start_path_from_point_70070$$,$app$main$data$workspace$path$drawing$reset_last_handler_70176$$,$app$main$data$workspace$path$selection$path_pointer_enter_69884$$,
$app$main$data$workspace$path$selection$path_pointer_leave_69901$$,$app$main$data$workspace$path$selection$path_handler_enter_69907$$,$app$main$data$workspace$path$selection$path_handler_leave_69919$$,$app$main$data$workspace$path$selection$select_node_area_69926$$,$app$main$data$workspace$path$selection$select_node_69942$$,$app$main$data$workspace$path$selection$deselect_all_69950$$,$app$main$data$workspace$path$selection$update_area_selection_69964$$,$app$main$data$workspace$path$selection$clear_area_selection_69973$$,
$app$main$data$workspace$path$selection$handle_area_selection_69998$$,$app$main$data$workspace$path$edition$modify_handler_70046$$,$app$main$data$workspace$path$edition$move_point_70107$$,$app$main$data$workspace$path$edition$start_move_path_point_70122$$,$app$main$data$workspace$path$edition$drag_selected_points_70136$$,$app$main$data$workspace$path$edition$start_move_handler_70185$$,$app$main$data$workspace$path$edition$split_segments_70209$$,$app$main$data$workspace$path$edition$create_node_at_position_70217$$,
$app$main$data$workspace$comments$initialize_comments_70382$$,$app$main$data$workspace$comments$handle_interrupt_70398$$,$app$main$data$workspace$comments$handle_comment_layer_click_70409$$,$app$main$data$workspace$guides$remove_frame_guides_70514$$,$app$main$data$workspace$guides$update_guide_color_70551$$,$app$main$data$workspace$guides$set_hover_guide_70564$$,$app$main$data$workspace$highlight$set_search_match_highlight_70554$$,$app$main$data$workspace$highlight$clear_search_match_highlight_70574$$,
$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$,$app$main$data$workspace$interactions$rename_flow_70651$$,$app$main$data$workspace$interactions$add_new_interaction_70675$$,$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$,$app$main$data$workspace$interactions$start_edit_interaction_70722$$,$app$main$data$workspace$interactions$move_edit_interaction_70746$$,$app$main$data$workspace$interactions$finish_edit_interaction_70755$$,$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$,
$app$main$data$workspace$interactions$move_overlay_pos_70780$$,$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$,$app$main$data$workspace$notifications$finalize_70946$$,$app$main$data$workspace$pages$finalize_page_70956$$,$app$main$data$workspace$pages$duplicate_page_71028$$,$app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$,$app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$,$app$main$data$workspace$grid_layout$editor$set_selection_71118$$,$app$main$data$workspace$grid_layout$editor$remove_selection_71137$$,
$app$main$data$workspace$grid_layout$editor$clear_selection_71149$$,$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$,$app$main$data$workspace$grid_layout$editor$locate_board_71167$$,$app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$,$app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$,$app$main$data$workspace$shape_layout$reorder_layout_track_71461$$,$app$main$data$workspace$shape_layout$hover_layout_track_71465$$,$app$main$data$workspace$shape_layout$merge_cells_71557$$,
$app$main$data$workspace$shape_layout$create_cell_board_71569$$,$app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$,$app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$,$app$main$data$workspace$variants$reorder_variant_properties_71700$$,$app$main$data$workspace$variants$combine_selected_as_variants_71768$$,$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$,$app$main$data$workspace$viewport$initialize_viewport_71297$$,$app$main$data$workspace$viewport$update_viewport_size_71326$$,
$app$main$data$workspace$viewport$activate_panning_71344$$,$app$main$data$workspace$viewport$start_panning_71351$$,$app$main$data$workspace$viewport$finish_panning_71354$$,$app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$,$app$main$data$workspace$tokens$application$apply_token_from_input_72746$$,$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$,$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$,$app$main$data$workspace$tokens$library_edit$open_token_type_72902$$,
$app$main$data$workspace$tokens$library_edit$close_token_type_72914$$,$app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$,$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$,$app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$,
$app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$,$app$main$data$workspace$tokens$library_edit$drop_error_73176$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$,$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$,$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$,
$app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$,$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$,$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$,$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$,$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$,$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$,
$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$,$app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$,$app$main$data$workspace$versions$init_versions_state_73636$$,$app$main$data$workspace$versions$update_versions_state_73641$$,$app$main$data$workspace$versions$fetch_versions_73649$$,$app$main$data$workspace$versions$create_version_73657$$,$app$main$data$workspace$versions$rename_version_73666$$,$app$main$data$workspace$versions$delete_version_73674$$,
$app$main$data$workspace$versions$pin_version_73680$$,$app$main$data$workspace$versions$lock_version_73694$$,$app$main$data$workspace$versions$unlock_version_73710$$,$app$main$data$workspace$versions$exit_preview_cleanup_73715$$,$app$main$data$workspace$versions$exit_preview_73724$$,$app$main$data$workspace$versions$restore_version_73741$$,$app$main$data$workspace$versions$enter_restore_73746$$,$app$main$data$workspace$versions$apply_snapshot_data_73756$$,$app$main$data$workspace$versions$enter_preview_73767$$;
$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$=function($page_id$jscomp$121$$,$ids$jscomp$78$$){return $APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($page_id$jscomp$121$$,$ids$jscomp$78$$)};
$goog$functions$throttle$$=function($f$jscomp$6$$,$interval$jscomp$1$$){function $fire$$(){$timeout$jscomp$4$$=$APP.$goog$global$$.setTimeout($handleTimeout$$,$interval$jscomp$1$$);let $args$jscomp$8$$=$storedArgs$$;$storedArgs$$=[];$f$jscomp$6$$.apply(void 0,$args$jscomp$8$$)}function $handleTimeout$$(){$timeout$jscomp$4$$=0;$shouldFire$$&&($shouldFire$$=!1,$fire$$())}let $timeout$jscomp$4$$=0,$shouldFire$$=!1,$storedArgs$$=[];return function($var_args$jscomp$61$$){$storedArgs$$=arguments;$timeout$jscomp$4$$?
$shouldFire$$=!0:$fire$$()}};$module$contents$goog$array_slice$$=function($arr$jscomp$48$$,$start$jscomp$14$$,$opt_end$jscomp$9$$){return arguments.length<=2?Array.prototype.slice.call($arr$jscomp$48$$,$start$jscomp$14$$):Array.prototype.slice.call($arr$jscomp$48$$,$start$jscomp$14$$,$opt_end$jscomp$9$$)};
$module$contents$goog$array_splice$$=function($arr$jscomp$47$$,$index$jscomp$109$$,$howMany$jscomp$1$$,$var_args$jscomp$73$$){return Array.prototype.splice.apply($arr$jscomp$47$$,$module$contents$goog$array_slice$$(arguments,1))};$cljs$tools$reader$macro_terminating_QMARK_$$=function($ch$jscomp$25$$){switch($ch$jscomp$25$$){case '"':case ";":case "@":case "^":case "`":case "~":case "(":case ")":case "[":case "]":case "{":case "}":case "\\":return!0;default:return!1}};
$app$common$math$sq$$=function($v$jscomp$94$$){return $v$jscomp$94$$*$v$jscomp$94$$};$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$=function($s$jscomp$212$$,$val$jscomp$110$$,$from$jscomp$5$$){return typeof $s$jscomp$212$$==="string"&&typeof $val$jscomp$110$$==="string"?$APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$212$$,$val$jscomp$110$$,$from$jscomp$5$$):null};
$goog$dom$getElementsByClass$$=function($className$jscomp$1$$,$opt_el$jscomp$2$$){var $parent$jscomp$107$$=$opt_el$jscomp$2$$||document;return $parent$jscomp$107$$.querySelectorAll&&$parent$jscomp$107$$.querySelector?$parent$jscomp$107$$.querySelectorAll("."+$className$jscomp$1$$):$APP.$goog$dom$getElementsByTagNameAndClass_$$(document,"*",$className$jscomp$1$$,$opt_el$jscomp$2$$)};
$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ob$jscomp$8$$,$next_fn$jscomp$2$$,$error_fn$jscomp$2$$){$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$03$$($ob$jscomp$8$$,$next_fn$jscomp$2$$,$error_fn$jscomp$2$$)};$app$util$dom$select_target$$=function($event$jscomp$26$$){return $event$jscomp$26$$!=null?$event$jscomp$26$$.target.select():null};
$app$util$dom$get_parent_with_selector$$=function($current$jscomp$10_node$jscomp$179$$,$selector$jscomp$7$$){for(;;){var $JSCompiler_inline_result$jscomp$1487_or__5025__auto__$jscomp$inline_8173$$=($JSCompiler_inline_result$jscomp$1487_or__5025__auto__$jscomp$inline_8173$$=$current$jscomp$10_node$jscomp$179$$==null)?$JSCompiler_inline_result$jscomp$1487_or__5025__auto__$jscomp$inline_8173$$:$current$jscomp$10_node$jscomp$179$$.matches($selector$jscomp$7$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1487_or__5025__auto__$jscomp$inline_8173$$))return $current$jscomp$10_node$jscomp$179$$;
$current$jscomp$10_node$jscomp$179$$=$current$jscomp$10_node$jscomp$179$$.parentElement}};$app$util$dom$valid_QMARK_$$=function($node$jscomp$188_temp__5825__auto__$jscomp$107$$){return $node$jscomp$188_temp__5825__auto__$jscomp$107$$!=null?($node$jscomp$188_temp__5825__auto__$jscomp$107$$=$node$jscomp$188_temp__5825__auto__$jscomp$107$$.validity,$APP.$cljs$core$truth_$$($node$jscomp$188_temp__5825__auto__$jscomp$107$$)?$node$jscomp$188_temp__5825__auto__$jscomp$107$$.valid:null):null};
$app$util$dom$set_value_BANG_$$=function($node$jscomp$191$$,$value$jscomp$369$$){return $node$jscomp$191$$!=null?$node$jscomp$191$$.value=$value$jscomp$369$$:null};
$app$util$dom$is_in_viewport_QMARK_$$=function($element$jscomp$53_rect$jscomp$10$$){if($element$jscomp$53_rect$jscomp$10$$!=null){$element$jscomp$53_rect$jscomp$10$$=$element$jscomp$53_rect$jscomp$10$$.getBoundingClientRect();var $height$jscomp$39$$=function(){var $or__5025__auto__$jscomp$308$$=window.innerHeight;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$308$$)?$or__5025__auto__$jscomp$308$$:document.documentElement.clientHeight}(),$width$jscomp$47$$=function(){var $or__5025__auto__$jscomp$309$$=
window.innerWidth;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$309$$)?$or__5025__auto__$jscomp$309$$:document.documentElement.clientWidth}();return $element$jscomp$53_rect$jscomp$10$$.top>=0&&$element$jscomp$53_rect$jscomp$10$$.left>=0&&$element$jscomp$53_rect$jscomp$10$$.bottom<=$height$jscomp$39$$&&$element$jscomp$53_rect$jscomp$10$$.right<=$width$jscomp$47$$}return null};
$rumext$v2$throttle$$=function($component$jscomp$6$$,$ms$jscomp$37$$){return function($props_44914$$){var $tmp$jscomp$6$$=(0,$APP.$rumext$v2$useState$$)($props_44914$$),$state$jscomp$45$$=$tmp$jscomp$6$$[0],$set_state$$=$tmp$jscomp$6$$[1],$ref$jscomp$14$$=(0,$APP.$rumext$v2$useRef$$)(!1),$render$$=(0,$APP.$rumext$v2$useMemo$$)(function(){return $goog$functions$throttle$$(function($v$jscomp$500$$){return $APP.$rumext$v2$ref_val$$($ref$jscomp$14$$)?null:$set_state$$($v$jscomp$500$$)},$ms$jscomp$37$$)},
[]);(0,$APP.$rumext$v2$useEffect$$)(function(){return $render$$($props_44914$$)},[$props_44914$$]);(0,$APP.$rumext$v2$useEffect$$)(function(){return function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$14$$,!0)}},[]);return(0,$APP.$rumext$v2$create_element$$)($component$jscomp$6$$,$state$jscomp$45$$)}};
$app$common$types$color$hue__GT_rgb$$=function($v1$jscomp$24$$,$v2$jscomp$17$$,$vh$jscomp$2_vh__$1$$){$vh$jscomp$2_vh__$1$$=$vh$jscomp$2_vh__$1$$<0?$vh$jscomp$2_vh__$1$$+1:$vh$jscomp$2_vh__$1$$>1?$vh$jscomp$2_vh__$1$$-1:$vh$jscomp$2_vh__$1$$;return 6*$vh$jscomp$2_vh__$1$$<1?$v1$jscomp$24$$+($v2$jscomp$17$$-$v1$jscomp$24$$)*6*$vh$jscomp$2_vh__$1$$:2*$vh$jscomp$2_vh__$1$$<1?$v2$jscomp$17$$:3*$vh$jscomp$2_vh__$1$$<2?$v1$jscomp$24$$+($v2$jscomp$17$$-$v1$jscomp$24$$)*(2/3-$vh$jscomp$2_vh__$1$$)*6:$v1$jscomp$24$$};
$app$common$types$tokens_lib$get_set_names$$=function($JSCompiler_temp$jscomp$1490__$jscomp$1293$$){if($JSCompiler_temp$jscomp$1490__$jscomp$1293$$!=null&&$JSCompiler_temp$jscomp$1490__$jscomp$1293$$.$app$common$types$tokens_lib$ITokenSets$get_set_names$arity$1$!=null)$JSCompiler_temp$jscomp$1490__$jscomp$1293$$=$JSCompiler_temp$jscomp$1490__$jscomp$1293$$.$app$common$types$tokens_lib$ITokenSets$get_set_names$arity$1$($JSCompiler_temp$jscomp$1490__$jscomp$1293$$);else{var $m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$=
$app$common$types$tokens_lib$get_set_names$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1490__$jscomp$1293$$==null?null:$JSCompiler_temp$jscomp$1490__$jscomp$1293$$)];if($m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$!=null)$JSCompiler_temp$jscomp$1490__$jscomp$1293$$=$m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1490__$jscomp$1293$$):
$m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$($JSCompiler_temp$jscomp$1490__$jscomp$1293$$);else if($m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$=$app$common$types$tokens_lib$get_set_names$$._,$m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$!=null)$JSCompiler_temp$jscomp$1490__$jscomp$1293$$=$m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1490__$jscomp$1293$$):
$m__5372__auto__$jscomp$inline_8177_m__5374__auto__$jscomp$inline_8176$$($JSCompiler_temp$jscomp$1490__$jscomp$1293$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.get-set-names",$JSCompiler_temp$jscomp$1490__$jscomp$1293$$);}return $JSCompiler_temp$jscomp$1490__$jscomp$1293$$};
$app$common$types$tokens_lib$get_sets_at_path$$=function($JSCompiler_temp$jscomp$1491__$jscomp$1297$$,$path_str$jscomp$5$$){if($JSCompiler_temp$jscomp$1491__$jscomp$1297$$!=null&&$JSCompiler_temp$jscomp$1491__$jscomp$1297$$.$app$common$types$tokens_lib$ITokenSets$get_sets_at_path$arity$2$!=null)$JSCompiler_temp$jscomp$1491__$jscomp$1297$$=$JSCompiler_temp$jscomp$1491__$jscomp$1297$$.$app$common$types$tokens_lib$ITokenSets$get_sets_at_path$arity$2$($JSCompiler_temp$jscomp$1491__$jscomp$1297$$,$path_str$jscomp$5$$);
else{var $m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$=$app$common$types$tokens_lib$get_sets_at_path$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1491__$jscomp$1297$$==null?null:$JSCompiler_temp$jscomp$1491__$jscomp$1297$$)];if($m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$!=null)$JSCompiler_temp$jscomp$1491__$jscomp$1297$$=$m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1491__$jscomp$1297$$,
$path_str$jscomp$5$$):$m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$($JSCompiler_temp$jscomp$1491__$jscomp$1297$$,$path_str$jscomp$5$$);else if($m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$=$app$common$types$tokens_lib$get_sets_at_path$$._,$m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$!=null)$JSCompiler_temp$jscomp$1491__$jscomp$1297$$=$m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1491__$jscomp$1297$$,$path_str$jscomp$5$$):$m__5372__auto__$jscomp$inline_8182_m__5374__auto__$jscomp$inline_8181$$($JSCompiler_temp$jscomp$1491__$jscomp$1297$$,$path_str$jscomp$5$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenSets.get-sets-at-path",$JSCompiler_temp$jscomp$1491__$jscomp$1297$$);}return $JSCompiler_temp$jscomp$1491__$jscomp$1297$$};
$app$common$types$tokens_lib$enable_sets$$=function($JSCompiler_temp$jscomp$1492__$jscomp$1303$$,$set_names$jscomp$3$$){if($JSCompiler_temp$jscomp$1492__$jscomp$1303$$!=null&&$JSCompiler_temp$jscomp$1492__$jscomp$1303$$.$app$common$types$tokens_lib$ITokenTheme$enable_sets$arity$2$!=null)$JSCompiler_temp$jscomp$1492__$jscomp$1303$$=$JSCompiler_temp$jscomp$1492__$jscomp$1303$$.$app$common$types$tokens_lib$ITokenTheme$enable_sets$arity$2$($JSCompiler_temp$jscomp$1492__$jscomp$1303$$,$set_names$jscomp$3$$);
else{var $m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$=$app$common$types$tokens_lib$enable_sets$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1492__$jscomp$1303$$==null?null:$JSCompiler_temp$jscomp$1492__$jscomp$1303$$)];if($m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$!=null)$JSCompiler_temp$jscomp$1492__$jscomp$1303$$=$m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1492__$jscomp$1303$$,
$set_names$jscomp$3$$):$m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$($JSCompiler_temp$jscomp$1492__$jscomp$1303$$,$set_names$jscomp$3$$);else if($m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$=$app$common$types$tokens_lib$enable_sets$$._,$m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$!=null)$JSCompiler_temp$jscomp$1492__$jscomp$1303$$=$m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1492__$jscomp$1303$$,$set_names$jscomp$3$$):$m__5372__auto__$jscomp$inline_8187_m__5374__auto__$jscomp$inline_8186$$($JSCompiler_temp$jscomp$1492__$jscomp$1303$$,$set_names$jscomp$3$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.enable-sets",$JSCompiler_temp$jscomp$1492__$jscomp$1303$$);}return $JSCompiler_temp$jscomp$1492__$jscomp$1303$$};
$app$common$types$tokens_lib$disable_sets$$=function($JSCompiler_temp$jscomp$1493__$jscomp$1307$$,$set_names$jscomp$5$$){if($JSCompiler_temp$jscomp$1493__$jscomp$1307$$!=null&&$JSCompiler_temp$jscomp$1493__$jscomp$1307$$.$app$common$types$tokens_lib$ITokenTheme$disable_sets$arity$2$!=null)$JSCompiler_temp$jscomp$1493__$jscomp$1307$$=$JSCompiler_temp$jscomp$1493__$jscomp$1307$$.$app$common$types$tokens_lib$ITokenTheme$disable_sets$arity$2$($JSCompiler_temp$jscomp$1493__$jscomp$1307$$,$set_names$jscomp$5$$);
else{var $m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$=$app$common$types$tokens_lib$disable_sets$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1493__$jscomp$1307$$==null?null:$JSCompiler_temp$jscomp$1493__$jscomp$1307$$)];if($m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$!=null)$JSCompiler_temp$jscomp$1493__$jscomp$1307$$=$m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1493__$jscomp$1307$$,
$set_names$jscomp$5$$):$m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$($JSCompiler_temp$jscomp$1493__$jscomp$1307$$,$set_names$jscomp$5$$);else if($m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$=$app$common$types$tokens_lib$disable_sets$$._,$m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$!=null)$JSCompiler_temp$jscomp$1493__$jscomp$1307$$=$m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1493__$jscomp$1307$$,$set_names$jscomp$5$$):$m__5372__auto__$jscomp$inline_8192_m__5374__auto__$jscomp$inline_8191$$($JSCompiler_temp$jscomp$1493__$jscomp$1307$$,$set_names$jscomp$5$$);else throw $APP.$cljs$core$missing_protocol$$("ITokenTheme.disable-sets",$JSCompiler_temp$jscomp$1493__$jscomp$1307$$);}return $JSCompiler_temp$jscomp$1493__$jscomp$1307$$};
$app$common$types$tokens_lib$set_path_exists_QMARK_$$=function($JSCompiler_temp$jscomp$1494__$jscomp$1358$$,$path$jscomp$178$$){if($JSCompiler_temp$jscomp$1494__$jscomp$1358$$!=null&&$JSCompiler_temp$jscomp$1494__$jscomp$1358$$.$app$common$types$tokens_lib$ITokensLib$set_path_exists_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$1494__$jscomp$1358$$=$JSCompiler_temp$jscomp$1494__$jscomp$1358$$.$app$common$types$tokens_lib$ITokensLib$set_path_exists_QMARK_$arity$2$($JSCompiler_temp$jscomp$1494__$jscomp$1358$$,
$path$jscomp$178$$);else{var $m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$=$app$common$types$tokens_lib$set_path_exists_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1494__$jscomp$1358$$==null?null:$JSCompiler_temp$jscomp$1494__$jscomp$1358$$)];if($m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$!=null)$JSCompiler_temp$jscomp$1494__$jscomp$1358$$=$m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1494__$jscomp$1358$$,$path$jscomp$178$$):$m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$($JSCompiler_temp$jscomp$1494__$jscomp$1358$$,$path$jscomp$178$$);else if($m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$=$app$common$types$tokens_lib$set_path_exists_QMARK_$$._,$m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$!=
null)$JSCompiler_temp$jscomp$1494__$jscomp$1358$$=$m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1494__$jscomp$1358$$,$path$jscomp$178$$):$m__5372__auto__$jscomp$inline_8197_m__5374__auto__$jscomp$inline_8196$$($JSCompiler_temp$jscomp$1494__$jscomp$1358$$,$path$jscomp$178$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.set-path-exists?",
$JSCompiler_temp$jscomp$1494__$jscomp$1358$$);}return $JSCompiler_temp$jscomp$1494__$jscomp$1358$$};
$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$=function($JSCompiler_temp$jscomp$1495__$jscomp$1360$$,$path$jscomp$180$$){if($JSCompiler_temp$jscomp$1495__$jscomp$1360$$!=null&&$JSCompiler_temp$jscomp$1495__$jscomp$1360$$.$app$common$types$tokens_lib$ITokensLib$set_group_path_exists_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$1495__$jscomp$1360$$=$JSCompiler_temp$jscomp$1495__$jscomp$1360$$.$app$common$types$tokens_lib$ITokensLib$set_group_path_exists_QMARK_$arity$2$($JSCompiler_temp$jscomp$1495__$jscomp$1360$$,$path$jscomp$180$$);
else{var $m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$=$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1495__$jscomp$1360$$==null?null:$JSCompiler_temp$jscomp$1495__$jscomp$1360$$)];if($m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$!=null)$JSCompiler_temp$jscomp$1495__$jscomp$1360$$=$m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1495__$jscomp$1360$$,
$path$jscomp$180$$):$m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$($JSCompiler_temp$jscomp$1495__$jscomp$1360$$,$path$jscomp$180$$);else if($m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$=$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$._,$m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$!=null)$JSCompiler_temp$jscomp$1495__$jscomp$1360$$=$m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1495__$jscomp$1360$$,$path$jscomp$180$$):$m__5372__auto__$jscomp$inline_8202_m__5374__auto__$jscomp$inline_8201$$($JSCompiler_temp$jscomp$1495__$jscomp$1360$$,$path$jscomp$180$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.set-group-path-exists?",$JSCompiler_temp$jscomp$1495__$jscomp$1360$$);}return $JSCompiler_temp$jscomp$1495__$jscomp$1360$$};
$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$=function($JSCompiler_temp$jscomp$1496__$jscomp$1378$$,$group_path$jscomp$2$$){if($JSCompiler_temp$jscomp$1496__$jscomp$1378$$!=null&&$JSCompiler_temp$jscomp$1496__$jscomp$1378$$.$app$common$types$tokens_lib$ITokensLib$sets_at_path_all_active_QMARK_$arity$2$!=null)$JSCompiler_temp$jscomp$1496__$jscomp$1378$$=$JSCompiler_temp$jscomp$1496__$jscomp$1378$$.$app$common$types$tokens_lib$ITokensLib$sets_at_path_all_active_QMARK_$arity$2$($JSCompiler_temp$jscomp$1496__$jscomp$1378$$,
$group_path$jscomp$2$$);else{var $m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$=$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1496__$jscomp$1378$$==null?null:$JSCompiler_temp$jscomp$1496__$jscomp$1378$$)];if($m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$!=null)$JSCompiler_temp$jscomp$1496__$jscomp$1378$$=$m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1496__$jscomp$1378$$,$group_path$jscomp$2$$):$m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$($JSCompiler_temp$jscomp$1496__$jscomp$1378$$,$group_path$jscomp$2$$);else if($m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$=$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$._,$m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$!=
null)$JSCompiler_temp$jscomp$1496__$jscomp$1378$$=$m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1496__$jscomp$1378$$,$group_path$jscomp$2$$):$m__5372__auto__$jscomp$inline_8207_m__5374__auto__$jscomp$inline_8206$$($JSCompiler_temp$jscomp$1496__$jscomp$1378$$,$group_path$jscomp$2$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.sets-at-path-all-active?",
$JSCompiler_temp$jscomp$1496__$jscomp$1378$$);}return $JSCompiler_temp$jscomp$1496__$jscomp$1378$$};
$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$=function($JSCompiler_temp$jscomp$1497__$jscomp$1382$$,$force_set_id$jscomp$1$$){if($JSCompiler_temp$jscomp$1497__$jscomp$1382$$!=null&&$JSCompiler_temp$jscomp$1497__$jscomp$1382$$.$app$common$types$tokens_lib$ITokensLib$get_tokens_in_active_sets_force$arity$2$!=null)$JSCompiler_temp$jscomp$1497__$jscomp$1382$$=$JSCompiler_temp$jscomp$1497__$jscomp$1382$$.$app$common$types$tokens_lib$ITokensLib$get_tokens_in_active_sets_force$arity$2$($JSCompiler_temp$jscomp$1497__$jscomp$1382$$,$force_set_id$jscomp$1$$);
else{var $m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$=$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1497__$jscomp$1382$$==null?null:$JSCompiler_temp$jscomp$1497__$jscomp$1382$$)];if($m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$!=null)$JSCompiler_temp$jscomp$1497__$jscomp$1382$$=$m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1497__$jscomp$1382$$,
$force_set_id$jscomp$1$$):$m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$($JSCompiler_temp$jscomp$1497__$jscomp$1382$$,$force_set_id$jscomp$1$$);else if($m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$=$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$._,$m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$!=null)$JSCompiler_temp$jscomp$1497__$jscomp$1382$$=$m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1497__$jscomp$1382$$,$force_set_id$jscomp$1$$):$m__5372__auto__$jscomp$inline_8212_m__5374__auto__$jscomp$inline_8211$$($JSCompiler_temp$jscomp$1497__$jscomp$1382$$,$force_set_id$jscomp$1$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-tokens-in-active-sets-force",$JSCompiler_temp$jscomp$1497__$jscomp$1382$$);}return $JSCompiler_temp$jscomp$1497__$jscomp$1382$$};
$app$common$types$tokens_lib$get_all_tokens$$=function($JSCompiler_temp$jscomp$1498__$jscomp$1384$$){if($JSCompiler_temp$jscomp$1498__$jscomp$1384$$!=null&&$JSCompiler_temp$jscomp$1498__$jscomp$1384$$.$app$common$types$tokens_lib$ITokensLib$get_all_tokens$arity$1$!=null)$JSCompiler_temp$jscomp$1498__$jscomp$1384$$=$JSCompiler_temp$jscomp$1498__$jscomp$1384$$.$app$common$types$tokens_lib$ITokensLib$get_all_tokens$arity$1$($JSCompiler_temp$jscomp$1498__$jscomp$1384$$);else{var $m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$=
$app$common$types$tokens_lib$get_all_tokens$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1498__$jscomp$1384$$==null?null:$JSCompiler_temp$jscomp$1498__$jscomp$1384$$)];if($m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$!=null)$JSCompiler_temp$jscomp$1498__$jscomp$1384$$=$m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1498__$jscomp$1384$$):
$m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$($JSCompiler_temp$jscomp$1498__$jscomp$1384$$);else if($m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$=$app$common$types$tokens_lib$get_all_tokens$$._,$m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$!=null)$JSCompiler_temp$jscomp$1498__$jscomp$1384$$=$m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$.$cljs$core$IFn$_invoke$arity$1$?$m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1498__$jscomp$1384$$):
$m__5372__auto__$jscomp$inline_8216_m__5374__auto__$jscomp$inline_8215$$($JSCompiler_temp$jscomp$1498__$jscomp$1384$$);else throw $APP.$cljs$core$missing_protocol$$("ITokensLib.get-all-tokens",$JSCompiler_temp$jscomp$1498__$jscomp$1384$$);}return $JSCompiler_temp$jscomp$1498__$jscomp$1384$$};$app$util$keyboard$mod_event_QMARK_$$=function($event$jscomp$47$$){return $event$jscomp$47$$.$mod$===!0};$app$util$mouse$get_pointer_movement$$=function($ev$jscomp$3$$){return $ev$jscomp$3$$.$movement$};
$app$main$ui$hooks$sortable_container_STAR_$$=function($children$jscomp$198_props_52695$$){$children$jscomp$198_props_52695$$=$children$jscomp$198_props_52695$$.children;var $global_drag_end$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$hooks$sortable_ctx$$),{value:$global_drag_end$$,children:$children$jscomp$198_props_52695$$})};
$app$util$text$content$to_dom$create_random_key$$=function(){return Math.floor(Math.random()*Number.MAX_SAFE_INTEGER).toString(36)};$app$util$array$normalize_to_array$$=function($o$jscomp$267$$){return $APP.$cljs$core$array_QMARK_$$($o$jscomp$267$$)?$o$jscomp$267$$:[$o$jscomp$267$$]};$app$util$array$without_nils$$=function($o$jscomp$268$$){return $o$jscomp$268$$.filter(function($v$jscomp$584$$){return $v$jscomp$584$$!=null})};$app$util$array$filter$$=function($pred$jscomp$82$$,$o$jscomp$269$$){return $o$jscomp$269$$.filter($pred$jscomp$82$$)};
$app$util$text_editor$editor_select_all$$=function($state$jscomp$550$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.selectAll($state$jscomp$550$$)};$app$util$text_editor$cursor_to_end$$=function($state$jscomp$560$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.cursorToEnd($state$jscomp$560$$)};
$app$main$data$tinycolor$__GT_string$$=function($tc$jscomp$4$$,$format$jscomp$34$$){return $tc$jscomp$4$$.toString(function(){switch($format$jscomp$34$$){case "rgba":return"rgb";case "hsva":return"hsv";case "rgb":return"rgb";case "hsv":return"hsv";default:return"hex"}}())};$app$main$ui$css_cursors$get_dynamic$$=function($name$jscomp$417$$,$rotation$jscomp$18$$){return"cursor-"+($name$jscomp$417$$??"")+"-"+($APP.$cljs$core$mod$$(Math.floor($rotation$jscomp$18$$/10)*10,360)??"")};
$cljs$tools$reader$ending_line_col_info$$=function($rdr$jscomp$60$$){return $APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($rdr$jscomp$60$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rdr$jscomp$60$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$(null),$rdr$jscomp$60$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$(null)],null):null};
$cljs$tools$reader$starting_line_col_info$$=function($rdr$jscomp$59$$){return $APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($rdr$jscomp$59$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$rdr$jscomp$59$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$(null),$rdr$jscomp$59$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$(null)-1|0],null):null};
$app$util$dom$left_mouse_QMARK_$$=function($bevent$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$bevent$$.nativeEvent.which)};$app$util$dom$active_QMARK_$$=function($node$jscomp$214$$){return $node$jscomp$214$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$globals$document$$.activeElement,$node$jscomp$214$$):null};
$app$render_wasm$api$set_transition_tiles_complete_handler_BANG_$$=function(){var $epoch$$=$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$transition_epoch_STAR_$$),$handler$jscomp$28_temp__5825__auto___54585$$=$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$);$APP.$cljs$core$truth_$$($handler$jscomp$28_temp__5825__auto___54585$$)&&$APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:tiles-complete",$handler$jscomp$28_temp__5825__auto___54585$$);
$handler$jscomp$28_temp__5825__auto___54585$$=function $app$render_wasm$api$set_transition_tiles_complete_handler_BANG__$_handler$$(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($epoch$$,$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$transition_epoch_STAR_$$))?($APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:tiles-complete",$app$render_wasm$api$set_transition_tiles_complete_handler_BANG__$_handler$$),$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$,
null),$APP.$app$render_wasm$api$end_page_transition_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$APP.$app$render_wasm$api$end_page_transition_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$app$render_wasm$api$end_page_transition_BANG_$$()):null};$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_tiles_handler_STAR_$$,$handler$jscomp$28_temp__5825__auto___54585$$);$APP.$app$util$globals$document$$.addEventListener("penpot:wasm:tiles-complete",$handler$jscomp$28_temp__5825__auto___54585$$)};
$app$render_wasm$serializers$translate_guide_axis$$=function($axis$jscomp$21$$){var $values$jscomp$71$$=$APP.$app$render_wasm$wasm$serializers$$["guide-kind"],$default$$jscomp$85$$=$values$jscomp$71$$.vertical;switch($axis$jscomp$21$$ instanceof $APP.$cljs$core$Keyword$$?$axis$jscomp$21$$.$fqn$:null){case "x":return $values$jscomp$71$$.vertical;case "y":return $values$jscomp$71$$.horizontal;default:return $default$$jscomp$85$$}};
$app$main$data$workspace$colors$recent_color_equal_QMARK_$$=function($c1$jscomp$36$$,$c2$jscomp$24$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c1$jscomp$36$$,$c2$jscomp$24$$)||$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$36$$)!=null&&$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$24$$)!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$36$$),$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$24$$))};
$app$main$data$workspace$specialized_panel$interrupt_QMARK_$$=function($e$jscomp$323$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$323$$,$APP.$cljs$cst$2177$interrupt$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$323$$,$APP.$cljs$cst$3647$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$)};
$app$util$shape_icon$get_shape_icon_by_type$$=function($type$jscomp$579$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$579$$,$APP.$cljs$cst$1630$component$$))return"component";switch($type$jscomp$579$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$579$$.$fqn$:null){case "frame":return"board";case "image":return"img";case "shape":return"path";case "text":return"text";case "mask":return"mask";case "group":return"group";default:return null}};
$app$util$mouse$mouse_click_event_QMARK_$$=function($v$jscomp$546$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1955$click$$,$v$jscomp$546$$.type)};
$app$common$types$shape$interactions$has_offset_effect_QMARK_$$=function($interaction$jscomp$29$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$29$$),$APP.$cljs$cst$1957$navigate$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$29$$)),$APP.$cljs$cst$1974$slide$$)};
$app$common$types$shape$interactions$has_way_QMARK_$$=function($interaction$jscomp$25$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$25$$),$APP.$cljs$cst$1957$navigate$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$25$$)),$APP.$cljs$cst$1974$slide$$)};
$app$main$data$workspace$notifications$finalize$$=function($_$jscomp$2452$$){typeof $app$main$data$workspace$notifications$finalize_70946$$==="undefined"&&($app$main$data$workspace$notifications$finalize_70946$$=function($_$jscomp$2453$$,$meta70947$$){this.$_$=$_$jscomp$2453$$;this.$meta70947$=$meta70947$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$notifications$finalize_70946$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$notifications$finalize_70946$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4414$app_DOT_main_DOT_data_DOT_workspace_DOT_notifications_SLASH_finalize$$},$app$main$data$workspace$notifications$finalize_70946$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70948$$,$meta70947__$1$$){return new $app$main$data$workspace$notifications$finalize_70946$$(this.$_$,$meta70947__$1$$)},$app$main$data$workspace$notifications$finalize_70946$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70947$});return new $app$main$data$workspace$notifications$finalize_70946$$($_$jscomp$2452$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$measurements$get_edge_for_badge$$=function($rot_rotation$jscomp$21$$){$rot_rotation$jscomp$21$$=$APP.$cljs$core$mod$$($rot_rotation$jscomp$21$$,360);return $rot_rotation$jscomp$21$$<45||$rot_rotation$jscomp$21$$>=315?$APP.$cljs$cst$1568$bottom$$:$rot_rotation$jscomp$21$$<135?$APP.$cljs$cst$258$right$$:$rot_rotation$jscomp$21$$<225?$APP.$cljs$cst$1567$top$$:$APP.$cljs$cst$257$left$$};
$app$main$ui$hooks$use_ref_callback$$=function($f$jscomp$812$$){var $ptr$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($f$jscomp$812$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($ptr$jscomp$2$$,{f:$f$jscomp$812$$})});return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){function $G__52805$$($var_args$jscomp$1118$$){var $G__52806__i_args$jscomp$245$$=null;if(arguments.length>
0){$G__52806__i_args$jscomp$245$$=0;for(var $G__52806__a$$=Array(arguments.length-0);$G__52806__i_args$jscomp$245$$<$G__52806__a$$.length;)$G__52806__a$$[$G__52806__i_args$jscomp$245$$]=arguments[$G__52806__i_args$jscomp$245$$+0],++$G__52806__i_args$jscomp$245$$;$G__52806__i_args$jscomp$245$$=new $APP.$cljs$core$IndexedSeq$$($G__52806__a$$,0,null)}return $G__52805__delegate$$.call(this,$G__52806__i_args$jscomp$245$$)}function $G__52805__delegate$$($args$jscomp$244$$){var $obj$jscomp$191$$=$APP.$rumext$v2$ref_val$$($ptr$jscomp$2$$);
return $obj$jscomp$191$$?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$191$$.f,$args$jscomp$244$$):null}$G__52805$$.$cljs$lang$maxFixedArity$=0;$G__52805$$.$cljs$lang$applyTo$=function($arglist__52807_args$jscomp$246$$){$arglist__52807_args$jscomp$246$$=$APP.$cljs$core$seq$$($arglist__52807_args$jscomp$246$$);return $G__52805__delegate$$($arglist__52807_args$jscomp$246$$)};$G__52805$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__52805__delegate$$;return $G__52805$$}())};
$app$main$ui$hooks$use_update_ref$$=function($value$jscomp$472$$){var $ref$jscomp$26$$=(0,$APP.$rumext$v2$use_ref$$)($value$jscomp$472$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$472$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$26$$,$value$jscomp$472$$)});return $ref$jscomp$26$$};
$cljs$core$partition_by$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$294$$,$coll$jscomp$765$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$28$$=$APP.$cljs$core$seq$$($coll$jscomp$765$$);if($temp__5825__auto__$jscomp$28$$){var $fst$$=$APP.$cljs$core$first$$($temp__5825__auto__$jscomp$28$$),$fv$$=$f$jscomp$294$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$294$$.$cljs$core$IFn$_invoke$arity$1$($fst$$):$f$jscomp$294$$($fst$$),$run$$=$APP.$cljs$core$cons$$($fst$$,
$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__23958_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($fv$$,$f$jscomp$294$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$294$$.$cljs$core$IFn$_invoke$arity$1$($p1__23958_SHARP_$$):$f$jscomp$294$$($p1__23958_SHARP_$$))},$APP.$cljs$core$next$$($temp__5825__auto__$jscomp$28$$)));return $APP.$cljs$core$cons$$($run$$,$cljs$core$partition_by$cljs$0core$0IFn$0_invoke$0arity$02$$($f$jscomp$294$$,new $APP.$cljs$core$LazySeq$$(null,
function(){return $APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$count$$($run$$),$temp__5825__auto__$jscomp$28$$)},null,null)))}return null},null,null)};$cljs$core$not_every_QMARK_$$=function($pred$jscomp$1$$,$coll$jscomp$275$$){return!$APP.$cljs$core$every_QMARK_$$($pred$jscomp$1$$,$coll$jscomp$275$$)};
$cljs$tools$reader$flatten_map$$=function($G__25226_form$jscomp$18_s$jscomp$173$$){$G__25226_form$jscomp$18_s$jscomp$173$$=$APP.$cljs$core$seq$$($G__25226_form$jscomp$18_s$jscomp$173$$);for(var $G__25227_key_vals$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;)if($G__25226_form$jscomp$18_s$jscomp$173$$){var $e$jscomp$127$$=$APP.$cljs$core$first$$($G__25226_form$jscomp$18_s$jscomp$173$$);$G__25226_form$jscomp$18_s$jscomp$173$$=$APP.$cljs$core$next$$($G__25226_form$jscomp$18_s$jscomp$173$$);
$G__25227_key_vals$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__25227_key_vals$$,$APP.$cljs$core$_key$$($e$jscomp$127$$)),$APP.$cljs$core$_val$$($e$jscomp$127$$))}else return $APP.$cljs$core$seq$$($APP.$cljs$core$_persistent_BANG_$$($G__25227_key_vals$$))};
$app$common$path_names$merge_path_item_with_dot$$=function($path$jscomp$159$$,$name$jscomp$180$$){return $APP.$cljs$core$empty_QMARK_$$($path$jscomp$159$$)?$name$jscomp$180$$:$APP.$cljs$core$empty_QMARK_$$($name$jscomp$180$$)?$path$jscomp$159$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$159$$)," • ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$180$$)].join("")};
$app$common$types$token$build_result$$=function($second_part_value$jscomp$438$$,$first_part_prefix_end$$,$suffix_start$$,$name$jscomp$176_ref$jscomp$21$$){$name$jscomp$176_ref$jscomp$21$$=["{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$176_ref$jscomp$21$$),"}"].join("");$first_part_prefix_end$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($second_part_value$jscomp$438$$,0,$first_part_prefix_end$$);$second_part_value$jscomp$438$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($second_part_value$jscomp$438$$,
$suffix_start$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($first_part_prefix_end$$),$name$jscomp$176_ref$jscomp$21$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($second_part_value$jscomp$438$$)].join(""),$APP.$cljs$cst$2013$cursor$$,$APP.$cljs$core$count$$($first_part_prefix_end$$)+$name$jscomp$176_ref$jscomp$21$$.length],null)};
$promesa$impl$promise$all$$=function($promises$$){return $promises$$.reduce(($acc$jscomp$79$$,$p$jscomp$117$$)=>$acc$jscomp$79$$.then($results$$=>$APP.$JSCompiler_StaticMethods_fmap$$($APP.$promesa$impl$promise$coerce$$($p$jscomp$117$$),$v$jscomp$292$$=>{$results$$.push($v$jscomp$292$$);return $results$$})),$APP.$promesa$impl$promise$resolved$$([]))};
$cljs$spec$alpha$explain_data_STAR_$$=function($spec$jscomp$21$$,$x$jscomp$882$$){var $path$jscomp$124_temp__5825__auto__$jscomp$77$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$via$jscomp$4$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$in$$jscomp$43$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$path$jscomp$124_temp__5825__auto__$jscomp$77$$=$APP.$cljs$spec$alpha$explain_STAR_$$($APP.$cljs$spec$alpha$specize$$.$cljs$core$IFn$_invoke$arity$1$($spec$jscomp$21$$),$path$jscomp$124_temp__5825__auto__$jscomp$77$$,
$via$jscomp$4$$,$in$$jscomp$43$$,$x$jscomp$882$$);return $APP.$cljs$core$truth_$$($path$jscomp$124_temp__5825__auto__$jscomp$77$$)?$APP.$cljs$core$empty_QMARK_$$($path$jscomp$124_temp__5825__auto__$jscomp$77$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$981$cljs_DOT_spec_DOT_alpha_SLASH_problems$$,$path$jscomp$124_temp__5825__auto__$jscomp$77$$,$APP.$cljs$cst$982$cljs_DOT_spec_DOT_alpha_SLASH_spec$$,$spec$jscomp$21$$,$APP.$cljs$cst$983$cljs_DOT_spec_DOT_alpha_SLASH_value$$,
$x$jscomp$882$$],null):null};
$app$common$data$nth_index_of_STAR_$$=function($G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$,$G__32230_G__32230__$1_char$$jscomp$1$$,$dir$$){for(var $s$jscomp$290$$=$G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$,$G__32775_G__32778_offset$jscomp$32$$=0,$G__32776_G__32779_cnt$jscomp$31$$=1;;){a:switch($G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$=$dir$$ instanceof $APP.$cljs$core$Keyword$$?$dir$$.$fqn$:null,$G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$){case "forward":$G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$=
$APP.$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$290$$,$G__32230_G__32230__$1_char$$jscomp$1$$);break a;case "backward":$G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$290$$,$G__32230_G__32230__$1_char$$jscomp$1$$);break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$)].join(""));
}if($G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$==null)return null;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__32776_G__32779_cnt$jscomp$31$$,1))switch($G__32230_G__32230__$1_char$$jscomp$1$$=$dir$$,$G__32230_G__32230__$1_char$$jscomp$1$$=$G__32230_G__32230__$1_char$$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__32230_G__32230__$1_char$$jscomp$1$$.$fqn$:null,$G__32230_G__32230__$1_char$$jscomp$1$$){case "forward":return $G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$+
$G__32775_G__32778_offset$jscomp$32$$;case "backward":return $G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__32230_G__32230__$1_char$$jscomp$1$$)].join(""));}else{var $G__32233_G__32233__$1$$=$dir$$;$G__32233_G__32233__$1$$=$G__32233_G__32233__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__32233_G__32233__$1$$.$fqn$:null;switch($G__32233_G__32233__$1$$){case "forward":$G__32775_G__32778_offset$jscomp$32$$=
$G__32775_G__32778_offset$jscomp$32$$+$G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$+1;$G__32776_G__32779_cnt$jscomp$31$$+=1;$s$jscomp$290$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$290$$,$G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$+1);continue;case "backward":$G__32776_G__32779_cnt$jscomp$31$$+=1;$s$jscomp$290$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$290$$,0,$G__32228__$1$jscomp$inline_8225_index$jscomp$130_string$jscomp$5$$);
continue;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__32233_G__32233__$1$$)].join(""));}}break}};$cljs$core$Namespace$$=function($obj$jscomp$102$$,$name$jscomp$117$$){this.$obj$=$obj$jscomp$102$$;this.name=$name$jscomp$117$$;this.$cljs$lang$protocol_mask$partition0$$=6291456;this.$cljs$lang$protocol_mask$partition1$$=0};
$app$common$types$text$replace_all_case_insensitive$$=function($text$jscomp$21$$,$search$jscomp$1_search_len$$,$replacement$jscomp$13$$){var $text_lower$$=$APP.$cuerdas$core$lower$$($text$jscomp$21$$),$search_lower$jscomp$1$$=$APP.$cuerdas$core$lower$$($search$jscomp$1_search_len$$);$search$jscomp$1_search_len$$=$APP.$cljs$core$count$$($search$jscomp$1_search_len$$);for(var $G__46061_result$jscomp$173$$="",$idx$jscomp$74$$=0;;){var $G__46062_found$jscomp$17$$=$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($text_lower$$,
$search_lower$jscomp$1$$,$idx$jscomp$74$$);if($G__46062_found$jscomp$17$$==null)return[$G__46061_result$jscomp$173$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($text$jscomp$21$$,$idx$jscomp$74$$)].join("");$G__46061_result$jscomp$173$$=[$G__46061_result$jscomp$173$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($text$jscomp$21$$,$idx$jscomp$74$$,$G__46062_found$jscomp$17$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($replacement$jscomp$13$$)].join("");$idx$jscomp$74$$=
$G__46062_found$jscomp$17$$+=$search$jscomp$1_search_len$$}};$app$common$types$color$remove_hash$$=function($color$jscomp$13$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($color$jscomp$13$$,"#")?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$13$$,1):$color$jscomp$13$$};
$app$common$data$macros$truncate$$=function($s$jscomp$291$$){var $JSCompiler_temp_const$jscomp$1509$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$,$y__5114__auto__$jscomp$inline_8227$$=$APP.$cljs$core$count$$($s$jscomp$291$$);return $JSCompiler_temp_const$jscomp$1509$$.call($APP.$cljs$core$subs$$,$s$jscomp$291$$,0,200<$y__5114__auto__$jscomp$inline_8227$$?200:$y__5114__auto__$jscomp$inline_8227$$)};
$app$util$array$sort_BANG_$$=function($a$jscomp$398$$){$APP.$module$contents$goog$array_sort$$($a$jscomp$398$$,$APP.$cljs$core$compare$$);return $a$jscomp$398$$};
$app$render_wasm$api$apply_canvas_blur$$=function(){$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_reveal_rulers_QMARK_$$,!1);var $already_QMARK__temp__5825__auto__$jscomp$174$$=$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$);$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$page_transition_QMARK_$$,!0);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$render_wasm$api$transition_epoch_STAR_$$,$APP.$cljs$core$inc$$);$APP.$cljs$core$truth_$$($already_QMARK__temp__5825__auto__$jscomp$174$$)||
($already_QMARK__temp__5825__auto__$jscomp$174$$=$APP.$app$render_wasm$wasm$canvas_snapshot$$,$APP.$cljs$core$truth_$$($already_QMARK__temp__5825__auto__$jscomp$174$$)&&$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_image_STAR_$$,$already_QMARK__temp__5825__auto__$jscomp$174$$))};
$app$render_wasm$api$start_initial_load_transition_BANG_$$=function($background$jscomp$2$$){$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_reveal_rulers_QMARK_$$,!0);($APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$))||$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$transition_image_STAR_$$)==null)&&typeof $background$jscomp$2$$==="string"&&$APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$transition_image_STAR_$$,["data:image/svg+xml;charset\x3dutf-8,",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(encodeURIComponent(["\x3csvg xmlns\x3d'http://www.w3.org/2000/svg' width\x3d'1' height\x3d'1'\x3e\x3crect width\x3d'1' height\x3d'1' fill\x3d'",$background$jscomp$2$$,"'/\x3e\x3c/svg\x3e"].join("")))].join(""));$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$))||($APP.$cljs$core$reset_BANG_$$($APP.$app$render_wasm$api$page_transition_QMARK_$$,!0),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$render_wasm$api$transition_epoch_STAR_$$,
$APP.$cljs$core$inc$$))};
$app$main$ui$workspace$viewport$utils$title_transform_use_width_QMARK_$$=function($map__74190__$1_p__74189_rotation$jscomp$20$$){$map__74190__$1_p__74189_rotation$jscomp$20$$=$APP.$cljs$core$__destructure_map$$($map__74190__$1_p__74189_rotation$jscomp$20$$);$map__74190__$1_p__74189_rotation$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74190__$1_p__74189_rotation$jscomp$20$$,$APP.$cljs$cst$1794$rotation$$);return $APP.$cljs$core$even_QMARK_$$($APP.$app$common$math$ceil$$(($map__74190__$1_p__74189_rotation$jscomp$20$$-45)/
90))};
$app$main$ui$workspace$viewport$utils$text_transform$$=function($p__74187_x$jscomp$1234$$,$zoom$jscomp$53$$){var $map__74188__$1_y$jscomp$454$$=$APP.$cljs$core$__destructure_map$$($p__74187_x$jscomp$1234$$);$p__74187_x$jscomp$1234$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74188__$1_y$jscomp$454$$,$APP.$cljs$cst$1515$x$$);$map__74188__$1_y$jscomp$454$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__74188__$1_y$jscomp$454$$,$APP.$cljs$cst$1516$y$$);var $inv_zoom$$=1/
$zoom$jscomp$53$$;return"scale("+($inv_zoom$$??"")+", "+($inv_zoom$$??"")+") translate("+$zoom$jscomp$53$$*$p__74187_x$jscomp$1234$$+", "+$zoom$jscomp$53$$*$map__74188__$1_y$jscomp$454$$+")"};
$app$common$geom$shapes$intersect$on_segment_QMARK_$$=function($p__48884_qx$$,$p__48885_px$jscomp$5$$,$p__48886_rx$jscomp$11$$){var $map__48888__$1_qy$$=$APP.$cljs$core$__destructure_map$$($p__48884_qx$$);$p__48884_qx$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48888__$1_qy$$,$APP.$cljs$cst$1515$x$$);$map__48888__$1_qy$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48888__$1_qy$$,$APP.$cljs$cst$1516$y$$);var $map__48890__$1_py$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($p__48885_px$jscomp$5$$);
$p__48885_px$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48890__$1_py$jscomp$4$$,$APP.$cljs$cst$1515$x$$);$map__48890__$1_py$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48890__$1_py$jscomp$4$$,$APP.$cljs$cst$1516$y$$);var $map__48891__$1_ry$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($p__48886_rx$jscomp$11$$);$p__48886_rx$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48891__$1_ry$jscomp$5$$,$APP.$cljs$cst$1515$x$$);
$map__48891__$1_ry$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48891__$1_ry$jscomp$5$$,$APP.$cljs$cst$1516$y$$);return $p__48884_qx$$<=Math.max($p__48885_px$jscomp$5$$,$p__48886_rx$jscomp$11$$)&&$p__48884_qx$$>=Math.min($p__48885_px$jscomp$5$$,$p__48886_rx$jscomp$11$$)&&$map__48888__$1_qy$$<=Math.max($map__48890__$1_py$jscomp$4$$,$map__48891__$1_ry$jscomp$5$$)&&$map__48888__$1_qy$$>=Math.min($map__48890__$1_py$jscomp$4$$,$map__48891__$1_ry$jscomp$5$$)};
$app$common$geom$shapes$intersect$orientation$$=function($p1$jscomp$53_v$jscomp$522_x1$jscomp$29$$,$p2$jscomp$42_x2$jscomp$27$$,$p3$jscomp$9_x3$jscomp$2$$){var $map__48873__$1_y1$jscomp$31$$=$APP.$cljs$core$__destructure_map$$($p1$jscomp$53_v$jscomp$522_x1$jscomp$29$$);$p1$jscomp$53_v$jscomp$522_x1$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48873__$1_y1$jscomp$31$$,$APP.$cljs$cst$1515$x$$);$map__48873__$1_y1$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48873__$1_y1$jscomp$31$$,
$APP.$cljs$cst$1516$y$$);var $map__48874__$1_y2$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($p2$jscomp$42_x2$jscomp$27$$);$p2$jscomp$42_x2$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48874__$1_y2$jscomp$29$$,$APP.$cljs$cst$1515$x$$);$map__48874__$1_y2$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48874__$1_y2$jscomp$29$$,$APP.$cljs$cst$1516$y$$);var $map__48875__$1_y3$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($p3$jscomp$9_x3$jscomp$2$$);
$p3$jscomp$9_x3$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48875__$1_y3$jscomp$2$$,$APP.$cljs$cst$1515$x$$);$map__48875__$1_y3$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48875__$1_y3$jscomp$2$$,$APP.$cljs$cst$1516$y$$);$p1$jscomp$53_v$jscomp$522_x1$jscomp$29$$=($map__48874__$1_y2$jscomp$29$$-$map__48873__$1_y1$jscomp$31$$)*($p3$jscomp$9_x3$jscomp$2$$-$p2$jscomp$42_x2$jscomp$27$$)-($map__48875__$1_y3$jscomp$2$$-$map__48874__$1_y2$jscomp$29$$)*
($p2$jscomp$42_x2$jscomp$27$$-$p1$jscomp$53_v$jscomp$522_x1$jscomp$29$$);return $p1$jscomp$53_v$jscomp$522_x1$jscomp$29$$>0?$APP.$cljs$cst$1902$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_clockwise$$:$p1$jscomp$53_v$jscomp$522_x1$jscomp$29$$<0?$APP.$cljs$cst$1903$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_counter_clockwise$$:$APP.$cljs$cst$1904$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$};
$app$common$files$helpers$hidden_parent_QMARK_$$=function($objects$jscomp$28$$,$shape_id$jscomp$6$$){for(;;){var $parent_id$jscomp$4$$=$APP.$app$common$files$helpers$get_parent_id$$($objects$jscomp$28$$,$shape_id$jscomp$6$$);if($parent_id$jscomp$4$$==null||$shape_id$jscomp$6$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_id$jscomp$6$$,$APP.$app$common$uuid$zero$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$4$$,$APP.$app$common$uuid$zero$$))return!1;
if($APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$28$$,$parent_id$jscomp$4$$),$APP.$cljs$cst$1625$hidden$$)))return!0;$shape_id$jscomp$6$$=$parent_id$jscomp$4$$}};
$app$main$data$helpers$split_text_shapes$$=function($objects$jscomp$117$$,$G__49398_G__49401_ids$jscomp$20_ids__$1$jscomp$1$$){$G__49398_G__49401_ids$jscomp$20_ids__$1$jscomp$1$$=$APP.$cljs$core$seq$$($G__49398_G__49401_ids$jscomp$20_ids__$1$jscomp$1$$);for(var $G__49399_G__49402_text_ids$$=$APP.$cljs$core$PersistentVector$EMPTY$$,$G__49400_G__49403_shape_ids$jscomp$2$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $id$jscomp$157_temp__5823__auto__$jscomp$108$$=$APP.$cljs$core$first$$($G__49398_G__49401_ids$jscomp$20_ids__$1$jscomp$1$$);
if($APP.$cljs$core$truth_$$($id$jscomp$157_temp__5823__auto__$jscomp$108$$)){var $shape$jscomp$148$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$117$$,$id$jscomp$157_temp__5823__auto__$jscomp$108$$);$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$148$$)?($G__49398_G__49401_ids$jscomp$20_ids__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__49398_G__49401_ids$jscomp$20_ids__$1$jscomp$1$$),$G__49399_G__49402_text_ids$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__49399_G__49402_text_ids$$,
$id$jscomp$157_temp__5823__auto__$jscomp$108$$)):($G__49398_G__49401_ids$jscomp$20_ids__$1$jscomp$1$$=$APP.$cljs$core$rest$$($G__49398_G__49401_ids$jscomp$20_ids__$1$jscomp$1$$),$G__49400_G__49403_shape_ids$jscomp$2$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__49400_G__49403_shape_ids$jscomp$2$$,$id$jscomp$157_temp__5823__auto__$jscomp$108$$))}else return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__49399_G__49402_text_ids$$,$G__49400_G__49403_shape_ids$jscomp$2$$],
null)}};$app$common$files$helpers$unframed_shape_QMARK_$$=function($shape$jscomp$14$$){return $shape$jscomp$14$$!=null&&!$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$14$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$14$$?.$frame_id$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$14$$,$APP.$cljs$cst$1612$frame_id$$),$APP.$app$common$uuid$zero$$)};
$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$04$$=function($stream$jscomp$23$$,$deps$jscomp$13$$,$on_subscribe$jscomp$2$$,$on_dispose$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$($deps$jscomp$13$$,function(){if($APP.$cljs$core$truth_$$($stream$jscomp$23$$)){var $sub$jscomp$13$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$23$$,$on_subscribe$jscomp$2$$);return function(){$APP.$beicon$v2$core$_dispose$$($sub$jscomp$13$$);return $APP.$cljs$core$truth_$$($on_dispose$$)?
$on_dispose$$.$cljs$core$IFn$_invoke$arity$0$?$on_dispose$$.$cljs$core$IFn$_invoke$arity$0$():$on_dispose$$():null}}return null})};$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$=function($stream$jscomp$22$$,$deps$jscomp$12$$,$on_subscribe$jscomp$1$$){$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$04$$($stream$jscomp$22$$,$deps$jscomp$12$$,$on_subscribe$jscomp$1$$,null)};
$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$=function($stream$jscomp$21$$,$on_subscribe$$){$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$($stream$jscomp$21$$,[],$on_subscribe$$)};
$app$main$data$workspace$versions$apply_snapshot$$=function($p__73754$$){var $map__73755__$1$$=$APP.$cljs$core$__destructure_map$$($p__73754$$),$id$jscomp$870$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73755__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$versions$apply_snapshot_data_73756$$==="undefined"&&($app$main$data$workspace$versions$apply_snapshot_data_73756$$=function($p__73754$jscomp$1$$,$map__73755$jscomp$1$$,$snapshot$jscomp$3$$,$id$jscomp$871$$,$meta73757$$){this.$p__73754$=
$p__73754$jscomp$1$$;this.$map__73755$=$map__73755$jscomp$1$$;this.$snapshot$=$snapshot$jscomp$3$$;this.id=$id$jscomp$871$$;this.$meta73757$=$meta73757$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$apply_snapshot_data_73756$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$apply_snapshot_data_73756$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5160$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_apply_snapshot_data$$},
$app$main$data$workspace$versions$apply_snapshot_data_73756$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73758$$,$meta73757__$1$$){return new $app$main$data$workspace$versions$apply_snapshot_data_73756$$(this.$p__73754$,this.$map__73755$,this.$snapshot$,this.id,$meta73757__$1$$)},$app$main$data$workspace$versions$apply_snapshot_data_73756$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73757$},$app$main$data$workspace$versions$apply_snapshot_data_73756$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$apply_snapshot_data_73756$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2831$$,$state$jscomp$1099$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1099$$,$APP.$cljs$cst$1933$files$$,$APP.$cljs$core$assoc$$,this.id,this.$snapshot$)});return new $app$main$data$workspace$versions$apply_snapshot_data_73756$$($p__73754$$,$map__73755__$1$$,$map__73755__$1$$,$id$jscomp$870$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$start_token_set_edition$$=function($edition_id$$){typeof $app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$=function($edition_id$jscomp$1$$,$meta73264$$){this.$edition_id$=$edition_id$jscomp$1$$;this.$meta73264$=$meta73264$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4810$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_start_token_set_edition$$},$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73265$$,$meta73264__$1$$){return new $app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$(this.$edition_id$,
$meta73264__$1$$)},$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73264$},$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2712$$,$state$jscomp$1015$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1015$$,
$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4811$token_set_edition_id$$,this.$edition_id$)});return new $app$main$data$workspace$tokens$library_edit$start_token_set_edition_73263$$($edition_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$update_colorpicker_gradient$$=function($changes$jscomp$230$$){typeof $app$main$data$workspace$colors$update_colorpicker_gradient_71279$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_gradient_71279$$=function($changes$jscomp$231$$,$meta71280$$){this.$changes$=$changes$jscomp$231$$;this.$meta71280$=$meta71280$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_gradient_71279$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_gradient_71279$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4239$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_gradient$$},$app$main$data$workspace$colors$update_colorpicker_gradient_71279$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71281$$,$meta71280__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_gradient_71279$$(this.$changes$,
$meta71280__$1$$)},$app$main$data$workspace$colors$update_colorpicker_gradient_71279$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71280$},$app$main$data$workspace$colors$update_colorpicker_gradient_71279$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_gradient_71279$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2291$$,$state$jscomp$669$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$669$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2247$colorpicker$$,$APP.$cljs$cst$1730$gradient$$],null),$APP.$cljs$core$merge$$,this.$changes$)});return new $app$main$data$workspace$colors$update_colorpicker_gradient_71279$$($changes$jscomp$230$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$common$toggle_toolbar_visibility$$=function(){typeof $app$main$data$workspace$common$toggle_toolbar_visibility_67523$$==="undefined"&&($app$main$data$workspace$common$toggle_toolbar_visibility_67523$$=function($meta67524$$){this.$meta67524$=$meta67524$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$common$toggle_toolbar_visibility_67523$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$common$toggle_toolbar_visibility_67523$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3805$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_toggle_toolbar_visibility$$},$app$main$data$workspace$common$toggle_toolbar_visibility_67523$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67525$$,$meta67524__$1$$){return new $app$main$data$workspace$common$toggle_toolbar_visibility_67523$$($meta67524__$1$$)},$app$main$data$workspace$common$toggle_toolbar_visibility_67523$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67524$},$app$main$data$workspace$common$toggle_toolbar_visibility_67523$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$common$toggle_toolbar_visibility_67523$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2007$$,$state$jscomp$428$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$428$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$3803$hide_toolbar$$],null),$APP.$cljs$core$not$$)});return new $app$main$data$workspace$common$toggle_toolbar_visibility_67523$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$modal$update_props$$=function($props$jscomp$86$$){typeof $app$main$data$modal$update_modal_props_51549$$==="undefined"&&($app$main$data$modal$update_modal_props_51549$$=function($_type$jscomp$1$$,$props$jscomp$87$$,$meta51550$$){this.$_type$=$_type$jscomp$1$$;this.props=$props$jscomp$87$$;this.$meta51550$=$meta51550$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$modal$update_modal_props_51549$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$update_modal_props_51549$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$2351$app_DOT_main_DOT_data_DOT_modal_SLASH_update_modal_props$$},$app$main$data$modal$update_modal_props_51549$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_51551$$,$meta51550__$1$$){return new $app$main$data$modal$update_modal_props_51549$$(this.$_type$,this.props,$meta51550__$1$$)},$app$main$data$modal$update_modal_props_51549$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta51550$},$app$main$data$modal$update_modal_props_51549$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$modal$update_modal_props_51549$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1428$$,$state$jscomp$105$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2349$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$105$$))?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$105$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2349$app_DOT_main_DOT_data_DOT_modal_SLASH_modal$$,$APP.$cljs$cst$575$props$$],null),$APP.$cljs$core$merge$$,this.props):$state$jscomp$105$$});return new $app$main$data$modal$update_modal_props_51549$$($APP.$cljs$cst$2247$colorpicker$$,$props$jscomp$86$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$clear_tokens_paths$$=function(){typeof $app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$=function($meta72947$$){this.$meta72947$=$meta72947$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4774$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_tokens_paths$$},$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72948$$,$meta72947__$1$$){return new $app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$($meta72947__$1$$)},
$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72947$},$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2679$$,$state$jscomp$984$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$984$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$4775$folded_token_paths$$],null),$APP.$cljs$core$PersistentVector$EMPTY$$)});return new $app$main$data$workspace$tokens$library_edit$clear_tokens_paths_72946$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_clipboard_style$$=function($style$jscomp$47$$){typeof $app$main$data$workspace$set_clipboard_style_72295$$==="undefined"&&($app$main$data$workspace$set_clipboard_style_72295$$=function($style$jscomp$48$$,$meta72296$$){this.style=$style$jscomp$48$$;this.$meta72296$=$meta72296$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_clipboard_style_72295$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$set_clipboard_style_72295$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4600$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_clipboard_style$$},$app$main$data$workspace$set_clipboard_style_72295$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72297$$,$meta72296__$1$$){return new $app$main$data$workspace$set_clipboard_style_72295$$(this.style,$meta72296__$1$$)},$app$main$data$workspace$set_clipboard_style_72295$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72296$},$app$main$data$workspace$set_clipboard_style_72295$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_clipboard_style_72295$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2623$$,$state$jscomp$949$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$949$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,
$APP.$cljs$cst$2233$clipboard_style$$],null),this.style)});return new $app$main$data$workspace$set_clipboard_style_72295$$($style$jscomp$47$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_annotations_expanded$$=function($expanded$jscomp$4$$){typeof $app$main$data$workspace$set_annotations_expanded_72270$$==="undefined"&&($app$main$data$workspace$set_annotations_expanded_72270$$=function($expanded$jscomp$5$$,$meta72271$$){this.$expanded$=$expanded$jscomp$5$$;this.$meta72271$=$meta72271$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_annotations_expanded_72270$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_expanded_72270$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4593$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_annotations_expanded$$},$app$main$data$workspace$set_annotations_expanded_72270$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72272$$,$meta72271__$1$$){return new $app$main$data$workspace$set_annotations_expanded_72270$$(this.$expanded$,$meta72271__$1$$)},$app$main$data$workspace$set_annotations_expanded_72270$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72271$},$app$main$data$workspace$set_annotations_expanded_72270$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_expanded_72270$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2617$$,$state$jscomp$944$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$944$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4594$workspace_annotations$$,
$APP.$cljs$cst$3600$expanded$$],null),this.$expanded$)});return new $app$main$data$workspace$set_annotations_expanded_72270$$($expanded$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$start_rename_page_item$$=function($id$jscomp$759$$){typeof $app$main$data$workspace$start_rename_page_item_72261$$==="undefined"&&($app$main$data$workspace$start_rename_page_item_72261$$=function($id$jscomp$760$$,$meta72262$$){this.id=$id$jscomp$760$$;this.$meta72262$=$meta72262$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$start_rename_page_item_72261$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$start_rename_page_item_72261$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4590$app_DOT_main_DOT_data_DOT_workspace_SLASH_start_rename_page_item$$},$app$main$data$workspace$start_rename_page_item_72261$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72263$$,$meta72262__$1$$){return new $app$main$data$workspace$start_rename_page_item_72261$$(this.id,$meta72262__$1$$)},$app$main$data$workspace$start_rename_page_item_72261$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72262$},$app$main$data$workspace$start_rename_page_item_72261$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$start_rename_page_item_72261$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2614$$,$state$jscomp$941$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$941$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,
$APP.$cljs$cst$2215$page_item$$],null),this.id)});return new $app$main$data$workspace$start_rename_page_item_72261$$($id$jscomp$759$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_margins_selected$$=function($margins_selected$$){typeof $app$main$data$workspace$set_margins_selected_72228$$==="undefined"&&($app$main$data$workspace$set_margins_selected_72228$$=function($margins_selected$jscomp$1$$,$meta72229$$){this.$margins_selected$=$margins_selected$jscomp$1$$;this.$meta72229$=$meta72229$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_margins_selected_72228$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_margins_selected_72228$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4588$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_margins_selected$$},$app$main$data$workspace$set_margins_selected_72228$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72230$$,$meta72229__$1$$){return new $app$main$data$workspace$set_margins_selected_72228$$(this.$margins_selected$,$meta72229__$1$$)},$app$main$data$workspace$set_margins_selected_72228$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72229$},$app$main$data$workspace$set_margins_selected_72228$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_margins_selected_72228$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2612$$,$state$jscomp$937$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$937$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,
$APP.$cljs$cst$2228$margins_selected$$],null),this.$margins_selected$)});return new $app$main$data$workspace$set_margins_selected_72228$$($margins_selected$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_gap_selected$$=function($gap_selected$$){typeof $app$main$data$workspace$set_gap_selected_72225$$==="undefined"&&($app$main$data$workspace$set_gap_selected_72225$$=function($gap_selected$jscomp$1$$,$meta72226$$){this.$gap_selected$=$gap_selected$jscomp$1$$;this.$meta72226$=$meta72226$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_gap_selected_72225$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$set_gap_selected_72225$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4587$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_gap_selected$$},$app$main$data$workspace$set_gap_selected_72225$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72227$$,$meta72226__$1$$){return new $app$main$data$workspace$set_gap_selected_72225$$(this.$gap_selected$,$meta72226__$1$$)},$app$main$data$workspace$set_gap_selected_72225$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72226$},$app$main$data$workspace$set_gap_selected_72225$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_gap_selected_72225$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2611$$,$state$jscomp$936$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$936$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$2227$gap_selected$$],
null),this.$gap_selected$)});return new $app$main$data$workspace$set_gap_selected_72225$$($gap_selected$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_paddings_selected$$=function($paddings_selected$$){typeof $app$main$data$workspace$set_paddings_selected_72222$$==="undefined"&&($app$main$data$workspace$set_paddings_selected_72222$$=function($paddings_selected$jscomp$1$$,$meta72223$$){this.$paddings_selected$=$paddings_selected$jscomp$1$$;this.$meta72223$=$meta72223$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_paddings_selected_72222$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_paddings_selected_72222$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4586$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_paddings_selected$$},$app$main$data$workspace$set_paddings_selected_72222$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72224$$,$meta72223__$1$$){return new $app$main$data$workspace$set_paddings_selected_72222$$(this.$paddings_selected$,$meta72223__$1$$)},$app$main$data$workspace$set_paddings_selected_72222$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72223$},$app$main$data$workspace$set_paddings_selected_72222$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_paddings_selected_72222$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2610$$,$state$jscomp$935$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$935$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,
$APP.$cljs$cst$2226$paddings_selected$$],null),this.$paddings_selected$)});return new $app$main$data$workspace$set_paddings_selected_72222$$($paddings_selected$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$show_guide_context_menu$$=function($p__72165$$){var $map__72166__$1$$=$APP.$cljs$core$__destructure_map$$($p__72165$$),$position$jscomp$169$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72166__$1$$,$APP.$cljs$cst$1681$position$$),$guide$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72166__$1$$,$APP.$cljs$cst$3916$guide$$);typeof $app$main$data$workspace$show_guide_context_menu_72167$$==="undefined"&&($app$main$data$workspace$show_guide_context_menu_72167$$=
function($p__72165$jscomp$1$$,$map__72166$jscomp$1$$,$params$jscomp$307$$,$position$jscomp$170$$,$guide$jscomp$11$$,$meta72168$$){this.$p__72165$=$p__72165$jscomp$1$$;this.$map__72166$=$map__72166$jscomp$1$$;this.params=$params$jscomp$307$$;this.position=$position$jscomp$170$$;this.guide=$guide$jscomp$11$$;this.$meta72168$=$meta72168$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_guide_context_menu_72167$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_guide_context_menu_72167$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4581$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_guide_context_menu$$},$app$main$data$workspace$show_guide_context_menu_72167$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72169$$,$meta72168__$1$$){return new $app$main$data$workspace$show_guide_context_menu_72167$$(this.$p__72165$,this.$map__72166$,this.params,
this.position,this.guide,$meta72168__$1$$)},$app$main$data$workspace$show_guide_context_menu_72167$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72168$},$app$main$data$workspace$show_guide_context_menu_72167$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_guide_context_menu_72167$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,
$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$3916$guide$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3916$guide$$,this.guide]))))});return new $app$main$data$workspace$show_guide_context_menu_72167$$($p__72165$$,$map__72166__$1$$,$map__72166__$1$$,$position$jscomp$169$$,$guide$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$show_page_item_context_menu$$=function($p__72149$$){var $map__72150__$1$$=$APP.$cljs$core$__destructure_map$$($p__72149$$),$position$jscomp$167$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72150__$1$$,$APP.$cljs$cst$1681$position$$),$page$jscomp$104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72150__$1$$,$APP.$cljs$cst$1629$page$$);typeof $app$main$data$workspace$show_page_item_context_menu_72151$$==="undefined"&&($app$main$data$workspace$show_page_item_context_menu_72151$$=
function($p__72149$jscomp$1$$,$map__72150$jscomp$1$$,$params$jscomp$301$$,$position$jscomp$168$$,$page$jscomp$105$$,$meta72152$$){this.$p__72149$=$p__72149$jscomp$1$$;this.$map__72150$=$map__72150$jscomp$1$$;this.params=$params$jscomp$301$$;this.position=$position$jscomp$168$$;this.page=$page$jscomp$105$$;this.$meta72152$=$meta72152$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_page_item_context_menu_72151$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_page_item_context_menu_72151$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4576$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_page_item_context_menu$$},$app$main$data$workspace$show_page_item_context_menu_72151$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72153$$,$meta72152__$1$$){return new $app$main$data$workspace$show_page_item_context_menu_72151$$(this.$p__72149$,this.$map__72150$,
this.params,this.position,this.page,$meta72152__$1$$)},$app$main$data$workspace$show_page_item_context_menu_72151$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72152$},$app$main$data$workspace$show_page_item_context_menu_72151$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_page_item_context_menu_72151$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,
$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$1629$page$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1938$selected$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.page)]))))});return new $app$main$data$workspace$show_page_item_context_menu_72151$$($p__72149$$,$map__72150__$1$$,$map__72150__$1$$,$position$jscomp$167$$,$page$jscomp$104$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_assets_group_open$$=function($file_id$jscomp$285$$,$section$jscomp$15$$,$path$jscomp$244$$,$open_QMARK_$jscomp$6$$){typeof $app$main$data$workspace$set_assets_group_open_72101$$==="undefined"&&($app$main$data$workspace$set_assets_group_open_72101$$=function($file_id$jscomp$286$$,$section$jscomp$16$$,$path$jscomp$245$$,$open_QMARK_$jscomp$7$$,$meta72102$$){this.$file_id$=$file_id$jscomp$286$$;this.section=$section$jscomp$16$$;this.path=$path$jscomp$245$$;this.$open_QMARK_$=
$open_QMARK_$jscomp$7$$;this.$meta72102$=$meta72102$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_assets_group_open_72101$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_assets_group_open_72101$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4566$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_assets_group_open$$},$app$main$data$workspace$set_assets_group_open_72101$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72103$$,$meta72102__$1$$){return new $app$main$data$workspace$set_assets_group_open_72101$$(this.$file_id$,this.section,this.path,this.$open_QMARK_$,$meta72102__$1$$)},$app$main$data$workspace$set_assets_group_open_72101$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72102$},$app$main$data$workspace$set_assets_group_open_72101$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_assets_group_open_72101$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2593$$,$state$jscomp$921$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$921$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$4564$open_status$$,this.$file_id$,$APP.$cljs$cst$4449$groups$$,this.section,this.path],null),this.$open_QMARK_$)});return new $app$main$data$workspace$set_assets_group_open_72101$$($file_id$jscomp$285$$,$section$jscomp$15$$,$path$jscomp$244$$,$open_QMARK_$jscomp$6$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_assets_section_open$$=function($file_id$jscomp$283$$,$section$jscomp$13$$,$open_QMARK_$jscomp$4$$){typeof $app$main$data$workspace$set_assets_section_open_72090$$==="undefined"&&($app$main$data$workspace$set_assets_section_open_72090$$=function($file_id$jscomp$284$$,$section$jscomp$14$$,$open_QMARK_$jscomp$5$$,$meta72091$$){this.$file_id$=$file_id$jscomp$284$$;this.section=$section$jscomp$14$$;this.$open_QMARK_$=$open_QMARK_$jscomp$5$$;this.$meta72091$=$meta72091$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_assets_section_open_72090$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_assets_section_open_72090$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4562$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_assets_section_open$$},$app$main$data$workspace$set_assets_section_open_72090$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72092$$,
$meta72091__$1$$){return new $app$main$data$workspace$set_assets_section_open_72090$$(this.$file_id$,this.section,this.$open_QMARK_$,$meta72091__$1$$)},$app$main$data$workspace$set_assets_section_open_72090$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72091$},$app$main$data$workspace$set_assets_section_open_72090$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_assets_section_open_72090$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2591$$,$state$jscomp$919$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$919$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$4564$open_status$$,this.$file_id$,this.section],null),this.$open_QMARK_$)});return new $app$main$data$workspace$set_assets_section_open_72090$$($file_id$jscomp$283$$,$section$jscomp$13$$,$open_QMARK_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$workspace_focus_lost$$=function(){typeof $app$main$data$workspace$workspace_focus_lost_72081$$==="undefined"&&($app$main$data$workspace$workspace_focus_lost_72081$$=function($meta72082$$){this.$meta72082$=$meta72082$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$workspace_focus_lost_72081$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$workspace_focus_lost_72081$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4560$app_DOT_main_DOT_data_DOT_workspace_SLASH_workspace_focus_lost$$},$app$main$data$workspace$workspace_focus_lost_72081$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72083$$,$meta72082__$1$$){return new $app$main$data$workspace$workspace_focus_lost_72081$$($meta72082__$1$$)},$app$main$data$workspace$workspace_focus_lost_72081$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72082$},$app$main$data$workspace$workspace_focus_lost_72081$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$workspace_focus_lost_72081$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2590$$,$state$jscomp$918$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$918$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$4561$show_distances_QMARK_$$],null),!1)});return new $app$main$data$workspace$workspace_focus_lost_72081$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$update_area_selection$$=function($rect$jscomp$42$$){typeof $app$main$data$workspace$path$selection$update_area_selection_69964$$==="undefined"&&($app$main$data$workspace$path$selection$update_area_selection_69964$$=function($rect$jscomp$43$$,$meta69965$$){this.rect=$rect$jscomp$43$$;this.$meta69965$=$meta69965$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$update_area_selection_69964$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$update_area_selection_69964$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4311$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_update_area_selection$$},$app$main$data$workspace$path$selection$update_area_selection_69964$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69966$$,$meta69965__$1$$){return new $app$main$data$workspace$path$selection$update_area_selection_69964$$(this.rect,
$meta69965__$1$$)},$app$main$data$workspace$path$selection$update_area_selection_69964$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69965$},$app$main$data$workspace$path$selection$update_area_selection_69964$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$update_area_selection_69964$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2344$$,$state$jscomp$726$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$726$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1610$selrect$$],null),this.rect)});return new $app$main$data$workspace$path$selection$update_area_selection_69964$$($rect$jscomp$42$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$reset_last_handler$$=function(){typeof $app$main$data$workspace$path$drawing$reset_last_handler_70176$$==="undefined"&&($app$main$data$workspace$path$drawing$reset_last_handler_70176$$=function($meta70177$$){this.$meta70177$=$meta70177$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$reset_last_handler_70176$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$drawing$reset_last_handler_70176$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4299$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_reset_last_handler$$},$app$main$data$workspace$path$drawing$reset_last_handler_70176$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70178$$,$meta70177__$1$$){return new $app$main$data$workspace$path$drawing$reset_last_handler_70176$$($meta70177__$1$$)},$app$main$data$workspace$path$drawing$reset_last_handler_70176$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70177$},$app$main$data$workspace$path$drawing$reset_last_handler_70176$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$reset_last_handler_70176$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2335_id$jscomp$680$$,$state$jscomp$717$$){$_$jscomp$2335_id$jscomp$680$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$717$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$717$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2335_id$jscomp$680$$,$APP.$cljs$cst$3607$prev_handler$$],null),null)});return new $app$main$data$workspace$path$drawing$reset_last_handler_70176$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$pick_color_select$$=function($shift_QMARK_$jscomp$10$$){typeof $app$main$data$workspace$colors$pick_color_select_70690$$==="undefined"&&($app$main$data$workspace$colors$pick_color_select_70690$$=function($value$jscomp$595$$,$shift_QMARK_$jscomp$11$$,$meta70691$$){this.value=$value$jscomp$595$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$11$$;this.$meta70691$=$meta70691$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$pick_color_select_70690$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$pick_color_select_70690$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4203$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_pick_color_select$$},$app$main$data$workspace$colors$pick_color_select_70690$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70692$$,$meta70691__$1$$){return new $app$main$data$workspace$colors$pick_color_select_70690$$(this.value,this.$shift_QMARK_$,$meta70691__$1$$)},
$app$main$data$workspace$colors$pick_color_select_70690$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70691$},$app$main$data$workspace$colors$pick_color_select_70690$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$pick_color_select_70690$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2252$$,$state$jscomp$638$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$638$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$4199$picked_color_select$$],null),this.value),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$4200$picked_shift_QMARK_$$],null),this.$shift_QMARK_$)});return new $app$main$data$workspace$colors$pick_color_select_70690$$(!0,$shift_QMARK_$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$pick_color$$=function($rgba$jscomp$10$$){typeof $app$main$data$workspace$colors$pick_color_70686$$==="undefined"&&($app$main$data$workspace$colors$pick_color_70686$$=function($rgba$jscomp$11$$,$meta70687$$){this.$rgba$=$rgba$jscomp$11$$;this.$meta70687$=$meta70687$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$pick_color_70686$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$pick_color_70686$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4201$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_pick_color$$},$app$main$data$workspace$colors$pick_color_70686$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70688$$,$meta70687__$1$$){return new $app$main$data$workspace$colors$pick_color_70686$$(this.$rgba$,$meta70687__$1$$)},$app$main$data$workspace$colors$pick_color_70686$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70687$},$app$main$data$workspace$colors$pick_color_70686$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$pick_color_70686$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2251$$,$state$jscomp$637$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$637$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,
$APP.$cljs$cst$4202$picked_color$$],null),this.$rgba$)});return new $app$main$data$workspace$colors$pick_color_70686$$($rgba$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$update_selrect$$=function($selrect$jscomp$43$$){typeof $app$main$data$workspace$selection$update_selrect_67246$$==="undefined"&&($app$main$data$workspace$selection$update_selrect_67246$$=function($selrect$jscomp$44$$,$meta67247$$){this.selrect=$selrect$jscomp$44$$;this.$meta67247$=$meta67247$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$update_selrect_67246$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$update_selrect_67246$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3641$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_update_selrect$$},$app$main$data$workspace$selection$update_selrect_67246$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67248$$,$meta67247__$1$$){return new $app$main$data$workspace$selection$update_selrect_67246$$(this.selrect,$meta67247__$1$$)},$app$main$data$workspace$selection$update_selrect_67246$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67247$},$app$main$data$workspace$selection$update_selrect_67246$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$update_selrect_67246$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1927$$,$state$jscomp$363$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$363$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,
$APP.$cljs$cst$1610$selrect$$],null),this.selrect)});return new $app$main$data$workspace$selection$update_selrect_67246$$($selrect$jscomp$43$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_layers_search_scope$$=function($scope$jscomp$8$$){typeof $app$main$data$workspace$update_layers_search_scope_72314$$==="undefined"&&($app$main$data$workspace$update_layers_search_scope_72314$$=function($scope$jscomp$9$$,$meta72315$$){this.scope=$scope$jscomp$9$$;this.$meta72315$=$meta72315$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$update_layers_search_scope_72314$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_layers_search_scope_72314$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4607$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_layers_search_scope$$},$app$main$data$workspace$update_layers_search_scope_72314$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72316$$,$meta72315__$1$$){return new $app$main$data$workspace$update_layers_search_scope_72314$$(this.scope,$meta72315__$1$$)},
$app$main$data$workspace$update_layers_search_scope_72314$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72315$},$app$main$data$workspace$update_layers_search_scope_72314$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_layers_search_scope_72314$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2626$$,$state$jscomp$952$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$952$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4605$layers_search$$],null)))?$APP.$cljs$core$assoc_in$$($state$jscomp$952$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4605$layers_search$$,$APP.$cljs$cst$571$scope$$],null),this.scope):$state$jscomp$952$$});return new $app$main$data$workspace$update_layers_search_scope_72314$$($scope$jscomp$8$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$select_colorpicker_gradient_stop$$=function($index$jscomp$312$$){typeof $app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$==="undefined"&&($app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$=function($index$jscomp$313$$,$meta71287$$){this.index=$index$jscomp$313$$;this.$meta71287$=$meta71287$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4249$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_select_colorpicket_gradient_stop$$},$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71288$$,$meta71287__$1$$){return new $app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$(this.index,
$meta71287__$1$$)},$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71287$},$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2292$$,$state$jscomp$670$$){var $self__$jscomp$5356$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$670$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$40$$){var $temp__5823__auto__$jscomp$181$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$40$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1739$stops$$,$self__$jscomp$5356$$.index],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$181$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state__$1$jscomp$40$$,
$APP.$cljs$cst$4231$current_color$$,$temp__5823__auto__$jscomp$181$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4229$editing_stop$$,$self__$jscomp$5356$$.index])):$state__$1$jscomp$40$$})});return new $app$main$data$workspace$colors$select_colorpicket_gradient_stop_71286$$($index$jscomp$312$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$file$get_base_font_size$$=function($file_data$jscomp$57$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($file_data$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$873$options$$,$APP.$cljs$cst$2587$base_font_size$$],null),"16px")};
$app$main$data$workspace$texts$cursor_to_end$$=function($p__70270$$){var $map__70271__$1$$=$APP.$cljs$core$__destructure_map$$($p__70270$$),$id$jscomp$616$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70271__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$texts$cursor_to_end_70272$$==="undefined"&&($app$main$data$workspace$texts$cursor_to_end_70272$$=function($p__70270$jscomp$1$$,$map__70271$jscomp$1$$,$shape$jscomp$575$$,$id$jscomp$617$$,$meta70273$$){this.$p__70270$=
$p__70270$jscomp$1$$;this.$map__70271$=$map__70271$jscomp$1$$;this.shape=$shape$jscomp$575$$;this.id=$id$jscomp$617$$;this.$meta70273$=$meta70273$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$cursor_to_end_70272$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$cursor_to_end_70272$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4075$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_cursor_to_end$$},
$app$main$data$workspace$texts$cursor_to_end_70272$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70274$$,$meta70273__$1$$){return new $app$main$data$workspace$texts$cursor_to_end_70272$$(this.$p__70270$,this.$map__70271$,this.shape,this.id,$meta70273__$1$$)},$app$main$data$workspace$texts$cursor_to_end_70272$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70273$},$app$main$data$workspace$texts$cursor_to_end_70272$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$cursor_to_end_70272$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2184$$,$state$jscomp$575$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$575$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2230$workspace_editor_state$$,this.id],null),$app$util$text_editor$cursor_to_end$$)});return new $app$main$data$workspace$texts$cursor_to_end_70272$$($p__70270$$,$map__70271__$1$$,
$map__70271__$1$$,$id$jscomp$616$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$select_all$$=function($p__70264$$){var $map__70265__$1$$=$APP.$cljs$core$__destructure_map$$($p__70264$$),$id$jscomp$614$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70265__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$texts$editor_select_all_70266$$==="undefined"&&($app$main$data$workspace$texts$editor_select_all_70266$$=function($p__70264$jscomp$1$$,$map__70265$jscomp$1$$,$shape$jscomp$573$$,$id$jscomp$615$$,$meta70267$$){this.$p__70264$=
$p__70264$jscomp$1$$;this.$map__70265$=$map__70265$jscomp$1$$;this.shape=$shape$jscomp$573$$;this.id=$id$jscomp$615$$;this.$meta70267$=$meta70267$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$editor_select_all_70266$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$editor_select_all_70266$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4074$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_editor_select_all$$},
$app$main$data$workspace$texts$editor_select_all_70266$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70268$$,$meta70267__$1$$){return new $app$main$data$workspace$texts$editor_select_all_70266$$(this.$p__70264$,this.$map__70265$,this.shape,this.id,$meta70267__$1$$)},$app$main$data$workspace$texts$editor_select_all_70266$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70267$},$app$main$data$workspace$texts$editor_select_all_70266$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$editor_select_all_70266$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2183$$,$state$jscomp$574$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$574$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2230$workspace_editor_state$$,this.id],null),$app$util$text_editor$editor_select_all$$)});return new $app$main$data$workspace$texts$editor_select_all_70266$$($p__70264$$,
$map__70265__$1$$,$map__70265__$1$$,$id$jscomp$614$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$helpers$update_file$cljs$0core$0IFn$0_invoke$0arity$03$$=function($state$jscomp$70$$,$file_id$jscomp$7$$,$f$jscomp$774$$){return $APP.$app$common$data$update_in_when$$($state$jscomp$70$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1933$files$$,$file_id$jscomp$7$$],null),$f$jscomp$774$$)};
$clojure$set$superset_QMARK_$$=function($set1$jscomp$1$$,$set2$jscomp$1$$){return $APP.$cljs$core$count$$($set1$jscomp$1$$)>=$APP.$cljs$core$count$$($set2$jscomp$1$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__24295_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($set1$jscomp$1$$,$p1__24295_SHARP_$$)},$set2$jscomp$1$$)};
$app$common$files$tokens$shapes_applied_all_QMARK_$$=function($ids_by_attributes$$,$shape_ids$jscomp$16$$,$attributes$jscomp$19$$){return $APP.$cljs$core$every_QMARK_$$(function($p1__72121_SHARP_$$){return $clojure$set$superset_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($ids_by_attributes$$,$p1__72121_SHARP_$$),$shape_ids$jscomp$16$$)},$attributes$jscomp$19$$)};
$cljs$tools$reader$unquote_QMARK_$$=function($form$jscomp$17$$){return $APP.$cljs$core$seq_QMARK_$$($form$jscomp$17$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($form$jscomp$17$$),$APP.$cljs$cst$234$clojure_DOT_core_SLASH_unquote$$)};$cljs$tools$reader$unquote_splicing_QMARK_$$=function($form$jscomp$16$$){return $APP.$cljs$core$seq_QMARK_$$($form$jscomp$16$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($form$jscomp$16$$),$APP.$cljs$cst$233$clojure_DOT_core_SLASH_unquote_splicing$$)};
$app$main$data$workspace$set_preview_blend_mode$$=function($ids$jscomp$255$$,$blend_mode$jscomp$4$$){typeof $app$main$data$workspace$set_preview_blend_mode_72278$$==="undefined"&&($app$main$data$workspace$set_preview_blend_mode_72278$$=function($ids$jscomp$256$$,$blend_mode$jscomp$5$$,$meta72279$$){this.ids=$ids$jscomp$256$$;this.$blend_mode$=$blend_mode$jscomp$5$$;this.$meta72279$=$meta72279$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_preview_blend_mode_72278$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_preview_blend_mode_72278$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4597$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_preview_blend_mode$$},$app$main$data$workspace$set_preview_blend_mode_72278$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72280$$,$meta72279__$1$$){return new $app$main$data$workspace$set_preview_blend_mode_72278$$(this.ids,this.$blend_mode$,$meta72279__$1$$)},
$app$main$data$workspace$set_preview_blend_mode_72278$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72279$},$app$main$data$workspace$set_preview_blend_mode_72278$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_preview_blend_mode_72278$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2620$$,$state$jscomp$946$$){var $self__$jscomp$6463$$=this;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__72276_SHARP_$$,
$p2__72277_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__72276_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2249$workspace_preview_blend$$,$p2__72277_SHARP_$$],null),$self__$jscomp$6463$$.$blend_mode$)},$state$jscomp$946$$,$self__$jscomp$6463$$.ids)});return new $app$main$data$workspace$set_preview_blend_mode_72278$$($ids$jscomp$255$$,$blend_mode$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$core$js_reserved_QMARK_$$=function($x$jscomp$652$$){$cljs$core$js_reserved$$==null&&($cljs$core$js_reserved$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__24203_SHARP_$$,$p2__24204_SHARP_$$){$p1__24203_SHARP_$$[$p2__24204_SHARP_$$]=!0;return $p1__24203_SHARP_$$},{},$cljs$core$js_reserved_arr$$));return $cljs$core$js_reserved$$.hasOwnProperty($x$jscomp$652$$)};
$app$main$data$workspace$grid_layout$editor$remove_selection$$=function($grid_id$jscomp$7$$,$cell_id$jscomp$7$$){typeof $app$main$data$workspace$grid_layout$editor$remove_selection_71137$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$remove_selection_71137$$=function($grid_id$jscomp$8$$,$cell_id$jscomp$8$$,$meta71138$$){this.$grid_id$=$grid_id$jscomp$8$$;this.$cell_id$=$cell_id$jscomp$8$$;this.$meta71138$=$meta71138$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$grid_layout$editor$remove_selection_71137$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$remove_selection_71137$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4453$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_remove_selection$$},$app$main$data$workspace$grid_layout$editor$remove_selection_71137$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71139$$,$meta71138__$1$$){return new $app$main$data$workspace$grid_layout$editor$remove_selection_71137$$(this.$grid_id$,this.$cell_id$,$meta71138__$1$$)},$app$main$data$workspace$grid_layout$editor$remove_selection_71137$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71138$},$app$main$data$workspace$grid_layout$editor$remove_selection_71137$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$remove_selection_71137$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2477$$,$state$jscomp$828$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$828$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1938$selected$$],null),$APP.$cljs$core$disj$$,this.$cell_id$)});return new $app$main$data$workspace$grid_layout$editor$remove_selection_71137$$($grid_id$jscomp$7$$,$cell_id$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$path_handler_leave$$=function($index$jscomp$327$$,$prefix$jscomp$55$$){typeof $app$main$data$workspace$path$selection$path_handler_leave_69919$$==="undefined"&&($app$main$data$workspace$path$selection$path_handler_leave_69919$$=function($index$jscomp$328$$,$prefix$jscomp$56$$,$meta69920$$){this.index=$index$jscomp$328$$;this.prefix=$prefix$jscomp$56$$;this.$meta69920$=$meta69920$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$selection$path_handler_leave_69919$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_handler_leave_69919$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4306$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_handler_leave$$},$app$main$data$workspace$path$selection$path_handler_leave_69919$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69921$$,
$meta69920__$1$$){return new $app$main$data$workspace$path$selection$path_handler_leave_69919$$(this.index,this.prefix,$meta69920__$1$$)},$app$main$data$workspace$path$selection$path_handler_leave_69919$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69920$},$app$main$data$workspace$path$selection$path_handler_leave_69919$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_handler_leave_69919$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2340_id$jscomp$685$$,$state$jscomp$722$$){$_$jscomp$2340_id$jscomp$685$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$722$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$722$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2340_id$jscomp$685$$,$APP.$cljs$cst$4305$hover_handlers$$],null),$APP.$cljs$core$disj$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.index,this.prefix],null))});return new $app$main$data$workspace$path$selection$path_handler_leave_69919$$($index$jscomp$327$$,$prefix$jscomp$55$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$path_pointer_leave$$=function($position$jscomp$141$$){typeof $app$main$data$workspace$path$selection$path_pointer_leave_69901$$==="undefined"&&($app$main$data$workspace$path$selection$path_pointer_leave_69901$$=function($position$jscomp$142$$,$meta69902$$){this.position=$position$jscomp$142$$;this.$meta69902$=$meta69902$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$path_pointer_leave_69901$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_pointer_leave_69901$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4303$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_pointer_leave$$},$app$main$data$workspace$path$selection$path_pointer_leave_69901$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69903$$,$meta69902__$1$$){return new $app$main$data$workspace$path$selection$path_pointer_leave_69901$$(this.position,
$meta69902__$1$$)},$app$main$data$workspace$path$selection$path_pointer_leave_69901$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69902$},$app$main$data$workspace$path$selection$path_pointer_leave_69901$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_pointer_leave_69901$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2338_id$jscomp$683$$,$state$jscomp$720$$){$_$jscomp$2338_id$jscomp$683$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$720$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$720$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2338_id$jscomp$683$$,$APP.$cljs$cst$4302$hover_points$$],null),$APP.$cljs$core$disj$$,this.position)});return new $app$main$data$workspace$path$selection$path_pointer_leave_69901$$($position$jscomp$141$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$clear_token_set_creation$$=function(){typeof $app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$=function($meta73279$$){this.$meta73279$=$meta73279$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4815$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_token_set_creation$$},$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73280$$,$meta73279__$1$$){return new $app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$($meta73279__$1$$)},
$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73279$},$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2715$$,$state$jscomp$1018$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1018$$,
$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4813$token_set_new_path$$)});return new $app$main$data$workspace$tokens$library_edit$clear_token_set_creation_73278$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$=function($p__73251$$){var $map__73252__$1$$=$APP.$cljs$core$__destructure_map$$($p__73251$$),$position$jscomp$177$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73252__$1$$,$APP.$cljs$cst$1681$position$$);typeof $app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$=function($p__73251$jscomp$1$$,
$map__73252$jscomp$1$$,$params$jscomp$320$$,$position$jscomp$178$$,$meta73254$$){this.$p__73251$=$p__73251$jscomp$1$$;this.$map__73252$=$map__73252$jscomp$1$$;this.params=$params$jscomp$320$$;this.position=$position$jscomp$178$$;this.$meta73254$=$meta73254$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4807$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_assign_token_set_context_menu$$},$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73255$$,$meta73254__$1$$){return new $app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$(this.$p__73251$,
this.$map__73252$,this.params,this.position,$meta73254__$1$$)},$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73254$},$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2710$$,$state$jscomp$1013$$){return $APP.$cljs$core$truth_$$(this.params)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1013$$,$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4808$token_set_context_menu$$,this.params):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1013$$,$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4808$token_set_context_menu$$)});return new $app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu_73253$$($p__73251$$,
$map__73252__$1$$,$map__73252__$1$$,$position$jscomp$177$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$assign_token_node_context_menu$$=function($p__73246$$){var $map__73247__$1$$=$APP.$cljs$core$__destructure_map$$($p__73246$$),$position$jscomp$175$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73247__$1$$,$APP.$cljs$cst$1681$position$$);typeof $app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$=function($p__73246$jscomp$1$$,
$map__73247$jscomp$1$$,$params$jscomp$318$$,$position$jscomp$176$$,$meta73249$$){this.$p__73246$=$p__73246$jscomp$1$$;this.$map__73247$=$map__73247$jscomp$1$$;this.params=$params$jscomp$318$$;this.position=$position$jscomp$176$$;this.$meta73249$=$meta73249$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4805$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_show_token_node_context_menu$$},$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73250$$,$meta73249__$1$$){return new $app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$(this.$p__73246$,
this.$map__73247$,this.params,this.position,$meta73249__$1$$)},$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73249$},$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2709$$,$state$jscomp$1012$$){return $APP.$cljs$core$truth_$$(this.params)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1012$$,$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4806$token_node_context_menu$$,this.params):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1012$$,$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4806$token_node_context_menu$$)});return new $app$main$data$workspace$tokens$library_edit$show_token_node_context_menu_73248$$($p__73246$$,
$map__73247__$1$$,$map__73247__$1$$,$position$jscomp$175$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$=function($p__73241$$){var $map__73242__$1$$=$APP.$cljs$core$__destructure_map$$($p__73241$$),$position$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73242__$1$$,$APP.$cljs$cst$1681$position$$);typeof $app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$=function($p__73241$jscomp$1$$,$map__73242$jscomp$1$$,
$params$jscomp$316$$,$position$jscomp$174$$,$meta73244$$){this.$p__73241$=$p__73241$jscomp$1$$;this.$map__73242$=$map__73242$jscomp$1$$;this.params=$params$jscomp$316$$;this.position=$position$jscomp$174$$;this.$meta73244$=$meta73244$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4804$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_show_token_context_menu$$},$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73245$$,$meta73244__$1$$){return new $app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$(this.$p__73241$,this.$map__73242$,this.params,this.position,$meta73244__$1$$)},$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73244$},$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2708$$,$state$jscomp$1011$$){return $APP.$cljs$core$truth_$$(this.params)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1011$$,$APP.$cljs$cst$2145$workspace_tokens$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2214$token_context_menu$$,this.params):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1011$$,$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2214$token_context_menu$$)});return new $app$main$data$workspace$tokens$library_edit$show_token_context_menu_73243$$($p__73241$$,$map__73242__$1$$,$map__73242__$1$$,$position$jscomp$173$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$unset_preview_blend_mode$$=function($ids$jscomp$257$$){typeof $app$main$data$workspace$unset_preview_blend_mode_72283$$==="undefined"&&($app$main$data$workspace$unset_preview_blend_mode_72283$$=function($ids$jscomp$258$$,$meta72284$$){this.ids=$ids$jscomp$258$$;this.$meta72284$=$meta72284$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$unset_preview_blend_mode_72283$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$unset_preview_blend_mode_72283$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4598$app_DOT_main_DOT_data_DOT_workspace_SLASH_unset_preview_blend_mode$$},$app$main$data$workspace$unset_preview_blend_mode_72283$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72285$$,$meta72284__$1$$){return new $app$main$data$workspace$unset_preview_blend_mode_72283$$(this.ids,$meta72284__$1$$)},$app$main$data$workspace$unset_preview_blend_mode_72283$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72284$},$app$main$data$workspace$unset_preview_blend_mode_72283$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$unset_preview_blend_mode_72283$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2621$$,$state$jscomp$947$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__72281_SHARP_$$,$p2__72282_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__72281_SHARP_$$,
$APP.$cljs$cst$2249$workspace_preview_blend$$,$APP.$cljs$core$dissoc$$,$p2__72282_SHARP_$$)},$state$jscomp$947$$,this.ids)});return new $app$main$data$workspace$unset_preview_blend_mode_72283$$($ids$jscomp$257$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$stop_rename_page_item$$=function(){typeof $app$main$data$workspace$stop_rename_page_item_72264$$==="undefined"&&($app$main$data$workspace$stop_rename_page_item_72264$$=function($meta72265$$){this.$meta72265$=$meta72265$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$stop_rename_page_item_72264$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$stop_rename_page_item_72264$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4591$app_DOT_main_DOT_data_DOT_workspace_SLASH_stop_rename_page_item$$},$app$main$data$workspace$stop_rename_page_item_72264$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72266$$,$meta72265__$1$$){return new $app$main$data$workspace$stop_rename_page_item_72264$$($meta72265__$1$$)},$app$main$data$workspace$stop_rename_page_item_72264$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72265$},$app$main$data$workspace$stop_rename_page_item_72264$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$stop_rename_page_item_72264$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2615_local$jscomp$23$$,$state$jscomp$942$$){$_$jscomp$2615_local$jscomp$23$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1937$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$942$$),$APP.$cljs$cst$2215$page_item$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$942$$,
$APP.$cljs$cst$1937$workspace_local$$,$_$jscomp$2615_local$jscomp$23$$)});return new $app$main$data$workspace$stop_rename_page_item_72264$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$=function($file_id$jscomp$293$$){typeof $app$main$data$workspace$unselect_all_assets_72130$$==="undefined"&&($app$main$data$workspace$unselect_all_assets_72130$$=function($file_id$jscomp$294$$,$meta72131$$){this.$file_id$=$file_id$jscomp$294$$;this.$meta72131$=$meta72131$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$unselect_all_assets_72130$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$unselect_all_assets_72130$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4570$app_DOT_main_DOT_data_DOT_workspace_SLASH_unselect_all_assets$$},$app$main$data$workspace$unselect_all_assets_72130$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72132$$,$meta72131__$1$$){return new $app$main$data$workspace$unselect_all_assets_72130$$(this.$file_id$,$meta72131__$1$$)},$app$main$data$workspace$unselect_all_assets_72130$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72131$},$app$main$data$workspace$unselect_all_assets_72130$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$unselect_all_assets_72130$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2597$$,$state$jscomp$925$$){return $APP.$cljs$core$truth_$$(this.$file_id$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$925$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$1938$selected$$],null),$APP.$cljs$core$dissoc$$,this.$file_id$):$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$925$$,$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1938$selected$$)});return new $app$main$data$workspace$unselect_all_assets_72130$$($file_id$jscomp$293$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing$$=function($grid_id$jscomp$13$$){typeof $app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$=function($grid_id$jscomp$14$$,$meta71161$$){this.$grid_id$=$grid_id$jscomp$14$$;this.$meta71161$=$meta71161$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4456$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_stop_grid_layout_editing$$},$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71162$$,$meta71161__$1$$){return new $app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$(this.$grid_id$,
$meta71161__$1$$)},$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71161$},$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2480$$,$state$jscomp$831$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$831$$,
$APP.$cljs$cst$2248$workspace_grid_edition$$,$APP.$cljs$core$dissoc$$,this.$grid_id$)});return new $app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing_71160$$($grid_id$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$clear_selection$$=function($grid_id$jscomp$9$$){typeof $app$main$data$workspace$grid_layout$editor$clear_selection_71149$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$clear_selection_71149$$=function($grid_id$jscomp$10$$,$meta71150$$){this.$grid_id$=$grid_id$jscomp$10$$;this.$meta71150$=$meta71150$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$clear_selection_71149$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$clear_selection_71149$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4454$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_clear_selection$$},$app$main$data$workspace$grid_layout$editor$clear_selection_71149$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71151$$,$meta71150__$1$$){return new $app$main$data$workspace$grid_layout$editor$clear_selection_71149$$(this.$grid_id$,
$meta71150__$1$$)},$app$main$data$workspace$grid_layout$editor$clear_selection_71149$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71150$},$app$main$data$workspace$grid_layout$editor$clear_selection_71149$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$clear_selection_71149$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2478$$,$state$jscomp$829$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$829$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,this.$grid_id$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1938$selected$$)});return new $app$main$data$workspace$grid_layout$editor$clear_selection_71149$$($grid_id$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$clear_area_selection$$=function(){typeof $app$main$data$workspace$path$selection$clear_area_selection_69973$$==="undefined"&&($app$main$data$workspace$path$selection$clear_area_selection_69973$$=function($meta69974$$){this.$meta69974$=$meta69974$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$clear_area_selection_69973$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$selection$clear_area_selection_69973$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4312$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_clear_area_selection$$},$app$main$data$workspace$path$selection$clear_area_selection_69973$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69975$$,$meta69974__$1$$){return new $app$main$data$workspace$path$selection$clear_area_selection_69973$$($meta69974__$1$$)},$app$main$data$workspace$path$selection$clear_area_selection_69973$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69974$},$app$main$data$workspace$path$selection$clear_area_selection_69973$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$clear_area_selection_69973$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2345$$,$state$jscomp$727$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$727$$,$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1610$selrect$$)});
return new $app$main$data$workspace$path$selection$clear_area_selection_69973$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$close_path_drag_end$$=function(){typeof $app$main$data$workspace$path$drawing$close_path_drag_end_70063$$==="undefined"&&($app$main$data$workspace$path$drawing$close_path_drag_end_70063$$=function($meta70064$$){this.$meta70064$=$meta70064$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$close_path_drag_end_70063$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$path$drawing$close_path_drag_end_70063$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4287$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_close_path_drag_end$$},$app$main$data$workspace$path$drawing$close_path_drag_end_70063$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70065$$,$meta70064__$1$$){return new $app$main$data$workspace$path$drawing$close_path_drag_end_70063$$($meta70064__$1$$)},$app$main$data$workspace$path$drawing$close_path_drag_end_70063$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70064$},$app$main$data$workspace$path$drawing$close_path_drag_end_70063$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$close_path_drag_end_70063$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2321_id$jscomp$674$$,$state$jscomp$703$$){$_$jscomp$2321_id$jscomp$674$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$703$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$703$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2321_id$jscomp$674$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3607$prev_handler$$)});return new $app$main$data$workspace$path$drawing$close_path_drag_end_70063$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$activate_colorpicker_image$$=function(){typeof $app$main$data$workspace$colors$activate_colorpicker_image_71301$$==="undefined"&&($app$main$data$workspace$colors$activate_colorpicker_image_71301$$=function($meta71302$$){this.$meta71302$=$meta71302$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$activate_colorpicker_image_71301$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$activate_colorpicker_image_71301$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4251$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_image$$},$app$main$data$workspace$colors$activate_colorpicker_image_71301$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71303$$,$meta71302__$1$$){return new $app$main$data$workspace$colors$activate_colorpicker_image_71301$$($meta71302__$1$$)},$app$main$data$workspace$colors$activate_colorpicker_image_71301$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71302$},$app$main$data$workspace$colors$activate_colorpicker_image_71301$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_image_71301$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2296$$,$state$jscomp$673$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$673$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$43$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$43$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1617$image$$),$APP.$cljs$cst$4229$editing_stop$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1739$stops$$,$APP.$cljs$cst$1730$gradient$$]))})});return new $app$main$data$workspace$colors$activate_colorpicker_image_71301$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$finalize_colorpicker$$=function(){typeof $app$main$data$workspace$colors$finalize_colorpicker_71228$$==="undefined"&&($app$main$data$workspace$colors$finalize_colorpicker_71228$$=function($meta71229$$){this.$meta71229$=$meta71229$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$finalize_colorpicker_71228$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$finalize_colorpicker_71228$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4238$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_finalize_colorpicker$$},$app$main$data$workspace$colors$finalize_colorpicker_71228$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71230$$,$meta71229__$1$$){return new $app$main$data$workspace$colors$finalize_colorpicker_71228$$($meta71229__$1$$)},$app$main$data$workspace$colors$finalize_colorpicker_71228$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71229$},$app$main$data$workspace$colors$finalize_colorpicker_71228$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$finalize_colorpicker_71228$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2281$$,$state$jscomp$659$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$659$$,$APP.$cljs$cst$2247$colorpicker$$)});return new $app$main$data$workspace$colors$finalize_colorpicker_71228$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$clear_color_components$$=function($data$jscomp$382$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($data$jscomp$382$$,$APP.$cljs$cst$2698$hex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$746$alpha$$,$APP.$cljs$cst$1749$r$$,$APP.$cljs$cst$1750$g$$,$APP.$cljs$cst$1525$b$$,$APP.$cljs$cst$1907$h$$,$APP.$cljs$cst$4235$s$$,$APP.$cljs$cst$3723$v$$,$APP.$cljs$cst$1617$image$$]))};
$app$main$data$workspace$texts$clean_text_modifier$$=function($id$jscomp$635$$){typeof $app$main$data$workspace$texts$clean_text_modifier_70486$$==="undefined"&&($app$main$data$workspace$texts$clean_text_modifier_70486$$=function($id$jscomp$636$$,$meta70487$$){this.id=$id$jscomp$636$$;this.$meta70487$=$meta70487$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$clean_text_modifier_70486$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$clean_text_modifier_70486$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4095$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_clean_text_modifier$$},$app$main$data$workspace$texts$clean_text_modifier_70486$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70488$$,$meta70487__$1$$){return new $app$main$data$workspace$texts$clean_text_modifier_70486$$(this.id,$meta70487__$1$$)},$app$main$data$workspace$texts$clean_text_modifier_70486$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70487$},$app$main$data$workspace$texts$clean_text_modifier_70486$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$clean_text_modifier_70486$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2202$$,$state$jscomp$593$$){var $self__$jscomp$5053$$=this,$current_value$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$593$$,
$APP.$cljs$cst$2246$workspace_text_modifier$$),$self__$jscomp$5053$$.id);return $APP.$beicon$v2$core$delay$$(100,(0,$APP.$beicon$v2$core$of$$)(function($state__$1$jscomp$25$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state__$1$jscomp$25$$,$APP.$cljs$cst$2246$workspace_text_modifier$$),$self__$jscomp$5053$$.id)===$current_value$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$25$$,$APP.$cljs$cst$2246$workspace_text_modifier$$,
$APP.$cljs$core$dissoc$$,$self__$jscomp$5053$$.id):$state__$1$jscomp$25$$}))});return new $app$main$data$workspace$texts$clean_text_modifier_70486$$($id$jscomp$635$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$update_editor$$=function($editor$$){typeof $app$main$data$workspace$texts$update_editor_70204$$==="undefined"&&($app$main$data$workspace$texts$update_editor_70204$$=function($editor$jscomp$1$$,$meta70205$$){this.editor=$editor$jscomp$1$$;this.$meta70205$=$meta70205$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_editor_70204$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$update_editor_70204$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4069$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_editor$$},$app$main$data$workspace$texts$update_editor_70204$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70206$$,$meta70205__$1$$){return new $app$main$data$workspace$texts$update_editor_70204$$(this.editor,$meta70205__$1$$)},$app$main$data$workspace$texts$update_editor_70204$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70205$},$app$main$data$workspace$texts$update_editor_70204$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_editor_70204$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2177$$,$state$jscomp$569$$){return this.editor!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$569$$,$APP.$cljs$cst$2229$workspace_editor$$,this.editor):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$569$$,
$APP.$cljs$cst$2229$workspace_editor$$)});return new $app$main$data$workspace$texts$update_editor_70204$$($editor$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$specialized_panel$clear_specialized_panel$$=function(){typeof $app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$==="undefined"&&($app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$=function($meta67537$$){this.$meta67537$=$meta67537$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3814$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_clear_specialized_panel$$},$app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67538$$,$meta67537__$1$$){return new $app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$($meta67537__$1$$)},
$app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67537$},$app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2016$$,$state$jscomp$436$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$436$$,
$APP.$cljs$cst$2250$specialized_panel$$)});return new $app$main$data$workspace$specialized_panel$clear_specialized_panel_67536$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$project$finalize_project$$=function($project_id$jscomp$9$$){typeof $app$main$data$project$finalize_project_55829$$==="undefined"&&($app$main$data$project$finalize_project_55829$$=function($project_id$jscomp$10$$,$meta55830$$){this.$project_id$=$project_id$jscomp$10$$;this.$meta55830$=$meta55830$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$project$finalize_project_55829$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$project$finalize_project_55829$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3566$app_DOT_main_DOT_data_DOT_project_SLASH_finalize_project$$},$app$main$data$project$finalize_project_55829$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55831$$,$meta55830__$1$$){return new $app$main$data$project$finalize_project_55829$$(this.$project_id$,$meta55830__$1$$)},$app$main$data$project$finalize_project_55829$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55830$},$app$main$data$project$finalize_project_55829$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$project$finalize_project_55829$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1869_project_id_SINGLEQUOTE_$$,$state$jscomp$306$$){$_$jscomp$1869_project_id_SINGLEQUOTE_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$306$$,$APP.$cljs$cst$2182$current_project_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1869_project_id_SINGLEQUOTE_$$,
this.$project_id$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$306$$,$APP.$cljs$cst$2182$current_project_id$$):$state$jscomp$306$$});return new $app$main$data$project$finalize_project_55829$$($project_id$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$discard_persistence_state$$=function(){typeof $app$main$data$persistence$discard_persistence_state_55283$$==="undefined"&&($app$main$data$persistence$discard_persistence_state_55283$$=function($meta55284$$){this.$meta55284$=$meta55284$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$discard_persistence_state_55283$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$discard_persistence_state_55283$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3179$app_DOT_main_DOT_data_DOT_persistence_SLASH_discard_persistence_state$$},$app$main$data$persistence$discard_persistence_state_55283$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55285$$,$meta55284__$1$$){return new $app$main$data$persistence$discard_persistence_state_55283$$($meta55284__$1$$)},$app$main$data$persistence$discard_persistence_state_55283$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55284$},$app$main$data$persistence$discard_persistence_state_55283$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$discard_persistence_state_55283$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1659$$,$state$jscomp$190$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$190$$,$APP.$cljs$cst$2186$persistence$$)});return new $app$main$data$persistence$discard_persistence_state_55283$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_annotations_id_for_create$$=function($id$jscomp$763$$){typeof $app$main$data$workspace$set_annotations_id_for_create_72273$$==="undefined"&&($app$main$data$workspace$set_annotations_id_for_create_72273$$=function($id$jscomp$764$$,$meta72274$$){this.id=$id$jscomp$764$$;this.$meta72274$=$meta72274$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_annotations_id_for_create_72273$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_id_for_create_72273$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4595$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_annotations_id_for_create$$},$app$main$data$workspace$set_annotations_id_for_create_72273$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72275$$,$meta72274__$1$$){return new $app$main$data$workspace$set_annotations_id_for_create_72273$$(this.id,$meta72274__$1$$)},
$app$main$data$workspace$set_annotations_id_for_create_72273$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72274$},$app$main$data$workspace$set_annotations_id_for_create_72273$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_id_for_create_72273$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2618$$,$state$jscomp$945$$){return $APP.$cljs$core$truth_$$(this.id)?$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$945$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4594$workspace_annotations$$,$APP.$cljs$cst$4596$id_for_create$$],null),this.id),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4594$workspace_annotations$$,$APP.$cljs$cst$3600$expanded$$],null),!0):$APP.$app$common$data$dissoc_in$$($state$jscomp$945$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4594$workspace_annotations$$,$APP.$cljs$cst$4596$id_for_create$$],null))},$app$main$data$workspace$set_annotations_id_for_create_72273$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_annotations_id_for_create_72273$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return this.id!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"create-component-annotation"],null))):null});return new $app$main$data$workspace$set_annotations_id_for_create_72273$$($id$jscomp$763$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$measurements$get_edge_points$$=function($p3$jscomp$23_points$jscomp$101$$,$G__75311__$1_edge$$){var $p0$jscomp$21$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$23_points$jscomp$101$$,0,null),$p1$jscomp$82$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$23_points$jscomp$101$$,1,null),$p2$jscomp$63$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$23_points$jscomp$101$$,2,null);$p3$jscomp$23_points$jscomp$101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p3$jscomp$23_points$jscomp$101$$,
3,null);$G__75311__$1_edge$$=$G__75311__$1_edge$$ instanceof $APP.$cljs$core$Keyword$$?$G__75311__$1_edge$$.$fqn$:null;switch($G__75311__$1_edge$$){case "bottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p2$jscomp$63$$,$p3$jscomp$23_points$jscomp$101$$],null);case "right":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1$jscomp$82$$,$p2$jscomp$63$$],null);case "top":return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p0$jscomp$21$$,$p1$jscomp$82$$],null);case "left":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p3$jscomp$23_points$jscomp$101$$,$p0$jscomp$21$$],null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75311__$1_edge$$)].join(""));}};
$app$util$text$content$to_dom$set_dataset$$=function($element$jscomp$66$$,$G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$){$G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$=$APP.$cljs$core$seq$$($G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$);for(var $c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$=null,$G__53649_count__53497$$=0,$i__53498$$=0;;)if($i__53498$$<$G__53649_count__53497$$){var $data_value_vec__53508$$=
$c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__53498$$),$G__53648_data_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data_value_vec__53508$$,0,null);$data_value_vec__53508$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($data_value_vec__53508$$,1,null);$APP.$app$util$dom$set_data_BANG_$$($element$jscomp$66$$,$APP.$cljs$core$name$$($G__53648_data_name$$),$data_value_vec__53508$$);$i__53498$$+=1}else if($G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$=
$APP.$cljs$core$seq$$($G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$)?($c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$=$APP.$cljs$core$_chunked_first$$($G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$),$G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$=$APP.$cljs$core$_chunked_rest$$($G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$),
$G__53648_data_name$$=$c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$,$G__53649_count__53497$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$),$c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$=$G__53648_data_name$$):($c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$=$APP.$cljs$core$first$$($G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$),$G__53648_data_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$,
0,null),$data_value_vec__53508$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$,1,null),$APP.$app$util$dom$set_data_BANG_$$($element$jscomp$66$$,$APP.$cljs$core$name$$($G__53648_data_name$$),$data_value_vec__53508$$),$G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$=$APP.$cljs$core$next$$($G__53647_data$jscomp$255_seq__53495_seq__53495__$1_temp__5825__auto__$jscomp$166$$),$c__5548__auto__$jscomp$16_chunk__53496_vec__53512$$=
null,$G__53649_count__53497$$=0),$i__53498$$=0;else break};
$app$main$ui$hooks$use_rxsub$$=function(){var $vec__52683$$=(0,$APP.$rumext$v2$useState$$)(function(){return($APP.$app$main$streams$mouse_position$$!=null?$APP.$app$main$streams$mouse_position$$.$cljs$lang$protocol_mask$partition0$$&32768||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$APP.$app$main$streams$mouse_position$$.$cljs$core$IDeref$$||($APP.$app$main$streams$mouse_position$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,$APP.$app$main$streams$mouse_position$$)):
$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IDeref$$,$APP.$app$main$streams$mouse_position$$))?$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$):null}),$state$jscomp$150$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52683$$,0,null),$reset_state_BANG_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__52683$$,1,null);(0,$APP.$rumext$v2$useEffect$$)(function(){var $sub$jscomp$12$$=$APP.$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$streams$mouse_position$$,
function($p1__52682_SHARP_$$){return $reset_state_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$reset_state_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($p1__52682_SHARP_$$):$reset_state_BANG_$$($p1__52682_SHARP_$$)});return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$12$$)}},[$APP.$app$main$streams$mouse_position$$]);return $state$jscomp$150$$};
$app$common$geom$shapes$intersect$intersects_line_ellipse_QMARK_$$=function($b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$,$a$jscomp$364_map__48931__$1_p__48925$$){var $determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$,0,null),$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$=$APP.$cljs$core$__destructure_map$$($determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$);$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$,$APP.$cljs$cst$1515$x$$);$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$,$APP.$cljs$cst$1516$y$$);$b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$,1,null);var $map__48930__$1_y2$jscomp$32$$=
$APP.$cljs$core$__destructure_map$$($b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$);$b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48930__$1_y2$jscomp$32$$,$APP.$cljs$cst$1515$x$$);$map__48930__$1_y2$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48930__$1_y2$jscomp$32$$,$APP.$cljs$cst$1516$y$$);$a$jscomp$364_map__48931__$1_p__48925$$=$APP.$cljs$core$__destructure_map$$($a$jscomp$364_map__48931__$1_p__48925$$);
var $cx$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$364_map__48931__$1_p__48925$$,$APP.$cljs$cst$1905$cx$$),$cy$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$364_map__48931__$1_p__48925$$,$APP.$cljs$cst$1906$cy$$),$rx$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$364_map__48931__$1_p__48925$$,$APP.$cljs$cst$1889$rx$$),$ry$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$364_map__48931__$1_p__48925$$,
$APP.$cljs$cst$1890$ry$$);$a$jscomp$364_map__48931__$1_p__48925$$=$app$common$math$sq$$($b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$-$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$)/($rx$jscomp$13$$*$rx$jscomp$13$$)+$app$common$math$sq$$($map__48930__$1_y2$jscomp$32$$-$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$)/($ry$jscomp$7$$*$ry$jscomp$7$$);$b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$=(2*$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$*($b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$-
$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$)-2*$cx$jscomp$11$$*($b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$-$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$))/($rx$jscomp$13$$*$rx$jscomp$13$$)+(2*$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$*($map__48930__$1_y2$jscomp$32$$-$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$)-2*$cy$jscomp$12$$*($map__48930__$1_y2$jscomp$32$$-$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$))/($ry$jscomp$7$$*$ry$jscomp$7$$);
$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$=($determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$*$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$+$cx$jscomp$11$$*$cx$jscomp$11$$+-2*$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$*$cx$jscomp$11$$)/($rx$jscomp$13$$*$rx$jscomp$13$$)+($c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$*$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$+$cy$jscomp$12$$*$cy$jscomp$12$$+-2*$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$*
$cy$jscomp$12$$)/($ry$jscomp$7$$*$ry$jscomp$7$$)+-1;$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=$b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$*$b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$-4*$a$jscomp$364_map__48931__$1_p__48925$$*$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$;if($APP.$app$common$math$almost_zero_QMARK_$$($a$jscomp$364_map__48931__$1_p__48925$$)){if($APP.$app$common$math$almost_zero_QMARK_$$($b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$))return null;
$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=-$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$/$b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$;return $determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$>=0&&$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$<=1}return $determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$>=0?($c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$=(-$b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$+Math.sqrt($determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$))/
(2*$a$jscomp$364_map__48931__$1_p__48925$$),$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$=(-$b$jscomp$296_map__48930_p__48924_x2$jscomp$30$$-Math.sqrt($determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$))/(2*$a$jscomp$364_map__48931__$1_p__48925$$),$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$>=0&&$c$jscomp$278_map__48929__$1_t1$jscomp$9_y1$jscomp$34$$<=1||$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$>=0&&$determ_map__48929_t$jscomp$87_t2$jscomp$10_x1$jscomp$32$$<=
1):null};
$app$common$types$color$hsl__GT_rgb$$=function($l$jscomp$96_p__45449_temp1$$){var $h$jscomp$143_norm_h$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l$jscomp$96_p__45449_temp1$$,0,null),$o$jscomp$238_s$jscomp$515_temp2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l$jscomp$96_p__45449_temp1$$,1,null);$l$jscomp$96_p__45449_temp1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l$jscomp$96_p__45449_temp1$$,2,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o$jscomp$238_s$jscomp$515_temp2$$,0))return $o$jscomp$238_s$jscomp$515_temp2$$=
$l$jscomp$96_p__45449_temp1$$*255,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$o$jscomp$238_s$jscomp$515_temp2$$,$o$jscomp$238_s$jscomp$515_temp2$$,$o$jscomp$238_s$jscomp$515_temp2$$],null);$h$jscomp$143_norm_h$$/=360;$o$jscomp$238_s$jscomp$515_temp2$$=$l$jscomp$96_p__45449_temp1$$<.5?$l$jscomp$96_p__45449_temp1$$*(1+$o$jscomp$238_s$jscomp$515_temp2$$):$l$jscomp$96_p__45449_temp1$$+$o$jscomp$238_s$jscomp$515_temp2$$-$o$jscomp$238_s$jscomp$515_temp2$$*
$l$jscomp$96_p__45449_temp1$$;$l$jscomp$96_p__45449_temp1$$=$l$jscomp$96_p__45449_temp1$$*2-$o$jscomp$238_s$jscomp$515_temp2$$;return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(255*$app$common$types$color$hue__GT_rgb$$($l$jscomp$96_p__45449_temp1$$,$o$jscomp$238_s$jscomp$515_temp2$$,$h$jscomp$143_norm_h$$+1/3)),$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(255*$app$common$types$color$hue__GT_rgb$$($l$jscomp$96_p__45449_temp1$$,
$o$jscomp$238_s$jscomp$515_temp2$$,$h$jscomp$143_norm_h$$)),$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$(255*$app$common$types$color$hue__GT_rgb$$($l$jscomp$96_p__45449_temp1$$,$o$jscomp$238_s$jscomp$515_temp2$$,$h$jscomp$143_norm_h$$-1/3))],null)};
$app$common$types$color$hex__GT_hsv$$=function($JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$){$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$=$APP.$app$common$types$color$hex__GT_rgb$$($JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$);var $hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$,
0,null),$green$jscomp$inline_8237$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$,1,null),$blue$jscomp$inline_8238$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$,2,null);$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$=
$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$3$($hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$,$green$jscomp$inline_8237$$,$blue$jscomp$inline_8238$$);var $min$jscomp$inline_8240_sat$jscomp$inline_8242$$=$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$3$($hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$,$green$jscomp$inline_8237$$,$blue$jscomp$inline_8238$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($min$jscomp$inline_8240_sat$jscomp$inline_8242$$,
$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$))$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$],null);else{var $delta$jscomp$inline_8241$$=$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$-
$min$jscomp$inline_8240_sat$jscomp$inline_8242$$;$min$jscomp$inline_8240_sat$jscomp$inline_8242$$=$delta$jscomp$inline_8241$$/$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$;$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$=60*($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$,$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$)?
($green$jscomp$inline_8237$$-$blue$jscomp$inline_8238$$)/$delta$jscomp$inline_8241$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($green$jscomp$inline_8237$$,$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$)?2+($blue$jscomp$inline_8238$$-$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$)/$delta$jscomp$inline_8241$$:4+($hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$-$green$jscomp$inline_8237$$)/
$delta$jscomp$inline_8241$$);$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$=$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$<0?$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$+360:$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$;$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$>360?$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$-360:$hue__$1$jscomp$inline_8243_hue__$2$jscomp$inline_8244_red$jscomp$inline_8236$$,$min$jscomp$inline_8240_sat$jscomp$inline_8242$$,$JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$],null)}return $JSCompiler_inline_result$jscomp$1525_max$jscomp$inline_8239_p__45358$jscomp$inline_8235_v$jscomp$508$$};
$app$common$types$color$sort_colors$$=function($a$jscomp$348_ah$jscomp$1$$,$b$jscomp$279_bh$jscomp$1$$){var $av_vec__45552$$=$app$common$types$color$hex__GT_hsv$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$348_ah$jscomp$1$$));$a$jscomp$348_ah$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($av_vec__45552$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($av_vec__45552$$,1,null);$av_vec__45552$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($av_vec__45552$$,
2,null);var $bv_vec__45555$$=$app$common$types$color$hex__GT_hsv$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$279_bh$jscomp$1$$));$b$jscomp$279_bh$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bv_vec__45555$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bv_vec__45555$$,1,null);$bv_vec__45555$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bv_vec__45555$$,2,null);return $APP.$cljs$core$compare$$($APP.$app$common$math$floor$$($a$jscomp$348_ah$jscomp$1$$/
60*8)/8*100+$av_vec__45552$$/255*10,$APP.$app$common$math$floor$$($b$jscomp$279_bh$jscomp$1$$/60*8)/8*100+$bv_vec__45555$$/255*10)};
$rumext$v2$use_debounce$$=function($value$jscomp$387$$){var $vec__44941$$=(0,$APP.$rumext$v2$useState$$)($value$jscomp$387$$),$state$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__44941$$,0,null),$update_fn$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__44941$$,1,null),$update_fn__$1$$=(0,$APP.$rumext$v2$useMemo$$)(function(){return $APP.$goog$functions$debounce$$($update_fn$jscomp$3$$,100)},[100]);(0,$APP.$rumext$v2$useEffect$$)(function(){return $update_fn__$1$$.$cljs$core$IFn$_invoke$arity$1$?
$update_fn__$1$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$387$$):$update_fn__$1$$($value$jscomp$387$$)},[$value$jscomp$387$$]);return $state$jscomp$46$$};
$app$common$types$pages_list$get_last_page$$=function($file_data$jscomp$14$$){var $id$jscomp$247$$=$APP.$cljs$core$last$$($APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$14$$));return $APP.$cljs$core$truth_$$($id$jscomp$247$$)?$APP.$app$common$types$pages_list$get_page$$($file_data$jscomp$14$$,$id$jscomp$247$$):null};
$app$main$data$workspace$clear_assets_section_open$$=function(){typeof $app$main$data$workspace$clear_assets_section_open_72095$$==="undefined"&&($app$main$data$workspace$clear_assets_section_open_72095$$=function($meta72096$$){this.$meta72096$=$meta72096$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clear_assets_section_open_72095$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clear_assets_section_open_72095$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4565$app_DOT_main_DOT_data_DOT_workspace_SLASH_clear_assets_section_open$$},$app$main$data$workspace$clear_assets_section_open_72095$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72097$$,$meta72096__$1$$){return new $app$main$data$workspace$clear_assets_section_open_72095$$($meta72096__$1$$)},$app$main$data$workspace$clear_assets_section_open_72095$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72096$},$app$main$data$workspace$clear_assets_section_open_72095$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clear_assets_section_open_72095$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2592$$,$state$jscomp$920$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$920$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$4564$open_status$$],null),$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return new $app$main$data$workspace$clear_assets_section_open_72095$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$=function(){typeof $app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$=function($meta73276$$){this.$meta73276$=$meta73276$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4814$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_token_set_edition$$},$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73277$$,$meta73276__$1$$){return new $app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$($meta73276__$1$$)},
$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73276$},$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2714$$,$state$jscomp$1017$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1017$$,
$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4811$token_set_edition_id$$)});return new $app$main$data$workspace$tokens$library_edit$clear_token_set_edition_73275$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$common$initialized_QMARK_$$=function($state$jscomp$424$$){return $APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$424$$))&&$APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$424$$))};
$app$main$ui$workspace$viewport$utils$format_viewbox$$=function($vbox$jscomp$32$$){return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$32$$,0))??"")+" "+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$32$$,0))??"")+" "+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$32$$,
0))??"")+" "+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$32$$,0))??"")};
$app$main$data$workspace$viewport$update_viewport_size$$=function($resize_type$$,$p__71324$$){var $map__71325__$1$$=$APP.$cljs$core$__destructure_map$$($p__71324$$),$width$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71325__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$142$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71325__$1$$,$APP.$cljs$cst$1527$height$$);typeof $app$main$data$workspace$viewport$update_viewport_size_71326$$==="undefined"&&($app$main$data$workspace$viewport$update_viewport_size_71326$$=
function($resize_type$jscomp$1$$,$p__71324$jscomp$1$$,$map__71325$jscomp$1$$,$size$jscomp$132$$,$width$jscomp$160$$,$height$jscomp$143$$,$meta71327$$){this.$resize_type$=$resize_type$jscomp$1$$;this.$p__71324$=$p__71324$jscomp$1$$;this.$map__71325$=$map__71325$jscomp$1$$;this.size=$size$jscomp$132$$;this.width=$width$jscomp$160$$;this.height=$height$jscomp$143$$;this.$meta71327$=$meta71327$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$update_viewport_size_71326$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_size_71326$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4518$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_update_viewport_size$$},$app$main$data$workspace$viewport$update_viewport_size_71326$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71328$$,$meta71327__$1$$){return new $app$main$data$workspace$viewport$update_viewport_size_71326$$(this.$resize_type$,
this.$p__71324$,this.$map__71325$,this.size,this.width,this.height,$meta71327__$1$$)},$app$main$data$workspace$viewport$update_viewport_size_71326$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71327$},$app$main$data$workspace$viewport$update_viewport_size_71326$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$update_viewport_size_71326$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2538$$,
$state$jscomp$878$$){var $self__$jscomp$6184$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$878$$,$APP.$cljs$cst$1937$workspace_local$$,function($map__71331__$1_p__71330$$){$map__71331__$1_p__71330$$=$APP.$cljs$core$__destructure_map$$($map__71331__$1_p__71330$$);var $hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71331__$1_p__71330$$,$APP.$cljs$cst$2211$vport$$);if($hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$==
null||$APP.$app$common$math$almost_zero_QMARK_$$($self__$jscomp$6184$$.width)||$APP.$app$common$math$almost_zero_QMARK_$$($self__$jscomp$6184$$.height))return $map__71331__$1_p__71330$$;var $vbox_x_SINGLEQUOTE__wprop$jscomp$1$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$)/$self__$jscomp$6184$$.width;$hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$)/
$self__$jscomp$6184$$.height;var $vbox$jscomp$30$$=$APP.$cljs$cst$1942$vbox$$.$cljs$core$IFn$_invoke$arity$1$($map__71331__$1_p__71330$$),$vbox_x$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30$$),$vbox_y$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30$$),$vbox_width$jscomp$1$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30$$),$vbox_height$jscomp$1$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$30$$),
$vbox_width_SINGLEQUOTE_$$=$vbox_width$jscomp$1$$/$vbox_x_SINGLEQUOTE__wprop$jscomp$1$$,$vbox_height_SINGLEQUOTE_$$=$vbox_height$jscomp$1$$/$hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$;$vbox_x_SINGLEQUOTE__wprop$jscomp$1$$=function(){var $G__71333$$=$self__$jscomp$6184$$.$resize_type$;switch($G__71333$$ instanceof $APP.$cljs$core$Keyword$$?$G__71333$$.$fqn$:null){case "left":return $vbox_x$$+($vbox_width$jscomp$1$$-$vbox_width_SINGLEQUOTE_$$);case "right":return $vbox_x$$;default:return $vbox_x$$+
($vbox_width$jscomp$1$$-$vbox_width_SINGLEQUOTE_$$)/2}}();$hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$=function(){var $G__71342$$=$self__$jscomp$6184$$.$resize_type$;switch($G__71342$$ instanceof $APP.$cljs$core$Keyword$$?$G__71342$$.$fqn$:null){case "top":return $vbox_y$$+($vbox_height$jscomp$1$$-$vbox_height_SINGLEQUOTE_$$);case "bottom":return $vbox_y$$;default:return $vbox_y$$+($vbox_height$jscomp$1$$-$vbox_height_SINGLEQUOTE_$$)/2}}();return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71331__$1_p__71330$$,
$APP.$cljs$cst$2211$vport$$,$self__$jscomp$6184$$.size),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1942$vbox$$,$APP.$cljs$cst$1515$x$$],null),$vbox_x_SINGLEQUOTE__wprop$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1942$vbox$$,$APP.$cljs$cst$1516$y$$],null),$hprop$jscomp$1_vbox_y_SINGLEQUOTE__vport$jscomp$7$$),new $APP.$cljs$core$PersistentVector$$(null,2,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1942$vbox$$,$APP.$cljs$cst$290$width$$],null),$vbox_width_SINGLEQUOTE_$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1942$vbox$$,$APP.$cljs$cst$1527$height$$],null),$vbox_height_SINGLEQUOTE_$$)})});return new $app$main$data$workspace$viewport$update_viewport_size_71326$$($resize_type$$,$p__71324$$,$map__71325__$1$$,$map__71325__$1$$,$width$jscomp$159$$,$height$jscomp$142$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$set_default_size$$=function($width$jscomp$153$$,$height$jscomp$137$$){typeof $app$main$data$workspace$drawing$change_preset_70325$$==="undefined"&&($app$main$data$workspace$drawing$change_preset_70325$$=function($width$jscomp$154$$,$height$jscomp$138$$,$meta70326$$){this.width=$width$jscomp$154$$;this.height=$height$jscomp$138$$;this.$meta70326$=$meta70326$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$change_preset_70325$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$change_preset_70325$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4338$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_change_preset$$},$app$main$data$workspace$drawing$change_preset_70325$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70327$$,$meta70326__$1$$){return new $app$main$data$workspace$drawing$change_preset_70325$$(this.width,this.height,$meta70326__$1$$)},$app$main$data$workspace$drawing$change_preset_70325$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70326$},$app$main$data$workspace$drawing$change_preset_70325$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$change_preset_70325$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2374$$,$state$jscomp$750$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$750$$,$APP.$cljs$cst$2197$workspace_drawing$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,
this.width,$APP.$cljs$cst$1527$height$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.height]))});return new $app$main$data$workspace$drawing$change_preset_70325$$($width$jscomp$153$$,$height$jscomp$137$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$fix_init_point$$=function($initial$jscomp$16$$,$G__69143__$1_handler$jscomp$32$$,$shape$jscomp$543_x$jscomp$1200$$){var $height$jscomp$123_selrect$jscomp$63$$=$shape$jscomp$543_x$jscomp$1200$$?.selrect??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$543_x$jscomp$1200$$,$APP.$cljs$cst$1610$selrect$$);$shape$jscomp$543_x$jscomp$1200$$=$height$jscomp$123_selrect$jscomp$63$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$123_selrect$jscomp$63$$,
$APP.$cljs$cst$1515$x$$);var $y$jscomp$433$$=$height$jscomp$123_selrect$jscomp$63$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$123_selrect$jscomp$63$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$137$$=$height$jscomp$123_selrect$jscomp$63$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$123_selrect$jscomp$63$$,$APP.$cljs$cst$290$width$$);$height$jscomp$123_selrect$jscomp$63$$=$height$jscomp$123_selrect$jscomp$63$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$123_selrect$jscomp$63$$,
$APP.$cljs$cst$1527$height$$);$G__69143__$1_handler$jscomp$32$$=$G__69143__$1_handler$jscomp$32$$ instanceof $APP.$cljs$core$Keyword$$?$G__69143__$1_handler$jscomp$32$$.$fqn$:null;switch($G__69143__$1_handler$jscomp$32$$){case "left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1515$x$$,$shape$jscomp$543_x$jscomp$1200$$);case "top":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1516$y$$,$y$jscomp$433$$);
case "top-left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1515$x$$,$shape$jscomp$543_x$jscomp$1200$$),$APP.$cljs$cst$1516$y$$,$y$jscomp$433$$);case "bottom-left":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1515$x$$,$shape$jscomp$543_x$jscomp$1200$$),$APP.$cljs$cst$1516$y$$,$y$jscomp$433$$+
$height$jscomp$123_selrect$jscomp$63$$);case "right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1515$x$$,$shape$jscomp$543_x$jscomp$1200$$+$width$jscomp$137$$);case "top-right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1515$x$$,$shape$jscomp$543_x$jscomp$1200$$+$width$jscomp$137$$),$APP.$cljs$cst$1516$y$$,$y$jscomp$433$$);case "bottom-right":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,
$APP.$cljs$cst$1515$x$$,$shape$jscomp$543_x$jscomp$1200$$+$width$jscomp$137$$),$APP.$cljs$cst$1516$y$$,$y$jscomp$433$$+$height$jscomp$123_selrect$jscomp$63$$);case "bottom":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$16$$,$APP.$cljs$cst$1516$y$$,$y$jscomp$433$$+$height$jscomp$123_selrect$jscomp$63$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__69143__$1_handler$jscomp$32$$)].join(""));}};
$app$main$data$workspace$tokens$library_edit$start_token_set_creation$$=function($path$jscomp$253$$){typeof $app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$=function($path$jscomp$254$$,$meta73270$$){this.path=$path$jscomp$254$$;this.$meta73270$=$meta73270$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4812$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_start_token_set_creation$$},$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73271$$,$meta73270__$1$$){return new $app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$(this.path,
$meta73270__$1$$)},$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73270$},$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2713$$,$state$jscomp$1016$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1016$$,
$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4813$token_set_new_path$$,this.path)});return new $app$main$data$workspace$tokens$library_edit$start_token_set_creation_73269$$($path$jscomp$253$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$file$find_remote_shape$$=function($var_args$jscomp$1094$$){for(var $args__5755__auto__$jscomp$199$$=[],$len__5749__auto___52277$$=arguments.length,$i__5750__auto___52278$$=0;;)if($i__5750__auto___52278$$<$len__5749__auto___52277$$)$args__5755__auto__$jscomp$199$$.push(arguments[$i__5750__auto___52278$$]),$i__5750__auto___52278$$+=1;else break;return $APP.$app$common$types$file$find_remote_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],arguments[2],3<
$args__5755__auto__$jscomp$199$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$199$$.slice(3),0,null):null)};
$app$main$data$workspace$colors$stop_picker$$=function(){typeof $app$main$data$workspace$colors$stop_picker_70672$$==="undefined"&&($app$main$data$workspace$colors$stop_picker_70672$$=function($meta70673$$){this.$meta70673$=$meta70673$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$stop_picker_70672$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$stop_picker_70672$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4198$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_stop_picker$$},$app$main$data$workspace$colors$stop_picker_70672$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70674$$,$meta70673__$1$$){return new $app$main$data$workspace$colors$stop_picker_70672$$($meta70673__$1$$)},$app$main$data$workspace$colors$stop_picker_70672$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70673$},$app$main$data$workspace$colors$stop_picker_70672$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$stop_picker_70672$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2250$$,$state$jscomp$636$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$636$$,$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4199$picked_color_select$$,$APP.$cljs$cst$4200$picked_shift_QMARK_$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$4197$picking_color_QMARK_$$],null),!1)});return new $app$main$data$workspace$colors$stop_picker_70672$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$start_picker$$=function(){typeof $app$main$data$workspace$colors$start_picker_70669$$==="undefined"&&($app$main$data$workspace$colors$start_picker_70669$$=function($meta70670$$){this.$meta70670$=$meta70670$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$start_picker_70669$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$start_picker_70669$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4196$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_start_picker$$},$app$main$data$workspace$colors$start_picker_70669$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70671$$,$meta70670__$1$$){return new $app$main$data$workspace$colors$start_picker_70669$$($meta70670__$1$$)},$app$main$data$workspace$colors$start_picker_70669$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70670$},$app$main$data$workspace$colors$start_picker_70669$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$start_picker_70669$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2249$$,$state$jscomp$635$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$635$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$4197$picking_color_QMARK_$$],null),!0)});return new $app$main$data$workspace$colors$start_picker_70669$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$show_track_context_menu$$=function($p__72154$$){var $map__72155__$1$$=$APP.$cljs$core$__destructure_map$$($p__72154$$),$grid_id$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72155__$1$$,$APP.$cljs$cst$4487$grid_id$$),$type$jscomp$543$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72155__$1$$,$APP.$cljs$cst$139$type$$),$index$jscomp$368$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72155__$1$$,$APP.$cljs$cst$1801$index$$);
typeof $app$main$data$workspace$show_track_context_menu_72156$$==="undefined"&&($app$main$data$workspace$show_track_context_menu_72156$$=function($p__72154$jscomp$1$$,$map__72155$jscomp$1$$,$params$jscomp$303$$,$grid_id$jscomp$24$$,$type$jscomp$544$$,$index$jscomp$369$$,$meta72157$$){this.$p__72154$=$p__72154$jscomp$1$$;this.$map__72155$=$map__72155$jscomp$1$$;this.params=$params$jscomp$303$$;this.$grid_id$=$grid_id$jscomp$24$$;this.type=$type$jscomp$544$$;this.index=$index$jscomp$369$$;this.$meta72157$=
$meta72157$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_track_context_menu_72156$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_track_context_menu_72156$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4577$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_track_context_menu$$},$app$main$data$workspace$show_track_context_menu_72156$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72158$$,$meta72157__$1$$){return new $app$main$data$workspace$show_track_context_menu_72156$$(this.$p__72154$,this.$map__72155$,this.params,this.$grid_id$,this.type,this.index,$meta72157__$1$$)},$app$main$data$workspace$show_track_context_menu_72156$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72157$},$app$main$data$workspace$show_track_context_menu_72156$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_track_context_menu_72156$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$4578$grid_track$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4487$grid_id$$,this.$grid_id$,$APP.$cljs$cst$139$type$$,this.type,$APP.$cljs$cst$1801$index$$,this.index]))))});return new $app$main$data$workspace$show_track_context_menu_72156$$($p__72154$$,
$map__72155__$1$$,$map__72155__$1$$,$grid_id$jscomp$23$$,$type$jscomp$543$$,$index$jscomp$368$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$exit_preview_cleanup$$=function(){typeof $app$main$data$workspace$versions$exit_preview_cleanup_73715$$==="undefined"&&($app$main$data$workspace$versions$exit_preview_cleanup_73715$$=function($meta73716$$){this.$meta73716$=$meta73716$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$exit_preview_cleanup_73715$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$exit_preview_cleanup_73715$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5154$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_exit_preview_cleanup$$},$app$main$data$workspace$versions$exit_preview_cleanup_73715$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73717$$,$meta73716__$1$$){return new $app$main$data$workspace$versions$exit_preview_cleanup_73715$$($meta73716__$1$$)},$app$main$data$workspace$versions$exit_preview_cleanup_73715$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73716$},
$app$main$data$workspace$versions$exit_preview_cleanup_73715$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$exit_preview_cleanup_73715$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2826_backup$$,$state$jscomp$1095$$){$_$jscomp$2826_backup$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1095$$,$APP.$cljs$cst$4537$workspace_versions$$),
$APP.$cljs$cst$5155$backup$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1095$$,$APP.$cljs$cst$4537$workspace_versions$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$5155$backup$$),$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2225$read_only_QMARK_$$,$APP.$cljs$cst$5134$preview_id$$),$APP.$cljs$cst$1933$files$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2826_backup$$),$_$jscomp$2826_backup$$)});return new $app$main$data$workspace$versions$exit_preview_cleanup_73715$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$update_versions_state$$=function($version_state$$){typeof $app$main$data$workspace$versions$update_versions_state_73641$$==="undefined"&&($app$main$data$workspace$versions$update_versions_state_73641$$=function($version_state$jscomp$1$$,$meta73642$$){this.$version_state$=$version_state$jscomp$1$$;this.$meta73642$=$meta73642$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$update_versions_state_73641$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$update_versions_state_73641$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5136$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_update_versions_state$$},$app$main$data$workspace$versions$update_versions_state_73641$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73643$$,$meta73642__$1$$){return new $app$main$data$workspace$versions$update_versions_state_73641$$(this.$version_state$,
$meta73642__$1$$)},$app$main$data$workspace$versions$update_versions_state_73641$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73642$},$app$main$data$workspace$versions$update_versions_state_73641$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$update_versions_state_73641$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2816$$,$state$jscomp$1089$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1089$$,
$APP.$cljs$cst$4537$workspace_versions$$,$APP.$cljs$core$merge$$,this.$version_state$)});return new $app$main$data$workspace$versions$update_versions_state_73641$$($version_state$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$drawing$change_orientation$$=function($orientation$jscomp$5$$){typeof $app$main$data$workspace$drawing$change_orientation_70315$$==="undefined"&&($app$main$data$workspace$drawing$change_orientation_70315$$=function($orientation$jscomp$6$$,$meta70316$$){this.orientation=$orientation$jscomp$6$$;this.$meta70316$=$meta70316$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$drawing$change_orientation_70315$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$change_orientation_70315$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4337$app_DOT_main_DOT_data_DOT_workspace_DOT_drawing_SLASH_change_orientation$$},$app$main$data$workspace$drawing$change_orientation_70315$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70317$$,$meta70316__$1$$){return new $app$main$data$workspace$drawing$change_orientation_70315$$(this.orientation,$meta70316__$1$$)},
$app$main$data$workspace$drawing$change_orientation_70315$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70316$},$app$main$data$workspace$drawing$change_orientation_70315$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$drawing$change_orientation_70315$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$,$state$jscomp$749$$){$_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$749$$,$APP.$cljs$cst$2197$workspace_drawing$$);var $map__70324__$1_width_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$);$_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70324__$1_width_SINGLEQUOTE_$jscomp$1$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$136$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70324__$1_width_SINGLEQUOTE_$jscomp$1$$,$APP.$cljs$cst$1527$height$$);$map__70324__$1_width_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.orientation,$APP.$cljs$cst$1927$vertical$$)?Math.min($_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$,$height$jscomp$136$$):Math.max($_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$,$height$jscomp$136$$);$_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.orientation,$APP.$cljs$cst$1927$vertical$$)?Math.max($_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$,$height$jscomp$136$$):Math.min($_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$,$height$jscomp$136$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$749$$,$APP.$cljs$cst$2197$workspace_drawing$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$map__70324__$1_width_SINGLEQUOTE_$jscomp$1$$,
$APP.$cljs$cst$1527$height$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$_$jscomp$2373_height_SINGLEQUOTE_$jscomp$1_map__70324_width$jscomp$152$$]))});return new $app$main$data$workspace$drawing$change_orientation_70315$$($orientation$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$files$variant$get_primary_component$$=function($JSCompiler_temp$jscomp$1534_JSCompiler_temp$jscomp$1535_data$jscomp$300$$,$JSCompiler_temp_const$jscomp$1536_component_id$jscomp$32$$){var $JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1534_JSCompiler_temp$jscomp$1535_data$jscomp$300$$,$JSCompiler_temp_const$jscomp$1536_component_id$jscomp$32$$);
if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$))if($APP.$app$common$types$component$is_variant_QMARK_$$($JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$)){$JSCompiler_temp_const$jscomp$1536_component_id$jscomp$32$$=$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$;var $objects$jscomp$inline_8251_page_id$jscomp$inline_8250$$=$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$);
$objects$jscomp$inline_8251_page_id$jscomp$inline_8250$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1534_JSCompiler_temp$jscomp$1535_data$jscomp$300$$,$APP.$cljs$cst$1635$pages_index$$),$objects$jscomp$inline_8251_page_id$jscomp$inline_8250$$),$APP.$cljs$cst$1636$objects$$);$JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$=
$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$);$JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_8251_page_id$jscomp$inline_8250$$,$APP.$cljs$core$peek$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$inline_8251_page_id$jscomp$inline_8250$$,
$JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$),$APP.$cljs$cst$1619$shapes$$)));$JSCompiler_temp$jscomp$1534_JSCompiler_temp$jscomp$1535_data$jscomp$300$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1534_JSCompiler_temp$jscomp$1535_data$jscomp$300$$,$JSCompiler_temp_const$jscomp$1536_component_id$jscomp$32$$.call($APP.$cljs$cst$1632$component_id$$,$JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$))}else $JSCompiler_temp$jscomp$1534_JSCompiler_temp$jscomp$1535_data$jscomp$300$$=
$JSCompiler_inline_result$jscomp$1538_temp__5825__auto__$jscomp$195_variant_id$jscomp$inline_8252$$;else $JSCompiler_temp$jscomp$1534_JSCompiler_temp$jscomp$1535_data$jscomp$300$$=null;return $JSCompiler_temp$jscomp$1534_JSCompiler_temp$jscomp$1535_data$jscomp$300$$};$cljs$core$TaggedLiteral$$=function($tag$jscomp$13$$,$form$jscomp$3$$){this.tag=$tag$jscomp$13$$;this.form=$form$jscomp$3$$;this.$cljs$lang$protocol_mask$partition0$$=2153775360;this.$cljs$lang$protocol_mask$partition1$$=0};
$cljs$tools$reader$garg$$=function($n$jscomp$174$$){return $APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$([-1===$n$jscomp$174$$?"rest":["p",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$174$$)].join(""),"__",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$tools$reader$impl$utils$last_id$$,$APP.$cljs$core$inc$$)),"#"].join(""))};
$app$main$data$workspace$versions$fetch_versions$$=function(){typeof $app$main$data$workspace$versions$fetch_versions_73649$$==="undefined"&&($app$main$data$workspace$versions$fetch_versions_73649$$=function($meta73650$$){this.$meta73650$=$meta73650$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$fetch_versions_73649$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$fetch_versions_73649$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5137$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_fetch_versions$$},$app$main$data$workspace$versions$fetch_versions_73649$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73651$$,$meta73650__$1$$){return new $app$main$data$workspace$versions$fetch_versions_73649$$($meta73650__$1$$)},$app$main$data$workspace$versions$fetch_versions_73649$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73650$},$app$main$data$workspace$versions$fetch_versions_73649$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$fetch_versions_73649$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2817_temp__5825__auto__$jscomp$278$$,$state$jscomp$1090$$){$_$jscomp$2817_temp__5825__auto__$jscomp$278$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1090$$);return $APP.$cljs$core$truth_$$($_$jscomp$2817_temp__5825__auto__$jscomp$278$$)?$APP.$beicon$v2$core$map$$(function($p1__73647_SHARP_$$){return $app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$109$status$$,$APP.$cljs$cst$5138$loaded$$,$APP.$cljs$cst$142$data$$,$p1__73647_SHARP_$$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5139$get_file_snapshots$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$_$jscomp$2817_temp__5825__auto__$jscomp$278$$],null))):null});return new $app$main$data$workspace$versions$fetch_versions_73649$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$unlock_version$$=function($id$jscomp$864$$){typeof $app$main$data$workspace$versions$unlock_version_73710$$==="undefined"&&($app$main$data$workspace$versions$unlock_version_73710$$=function($id$jscomp$865$$,$meta73711$$){this.id=$id$jscomp$865$$;this.$meta73711$=$meta73711$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$unlock_version_73710$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$unlock_version_73710$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5152$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_unlock_version$$},$app$main$data$workspace$versions$unlock_version_73710$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73712$$,$meta73711__$1$$){return new $app$main$data$workspace$versions$unlock_version_73710$$(this.id,$meta73711__$1$$)},$app$main$data$workspace$versions$unlock_version_73710$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73711$},$app$main$data$workspace$versions$unlock_version_73710$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$unlock_version_73710$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$versions$fetch_versions$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5153$unlock_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$workspace$versions$unlock_version_73710$$($id$jscomp$864$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$lock_version$$=function($id$jscomp$862$$){typeof $app$main$data$workspace$versions$lock_version_73694$$==="undefined"&&($app$main$data$workspace$versions$lock_version_73694$$=function($id$jscomp$863$$,$meta73695$$){this.id=$id$jscomp$863$$;this.$meta73695$=$meta73695$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$lock_version_73694$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$lock_version_73694$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5150$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_lock_version$$},$app$main$data$workspace$versions$lock_version_73694$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73696$$,$meta73695__$1$$){return new $app$main$data$workspace$versions$lock_version_73694$$(this.id,$meta73695__$1$$)},$app$main$data$workspace$versions$lock_version_73694$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73695$},$app$main$data$workspace$versions$lock_version_73694$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$lock_version_73694$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$versions$fetch_versions$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5151$lock_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$workspace$versions$lock_version_73694$$($id$jscomp$862$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$delete_version$$=function($id$jscomp$858$$){typeof $app$main$data$workspace$versions$delete_version_73674$$==="undefined"&&($app$main$data$workspace$versions$delete_version_73674$$=function($id$jscomp$859$$,$meta73675$$){this.id=$id$jscomp$859$$;this.$meta73675$=$meta73675$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$delete_version_73674$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$delete_version_73674$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5147$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_delete_version$$},$app$main$data$workspace$versions$delete_version_73674$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73676$$,$meta73675__$1$$){return new $app$main$data$workspace$versions$delete_version_73674$$(this.id,$meta73675__$1$$)},$app$main$data$workspace$versions$delete_version_73674$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73675$},$app$main$data$workspace$versions$delete_version_73674$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$delete_version_73674$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$versions$fetch_versions$$,$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5148$delete_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,this.id],null)))});return new $app$main$data$workspace$versions$delete_version_73674$$($id$jscomp$858$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$rename_version$$=function($id$jscomp$856$$,$label$jscomp$33$$){typeof $app$main$data$workspace$versions$rename_version_73666$$==="undefined"&&($app$main$data$workspace$versions$rename_version_73666$$=function($id$jscomp$857$$,$label$jscomp$34$$,$meta73667$$){this.id=$id$jscomp$857$$;this.label=$label$jscomp$34$$;this.$meta73667$=$meta73667$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$rename_version_73666$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$rename_version_73666$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5143$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_rename_version$$},$app$main$data$workspace$versions$rename_version_73666$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73668$$,$meta73667__$1$$){return new $app$main$data$workspace$versions$rename_version_73666$$(this.id,this.label,$meta73667__$1$$)},
$app$main$data$workspace$versions$rename_version_73666$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73667$},$app$main$data$workspace$versions$rename_version_73666$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$rename_version_73666$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2819_file_id$jscomp$329$$,$state$jscomp$1092$$){$_$jscomp$2819_file_id$jscomp$329$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1092$$);
return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2160$editing$$,null],null)),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"rename-version",$APP.$cljs$cst$1649$file_id$$,$_$jscomp$2819_file_id$jscomp$329$$],null))),$APP.$beicon$v2$core$map$$($app$main$data$workspace$versions$fetch_versions$$,
$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5144$update_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$2296$label$$,this.label],null))))});return new $app$main$data$workspace$versions$rename_version_73666$$($id$jscomp$856$$,$label$jscomp$33$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$init_versions_state$$=function(){typeof $app$main$data$workspace$versions$init_versions_state_73636$$==="undefined"&&($app$main$data$workspace$versions$init_versions_state_73636$$=function($meta73637$$){this.$meta73637$=$meta73637$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$init_versions_state_73636$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$init_versions_state_73636$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5135$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_init_versions_state$$},$app$main$data$workspace$versions$init_versions_state_73636$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73638$$,$meta73637__$1$$){return new $app$main$data$workspace$versions$init_versions_state_73636$$($meta73637__$1$$)},$app$main$data$workspace$versions$init_versions_state_73636$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73637$},$app$main$data$workspace$versions$init_versions_state_73636$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$init_versions_state_73636$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2814$$,$state$jscomp$1088$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1088$$,$APP.$cljs$cst$4537$workspace_versions$$,$APP.$app$main$data$workspace$versions$default_state$$)},$app$main$data$workspace$versions$init_versions_state_73636$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$init_versions_state_73636$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$fetch_versions$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$versions$fetch_versions$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$versions$fetch_versions$$())});return new $app$main$data$workspace$versions$init_versions_state_73636$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$rename_file$$=function($id$jscomp$742$$,$name$jscomp$357_name__$1$jscomp$12$$){$name$jscomp$357_name__$1$jscomp$12$$=$app$common$data$macros$truncate$$($name$jscomp$357_name__$1$jscomp$12$$);typeof $app$main$data$workspace$rename_file_71926$$==="undefined"&&($app$main$data$workspace$rename_file_71926$$=function($id$jscomp$743$$,$name$jscomp$358$$,$meta71927$$){this.id=$id$jscomp$743$$;this.name=$name$jscomp$358$$;this.$meta71927$=$meta71927$$;this.$cljs$lang$protocol_mask$partition0$$=
425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$rename_file_71926$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$rename_file_71926$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4538$app_DOT_main_DOT_data_DOT_workspace_SLASH_rename_file$$},$app$main$data$workspace$rename_file_71926$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71928$$,$meta71927__$1$$){return new $app$main$data$workspace$rename_file_71926$$(this.id,
this.name,$meta71927__$1$$)},$app$main$data$workspace$rename_file_71926$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71927$},$app$main$data$workspace$rename_file_71926$$.prototype.$cljs$core$IDeref$_deref$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$725$name$$,this.name],null)},$app$main$data$workspace$rename_file_71926$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$rename_file_71926$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2565_file_id$jscomp$276$$,$state$jscomp$897$$){$_$jscomp$2565_file_id$jscomp$276$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$897$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$897$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1933$files$$,
$_$jscomp$2565_file_id$jscomp$276$$,$APP.$cljs$cst$725$name$$],null),this.name)},$app$main$data$workspace$rename_file_71926$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$rename_file_71926$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return $APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4539$rename_file$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,
this.id,$APP.$cljs$cst$725$name$$,this.name],null)))});return new $app$main$data$workspace$rename_file_71926$$($id$jscomp$742$$,$name$jscomp$357_name__$1$jscomp$12$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$tinycolor$hex_without_hash_prefix_QMARK_$$=function($color_str$jscomp$1_tc$jscomp$3$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("#",$APP.$cljs$core$first$$($color_str$jscomp$1_tc$jscomp$3$$))?($color_str$jscomp$1_tc$jscomp$3$$=(0,$APP.$shadow$js$shim$module$0tinycolor2$0default$$)($color_str$jscomp$1_tc$jscomp$3$$),$APP.$cuerdas$core$starts_with_QMARK_$$($color_str$jscomp$1_tc$jscomp$3$$.getFormat(),"hex")):null};
$app$main$data$workspace$pages$finalize_page$$=function($file_id$jscomp$245$$,$page_id$jscomp$236$$){typeof $app$main$data$workspace$pages$finalize_page_70956$$==="undefined"&&($app$main$data$workspace$pages$finalize_page_70956$$=function($file_id$jscomp$246$$,$page_id$jscomp$237$$,$meta70957$$){this.$file_id$=$file_id$jscomp$246$$;this.$page_id$=$page_id$jscomp$237$$;this.$meta70957$=$meta70957$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$pages$finalize_page_70956$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$finalize_page_70956$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3681$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_finalize_page$$},$app$main$data$workspace$pages$finalize_page_70956$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70958$$,$meta70957__$1$$){return new $app$main$data$workspace$pages$finalize_page_70956$$(this.$file_id$,this.$page_id$,$meta70957__$1$$)},$app$main$data$workspace$pages$finalize_page_70956$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70957$},$app$main$data$workspace$pages$finalize_page_70956$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$finalize_page_70956$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2465_exit_QMARK_$$,$G__70967_state$jscomp$817$$){var $local$jscomp$15$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1937$workspace_local$$.$cljs$core$IFn$_invoke$arity$1$($G__70967_state$jscomp$817$$),
$APP.$cljs$cst$2207$edition$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1940$edit_path$$,$APP.$cljs$cst$1938$selected$$]));$_$jscomp$2465_exit_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2543$workspace$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70967_state$jscomp$817$$,$APP.$cljs$cst$2179$route$$),$APP.$cljs$cst$142$data$$),
$APP.$cljs$cst$725$name$$));$G__70967_state$jscomp$817$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($G__70967_state$jscomp$817$$,$APP.$cljs$cst$4431$workspace_cache$$,$APP.$cljs$core$assoc$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$file_id$,this.$page_id$],null),$local$jscomp$15$$),$APP.$cljs$cst$1935$current_page_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1937$workspace_local$$,
$APP.$cljs$cst$4433$workspace_trimmed_page$$,$APP.$cljs$cst$2234$workspace_focus_selected$$]));return $_$jscomp$2465_exit_QMARK_$$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__70967_state$jscomp$817$$,$APP.$cljs$cst$2197$workspace_drawing$$):$G__70967_state$jscomp$817$$});return new $app$main$data$workspace$pages$finalize_page_70956$$($file_id$jscomp$245$$,$page_id$jscomp$236$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$handle_comment_layer_click$$=function($position$jscomp$147$$){typeof $app$main$data$workspace$comments$handle_comment_layer_click_70409$$==="undefined"&&($app$main$data$workspace$comments$handle_comment_layer_click_70409$$=function($position$jscomp$148$$,$meta70410$$){this.position=$position$jscomp$148$$;this.$meta70410$=$meta70410$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$handle_comment_layer_click_70409$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$handle_comment_layer_click_70409$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4343$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_handle_comment_layer_click$$},$app$main$data$workspace$comments$handle_comment_layer_click_70409$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70411$$,$meta70410__$1$$){return new $app$main$data$workspace$comments$handle_comment_layer_click_70409$$(this.position,
$meta70410__$1$$)},$app$main$data$workspace$comments$handle_comment_layer_click_70409$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70410$},$app$main$data$workspace$comments$handle_comment_layer_click_70409$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$handle_comment_layer_click_70409$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2378_local$jscomp$10_page_id$jscomp$206$$,$file_id$jscomp$220_state$jscomp$753$$){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3489$comments$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$220_state$jscomp$753$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2197$workspace_drawing$$,$APP.$cljs$cst$2205$tool$$],null))))return $APP.$beicon$v2$core$empty$$();$_$jscomp$2378_local$jscomp$10_page_id$jscomp$206$$=$APP.$cljs$cst$2241$comments_local$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$220_state$jscomp$753$$);if($APP.$cljs$cst$3487$open$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2378_local$jscomp$10_page_id$jscomp$206$$)!=
null)return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$());$_$jscomp$2378_local$jscomp$10_page_id$jscomp$206$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$220_state$jscomp$753$$);$file_id$jscomp$220_state$jscomp$753$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$220_state$jscomp$753$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$create_draft$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1681$position$$,this.position,$APP.$cljs$cst$2051$page_id$$,$_$jscomp$2378_local$jscomp$10_page_id$jscomp$206$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$220_state$jscomp$753$$],null)))});return new $app$main$data$workspace$comments$handle_comment_layer_click_70409$$($position$jscomp$147$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$gen_name$$=function($editor$jscomp$3_result$jscomp$306$$){return $editor$jscomp$3_result$jscomp$306$$!=null?($editor$jscomp$3_result$jscomp$306$$=$APP.$app$common$types$text$generate_shape_name$$($editor$jscomp$3_result$jscomp$306$$.getCurrentContent().getPlainText()),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editor$jscomp$3_result$jscomp$306$$,"")?$editor$jscomp$3_result$jscomp$306$$:null):null};
$app$common$types$shape$interactions$allowed_animation_QMARK_$$=function($action_type$jscomp$2$$,$animation_type$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($animation_type$$,$APP.$cljs$cst$1972$push$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1957$navigate$$,$action_type$jscomp$2$$)};
$app$common$geom$shapes$intersect$is_point_inside_nonzero_QMARK_$$=function($p$jscomp$205$$,$G__48947_lines$jscomp$2_lines__$1$$){var $G__48945_wn$jscomp$1_wn$jscomp$inline_8254$$=0,$G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$=$APP.$cljs$core$first$$($G__48947_lines$jscomp$2_lines__$1$$);for($G__48947_lines$jscomp$2_lines__$1$$=$APP.$cljs$core$rest$$($G__48947_lines$jscomp$2_lines__$1$$);;)if($APP.$cljs$core$truth_$$($G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$)){var $map__48920$jscomp$inline_8264_p__48914$jscomp$inline_8256_x2$jscomp$inline_8266$$=
$G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$,$map__48915__$1$jscomp$inline_8257_py$jscomp$inline_8259$$=$APP.$cljs$core$__destructure_map$$($p$jscomp$205$$);$G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48915__$1$jscomp$inline_8257_py$jscomp$inline_8259$$,$APP.$cljs$cst$1515$x$$);$map__48915__$1$jscomp$inline_8257_py$jscomp$inline_8259$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48915__$1$jscomp$inline_8257_py$jscomp$inline_8259$$,
$APP.$cljs$cst$1516$y$$);var $map__48919$jscomp$inline_8260_x1$jscomp$inline_8262$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__48920$jscomp$inline_8264_p__48914$jscomp$inline_8256_x2$jscomp$inline_8266$$,0,null),$map__48919__$1$jscomp$inline_8261_y1$jscomp$inline_8263$$=$APP.$cljs$core$__destructure_map$$($map__48919$jscomp$inline_8260_x1$jscomp$inline_8262$$);$map__48919$jscomp$inline_8260_x1$jscomp$inline_8262$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48919__$1$jscomp$inline_8261_y1$jscomp$inline_8263$$,
$APP.$cljs$cst$1515$x$$);$map__48919__$1$jscomp$inline_8261_y1$jscomp$inline_8263$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48919__$1$jscomp$inline_8261_y1$jscomp$inline_8263$$,$APP.$cljs$cst$1516$y$$);$map__48920$jscomp$inline_8264_p__48914$jscomp$inline_8256_x2$jscomp$inline_8266$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__48920$jscomp$inline_8264_p__48914$jscomp$inline_8256_x2$jscomp$inline_8266$$,1,null);var $map__48920__$1$jscomp$inline_8265_y2$jscomp$inline_8267$$=
$APP.$cljs$core$__destructure_map$$($map__48920$jscomp$inline_8264_p__48914$jscomp$inline_8256_x2$jscomp$inline_8266$$);$map__48920$jscomp$inline_8264_p__48914$jscomp$inline_8256_x2$jscomp$inline_8266$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48920__$1$jscomp$inline_8265_y2$jscomp$inline_8267$$,$APP.$cljs$cst$1515$x$$);$map__48920__$1$jscomp$inline_8265_y2$jscomp$inline_8267$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48920__$1$jscomp$inline_8265_y2$jscomp$inline_8267$$,
$APP.$cljs$cst$1516$y$$);$G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$=($map__48920$jscomp$inline_8264_p__48914$jscomp$inline_8256_x2$jscomp$inline_8266$$-$map__48919$jscomp$inline_8260_x1$jscomp$inline_8262$$)*($map__48915__$1$jscomp$inline_8257_py$jscomp$inline_8259$$-$map__48919__$1$jscomp$inline_8261_y1$jscomp$inline_8263$$)-($G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$-$map__48919$jscomp$inline_8260_x1$jscomp$inline_8262$$)*($map__48920__$1$jscomp$inline_8265_y2$jscomp$inline_8267$$-
$map__48919__$1$jscomp$inline_8261_y1$jscomp$inline_8263$$);$G__48945_wn$jscomp$1_wn$jscomp$inline_8254$$=$map__48919__$1$jscomp$inline_8261_y1$jscomp$inline_8263$$<=$map__48915__$1$jscomp$inline_8257_py$jscomp$inline_8259$$?$map__48920__$1$jscomp$inline_8265_y2$jscomp$inline_8267$$>$map__48915__$1$jscomp$inline_8257_py$jscomp$inline_8259$$&&$G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$>0?$G__48945_wn$jscomp$1_wn$jscomp$inline_8254$$+1:$G__48945_wn$jscomp$1_wn$jscomp$inline_8254$$:
$map__48920__$1$jscomp$inline_8265_y2$jscomp$inline_8267$$<=$map__48915__$1$jscomp$inline_8257_py$jscomp$inline_8259$$&&$G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$<0?$G__48945_wn$jscomp$1_wn$jscomp$inline_8254$$-1:$G__48945_wn$jscomp$1_wn$jscomp$inline_8254$$;$G__48946_line$jscomp$24_line_side$jscomp$inline_8268_px$jscomp$inline_8258$$=$APP.$cljs$core$first$$($G__48947_lines$jscomp$2_lines__$1$$);$G__48947_lines$jscomp$2_lines__$1$$=$APP.$cljs$core$rest$$($G__48947_lines$jscomp$2_lines__$1$$)}else return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__48945_wn$jscomp$1_wn$jscomp$inline_8254$$,
0)};
$app$common$geom$shapes$intersect$intersects_lines_QMARK_$$=function($G__48944_lines_a_pending$jscomp$7$$,$lines_b$$){var $G__48943_cur_line$$=$APP.$cljs$core$first$$($G__48944_lines_a_pending$jscomp$7$$);for($G__48944_lines_a_pending$jscomp$7$$=$APP.$cljs$core$rest$$($G__48944_lines_a_pending$jscomp$7$$);;){if($APP.$cljs$core$not$$($G__48943_cur_line$$))return!1;if($APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($cur_line$jscomp$1$$){return function($p1__48903_SHARP__q2$jscomp$inline_8275$$){var $p1$jscomp$inline_8272$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_line$jscomp$1$$,
0,null),$q1$jscomp$inline_8273$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_line$jscomp$1$$,1,null),$p2$jscomp$inline_8274$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__48903_SHARP__q2$jscomp$inline_8275$$,0,null);$p1__48903_SHARP__q2$jscomp$inline_8275$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__48903_SHARP__q2$jscomp$inline_8275$$,1,null);var $o1$jscomp$inline_8276$$=$app$common$geom$shapes$intersect$orientation$$($p1$jscomp$inline_8272$$,
$q1$jscomp$inline_8273$$,$p2$jscomp$inline_8274$$),$o2$jscomp$inline_8277$$=$app$common$geom$shapes$intersect$orientation$$($p1$jscomp$inline_8272$$,$q1$jscomp$inline_8273$$,$p1__48903_SHARP__q2$jscomp$inline_8275$$),$o3$jscomp$inline_8278$$=$app$common$geom$shapes$intersect$orientation$$($p2$jscomp$inline_8274$$,$p1__48903_SHARP__q2$jscomp$inline_8275$$,$p1$jscomp$inline_8272$$),$o4$jscomp$inline_8279$$=$app$common$geom$shapes$intersect$orientation$$($p2$jscomp$inline_8274$$,$p1__48903_SHARP__q2$jscomp$inline_8275$$,
$q1$jscomp$inline_8273$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o1$jscomp$inline_8276$$,$o2$jscomp$inline_8277$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o3$jscomp$inline_8278$$,$o4$jscomp$inline_8279$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o1$jscomp$inline_8276$$,$APP.$cljs$cst$1904$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$)&&$app$common$geom$shapes$intersect$on_segment_QMARK_$$($p2$jscomp$inline_8274$$,$p1$jscomp$inline_8272$$,
$q1$jscomp$inline_8273$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o2$jscomp$inline_8277$$,$APP.$cljs$cst$1904$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$)&&$app$common$geom$shapes$intersect$on_segment_QMARK_$$($p1__48903_SHARP__q2$jscomp$inline_8275$$,$p1$jscomp$inline_8272$$,$q1$jscomp$inline_8273$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o3$jscomp$inline_8278$$,$APP.$cljs$cst$1904$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$)&&
$app$common$geom$shapes$intersect$on_segment_QMARK_$$($p1$jscomp$inline_8272$$,$p2$jscomp$inline_8274$$,$p1__48903_SHARP__q2$jscomp$inline_8275$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($o4$jscomp$inline_8279$$,$APP.$cljs$cst$1904$app_DOT_common_DOT_geom_DOT_shapes_DOT_intersect_SLASH_coplanar$$)&&$app$common$geom$shapes$intersect$on_segment_QMARK_$$($q1$jscomp$inline_8273$$,$p2$jscomp$inline_8274$$,$p1__48903_SHARP__q2$jscomp$inline_8275$$)}}($G__48943_cur_line$$,$G__48944_lines_a_pending$jscomp$7$$),
$lines_b$$)))return!0;$G__48943_cur_line$$=$APP.$cljs$core$first$$($G__48944_lines_a_pending$jscomp$7$$);$G__48944_lines_a_pending$jscomp$7$$=$APP.$cljs$core$rest$$($G__48944_lines_a_pending$jscomp$7$$)}};
$app$render_wasm$serializers$guide_frame_range$$=function($guide$$,$objects$jscomp$236_temp__5825__auto__$jscomp$162$$){var $G__53252$jscomp$inline_8281$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide$$,$APP.$cljs$cst$1612$frame_id$$);$objects$jscomp$236_temp__5825__auto__$jscomp$162$$=$G__53252$jscomp$inline_8281$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$,$G__53252$jscomp$inline_8281$$);return $APP.$cljs$core$truth_$$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$)?
$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$)&&$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$,0))?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide$$,$APP.$cljs$cst$2062$axis$$))?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$),
$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$236_temp__5825__auto__$jscomp$162$$)],null):$APP.$app$render_wasm$serializers$guide_hidden_range$$:null};
$app$main$data$workspace$libraries$set_file_shared$$=function($id$jscomp$605$$,$is_shared$jscomp$1$$){typeof $app$main$data$workspace$libraries$set_file_shared_70119$$==="undefined"&&($app$main$data$workspace$libraries$set_file_shared_70119$$=function($id$jscomp$606$$,$is_shared$jscomp$2$$,$meta70120$$){this.id=$id$jscomp$606$$;this.$is_shared$=$is_shared$jscomp$2$$;this.$meta70120$=$meta70120$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4043$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_set_file_shared$$},$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70121$$,$meta70120__$1$$){return new $app$main$data$workspace$libraries$set_file_shared_70119$$(this.id,this.$is_shared$,$meta70120__$1$$)},
$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70120$},$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace",$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$4044$shared$$,this.$is_shared$],null)},$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2163$$,$state$jscomp$540$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$540$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1933$files$$,this.id],null),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2190$is_shared$$,this.$is_shared$)},$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$set_file_shared_70119$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_temp_const$jscomp$1543__$jscomp$2164$$,$JSCompiler_temp$jscomp$1544_has_variants_QMARK_$jscomp$inline_8283_state$jscomp$541$$){$JSCompiler_temp_const$jscomp$1543__$jscomp$2164$$=
$APP.$beicon$v2$core$ignore$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4045$set_file_shared$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,this.id,$APP.$cljs$cst$2190$is_shared$$,this.$is_shared$],null)));$APP.$cljs$core$truth_$$(this.$is_shared$)?($JSCompiler_temp$jscomp$1544_has_variants_QMARK_$jscomp$inline_8283_state$jscomp$541$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$APP.$cljs$core$vals$$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1544_has_variants_QMARK_$jscomp$inline_8283_state$jscomp$541$$)))),
$JSCompiler_temp$jscomp$1544_has_variants_QMARK_$jscomp$inline_8283_state$jscomp$541$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1544_has_variants_QMARK_$jscomp$inline_8283_state$jscomp$541$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"set-file-variants-shared",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace"],null))):$APP.$beicon$v2$core$empty$$()):
$JSCompiler_temp$jscomp$1544_has_variants_QMARK_$jscomp$inline_8283_state$jscomp$541$$=null;return $APP.$beicon$v2$core$concat$$($JSCompiler_temp_const$jscomp$1543__$jscomp$2164$$,$JSCompiler_temp$jscomp$1544_has_variants_QMARK_$jscomp$inline_8283_state$jscomp$541$$)});return new $app$main$data$workspace$libraries$set_file_shared_70119$$($id$jscomp$605$$,$is_shared$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$clipboard$to_clipboard_multi$$=function($items$jscomp$31$$){var $clipboard$jscomp$3$$=navigator.clipboard;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($clipboard$jscomp$3$$)?$clipboard$jscomp$3$$.write:$clipboard$jscomp$3$$)){var $item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$177$$=$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$119$$,$mime$$,$payload$jscomp$6$$){$acc$jscomp$119$$[$mime$$]=Promise.resolve(new Blob([$payload$jscomp$6$$],{type:$mime$$}));return $acc$jscomp$119$$},
{},$items$jscomp$31$$);$item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$177$$=new ClipboardItem($item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$177$$);return $clipboard$jscomp$3$$.write([$item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$177$$])}return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($clipboard$jscomp$3$$)?$clipboard$jscomp$3$$.writeText:$clipboard$jscomp$3$$)?($item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$177$$=function(){var $or__5025__auto__$jscomp$632$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$31$$,"text/plain");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$632$$)?$or__5025__auto__$jscomp$632$$:$APP.$cljs$core$first$$($APP.$cljs$core$vals$$($items$jscomp$31$$))}(),$APP.$cljs$core$truth_$$($item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$177$$)?$clipboard$jscomp$3$$.writeText($item$jscomp$64_obj$jscomp$195_temp__5825__auto__$jscomp$177$$):null):$APP.$app$util$clipboard$unavailable_error$$()};
$app$main$data$workspace$versions$pin_version$$=function($id$jscomp$860$$){typeof $app$main$data$workspace$versions$pin_version_73680$$==="undefined"&&($app$main$data$workspace$versions$pin_version_73680$$=function($id$jscomp$861$$,$meta73681$$){this.id=$id$jscomp$861$$;this.$meta73681$=$meta73681$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$pin_version_73680$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$pin_version_73680$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5149$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_pin_version$$},$app$main$data$workspace$versions$pin_version_73680$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73682$$,$meta73681__$1$$){return new $app$main$data$workspace$versions$pin_version_73680$$(this.id,$meta73681__$1$$)},$app$main$data$workspace$versions$pin_version_73680$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73681$},$app$main$data$workspace$versions$pin_version_73680$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$pin_version_73680$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2823_params$jscomp$359_temp__5825__auto__$jscomp$279$$,$state$jscomp$1094$$){var $self__$jscomp$7069$$=this;$_$jscomp$2823_params$jscomp$359_temp__5825__auto__$jscomp$279$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73678_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73678_SHARP_$$),
$self__$jscomp$7069$$.id)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1094$$,$APP.$cljs$cst$4537$workspace_versions$$),$APP.$cljs$cst$142$data$$));return $APP.$cljs$core$truth_$$($_$jscomp$2823_params$jscomp$359_temp__5825__auto__$jscomp$279$$)?($_$jscomp$2823_params$jscomp$359_temp__5825__auto__$jscomp$279$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$self__$jscomp$7069$$.id,$APP.$cljs$cst$2296$label$$,
$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2823_params$jscomp$359_temp__5825__auto__$jscomp$279$$),$APP.$cljs$cst$5141$localized_date$$)],null),$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2160$editing$$,$self__$jscomp$7069$$.id],null)),$app$main$data$workspace$versions$fetch_versions$$(),
$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"pin-version"],null)))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5144$update_file_snapshot$$,$_$jscomp$2823_params$jscomp$359_temp__5825__auto__$jscomp$279$$))):null});return new $app$main$data$workspace$versions$pin_version_73680$$($id$jscomp$860$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$save_font$$=function($data$jscomp$373$$){typeof $app$main$data$workspace$texts$save_font_70429$$==="undefined"&&($app$main$data$workspace$texts$save_font_70429$$=function($data$jscomp$374$$,$meta70430$$){this.data=$data$jscomp$374$$;this.$meta70430$=$meta70430$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$save_font_70429$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$save_font_70429$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4090$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_save_font$$},$app$main$data$workspace$texts$save_font_70429$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70431$$,$meta70430__$1$$){return new $app$main$data$workspace$texts$save_font_70429$$(this.data,$meta70430__$1$$)},$app$main$data$workspace$texts$save_font_70429$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70430$},$app$main$data$workspace$texts$save_font_70429$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$save_font_70429$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2198_multiple_QMARK_$$,$state$jscomp$589$$){$_$jscomp$2198_multiple_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__70427_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__70427_SHARP_$$,
$APP.$cljs$cst$1621$multiple$$)},$APP.$cljs$core$vals$$(this.data));return $APP.$cljs$core$not$$($_$jscomp$2198_multiple_QMARK_$$)?$APP.$cljs$core$assoc_in$$($state$jscomp$589$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$2209$default_font$$],null),this.data):$state$jscomp$589$$});return new $app$main$data$workspace$texts$save_font_70429$$($data$jscomp$373$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$01$$=function(){return function($rf$jscomp$14$$){return function(){function $G__29191__2$$($result$jscomp$59$$,$input$jscomp$36$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$some_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$some_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($input$jscomp$36$$):$input$jscomp$36$$!=null)?$rf$jscomp$14$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$14$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$59$$,
$input$jscomp$36$$):$rf$jscomp$14$$($result$jscomp$59$$,$input$jscomp$36$$):$APP.$cljs$core$reduced$$($result$jscomp$59$$)}function $G__29191__1$$($result$jscomp$58$$){return $rf$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$14$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$58$$):$rf$jscomp$14$$($result$jscomp$58$$)}function $G__29191__0$$(){return $rf$jscomp$14$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$14$$.$cljs$core$IFn$_invoke$arity$0$():$rf$jscomp$14$$()}var $G__29191$$=null;$G__29191$$=
function($result$jscomp$60$$,$input$jscomp$37$$){switch(arguments.length){case 0:return $G__29191__0$$.call(this);case 1:return $G__29191__1$$.call(this,$result$jscomp$60$$);case 2:return $G__29191__2$$.call(this,$result$jscomp$60$$,$input$jscomp$37$$)}throw Error("Invalid arity: "+arguments.length);};$G__29191$$.$cljs$core$IFn$_invoke$arity$0$=$G__29191__0$$;$G__29191$$.$cljs$core$IFn$_invoke$arity$1$=$G__29191__1$$;$G__29191$$.$cljs$core$IFn$_invoke$arity$2$=$G__29191__2$$;return $G__29191$$}()}};
$app$common$geom$point$resize$$=function($vector$$,$new_length$$){var $old_length$$=$APP.$app$common$geom$point$length$$($vector$$);return $APP.$app$common$geom$point$scale$$($vector$$,$new_length$$/$old_length$$)};
$app$main$data$workspace$interactions$move_overlay_pos$$=function($pos$jscomp$112$$,$frame_pos$jscomp$1$$,$offset$jscomp$178$$){typeof $app$main$data$workspace$interactions$move_overlay_pos_70780$$==="undefined"&&($app$main$data$workspace$interactions$move_overlay_pos_70780$$=function($pos$jscomp$113$$,$frame_pos$jscomp$2$$,$offset$jscomp$179$$,$meta70781$$){this.pos=$pos$jscomp$113$$;this.$frame_pos$=$frame_pos$jscomp$2$$;this.offset=$offset$jscomp$179$$;this.$meta70781$=$meta70781$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$move_overlay_pos_70780$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$move_overlay_pos_70780$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4390$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_move_overlay_pos$$},$app$main$data$workspace$interactions$move_overlay_pos_70780$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70782$$,$meta70781__$1$$){return new $app$main$data$workspace$interactions$move_overlay_pos_70780$$(this.pos,this.$frame_pos$,this.offset,$meta70781__$1$$)},$app$main$data$workspace$interactions$move_overlay_pos_70780$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70781$},$app$main$data$workspace$interactions$move_overlay_pos_70780$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$move_overlay_pos_70780$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2429_pos__$1$jscomp$18$$,$state$jscomp$794$$){$_$jscomp$2429_pos__$1$jscomp$18$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$(this.pos,this.$frame_pos$),this.offset);return $APP.$cljs$core$assoc_in$$($state$jscomp$794$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4388$move_overlay_to$$],null),$_$jscomp$2429_pos__$1$jscomp$18$$)});return new $app$main$data$workspace$interactions$move_overlay_pos_70780$$($pos$jscomp$112$$,
$frame_pos$jscomp$1$$,$offset$jscomp$178$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$streams$get_angle$$=function($node$jscomp$333_rot_angle$$,$handler$jscomp$38_v2$jscomp$28$$,$opposite$jscomp$2_rot_sign_v1$jscomp$36$$){return $node$jscomp$333_rot_angle$$!=null&&$handler$jscomp$38_v2$jscomp$28$$!=null&&$opposite$jscomp$2_rot_sign_v1$jscomp$36$$!=null?($opposite$jscomp$2_rot_sign_v1$jscomp$36$$=$APP.$app$common$geom$point$subtract$$($opposite$jscomp$2_rot_sign_v1$jscomp$36$$,$node$jscomp$333_rot_angle$$),$handler$jscomp$38_v2$jscomp$28$$=$APP.$app$common$geom$point$subtract$$($handler$jscomp$38_v2$jscomp$28$$,
$node$jscomp$333_rot_angle$$),$node$jscomp$333_rot_angle$$=$APP.$app$common$geom$point$angle_with_other$$($opposite$jscomp$2_rot_sign_v1$jscomp$36$$,$handler$jscomp$38_v2$jscomp$28$$),$opposite$jscomp$2_rot_sign_v1$jscomp$36$$=$APP.$app$common$geom$point$angle_sign$$($opposite$jscomp$2_rot_sign_v1$jscomp$36$$,$handler$jscomp$38_v2$jscomp$28$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$node$jscomp$333_rot_angle$$,$opposite$jscomp$2_rot_sign_v1$jscomp$36$$],
null)):null};
$app$render_wasm$serializers$write_guides$$=function($guides$jscomp$4_guides__$1$jscomp$1$$,$objects$jscomp$237$$,$offset$jscomp$132$$){var $heapu32$$=$APP.$app$render_wasm$mem$get_heap_u32$$(),$heapf32$$=$APP.$app$render_wasm$mem$get_heap_f32$$();$guides$jscomp$4_guides__$1$jscomp$1$$=$APP.$cljs$core$vec$$($APP.$cljs$core$vals$$($APP.$cljs$core$truth_$$($guides$jscomp$4_guides__$1$jscomp$1$$)?$guides$jscomp$4_guides__$1$jscomp$1$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$));var $total$jscomp$9$$=$APP.$cljs$core$count$$($guides$jscomp$4_guides__$1$jscomp$1$$);
$heapu32$$[$offset$jscomp$132$$]=$total$jscomp$9$$;for(var $i$jscomp$505$$=0;;)if($i$jscomp$505$$<$total$jscomp$9$$){var $guide_53280$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($guides$jscomp$4_guides__$1$jscomp$1$$,$i$jscomp$505$$),$base_53281$$=$offset$jscomp$132$$+1+$i$jscomp$505$$*5,$vec__53254_53282$$=$app$render_wasm$serializers$guide_frame_range$$($guide_53280$$,$objects$jscomp$237$$),$frame_start_53283$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__53254_53282$$,
0,null),$frame_end_53284$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__53254_53282$$,1,null);$heapu32$$[$base_53281$$]=$app$render_wasm$serializers$translate_guide_axis$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide_53280$$,$APP.$cljs$cst$2062$axis$$));$heapu32$$[$base_53281$$+1]=$APP.$app$render_wasm$serializers$color$hex__GT_u32argb$$(function(){var $or__5025__auto__$jscomp$553$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide_53280$$,$APP.$cljs$cst$1303$color$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$553$$)?$or__5025__auto__$jscomp$553$$:"#ff3277"}(),1);$heapf32$$[$base_53281$$+2]=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide_53280$$,$APP.$cljs$cst$1681$position$$);$heapf32$$[$base_53281$$+3]=function(){var $or__5025__auto__$jscomp$554$$=$frame_start_53283$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$554$$)?$or__5025__auto__$jscomp$554$$:NaN}();$heapf32$$[$base_53281$$+4]=function(){var $or__5025__auto__$jscomp$555$$=
$frame_end_53284$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$555$$)?$or__5025__auto__$jscomp$555$$:NaN}();$i$jscomp$505$$+=1}else break};$promesa$core$all$$=function($promises$jscomp$8$$){return $APP.$promesa$protocols$_fmap$$($promesa$impl$promise$all$$($APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$($promises$jscomp$8$$)),$APP.$cljs$core$vec$$)};
$malli$error$_get$$=function($x$jscomp$829$$,$k$jscomp$436$$){return $APP.$cljs$core$set_QMARK_$$($x$jscomp$829$$)||$APP.$cljs$core$associative_QMARK_$$($x$jscomp$829$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$829$$,$k$jscomp$436$$):$APP.$cljs$core$sequential_QMARK_$$($x$jscomp$829$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$($x$jscomp$829$$),$k$jscomp$436$$):null};
$app$common$types$tokens_lib$split_set_str_path_prefix$$=function($G__49609__$1_path_str$jscomp$3$$){$G__49609__$1_path_str$jscomp$3$$=$G__49609__$1_path_str$jscomp$3$$==null?null:$APP.$cljs$core$re_matches$$(/^([SG]-)(.*)/,$G__49609__$1_path_str$jscomp$3$$);return $G__49609__$1_path_str$jscomp$3$$==null?null:$APP.$cljs$core$rest$$($G__49609__$1_path_str$jscomp$3$$)};
$app$main$data$workspace$colors$split_color_components$$=function($map__71207__$1_p__71206$$){$map__71207__$1_p__71206$$=$APP.$cljs$core$__destructure_map$$($map__71207__$1_p__71206$$);var $color$jscomp$97_value$jscomp$596$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71207__$1_p__71206$$,$APP.$cljs$cst$1303$color$$),$opacity$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71207__$1_p__71206$$,$APP.$cljs$cst$1740$opacity$$);$color$jscomp$97_value$jscomp$596$$=
$APP.$app$common$types$color$valid_hex_color_QMARK_$$($color$jscomp$97_value$jscomp$596$$)?$color$jscomp$97_value$jscomp$596$$:"#000000";var $b$jscomp$319_vec__71208$$=$APP.$app$common$types$color$hex__GT_rgb$$($color$jscomp$97_value$jscomp$596$$),$r$jscomp$117$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$319_vec__71208$$,0,null),$g$jscomp$138$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$319_vec__71208$$,1,null);$b$jscomp$319_vec__71208$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$319_vec__71208$$,
2,null);var $v$jscomp$598_vec__71211$$=$app$common$types$color$hex__GT_hsv$$($color$jscomp$97_value$jscomp$596$$),$h$jscomp$164$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$598_vec__71211$$,0,null),$s$jscomp$552$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$598_vec__71211$$,1,null);$v$jscomp$598_vec__71211$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$598_vec__71211$$,2,null);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__71207__$1_p__71206$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$2698$hex$$,$APP.$cljs$core$truth_$$($color$jscomp$97_value$jscomp$596$$)?$color$jscomp$97_value$jscomp$596$$:"000000",$APP.$cljs$cst$746$alpha$$,$APP.$cljs$core$truth_$$(isNaN($opacity$jscomp$28$$))?1:$APP.$cljs$core$truth_$$($opacity$jscomp$28$$)?$opacity$jscomp$28$$:1,$APP.$cljs$cst$1749$r$$,$r$jscomp$117$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$138$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$319_vec__71208$$,$APP.$cljs$cst$1907$h$$,$h$jscomp$164$$,
$APP.$cljs$cst$4235$s$$,$s$jscomp$552$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$598_vec__71211$$],null)]))};
$app$common$types$color$library_color__GT_color$$=function($lcolor$$,$file_id$$){return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$06$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$select_keys$$($lcolor$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1617$image$$,$APP.$cljs$cst$1730$gradient$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1740$opacity$$],
null)),$APP.$cljs$cst$1741$ref_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($lcolor$$,$APP.$cljs$cst$266$id$$)),$APP.$cljs$cst$1742$ref_file$$,$file_id$$),$APP.$cljs$core$assoc$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($lcolor$$,$APP.$cljs$cst$296$path$$),$APP.$cljs$cst$725$name$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($lcolor$$,$APP.$cljs$cst$725$name$$))};
$app$main$fonts$get_node_fonts$$=function($node$jscomp$263_result$jscomp$234$$){$node$jscomp$263_result$jscomp$234$$=Array.from($APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$263_result$jscomp$234$$,"[style*\x3dfont]")).reduce(function($obj$jscomp$188$$,$font_id$jscomp$3_node__$1$jscomp$66_vec__53043$$){var $font_variant_font_variant_id$jscomp$2_style$jscomp$13$$=$font_id$jscomp$3_node__$1$jscomp$66_vec__53043$$.style,$font_family$jscomp$2$$=$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$.fontFamily;
$font_id$jscomp$3_node__$1$jscomp$66_vec__53043$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$294_map__53054_p__53050$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$294_map__53054_p__53050$$,0,null);$id$jscomp$294_map__53054_p__53050$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$294_map__53054_p__53050$$,1,null);var $family$jscomp$4_map__53054__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$294_map__53054_p__53050$$);
$id$jscomp$294_map__53054_p__53050$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$4_map__53054__$1$$,$APP.$cljs$cst$266$id$$);$family$jscomp$4_map__53054__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$4_map__53054__$1$$,$APP.$cljs$cst$2686$family$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$4_map__53054__$1$$,$font_family$jscomp$2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$294_map__53054_p__53050$$,
$font_family$jscomp$2$$)},$APP.$cljs$core$_deref$$($APP.$app$main$fonts$fontsdb$$)));$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_id$jscomp$3_node__$1$jscomp$66_vec__53043$$,0,null);var $font$jscomp$16$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font_id$jscomp$3_node__$1$jscomp$66_vec__53043$$,1,null);$font_id$jscomp$3_node__$1$jscomp$66_vec__53043$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$16$$);$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$=
$APP.$app$main$fonts$get_variant$$($font$jscomp$16$$,$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$.fontVariant);$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font_variant_font_variant_id$jscomp$2_style$jscomp$13$$);return $APP.$app$util$object$set_BANG_$$($obj$jscomp$188$$,""+($font_id$jscomp$3_node__$1$jscomp$66_vec__53043$$??"")+":"+($font_variant_font_variant_id$jscomp$2_style$jscomp$13$$??""),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1763$font_id$$,$font_id$jscomp$3_node__$1$jscomp$66_vec__53043$$,$APP.$cljs$cst$1765$font_variant_id$$,$font_variant_font_variant_id$jscomp$2_style$jscomp$13$$],null))},{});return Object.values($node$jscomp$263_result$jscomp$234$$)};
$app$common$types$text$content_has_text_QMARK_$$=function($content$jscomp$18$$,$search$$){var $search_lower$$=$APP.$cuerdas$core$lower$$($search$$);return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$(function($p1__45931_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($p1__45931_SHARP_$$)),$search_lower$$)},$APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,
$content$jscomp$18$$)))};
$app$common$types$shape$layout$cells_in_area$$=function($parent$jscomp$180$$,$first_row$$,$last_row$$,$first_column$$,$last_column$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__48381_row$jscomp$16$$){var $column_span$jscomp$8_map__48382__$1$$=$APP.$cljs$core$__destructure_map$$($p__48381_row$jscomp$16$$);$p__48381_row$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$8_map__48382__$1$$,$APP.$cljs$cst$1661$row$$);var $column$jscomp$23$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$8_map__48382__$1$$,$APP.$cljs$cst$216$column$$),$row_span$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$8_map__48382__$1$$,$APP.$cljs$cst$1662$row_span$$);$column_span$jscomp$8_map__48382__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($column_span$jscomp$8_map__48382__$1$$,$APP.$cljs$cst$1663$column_span$$);return($p__48381_row$jscomp$16$$<=$first_row$$&&$first_row$$<=$p__48381_row$jscomp$16$$+
$row_span$jscomp$8$$+-1||$p__48381_row$jscomp$16$$<=$last_row$$&&$last_row$$<=$p__48381_row$jscomp$16$$+$row_span$jscomp$8$$+-1||$first_row$$<=$p__48381_row$jscomp$16$$&&$p__48381_row$jscomp$16$$<=$last_row$$||$first_row$$<=$p__48381_row$jscomp$16$$+$row_span$jscomp$8$$+-1&&$p__48381_row$jscomp$16$$+$row_span$jscomp$8$$+-1<=$last_row$$)&&($column$jscomp$23$$<=$first_column$$&&$first_column$$<=$column$jscomp$23$$+$column_span$jscomp$8_map__48382__$1$$+-1||$column$jscomp$23$$<=$last_column$$&&$last_column$$<=
$column$jscomp$23$$+$column_span$jscomp$8_map__48382__$1$$+-1||$first_column$$<=$column$jscomp$23$$&&$column$jscomp$23$$<=$last_column$$||$first_column$$<=$column$jscomp$23$$+$column_span$jscomp$8_map__48382__$1$$+-1&&$column$jscomp$23$$+$column_span$jscomp$8_map__48382__$1$$+-1<=$last_column$$)},$APP.$cljs$core$vals$$($APP.$cljs$cst$1701$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$180$$)))};
$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$=function($parent$jscomp$178$$,$index$jscomp$160$$){return $APP.$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$178$$,$index$jscomp$160$$,!0)};
$app$common$types$shape$layout$cells_by_column$$=function($var_args$jscomp$916$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $APP.$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$=function($parent$jscomp$176$$,$index$jscomp$158$$){return $APP.$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$03$$($parent$jscomp$176$$,$index$jscomp$158$$,!0)};
$app$common$types$shape$layout$cells_by_row$$=function($var_args$jscomp$915$$){switch(arguments.length){case 2:return $app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);case 3:return $APP.$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$common$types$shape$layout$remove_cell_areas_after$$=function($parent$jscomp$139$$,$prop$jscomp$13$$,$index$jscomp$148$$){var $prop_span$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$13$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$cst$1663$column_span$$:$APP.$cljs$cst$1662$row_span$$,$cells$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$13$$,$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$?
$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$139$$,$index$jscomp$148$$):$app$common$types$shape$layout$cells_by_column$$($parent$jscomp$139$$,$index$jscomp$148$$):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$139$$,$index$jscomp$148$$):$app$common$types$shape$layout$cells_by_row$$($parent$jscomp$139$$,$index$jscomp$148$$);
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$1$jscomp$39$$,$cell$jscomp$1$$){var $area_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1679$area$$,$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$1$$)),$changed_cells$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop$jscomp$13$$),$index$jscomp$148$$+
1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$1$$,$prop_span$jscomp$1$$,1),function(){var $G__48059$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$jscomp$1$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$shapes$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$13$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop$jscomp$13$$)+1,$prop_span$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop_span$jscomp$1$$)-1])),$APP.$cljs$cst$1680$area_name$$);return $area_QMARK_$jscomp$1$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48059$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1678$manual$$):$G__48059$$}()],null):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,
$prop$jscomp$13$$)<$index$jscomp$148$$+1&&$index$jscomp$148$$+1<$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop$jscomp$13$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop_span$jscomp$1$$)-1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$1$$,$prop_span$jscomp$1$$,$index$jscomp$148$$+2-$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,
$prop$jscomp$13$$)),function(){var $G__48061$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$jscomp$1$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$13$$,$index$jscomp$148$$+2,$prop_span$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,
$prop$jscomp$13$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$1$$,$prop_span$jscomp$1$$)-1)-($index$jscomp$148$$+1)])),$APP.$cljs$cst$1680$area_name$$);return $area_QMARK_$jscomp$1$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48061$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1678$manual$$):$G__48061$$}()],null):null;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__48047_SHARP_$$,$p2__48048_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__48047_SHARP_$$,
$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p2__48048_SHARP_$$),$p2__48048_SHARP_$$)},$parent__$1$jscomp$39$$,$changed_cells$jscomp$1$$)},$parent$jscomp$139$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48046_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__48046_SHARP_$$,$prop_span$jscomp$1$$)>1},$cells$jscomp$1$$))};
$app$common$types$shape$layout$remove_cell_areas$$=function($parent$jscomp$138$$,$prop$jscomp$12$$,$index$jscomp$147$$){var $prop_span$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$12$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$cst$1663$column_span$$:$APP.$cljs$cst$1662$row_span$$,$cells$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$12$$,$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$138$$,
$index$jscomp$147$$):$app$common$types$shape$layout$cells_by_column$$($parent$jscomp$138$$,$index$jscomp$147$$):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($parent$jscomp$138$$,$index$jscomp$147$$):$app$common$types$shape$layout$cells_by_row$$($parent$jscomp$138$$,$index$jscomp$147$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($parent__$1$jscomp$38$$,
$cell$$){var $area_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1679$area$$,$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$$)),$changed_cells$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$),$index$jscomp$147$$+1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$$,
$prop_span$$,1),function(){var $G__48027$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$12$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)+1,$prop_span$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,
$prop_span$$)-1])),$APP.$cljs$cst$1680$area_name$$);return $area_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48027$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1678$manual$$):$G__48027$$}()],null):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)<$index$jscomp$147$$+1&&$index$jscomp$147$$+1<$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop_span$$)-
1)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$$,$prop_span$$,$index$jscomp$147$$+1-$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)),function(){var $G__48029$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$shapes$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$12$$,$index$jscomp$147$$+1,$prop_span$$,1])),$APP.$cljs$cst$1680$area_name$$);return $area_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48029$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1678$manual$$):$G__48029$$}(),function(){var $G__48031$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$12$$,$index$jscomp$147$$+2,$prop_span$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop_span$$)-1)-($index$jscomp$147$$+1)])),$APP.$cljs$cst$1680$area_name$$);return $area_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48031$$,$APP.$cljs$cst$1681$position$$,
$APP.$cljs$cst$1678$manual$$):$G__48031$$}()],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop$jscomp$12$$)+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,$prop_span$$)-1),$index$jscomp$147$$+1)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cell$$,$prop_span$$,$index$jscomp$147$$+1-$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$$,
$prop$jscomp$12$$)),function(){var $G__48034$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($cell$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$prop$jscomp$12$$,$index$jscomp$147$$+1,$prop_span$$,1])),$APP.$cljs$cst$1680$area_name$$);return $area_QMARK_$$?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48034$$,
$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1678$manual$$):$G__48034$$}()],null):null;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__48022_SHARP_$$,$p2__48023_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__48022_SHARP_$$,$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p2__48023_SHARP_$$),$p2__48023_SHARP_$$)},$parent__$1$jscomp$38$$,$changed_cells$$)},$parent$jscomp$138$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48021_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__48021_SHARP_$$,$prop_span$$)>1},$cells$$))};
$app$main$data$workspace$colors$remove_gradient_stop$cljs$0core$0IFn$0_invoke$0arity$01$$=function($index$jscomp$310$$){typeof $app$main$data$workspace$colors$remove_gradient_stop_71264$$==="undefined"&&($app$main$data$workspace$colors$remove_gradient_stop_71264$$=function($index$jscomp$311$$,$meta71265$$){this.index=$index$jscomp$311$$;this.$meta71265$=$meta71265$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$remove_gradient_stop_71264$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_gradient_stop_71264$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4246$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_gradient_stop$$},$app$main$data$workspace$colors$remove_gradient_stop_71264$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71266$$,$meta71265__$1$$){return new $app$main$data$workspace$colors$remove_gradient_stop_71264$$(this.index,$meta71265__$1$$)},
$app$main$data$workspace$colors$remove_gradient_stop_71264$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71265$},$app$main$data$workspace$colors$remove_gradient_stop_71264$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_gradient_stop_71264$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2288$$,$state$jscomp$666$$){var $self__$jscomp$5343$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$666$$,
$APP.$cljs$cst$2247$colorpicker$$,function($map__71268__$1_p__71267$$){$map__71268__$1_p__71267$$=$APP.$cljs$core$__destructure_map$$($map__71268__$1_p__71267$$);var $editing_stop$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71268__$1_p__71267$$,$APP.$cljs$cst$4229$editing_stop$$),$stops$jscomp$15_stops__$1$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71268__$1_p__71267$$,$APP.$cljs$cst$1739$stops$$);if($APP.$cljs$core$count$$($stops$jscomp$15_stops__$1$jscomp$6$$)>
2){var $delete_index_editing_stop__$1$jscomp$1$$=function(){var $or__5025__auto__$jscomp$845$$=$self__$jscomp$5343$$.index;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$845$$)?$or__5025__auto__$jscomp$845$$:$APP.$cljs$core$truth_$$($editing_stop$jscomp$2$$)?$editing_stop$jscomp$2$$:0}(),$delete_stop$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$15_stops__$1$jscomp$6$$,$delete_index_editing_stop__$1$jscomp$1$$);$stops$jscomp$15_stops__$1$jscomp$6$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__71261_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($delete_stop$$,$p1__71261_SHARP_$$)}),$stops$jscomp$15_stops__$1$jscomp$6$$);$delete_index_editing_stop__$1$jscomp$1$$=$editing_stop$jscomp$2$$<$delete_index_editing_stop__$1$jscomp$1$$?$editing_stop$jscomp$2$$:$editing_stop$jscomp$2$$>$delete_index_editing_stop__$1$jscomp$1$$?$editing_stop$jscomp$2$$-1:$APP.$cljs$core$count$$($stops$jscomp$15_stops__$1$jscomp$6$$)>=
$editing_stop$jscomp$2$$?$APP.$cljs$core$count$$($stops$jscomp$15_stops__$1$jscomp$6$$)-1:$editing_stop$jscomp$2$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71268__$1_p__71267$$,$APP.$cljs$cst$4229$editing_stop$$,$delete_index_editing_stop__$1$jscomp$1$$),$APP.$cljs$cst$1739$stops$$,$stops$jscomp$15_stops__$1$jscomp$6$$)}return $map__71268__$1_p__71267$$})});return new $app$main$data$workspace$colors$remove_gradient_stop_71264$$($index$jscomp$310$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$=function($f$jscomp$209$$,$coll$jscomp$280$$){return function $cljs$core$keepi$$($idx$jscomp$17$$,$coll__$1$jscomp$100$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $temp__5825__auto__$jscomp$4$$=$APP.$cljs$core$seq$$($coll__$1$jscomp$100$$);if($temp__5825__auto__$jscomp$4$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($temp__5825__auto__$jscomp$4$$)){for(var $c$jscomp$106$$=$APP.$cljs$core$_chunked_first$$($temp__5825__auto__$jscomp$4$$),$size$jscomp$32_x$jscomp$407$$=
$APP.$cljs$core$count$$($c$jscomp$106$$),$b$jscomp$130$$=$APP.$cljs$core$chunk_buffer$$($size$jscomp$32_x$jscomp$407$$),$i_27221$$=0;;)if($i_27221$$<$size$jscomp$32_x$jscomp$407$$){var $x_27222$$=function(){var $G__23382$$=$idx$jscomp$17$$+$i_27221$$,$G__23383$$=$APP.$cljs$core$_nth$$($c$jscomp$106$$,$i_27221$$);return $f$jscomp$209$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$209$$.$cljs$core$IFn$_invoke$arity$2$($G__23382$$,$G__23383$$):$f$jscomp$209$$($G__23382$$,$G__23383$$)}();$x_27222$$!=null&&
$b$jscomp$130$$.add($x_27222$$);$i_27221$$+=1}else break;return $APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b$jscomp$130$$),$cljs$core$keepi$$($idx$jscomp$17$$+$size$jscomp$32_x$jscomp$407$$,$APP.$cljs$core$_chunked_rest$$($temp__5825__auto__$jscomp$4$$)))}$size$jscomp$32_x$jscomp$407$$=function(){var $G__23385$$=$APP.$cljs$core$first$$($temp__5825__auto__$jscomp$4$$);return $f$jscomp$209$$.$cljs$core$IFn$_invoke$arity$2$?$f$jscomp$209$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$17$$,
$G__23385$$):$f$jscomp$209$$($idx$jscomp$17$$,$G__23385$$)}();return $size$jscomp$32_x$jscomp$407$$==null?$cljs$core$keepi$$($idx$jscomp$17$$+1,$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$4$$)):$APP.$cljs$core$cons$$($size$jscomp$32_x$jscomp$407$$,$cljs$core$keepi$$($idx$jscomp$17$$+1,$APP.$cljs$core$rest$$($temp__5825__auto__$jscomp$4$$)))}return null},null,null)}(0,$coll$jscomp$280$$)};
$app$main$data$workspace$tokens$errors$detail_errors$$=function($errors$jscomp$19$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($err$jscomp$41_fexpr__72087$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$4683$error_SLASH_detail$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$41_fexpr__72087$$))){var $G__72088$$=$APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$41_fexpr__72087$$);
$err$jscomp$41_fexpr__72087$$=$APP.$cljs$cst$4683$error_SLASH_detail$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$41_fexpr__72087$$);return $err$jscomp$41_fexpr__72087$$.$cljs$core$IFn$_invoke$arity$1$?$err$jscomp$41_fexpr__72087$$.$cljs$core$IFn$_invoke$arity$1$($G__72088$$):$err$jscomp$41_fexpr__72087$$($G__72088$$)}return null},$errors$jscomp$19$$)))};
$app$main$data$workspace$tokens$errors$humanize_errors$$=function($errors$jscomp$18$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($err$jscomp$40_fexpr__72084$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__72084$$))){var $G__72085$$=$APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__72084$$);$err$jscomp$40_fexpr__72084$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__72084$$);
return $err$jscomp$40_fexpr__72084$$.$cljs$core$IFn$_invoke$arity$1$?$err$jscomp$40_fexpr__72084$$.$cljs$core$IFn$_invoke$arity$1$($G__72085$$):$err$jscomp$40_fexpr__72084$$($G__72085$$)}return $APP.$cljs$core$truth_$$($APP.$cljs$cst$882$error_SLASH_message$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__72084$$))?$APP.$cljs$cst$882$error_SLASH_message$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$40_fexpr__72084$$):$err$jscomp$40_fexpr__72084$$},$errors$jscomp$18$$)};
$app$main$data$workspace$show_grid_cell_context_menu$$=function($p__72160$$){var $map__72161__$1$$=$APP.$cljs$core$__destructure_map$$($p__72160$$),$grid_id$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72161__$1$$,$APP.$cljs$cst$4487$grid_id$$);typeof $app$main$data$workspace$show_grid_cell_context_menu_72162$$==="undefined"&&($app$main$data$workspace$show_grid_cell_context_menu_72162$$=function($p__72160$jscomp$1$$,$map__72161$jscomp$1$$,$params$jscomp$305$$,$grid_id$jscomp$26$$,
$meta72163$$){this.$p__72160$=$p__72160$jscomp$1$$;this.$map__72161$=$map__72161$jscomp$1$$;this.params=$params$jscomp$305$$;this.$grid_id$=$grid_id$jscomp$26$$;this.$meta72163$=$meta72163$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_grid_cell_context_menu_72162$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_grid_cell_context_menu_72162$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4579$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_grid_cell_context_menu$$},$app$main$data$workspace$show_grid_cell_context_menu_72162$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72164$$,$meta72163__$1$$){return new $app$main$data$workspace$show_grid_cell_context_menu_72162$$(this.$p__72160$,this.$map__72161$,this.params,this.$grid_id$,$meta72163__$1$$)},$app$main$data$workspace$show_grid_cell_context_menu_72162$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72163$},$app$main$data$workspace$show_grid_cell_context_menu_72162$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_grid_cell_context_menu_72162$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2604_objects$jscomp$679$$,$cells$jscomp$28_state$jscomp$930$$){$_$jscomp$2604_objects$jscomp$679$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$28_state$jscomp$930$$);
var $grid$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2604_objects$jscomp$679$$,this.$grid_id$);$cells$jscomp$28_state$jscomp$930$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72159_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$p1__72159_SHARP_$$],null))},$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$28_state$jscomp$930$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1938$selected$$],null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$show_context_menu$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$(this.params,$APP.$cljs$cst$947$kind$$,$APP.$cljs$cst$3077$grid_cells$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1664$grid$$,
$grid$jscomp$9$$,$APP.$cljs$cst$4580$cells$$,$cells$jscomp$28_state$jscomp$930$$]))))});return new $app$main$data$workspace$show_grid_cell_context_menu_72162$$($p__72160$$,$map__72161__$1$$,$map__72161__$1$$,$grid_id$jscomp$25$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$color$offset_spread$$=function($from$jscomp$9$$,$to$jscomp$8$$,$num$jscomp$27$$){return $num$jscomp$27$$<=1?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from$jscomp$9$$],null):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__45574_SHARP_$$){return $APP.$app$common$math$precision$$($from$jscomp$9$$+($to$jscomp$8$$-$from$jscomp$9$$)/($num$jscomp$27$$-1)*$p1__45574_SHARP_$$,2)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(0,
$num$jscomp$27$$))};
$app$common$types$shape$layout$swap_track_content$$=function($parent$jscomp$149$$,$prop$jscomp$17$$,$from_track$$,$to_track$$){var $remap_tracks$$=$from_track$$>$to_track$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$from_track$$,$to_track$$]),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48164_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__48164_SHARP_$$,
$p1__48164_SHARP_$$+1],null)}),$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($to_track$$,$from_track$$)):$from_track$$<$to_track$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$from_track$$,$to_track$$]),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__48165_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__48165_SHARP_$$,$p1__48165_SHARP_$$-
1],null)}),$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($from_track$$+1,$to_track$$+1)):null;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($parent$jscomp$149$$,$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$core$update_vals$$,function($cell$jscomp$8$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($cell$jscomp$8$$,$prop$jscomp$17$$,function($p1__48166_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($remap_tracks$$,$p1__48166_SHARP_$$,
$p1__48166_SHARP_$$)})})};$app$common$data$natural_sort_key$$=function($s$jscomp$288$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($part$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$re_matches$$(/\d+/,$part$jscomp$1$$))?parseInt($part$jscomp$1$$):$part$jscomp$1$$},$APP.$cljs$core$re_seq$$(/\d+|\D+/,$s$jscomp$288$$))};
$app$common$data$natural_compare$$=function($G__32733_a$jscomp$232_ka$$,$G__32734_b$jscomp$189_kb$$){$G__32733_a$jscomp$232_ka$$=$app$common$data$natural_sort_key$$($G__32733_a$jscomp$232_ka$$);for($G__32734_b$jscomp$189_kb$$=$app$common$data$natural_sort_key$$($G__32734_b$jscomp$189_kb$$);;){if($APP.$app$common$data$empty_QMARK_$$($G__32733_a$jscomp$232_ka$$)&&$APP.$app$common$data$empty_QMARK_$$($G__32734_b$jscomp$189_kb$$))return 0;if($APP.$app$common$data$empty_QMARK_$$($G__32733_a$jscomp$232_ka$$))return-1;
if($APP.$app$common$data$empty_QMARK_$$($G__32734_b$jscomp$189_kb$$))return 1;var $pa$jscomp$2_result$jscomp$92$$=$APP.$cljs$core$first$$($G__32733_a$jscomp$232_ka$$),$pb$$=$APP.$cljs$core$first$$($G__32734_b$jscomp$189_kb$$);$pa$jscomp$2_result$jscomp$92$$=typeof $pa$jscomp$2_result$jscomp$92$$==="number"&&typeof $pb$$==="number"?$APP.$cljs$core$compare$$($pa$jscomp$2_result$jscomp$92$$,$pb$$):typeof $pa$jscomp$2_result$jscomp$92$$==="string"&&typeof $pb$$==="string"?$APP.$cljs$core$compare$$($pa$jscomp$2_result$jscomp$92$$,
$pb$$):typeof $pa$jscomp$2_result$jscomp$92$$==="number"?-1:1;if($pa$jscomp$2_result$jscomp$92$$===0)$G__32733_a$jscomp$232_ka$$=$APP.$cljs$core$rest$$($G__32733_a$jscomp$232_ka$$),$G__32734_b$jscomp$189_kb$$=$APP.$cljs$core$rest$$($G__32734_b$jscomp$189_kb$$);else return $pa$jscomp$2_result$jscomp$92$$}};
$app$common$data$invert_map$$=function($m$jscomp$100$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__32044_v$jscomp$147$$){var $k$jscomp$270$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32044_v$jscomp$147$$,0,null);$p__32044_v$jscomp$147$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__32044_v$jscomp$147$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__32044_v$jscomp$147$$,$k$jscomp$270$$],null)},$m$jscomp$100$$))};
$app$common$types$tokens_lib$get_json_format$cljs$0core$0IFn$0_invoke$0arity$03$$=function($decoded_json$jscomp$1$$){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,function $app$common$types$tokens_lib$walk$jscomp$2$$($node$jscomp$253$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $JSCompiler_inline_result$jscomp$1547$$=$APP.$cljs$core$truth_$$($APP.$app$common$types$tokens_lib$legacy_node_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$app$common$types$tokens_lib$legacy_node_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$253$$):(0,$APP.$app$common$types$tokens_lib$legacy_node_QMARK_$$)($node$jscomp$253$$))?$APP.$cljs$cst$2139$json_format_SLASH_legacy$$:$APP.$cljs$core$truth_$$($APP.$app$common$types$tokens_lib$dtcg_node_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$tokens_lib$dtcg_node_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$253$$):(0,$APP.$app$common$types$tokens_lib$dtcg_node_QMARK_$$)($node$jscomp$253$$))?
$APP.$cljs$cst$2140$json_format_SLASH_dtcg$$:null;return $APP.$cljs$core$cons$$($JSCompiler_inline_result$jscomp$1547$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$map_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$map_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$253$$):$APP.$cljs$core$map_QMARK_$$($node$jscomp$253$$))?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$common$types$tokens_lib$walk$jscomp$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($node$jscomp$253$$)])):
null)},null,null)}($decoded_json$jscomp$1$$))),$APP.$cljs$cst$2140$json_format_SLASH_dtcg$$)};
$app$common$types$color$hsv__GT_rgb$$=function($p__45362_sextant$$){var $h$jscomp$140_remainder$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45362_sextant$$,0,null),$s$jscomp$512_val3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45362_sextant$$,1,null),$brightness_brightness__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__45362_sextant$$,2,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$512_val3$$,0))return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$brightness_brightness__$1$$,$brightness_brightness__$1$$,$brightness_brightness__$1$$],null);$p__45362_sextant$$=$APP.$app$common$math$floor$$($h$jscomp$140_remainder$jscomp$12$$/60)|0;$h$jscomp$140_remainder$jscomp$12$$=$h$jscomp$140_remainder$jscomp$12$$/60-$p__45362_sextant$$;$brightness_brightness__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($brightness_brightness__$1$$,0);var $val1$jscomp$2$$=$brightness_brightness__$1$$*
(1-$s$jscomp$512_val3$$)|0,$val2$jscomp$2$$=$brightness_brightness__$1$$*(1-$s$jscomp$512_val3$$*$h$jscomp$140_remainder$jscomp$12$$)|0;$s$jscomp$512_val3$$=$brightness_brightness__$1$$*(1-$s$jscomp$512_val3$$*(1-$h$jscomp$140_remainder$jscomp$12$$))|0;switch($p__45362_sextant$$){case 1:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val2$jscomp$2$$,$brightness_brightness__$1$$,$val1$jscomp$2$$],null);case 2:return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val1$jscomp$2$$,$brightness_brightness__$1$$,$s$jscomp$512_val3$$],null);case 3:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val1$jscomp$2$$,$val2$jscomp$2$$,$brightness_brightness__$1$$],null);case 4:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s$jscomp$512_val3$$,$val1$jscomp$2$$,$brightness_brightness__$1$$],null);case 5:return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$brightness_brightness__$1$$,$val1$jscomp$2$$,$val2$jscomp$2$$],null);case 6:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$brightness_brightness__$1$$,$s$jscomp$512_val3$$,$val1$jscomp$2$$],null);case 0:return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$brightness_brightness__$1$$,$s$jscomp$512_val3$$,$val1$jscomp$2$$],null);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__45362_sextant$$)].join(""));}};
$app$util$dom$bounding_rect__GT_rect$$=function($rect$jscomp$9$$){return $rect$jscomp$9$$!=null?$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$(function(){var $or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$=$rect$jscomp$9$$.left;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$))return $or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$;$or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$=$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$9$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$)?$or__5025__auto__$jscomp$304_or__5025__auto____$1$jscomp$37$$:0}(),function(){var $or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$=$rect$jscomp$9$$.top;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$))return $or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$;$or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$=$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$9$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$)?$or__5025__auto__$jscomp$305_or__5025__auto____$1$jscomp$38$$:0}(),function(){var $or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$=$rect$jscomp$9$$.width;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$))return $or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$;$or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$9$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$)?$or__5025__auto__$jscomp$306_or__5025__auto____$1$jscomp$39$$:1}(),function(){var $or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$=$rect$jscomp$9$$.height;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$))return $or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$;$or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$9$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$)?$or__5025__auto__$jscomp$307_or__5025__auto____$1$jscomp$40$$:1}()):null};
$app$common$geom$shapes$text$overlaps_position_data_QMARK_$$=function($map__48865__$1_p__48864_points$jscomp$41$$,$position_data$jscomp$2$$){$map__48865__$1_p__48864_points$jscomp$41$$=$APP.$cljs$core$__destructure_map$$($map__48865__$1_p__48864_points$jscomp$41$$);$map__48865__$1_p__48864_points$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48865__$1_p__48864_points$jscomp$41$$,$APP.$cljs$cst$1609$points$$);var $bounding_box$$=$APP.$app$common$geom$rect$points__GT_rect$$($map__48865__$1_p__48864_points$jscomp$41$$);
return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$(function($JSCompiler_inline_result$jscomp$1548_p1__48863_SHARP_$$){$JSCompiler_inline_result$jscomp$1548_p1__48863_SHARP_$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1548_p1__48863_SHARP_$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1548_p1__48863_SHARP_$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1548_p1__48863_SHARP_$$));
return $APP.$app$common$geom$rect$overlaps_rects_QMARK_$$($bounding_box$$,$JSCompiler_inline_result$jscomp$1548_p1__48863_SHARP_$$)},$position_data$jscomp$2$$))};
$app$common$types$tokens_lib$legacy_json__GT_dtcg_json$$=function($decoded_json$jscomp$2$$){return $APP.$clojure$walk$postwalk$$(function($node$jscomp$254$$){var $G__50050__$1_G__50050__$2$$=$APP.$cljs$core$map_QMARK_$$($node$jscomp$254$$)&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$254$$,"value")&&$APP.$cljs$core$sequential_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$254$$,"value"))&&$APP.$cljs$core$map_QMARK_$$($APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$254$$,
"value")))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$254$$,"value",function($seq_value$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__50048_SHARP_$$){return $APP.$clojure$set$rename_keys$$($p1__50048_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,["type","$type"],null))},$seq_value$$)}):$node$jscomp$254$$;$G__50050__$1_G__50050__$2$$=($APP.$cljs$core$map_QMARK_$$($node$jscomp$254$$)&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$254$$,
"type")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("fontFamilies",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$254$$,"type"))&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$254$$,"value")&&$APP.$cljs$core$sequential_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$254$$,"value"))&&$APP.$cljs$core$map_QMARK_$$($APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$254$$,"value"))),$G__50050__$1_G__50050__$2$$);
return $APP.$cljs$core$map_QMARK_$$($node$jscomp$254$$)&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$254$$,"type")&&$APP.$cljs$core$contains_QMARK_$$($node$jscomp$254$$,"value")?$APP.$clojure$set$rename_keys$$($G__50050__$1_G__50050__$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["value","$value","type","$type"],null)):$G__50050__$1_G__50050__$2$$},$decoded_json$jscomp$2$$)};
$app$common$types$text$replace_text_in_content$$=function($content$jscomp$19$$,$search$jscomp$2$$,$replacement$jscomp$14$$){return $APP.$app$common$types$text$transform_nodes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$text$is_text_node_QMARK_$$,function($node$jscomp$237$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($node$jscomp$237$$,$APP.$cljs$cst$1593$text$$,$app$common$types$text$replace_all_case_insensitive$$,$search$jscomp$2$$,$replacement$jscomp$14$$)},
$content$jscomp$19$$)};
$cljs$spec$alpha$abbrev$$=function($form$jscomp$113$$){return $APP.$cljs$core$seq_QMARK_$$($form$jscomp$113$$)?$APP.$clojure$walk$postwalk$$(function($form__$1$$){var $JSCompiler_inline_result$jscomp$1549_and__5023__auto__$jscomp$inline_8297$$=($JSCompiler_inline_result$jscomp$1549_and__5023__auto__$jscomp$inline_8297$$=$form__$1$$ instanceof $APP.$cljs$core$Symbol$$)?$APP.$cljs$core$namespace$$($form__$1$$):$JSCompiler_inline_result$jscomp$1549_and__5023__auto__$jscomp$inline_8297$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1549_and__5023__auto__$jscomp$inline_8297$$)?
$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$name$$($form__$1$$)):$APP.$cljs$core$seq_QMARK_$$($form__$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$28$fn$$,$APP.$cljs$core$first$$($form__$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$979$_PERCENT_$$],null),$APP.$cljs$core$second$$($form__$1$$))?$APP.$cljs$core$last$$($form__$1$$):
$form__$1$$},$form$jscomp$113$$):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$150$$=$form$jscomp$113$$ instanceof $APP.$cljs$core$Symbol$$;return $and__5023__auto__$jscomp$150$$?$APP.$cljs$core$namespace$$($form$jscomp$113$$):$and__5023__auto__$jscomp$150$$}())?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$name$$($form$jscomp$113$$)):$form$jscomp$113$$};
$app$render_wasm$api$find_guide_at$$=function($cause54536_position$jscomp$59$$,$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$){var $fn_54535_hint__53068__auto__$jscomp$97$$=$APP.$app$render_wasm$wasm$internal_module$$._find_guide_at;try{return $fn_54535_hint__53068__auto__$jscomp$97$$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cause54536_position$jscomp$59$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cause54536_position$jscomp$59$$),
$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$,16)}catch($e54537$$){throw $cause54536_position$jscomp$59$$=$e54537$$,$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$)?
$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$():null,$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$,$APP.$cljs$cst$2982$wasm_critical$$),$fn_54535_hint__53068__auto__$jscomp$97$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_54535_hint__53068__auto__$jscomp$97$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_find_guide_at",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_54535_hint__53068__auto__$jscomp$97$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$97_code_num__53066__auto__$jscomp$97_read_code_fn__53065__auto__$jscomp$97_zoom$jscomp$6$$],null),$cause54536_position$jscomp$59$$);}};
$app$main$data$workspace$viewport_wasm$maybe_view_interaction_start_BANG_$$=function($state$jscomp$344$$){return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$344$$,"render-wasm/v1")&&!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$344$$)?$APP.$app$render_wasm$api$view_interaction_start_BANG_$$():null};
$app$main$data$workspace$viewport$activate_panning$$=function(){typeof $app$main$data$workspace$viewport$activate_panning_71344$$==="undefined"&&($app$main$data$workspace$viewport$activate_panning_71344$$=function($meta71345$$){this.$meta71345$=$meta71345$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$activate_panning_71344$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$activate_panning_71344$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4519$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_activate_panning$$},$app$main$data$workspace$viewport$activate_panning_71344$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71346$$,$meta71345__$1$$){return new $app$main$data$workspace$viewport$activate_panning_71344$$($meta71345__$1$$)},$app$main$data$workspace$viewport$activate_panning_71344$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71345$},$app$main$data$workspace$viewport$activate_panning_71344$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$activate_panning_71344$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2539$$,$state$jscomp$879$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$879$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$3110$panning$$],null),!0)},$app$main$data$workspace$viewport$activate_panning_71344$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$activate_panning_71344$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2540$$,$state$jscomp$880$$){return $app$main$data$workspace$viewport_wasm$maybe_view_interaction_start_BANG_$$($state$jscomp$880$$)});return new $app$main$data$workspace$viewport$activate_panning_71344$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$render_wasm$api$render_blurred_snapshot_BANG_$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$wasm$context_lost_QMARK_$$))){var $cause53821_fn_53820$$=$APP.$app$render_wasm$wasm$internal_module$$._render_blurred_snapshot;try{$cause53821_fn_53820$$(4)}catch($e53822$$){$cause53821_fn_53820$$=$e53822$$;var $code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$)?$code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$.$cljs$core$IFn$_invoke$arity$0$():
$code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$():null;$code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$40$$=["WASM Error (",
$APP.$app$common$data$name$$($code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$40$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render_blurred_snapshot",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$40$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$40_code_num__53066__auto__$jscomp$40_read_code_fn__53065__auto__$jscomp$40$$],
null),$cause53821_fn_53820$$);}}};
$app$render_wasm$api$render_from_cache_BANG_$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$wasm$context_lost_QMARK_$$))){var $cause53815_fn_53814$$=$APP.$app$render_wasm$wasm$internal_module$$._render_from_cache;try{return $cause53815_fn_53814$$(0)}catch($e53816$$){$cause53815_fn_53814$$=$e53816$$;var $code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;
$code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$)?$code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$.$cljs$core$IFn$_invoke$arity$0$():
$code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$():null;$code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$39$$=["WASM Error (",
$APP.$app$common$data$name$$($code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$39$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render_from_cache",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$39$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$39_code_num__53066__auto__$jscomp$39_read_code_fn__53065__auto__$jscomp$39$$],
null),$cause53815_fn_53814$$);}}else return null};
$app$render_wasm$api$render_ui_only$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$wasm$context_lost_QMARK_$$))){var $cause53811_fn_53810$$=$APP.$app$render_wasm$wasm$internal_module$$._render_ui_only;try{return $cause53811_fn_53810$$()}catch($e53812$$){$cause53811_fn_53810$$=$e53812$$;var $code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;
$code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$)?$code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$.$cljs$core$IFn$_invoke$arity$0$():
$code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$():null;$code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$38$$=["WASM Error (",
$APP.$app$common$data$name$$($code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$38$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render_ui_only",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$38$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$38_code_num__53066__auto__$jscomp$38_read_code_fn__53065__auto__$jscomp$38$$],
null),$cause53811_fn_53810$$);}}else return null};
$app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_has_focus;try{var $JSCompiler_inline_result$jscomp$1552_JSCompiler_temp$jscomp$1551_cause53626$jscomp$inline_8308$$=$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$()}catch($e53627$jscomp$inline_8313$$){$JSCompiler_inline_result$jscomp$1552_JSCompiler_temp$jscomp$1551_cause53626$jscomp$inline_8308$$=
$e53627$jscomp$inline_8313$$;$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$)?
$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$():
null;$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$inline_8312$$=
["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$inline_8312$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_has_focus",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53068__auto__$jscomp$inline_8312$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$inline_8311_code_num__53066__auto__$jscomp$inline_8310_fn_53625$jscomp$inline_8307_read_code_fn__53065__auto__$jscomp$inline_8309$$],null),$JSCompiler_inline_result$jscomp$1552_JSCompiler_temp$jscomp$1551_cause53626$jscomp$inline_8308$$);}$JSCompiler_inline_result$jscomp$1552_JSCompiler_temp$jscomp$1551_cause53626$jscomp$inline_8308$$=$JSCompiler_inline_result$jscomp$1552_JSCompiler_temp$jscomp$1551_cause53626$jscomp$inline_8308$$!==
0}else $JSCompiler_inline_result$jscomp$1552_JSCompiler_temp$jscomp$1551_cause53626$jscomp$inline_8308$$=null;return $JSCompiler_inline_result$jscomp$1552_JSCompiler_temp$jscomp$1551_cause53626$jscomp$inline_8308$$};
$app$render_wasm$text_editor$text_editor_blur$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_blur;try{var $JSCompiler_inline_result$jscomp$1553_cause53610$jscomp$inline_8316$$=$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$()}catch($e53612$jscomp$inline_8321$$){$JSCompiler_inline_result$jscomp$1553_cause53610$jscomp$inline_8316$$=
$e53612$jscomp$inline_8321$$;$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$)?
$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$():
null;$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$inline_8320$$=
["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$inline_8320$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_blur",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53068__auto__$jscomp$inline_8320$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$inline_8319_code_num__53066__auto__$jscomp$inline_8318_fn_53609$jscomp$inline_8315_read_code_fn__53065__auto__$jscomp$inline_8317$$],null),$JSCompiler_inline_result$jscomp$1553_cause53610$jscomp$inline_8316$$);}if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1553_cause53610$jscomp$inline_8316$$))return null;throw Error("TextEditor blur failed");}return null};
$app$render_wasm$text_editor$text_editor_select_word_boundary$$=function($cause53607_p__53601_x$jscomp$1161$$){var $code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$=$APP.$cljs$core$__destructure_map$$($cause53607_p__53601_x$jscomp$1161$$);$cause53607_p__53601_x$jscomp$1161$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$,
$APP.$cljs$cst$1515$x$$);$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$,$APP.$cljs$cst$1516$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53606_hint__53068__auto__$jscomp$27$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_select_word_boundary;
try{return $fn_53606_hint__53068__auto__$jscomp$27$$($cause53607_p__53601_x$jscomp$1161$$,$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$)}catch($e53608$$){throw $cause53607_p__53601_x$jscomp$1161$$=$e53608$$,$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$=
$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$)?$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$():
null,$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$,$APP.$cljs$cst$2982$wasm_critical$$),$fn_53606_hint__53068__auto__$jscomp$27$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53606_hint__53068__auto__$jscomp$27$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_select_word_boundary",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53606_hint__53068__auto__$jscomp$27$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$27_code_num__53066__auto__$jscomp$27_map__53605__$1_read_code_fn__53065__auto__$jscomp$27_y$jscomp$399$$],
null),$cause53607_p__53601_x$jscomp$1161$$);}}else return null};
$app$render_wasm$text_editor$text_editor_select_all$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $cause53594_fn_53593$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_select_all;try{$cause53594_fn_53593$$()}catch($e53595$$){$cause53594_fn_53593$$=$e53595$$;var $code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$=
$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$)?$code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$():
null;$code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$26$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$26$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_select_all",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$26$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$26_code_num__53066__auto__$jscomp$26_read_code_fn__53065__auto__$jscomp$26$$],null),$cause53594_fn_53593$$);}}};
$app$render_wasm$text_editor$text_editor_move_cursor$$=function($cause53584_direction$jscomp$12$$,$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$,$extend_selection_hint__53068__auto__$jscomp$25$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53583$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_move_cursor;try{$fn_53583$$($cause53584_direction$jscomp$12$$,$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$,
$APP.$cljs$core$truth_$$($extend_selection_hint__53068__auto__$jscomp$25$$)?1:0)}catch($e53585$$){throw $cause53584_direction$jscomp$12$$=$e53585$$,$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$)?
$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$():null,$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$,$APP.$cljs$cst$2982$wasm_critical$$),$extend_selection_hint__53068__auto__$jscomp$25$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($extend_selection_hint__53068__auto__$jscomp$25$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_move_cursor",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$extend_selection_hint__53068__auto__$jscomp$25$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$25_code_num__53066__auto__$jscomp$25_read_code_fn__53065__auto__$jscomp$25_word_boundary$jscomp$2$$],null),$cause53584_direction$jscomp$12$$);}}};
$app$render_wasm$text_editor$text_editor_insert_paragraph$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $cause53576_fn_53575$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_insert_paragraph;try{$cause53576_fn_53575$$()}catch($e53577$$){$cause53576_fn_53575$$=$e53577$$;var $code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$=
$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$)?$code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$():
null;$code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$24$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$24$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_insert_paragraph",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$24$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$24_code_num__53066__auto__$jscomp$24_read_code_fn__53065__auto__$jscomp$24$$],null),$cause53576_fn_53575$$);}}};
$app$render_wasm$text_editor$text_editor_delete_forward$cljs$0core$0IFn$0_invoke$0arity$01$$=function($cause53560_word_boundary$jscomp$1$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_delete_forward;try{$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$($cause53560_word_boundary$jscomp$1$$)}catch($e53561$$){$cause53560_word_boundary$jscomp$1$$=
$e53561$$;$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$)?$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$.$cljs$core$IFn$_invoke$arity$0$?
$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$():null;$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$,
$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$23$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$23$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_delete_forward",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$23$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$23_code_num__53066__auto__$jscomp$23_fn_53559_read_code_fn__53065__auto__$jscomp$23$$],null),$cause53560_word_boundary$jscomp$1$$);}}};
$app$render_wasm$text_editor$text_editor_delete_backward$cljs$0core$0IFn$0_invoke$0arity$01$$=function($cause53553_word_boundary$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_delete_backward;try{$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$($cause53553_word_boundary$$)}catch($e53554$$){$cause53553_word_boundary$$=
$e53554$$;$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$)?$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$?
$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$():null;$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$,
$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$22$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$22$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_delete_backward",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,
$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$22$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$22_code_num__53066__auto__$jscomp$22_fn_53552_read_code_fn__53065__auto__$jscomp$22$$],null),$cause53553_word_boundary$$);}}};
$app$render_wasm$text_editor$text_editor_pointer_up$$=function($cause53410_p__53407_x$jscomp$1160$$){var $code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$=$APP.$cljs$core$__destructure_map$$($cause53410_p__53407_x$jscomp$1160$$);$cause53410_p__53407_x$jscomp$1160$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$,
$APP.$cljs$cst$1515$x$$);$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$,$APP.$cljs$cst$1516$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53409_hint__53068__auto__$jscomp$16$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_pointer_up;
try{return $fn_53409_hint__53068__auto__$jscomp$16$$($cause53410_p__53407_x$jscomp$1160$$,$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$)}catch($e53411$$){throw $cause53410_p__53407_x$jscomp$1160$$=$e53411$$,$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$=
$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$)?$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$():
null,$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$,$APP.$cljs$cst$2982$wasm_critical$$),$fn_53409_hint__53068__auto__$jscomp$16$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53409_hint__53068__auto__$jscomp$16$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_pointer_up",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53409_hint__53068__auto__$jscomp$16$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$16_code_num__53066__auto__$jscomp$16_map__53408__$1_read_code_fn__53065__auto__$jscomp$16_y$jscomp$398$$],
null),$cause53410_p__53407_x$jscomp$1160$$);}}else return null};
$app$render_wasm$text_editor$text_editor_pointer_move$$=function($cause53404_p__53400_x$jscomp$1159$$){var $code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$=$APP.$cljs$core$__destructure_map$$($cause53404_p__53400_x$jscomp$1159$$);$cause53404_p__53400_x$jscomp$1159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$,$APP.$cljs$cst$1515$x$$);
$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$,$APP.$cljs$cst$1516$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53403_hint__53068__auto__$jscomp$15$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_pointer_move;
try{return $fn_53403_hint__53068__auto__$jscomp$15$$($cause53404_p__53400_x$jscomp$1159$$,$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$)}catch($e53405$$){throw $cause53404_p__53400_x$jscomp$1159$$=$e53405$$,$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$=
$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$)?$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$():
null,$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$,$APP.$cljs$cst$2982$wasm_critical$$),$fn_53403_hint__53068__auto__$jscomp$15$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53403_hint__53068__auto__$jscomp$15$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_pointer_move",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53403_hint__53068__auto__$jscomp$15$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$15_code_num__53066__auto__$jscomp$15_map__53402__$1_read_code_fn__53065__auto__$jscomp$15_y$jscomp$397$$],
null),$cause53404_p__53400_x$jscomp$1159$$);}}else return null};
$app$render_wasm$text_editor$text_editor_pointer_down$$=function($cause53397_p__53394_x$jscomp$1158$$){var $code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$=$APP.$cljs$core$__destructure_map$$($cause53397_p__53394_x$jscomp$1158$$);$cause53397_p__53394_x$jscomp$1158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$,$APP.$cljs$cst$1515$x$$);
$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$,$APP.$cljs$cst$1516$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53396_hint__53068__auto__$jscomp$14$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_pointer_down;
try{return $fn_53396_hint__53068__auto__$jscomp$14$$($cause53397_p__53394_x$jscomp$1158$$,$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$)}catch($e53398$$){throw $cause53397_p__53394_x$jscomp$1158$$=$e53398$$,$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$=
$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$)?$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$():
null,$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$,$APP.$cljs$cst$2982$wasm_critical$$),$fn_53396_hint__53068__auto__$jscomp$14$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53396_hint__53068__auto__$jscomp$14$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_pointer_down",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53396_hint__53068__auto__$jscomp$14$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$14_code_num__53066__auto__$jscomp$14_map__53395__$1_read_code_fn__53065__auto__$jscomp$14_y$jscomp$396$$],
null),$cause53397_p__53394_x$jscomp$1158$$);}}else return null};
$app$render_wasm$text_editor$text_editor_toggle_overtype_mode$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $cause53391_fn_53390$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_toggle_overtype_mode;try{$cause53391_fn_53390$$()}catch($e53392$$){$cause53391_fn_53390$$=$e53392$$;var $code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$=
$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$)?$code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$():
null;$code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$13$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$13$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_toggle_overtype_mode",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$13$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$13_code_num__53066__auto__$jscomp$13_read_code_fn__53065__auto__$jscomp$13$$],null),$cause53391_fn_53390$$);
}}};
$app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$=function($cause53383_p__53380_x$jscomp$1156$$){var $code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$=$APP.$cljs$core$__destructure_map$$($cause53383_p__53380_x$jscomp$1156$$);$cause53383_p__53380_x$jscomp$1156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$,$APP.$cljs$cst$1515$x$$);
$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$,$APP.$cljs$cst$1516$y$$);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $fn_53382_hint__53068__auto__$jscomp$11$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_set_cursor_from_offset;
try{return $fn_53382_hint__53068__auto__$jscomp$11$$($cause53383_p__53380_x$jscomp$1156$$,$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$)}catch($e53384$$){throw $cause53383_p__53380_x$jscomp$1156$$=$e53384$$,$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$=
$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$)?$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$():
null,$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$,$APP.$cljs$cst$2982$wasm_critical$$),$fn_53382_hint__53068__auto__$jscomp$11$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53382_hint__53068__auto__$jscomp$11$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_set_cursor_from_offset",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53382_hint__53068__auto__$jscomp$11$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$11_code_num__53066__auto__$jscomp$11_map__53381__$1_read_code_fn__53065__auto__$jscomp$11_y$jscomp$394$$],
null),$cause53383_p__53380_x$jscomp$1156$$);}}else return null};
$app$render_wasm$text_editor$text_editor_focus$$=function($buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$);
var $fn_53377$jscomp$inline_8323_hint__53068__auto__$jscomp$inline_8328$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_focus;try{var $JSCompiler_inline_result$jscomp$1555_cause53378$jscomp$inline_8324$$=$fn_53377$jscomp$inline_8323_hint__53068__auto__$jscomp$inline_8328$$($buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$[0],$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$[1],
$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$[2],$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$[3])}catch($e53379$jscomp$inline_8329$$){throw $JSCompiler_inline_result$jscomp$1555_cause53378$jscomp$inline_8324$$=$e53379$jscomp$inline_8329$$,$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$=$APP.$cljs$core$truth_$$($buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$)?$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$.$cljs$core$IFn$_invoke$arity$0$?
$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$.$cljs$core$IFn$_invoke$arity$0$():$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$():null,$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$,$APP.$cljs$cst$2982$wasm_critical$$),$fn_53377$jscomp$inline_8323_hint__53068__auto__$jscomp$inline_8328$$=["WASM Error (",$APP.$app$common$data$name$$($buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($fn_53377$jscomp$inline_8323_hint__53068__auto__$jscomp$inline_8328$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_focus",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$fn_53377$jscomp$inline_8323_hint__53068__auto__$jscomp$inline_8328$$,$APP.$cljs$cst$273$code$$,$buffer$jscomp$66_code__53067__auto__$jscomp$inline_8327_code_num__53066__auto__$jscomp$inline_8326_id$jscomp$322_read_code_fn__53065__auto__$jscomp$inline_8325$$],
null),$JSCompiler_inline_result$jscomp$1555_cause53378$jscomp$inline_8324$$);}if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1555_cause53378$jscomp$inline_8324$$))return null;throw Error("TextEditor focus failed");}return null};
$app$render_wasm$mem$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$=function($cause53199_ptr$jscomp$6$$){var $code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$=$APP.$app$render_wasm$wasm$internal_module$$.UTF8ToString;try{return $code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$($cause53199_ptr$jscomp$6$$)}catch($e53200$$){$cause53199_ptr$jscomp$6$$=$e53200$$;$code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$)?$code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():
$code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$():null;$code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$8$$=
["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$8$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"UTF8ToString",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$8$$,$APP.$cljs$cst$273$code$$,
$code__53067__auto__$jscomp$8_code_num__53066__auto__$jscomp$8_fn_53198_read_code_fn__53065__auto__$jscomp$8$$],null),$cause53199_ptr$jscomp$6$$);}};
$app$render_wasm$text_editor$text_editor_export_selection$$=function(){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_export_selection;try{var $cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$=$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$()}catch($e53637$jscomp$inline_13433$$){$cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$=
$e53637$jscomp$inline_13433$$;$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$)?
$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$():
null;$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$inline_13432$$=
["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$inline_13432$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_export_selection",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53068__auto__$jscomp$inline_13432$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$inline_13431_code_num__53066__auto__$jscomp$inline_13430_fn_53635$jscomp$inline_13427_read_code_fn__53065__auto__$jscomp$inline_13429$$],null),$cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$);}if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$)?$cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$!==0:$cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$))return $cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$=
$app$render_wasm$mem$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$($cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$),$APP.$app$render_wasm$mem$free$$(),$cause53636$jscomp$inline_13428_ptr$jscomp$9_text$jscomp$34$$}return null};
$app$render_wasm$text_editor$text_editor_encode_text_pre$$=function($buf$jscomp$18_text$jscomp$29$$){if(!$APP.$cljs$core$empty_QMARK_$$($buf$jscomp$18_text$jscomp$29$$)&&$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$buf$jscomp$18_text$jscomp$29$$=(new TextEncoder).encode($buf$jscomp$18_text$jscomp$29$$);var $heapu8$jscomp$1$$=$APP.$app$render_wasm$mem$get_heap_u8$$(),$offset$jscomp$150$$=$APP.$app$render_wasm$mem$alloc$$($buf$jscomp$18_text$jscomp$29$$.byteLength);$APP.$app$render_wasm$mem$write_buffer$$($offset$jscomp$150$$,
$heapu8$jscomp$1$$,$buf$jscomp$18_text$jscomp$29$$)}};
$app$render_wasm$text_editor$text_editor_insert_text$$=function($cause53533_53760_text$jscomp$33$$){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$app$render_wasm$text_editor$text_editor_encode_text_pre$$($cause53533_53760_text$jscomp$33$$);var $code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_insert_text;try{$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$()}catch($e53534$$){$cause53533_53760_text$jscomp$33$$=$e53534$$;
$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$=$APP.$cljs$core$truth_$$($code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$)?$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$.$cljs$core$IFn$_invoke$arity$0$?
$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$():null;$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$,
$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto___53764$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___53764$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_insert_text",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,
$hint__53068__auto___53764$$,$APP.$cljs$cst$273$code$$,$code__53067__auto___53763_code_num__53066__auto___53762_fn_53532_53759_read_code_fn__53065__auto___53761$$],null),$cause53533_53760_text$jscomp$33$$);}!$APP.$cljs$core$empty_QMARK_$$($cause53533_53760_text$jscomp$33$$)&&$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$app$render_wasm$mem$free$$()}};
$app$main$data$workspace$transforms$get_handler_resize_origin$$=function($mx$jscomp$1_selrect$jscomp$62$$,$G__69137__$1_handler$jscomp$31$$){var $sx$jscomp$10$$=$mx$jscomp$1_selrect$jscomp$62$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$62$$,$APP.$cljs$cst$1515$x$$),$sy$jscomp$9$$=$mx$jscomp$1_selrect$jscomp$62$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$62$$,$APP.$cljs$cst$1516$y$$),$ex$jscomp$16_width$jscomp$136$$=
$mx$jscomp$1_selrect$jscomp$62$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$62$$,$APP.$cljs$cst$290$width$$),$ey$jscomp$1_height$jscomp$122$$=$mx$jscomp$1_selrect$jscomp$62$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$62$$,$APP.$cljs$cst$1527$height$$);$mx$jscomp$1_selrect$jscomp$62$$=$sx$jscomp$10$$+$ex$jscomp$16_width$jscomp$136$$/2;var $my$jscomp$1$$=$sy$jscomp$9$$+$ey$jscomp$1_height$jscomp$122$$/2;
$ex$jscomp$16_width$jscomp$136$$=$sx$jscomp$10$$+$ex$jscomp$16_width$jscomp$136$$;$ey$jscomp$1_height$jscomp$122$$=$sy$jscomp$9$$+$ey$jscomp$1_height$jscomp$122$$;$G__69137__$1_handler$jscomp$31$$=$G__69137__$1_handler$jscomp$31$$ instanceof $APP.$cljs$core$Keyword$$?$G__69137__$1_handler$jscomp$31$$.$fqn$:null;switch($G__69137__$1_handler$jscomp$31$$){case "right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($sx$jscomp$10$$,$my$jscomp$1$$);case "bottom":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$62$$,
$sy$jscomp$9$$);case "left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($ex$jscomp$16_width$jscomp$136$$,$my$jscomp$1$$);case "top":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($mx$jscomp$1_selrect$jscomp$62$$,$ey$jscomp$1_height$jscomp$122$$);case "top-right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($sx$jscomp$10$$,$ey$jscomp$1_height$jscomp$122$$);case "top-left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($ex$jscomp$16_width$jscomp$136$$,
$ey$jscomp$1_height$jscomp$122$$);case "bottom-right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($sx$jscomp$10$$,$sy$jscomp$9$$);case "bottom-left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($ex$jscomp$16_width$jscomp$136$$,$sy$jscomp$9$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__69137__$1_handler$jscomp$31$$)].join(""));}};
$app$main$data$workspace$transforms$get_handler_multiplier$$=function($G__69134__$1_handler$jscomp$30$$){$G__69134__$1_handler$jscomp$30$$=$G__69134__$1_handler$jscomp$30$$ instanceof $APP.$cljs$core$Keyword$$?$G__69134__$1_handler$jscomp$30$$.$fqn$:null;switch($G__69134__$1_handler$jscomp$30$$){case "right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,0);case "bottom":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,1);case "left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,
0);case "top":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,-1);case "top-right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,-1);case "top-left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,-1);case "bottom-right":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,1);case "bottom-left":return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,1);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__69134__$1_handler$jscomp$30$$)].join(""));}};
$app$common$types$shape$interactions$calc_overlay_pos_initial$$=function($dest_frame_destination$jscomp$9_overlay_size$$,$frame_size_orig_frame_shape$jscomp$159$$,$objects$jscomp$125$$,$overlay_pos_type$jscomp$3$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$3$$,$APP.$cljs$cst$1678$manual$$)&&$dest_frame_destination$jscomp$9_overlay_size$$!=null?($dest_frame_destination$jscomp$9_overlay_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$125$$,
$dest_frame_destination$jscomp$9_overlay_size$$),$dest_frame_destination$jscomp$9_overlay_size$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($dest_frame_destination$jscomp$9_overlay_size$$),$frame_size_orig_frame_shape$jscomp$159$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$159$$),$APP.$cljs$cst$1611$frame$$)?$frame_size_orig_frame_shape$jscomp$159$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$125$$,
$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$159$$)),$frame_size_orig_frame_shape$jscomp$159$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$159$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$159$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($dest_frame_destination$jscomp$9_overlay_size$$))/
2,($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($frame_size_orig_frame_shape$jscomp$159$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($dest_frame_destination$jscomp$9_overlay_size$$))/2)):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0)};
$app$common$types$shape$interactions$set_destination$$=function($interaction$jscomp$6$$,$G__49066__$1_destination$jscomp$8$$){$G__49066__$1_destination$jscomp$8$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$6$$,$APP.$cljs$cst$1983$destination$$,$G__49066__$1_destination$jscomp$8$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$6$$),$APP.$cljs$cst$1962$open_overlay$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$6$$),$APP.$cljs$cst$1960$toggle_overlay$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49066__$1_destination$jscomp$8$$,$APP.$cljs$cst$1987$overlay_pos_type$$,$APP.$cljs$cst$1672$center$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1986$overlay_position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,
0)])):$G__49066__$1_destination$jscomp$8$$};
$app$common$types$shape$interactions$set_action_type$$=function($interaction$jscomp$1$$,$action_type$$){var $new_interaction$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$1$$),$action_type$$)?$interaction$jscomp$1$$:function(){var $G__49046__$1_overlay_pos_type$$=$action_type$$ instanceof $APP.$cljs$core$Keyword$$?$action_type$$.$fqn$:null;switch($G__49046__$1_overlay_pos_type$$){case "navigate":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($interaction$jscomp$1$$,$APP.$cljs$cst$1982$action_type$$,
$action_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1983$destination$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$1$$,$APP.$cljs$cst$1983$destination$$),$APP.$cljs$cst$1984$preserve_scroll$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,$APP.$cljs$cst$1984$preserve_scroll$$,!1)]));case "open-overlay":case "toggle-overlay":$G__49046__$1_overlay_pos_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,
$APP.$cljs$cst$1987$overlay_pos_type$$,$APP.$cljs$cst$1672$center$$);var $overlay_position$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,$APP.$cljs$cst$1986$overlay_position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($interaction$jscomp$1$$,$APP.$cljs$cst$1982$action_type$$,$action_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1987$overlay_pos_type$$,
$G__49046__$1_overlay_pos_type$$,$APP.$cljs$cst$1986$overlay_position$$,$overlay_position$$]));case "close-overlay":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($interaction$jscomp$1$$,$APP.$cljs$cst$1982$action_type$$,$action_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1983$destination$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$1$$,$APP.$cljs$cst$1983$destination$$)]));case "prev-screen":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,
$APP.$cljs$cst$1982$action_type$$,$action_type$$);case "open-url":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($interaction$jscomp$1$$,$APP.$cljs$cst$1982$action_type$$,$action_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1991$url$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($interaction$jscomp$1$$,$APP.$cljs$cst$1991$url$$,"")]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__49046__$1_overlay_pos_type$$)].join(""));
}}();return $APP.$cljs$core$not$$(function(){var $G__49057$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($new_interaction$$));return $app$common$types$shape$interactions$allowed_animation_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$shape$interactions$allowed_animation_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($action_type$$,$G__49057$$):$app$common$types$shape$interactions$allowed_animation_QMARK_$$($action_type$$,
$G__49057$$)}())?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($new_interaction$$,$APP.$cljs$cst$1975$animation_type$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1985$animation$$])):$new_interaction$$};
$app$common$geom$shapes$distance_selrect$$=function($selrect$jscomp$25_y2$jscomp$34$$,$other$jscomp$185_y1$jscomp$36$$){var $x1$jscomp$34$$=$other$jscomp$185_y1$jscomp$36$$?.x1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$185_y1$jscomp$36$$,$APP.$cljs$cst$1528$x1$$);$other$jscomp$185_y1$jscomp$36$$=$other$jscomp$185_y1$jscomp$36$$?.y1??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$185_y1$jscomp$36$$,$APP.$cljs$cst$1529$y1$$);var $x2$jscomp$32$$=$selrect$jscomp$25_y2$jscomp$34$$?.x2??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$25_y2$jscomp$34$$,$APP.$cljs$cst$1530$x2$$);$selrect$jscomp$25_y2$jscomp$34$$=$selrect$jscomp$25_y2$jscomp$34$$?.y2??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$25_y2$jscomp$34$$,$APP.$cljs$cst$1531$y2$$);return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x1$jscomp$34$$-$x2$jscomp$32$$,$other$jscomp$185_y1$jscomp$36$$-$selrect$jscomp$25_y2$jscomp$34$$)};
$app$common$geom$shapes$intersect$intersects_lines_ellipse_QMARK_$$=function($rect_lines$jscomp$2$$,$p__48932_transform$jscomp$53$$){var $map__48933__$1$$=$APP.$cljs$core$__destructure_map$$($p__48932_transform$jscomp$53$$),$center$jscomp$22_cx$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48933__$1$$,$APP.$cljs$cst$1905$cx$$),$cy$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48933__$1$$,$APP.$cljs$cst$1906$cy$$);$p__48932_transform$jscomp$53$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48933__$1$$,$APP.$cljs$cst$1294$transform$$);$center$jscomp$22_cx$jscomp$12$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$22_cx$jscomp$12$$,$cy$jscomp$13$$);var $transform__$1$jscomp$2$$=$p__48932_transform$jscomp$53$$!=null?$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$22_cx$jscomp$12$$,$p__48932_transform$jscomp$53$$):null;return $APP.$cljs$core$some$$(function($p2$jscomp$44_p2__$1_p__48934$$){var $p1$jscomp$55_p1__$1$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$44_p2__$1_p__48934$$,0,null);$p2$jscomp$44_p2__$1_p__48934$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$44_p2__$1_p__48934$$,1,null);$p1$jscomp$55_p1__$1$jscomp$2$$=$transform__$1$jscomp$2$$!=null?$APP.$app$common$geom$point$transform$$($p1$jscomp$55_p1__$1$jscomp$2$$,$transform__$1$jscomp$2$$):$p1$jscomp$55_p1__$1$jscomp$2$$;$p2$jscomp$44_p2__$1_p__48934$$=$transform__$1$jscomp$2$$!=null?$APP.$app$common$geom$point$transform$$($p2$jscomp$44_p2__$1_p__48934$$,
$transform__$1$jscomp$2$$):$p2$jscomp$44_p2__$1_p__48934$$;return $app$common$geom$shapes$intersect$intersects_line_ellipse_QMARK_$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1$jscomp$55_p1__$1$jscomp$2$$,$p2$jscomp$44_p2__$1_p__48934$$],null),$map__48933__$1$$)},$rect_lines$jscomp$2$$)};
$app$common$types$path$get_handler$$=function($command$jscomp$18$$,$prefix$jscomp$42$$){return $APP.$app$common$types$path$segment$get_handler$$($command$jscomp$18$$,$prefix$jscomp$42$$)};
$app$common$types$path$segment$curve_closest_point$$=function($position$jscomp$7$$,$start$jscomp$205$$,$end$jscomp$70$$,$h1$jscomp$26$$,$h2$jscomp$20$$,$precision$jscomp$6$$){for(var $d$jscomp$226$$=$APP.$cljs$core$memoize$$(function($t$jscomp$85$$){return $APP.$app$common$geom$point$distance$$($position$jscomp$7$$,$APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$205$$,$end$jscomp$70$$,$h1$jscomp$26$$,$h2$jscomp$20$$,$t$jscomp$85$$))}),$t1$jscomp$8_t1__$1$jscomp$1$$=
0,$G__48343_t2$jscomp$9_vec__48062$$=1;;){if($APP.$app$common$math$abs$$($t1$jscomp$8_t1__$1$jscomp$1$$-$G__48343_t2$jscomp$9_vec__48062$$)<=$precision$jscomp$6$$)return $APP.$cljs$core$with_meta$$($APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$205$$,$end$jscomp$70$$,$h1$jscomp$26$$,$h2$jscomp$20$$,$t1$jscomp$8_t1__$1$jscomp$1$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1858$t$$,$t1$jscomp$8_t1__$1$jscomp$1$$,$APP.$cljs$cst$1859$from_p$$,
$start$jscomp$205$$,$APP.$cljs$cst$1860$to_p$$,$end$jscomp$70$$],null));var $ht$jscomp$4$$=$t1$jscomp$8_t1__$1$jscomp$1$$+($G__48343_t2$jscomp$9_vec__48062$$-$t1$jscomp$8_t1__$1$jscomp$1$$)/2,$ht1$$=$t1$jscomp$8_t1__$1$jscomp$1$$+($G__48343_t2$jscomp$9_vec__48062$$-$t1$jscomp$8_t1__$1$jscomp$1$$)/4,$ht2$$=$t1$jscomp$8_t1__$1$jscomp$1$$+3*($G__48343_t2$jscomp$9_vec__48062$$-$t1$jscomp$8_t1__$1$jscomp$1$$)/4;$G__48343_t2$jscomp$9_vec__48062$$=$d$jscomp$226$$($ht1$$)<$d$jscomp$226$$($ht2$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$t1$jscomp$8_t1__$1$jscomp$1$$,$ht$jscomp$4$$],null):$d$jscomp$226$$($ht2$$)<$d$jscomp$226$$($ht1$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ht$jscomp$4$$,$G__48343_t2$jscomp$9_vec__48062$$],null):$d$jscomp$226$$($ht$jscomp$4$$)<$d$jscomp$226$$($t1$jscomp$8_t1__$1$jscomp$1$$)&&$d$jscomp$226$$($ht$jscomp$4$$)<$d$jscomp$226$$($G__48343_t2$jscomp$9_vec__48062$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ht1$$,$ht2$$],null):$d$jscomp$226$$($t1$jscomp$8_t1__$1$jscomp$1$$)<$d$jscomp$226$$($G__48343_t2$jscomp$9_vec__48062$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$t1$jscomp$8_t1__$1$jscomp$1$$,$ht$jscomp$4$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ht$jscomp$4$$,$G__48343_t2$jscomp$9_vec__48062$$],null);$t1$jscomp$8_t1__$1$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48343_t2$jscomp$9_vec__48062$$,0,null);$G__48343_t2$jscomp$9_vec__48062$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__48343_t2$jscomp$9_vec__48062$$,1,null)}};
$app$common$types$path$segment$path__GT_lines$$=function($G__48332_pending$jscomp$6_shape$jscomp$80$$){var $G__48331_command$jscomp$10_map__48028__$1_temp__5823__auto__$jscomp$103$$=$APP.$cljs$core$first$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($G__48332_pending$jscomp$6_shape$jscomp$80$$));$G__48332_pending$jscomp$6_shape$jscomp$80$$=$APP.$cljs$core$rest$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($G__48332_pending$jscomp$6_shape$jscomp$80$$));for(var $result$jscomp$188$$=
$APP.$cljs$core$PersistentVector$EMPTY$$,$last_start$$=null,$prev_point$jscomp$2$$=null;;)if($APP.$cljs$core$truth_$$($G__48331_command$jscomp$10_map__48028__$1_temp__5823__auto__$jscomp$103$$)){$G__48331_command$jscomp$10_map__48028__$1_temp__5823__auto__$jscomp$103$$=$APP.$cljs$core$__destructure_map$$($G__48331_command$jscomp$10_map__48028__$1_temp__5823__auto__$jscomp$103$$);var $command__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48331_command$jscomp$10_map__48028__$1_temp__5823__auto__$jscomp$103$$,
$APP.$cljs$cst$1818$command$$),$params$jscomp$101$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48331_command$jscomp$10_map__48028__$1_temp__5823__auto__$jscomp$103$$,$APP.$cljs$cst$1435$params$$),$point$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1856$close_path$$,$command__$1$$)?$last_start$$:$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$),$G__48333_result__$1$jscomp$19$$=function(){var $G__48030_G__48032_JSCompiler_temp_const$jscomp$11241$$=
$command__$1$$;switch($G__48030_G__48032_JSCompiler_temp_const$jscomp$11241$$ instanceof $APP.$cljs$core$Keyword$$?$G__48030_G__48032_JSCompiler_temp_const$jscomp$11241$$.$fqn$:null){case "line-to":return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$188$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$jscomp$2$$,$point$jscomp$26$$],null));case "curve-to":var $JSCompiler_inline_result$jscomp$11243_h1$jscomp$25$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1821$c1x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$),
$APP.$cljs$cst$1822$c1y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$)),$h2$jscomp$19$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1823$c2x$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$),$APP.$cljs$cst$1824$c2y$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$101$$));$G__48030_G__48032_JSCompiler_temp_const$jscomp$11241$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$;var $JSCompiler_temp_const$jscomp$11240$$=$result$jscomp$188$$;a:{for(var $start$jscomp$inline_13443$$=
$prev_point$jscomp$2$$,$end$jscomp$inline_13444$$=$point$jscomp$26$$,$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$=0,$G__46924$jscomp$inline_13452_result$jscomp$inline_13448$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $to$jscomp$inline_13449$$=Math.min(1,$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$+.1);$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$inline_13443$$,$end$jscomp$inline_13444$$,$JSCompiler_inline_result$jscomp$11243_h1$jscomp$25$$,$h2$jscomp$19$$,$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$),$APP.$app$common$types$path$helpers$curve_values$cljs$0core$0IFn$0_invoke$0arity$05$$($start$jscomp$inline_13443$$,$end$jscomp$inline_13444$$,$JSCompiler_inline_result$jscomp$11243_h1$jscomp$25$$,
$h2$jscomp$19$$,$to$jscomp$inline_13449$$)],null);$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__46924$jscomp$inline_13452_result$jscomp$inline_13448$$,$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$);if($to$jscomp$inline_13449$$>=1){$JSCompiler_inline_result$jscomp$11243_h1$jscomp$25$$=$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$;
break a}$G__46924$jscomp$inline_13452_result$jscomp$inline_13448$$=$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$;$from$jscomp$inline_13447_line$jscomp$inline_13450_result__$1$jscomp$inline_13451$$=$to$jscomp$inline_13449$$}$JSCompiler_inline_result$jscomp$11243_h1$jscomp$25$$=void 0}return $G__48030_G__48032_JSCompiler_temp_const$jscomp$11241$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$11240$$,$JSCompiler_inline_result$jscomp$11243_h1$jscomp$25$$);
case "move-to":return $G__48030_G__48032_JSCompiler_temp_const$jscomp$11241$$=$result$jscomp$188$$,$APP.$cljs$core$truth_$$($last_start$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48030_G__48032_JSCompiler_temp_const$jscomp$11241$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$jscomp$2$$,$last_start$$],null)):$G__48030_G__48032_JSCompiler_temp_const$jscomp$11241$$;default:return $result$jscomp$188$$}}(),$G__48334_last_start__$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1819$move_to$$,$command__$1$$)?$point$jscomp$26$$:$last_start$$;$G__48331_command$jscomp$10_map__48028__$1_temp__5823__auto__$jscomp$103$$=$APP.$cljs$core$first$$($G__48332_pending$jscomp$6_shape$jscomp$80$$);$G__48332_pending$jscomp$6_shape$jscomp$80$$=$APP.$cljs$core$rest$$($G__48332_pending$jscomp$6_shape$jscomp$80$$);var $G__48335$$=$point$jscomp$26$$;$result$jscomp$188$$=$G__48333_result__$1$jscomp$19$$;$last_start$$=$G__48334_last_start__$1$$;
$prev_point$jscomp$2$$=$G__48335$$}else return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$188$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev_point$jscomp$2$$,$last_start$$],null))};
$app$common$types$path$segment$closest_point$$=function($content$jscomp$31$$,$position$jscomp$9$$,$precision$jscomp$7$$){return $APP.$cljs$core$first$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__48077$$,$p__48078$$){var $min_p$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48077$$,0,null),$min_dist$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48077$$,1,null),$cur_p$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48078$$,
0,null),$cur_dist$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48078$$,1,null);return $p__48077$$!=null&&($APP.$cljs$core$not$$($p__48078$$)||$min_dist$$<=$cur_dist$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$min_p$$,$min_dist$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cur_p$$,$cur_dist$$],null)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__48071_point$jscomp$27_prev_segment$$){var $cur_segment$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48071_point$jscomp$27_prev_segment$$,0,null);$p__48071_point$jscomp$27_prev_segment$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__48071_point$jscomp$27_prev_segment$$,1,null);var $from_p$jscomp$9$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($p__48071_point$jscomp$27_prev_segment$$),$to_p$jscomp$8$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment$jscomp$1$$),
$h1$jscomp$27$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_segment$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$1821$c1x$$],null)),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_segment$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,
$APP.$cljs$cst$1822$c1y$$],null))),$h2$jscomp$21$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_segment$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$1823$c2x$$],null)),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_segment$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$1824$c2y$$],null)));$p__48071_point$jscomp$27_prev_segment$$=function(){var $G__48076_e1$jscomp$inline_8338$$=$APP.$cljs$cst$1818$command$$.$cljs$core$IFn$_invoke$arity$1$($cur_segment$jscomp$1$$);switch($G__48076_e1$jscomp$inline_8338$$ instanceof $APP.$cljs$core$Keyword$$?$G__48076_e1$jscomp$inline_8338$$.$fqn$:null){case "line-to":$G__48076_e1$jscomp$inline_8338$$=$APP.$app$common$geom$point$subtract$$($to_p$jscomp$8$$,$from_p$jscomp$9$$);var $e2$jscomp$inline_8339_t$jscomp$inline_8341$$=
$APP.$app$common$geom$point$subtract$$($position$jscomp$9$$,$from_p$jscomp$9$$),$len2$jscomp$inline_8340$$=$app$common$math$sq$$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($G__48076_e1$jscomp$inline_8338$$))+$app$common$math$sq$$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($G__48076_e1$jscomp$inline_8338$$));$e2$jscomp$inline_8339_t$jscomp$inline_8341$$=$APP.$app$common$geom$point$dot$$($G__48076_e1$jscomp$inline_8338$$,$e2$jscomp$inline_8339_t$jscomp$inline_8341$$)/$len2$jscomp$inline_8340$$;
return $e2$jscomp$inline_8339_t$jscomp$inline_8341$$>=0&&$e2$jscomp$inline_8339_t$jscomp$inline_8341$$<=1&&!$APP.$app$common$math$almost_zero_QMARK_$$($len2$jscomp$inline_8340$$)?$APP.$cljs$core$with_meta$$($APP.$app$common$geom$point$add$$($from_p$jscomp$9$$,$APP.$app$common$geom$point$scale$$($G__48076_e1$jscomp$inline_8338$$,$e2$jscomp$inline_8339_t$jscomp$inline_8341$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1858$t$$,$e2$jscomp$inline_8339_t$jscomp$inline_8341$$,$APP.$cljs$cst$1859$from_p$$,
$from_p$jscomp$9$$,$APP.$cljs$cst$1860$to_p$$,$to_p$jscomp$8$$],null)):$APP.$app$common$geom$point$distance$$($position$jscomp$9$$,$from_p$jscomp$9$$)<=$APP.$app$common$geom$point$distance$$($position$jscomp$9$$,$to_p$jscomp$8$$)?$from_p$jscomp$9$$:$to_p$jscomp$8$$;case "curve-to":return $app$common$types$path$segment$curve_closest_point$$($position$jscomp$9$$,$from_p$jscomp$9$$,$to_p$jscomp$8$$,$h1$jscomp$27$$,$h2$jscomp$21$$,$precision$jscomp$7$$);default:return null}}();return $APP.$cljs$core$truth_$$($p__48071_point$jscomp$27_prev_segment$$)?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p__48071_point$jscomp$27_prev_segment$$,$APP.$app$common$geom$point$distance$$($p__48071_point$jscomp$27_prev_segment$$,$position$jscomp$9$$)],null):null},$APP.$app$common$data$with_prev$$($content$jscomp$31$$))))};
$app$util$dom$get_delta_position$$=function($e$jscomp$247_event$jscomp$32$$){$e$jscomp$247_event$jscomp$32$$=$e$jscomp$247_event$jscomp$32$$ instanceof $APP.$goog$events$BrowserEvent$$?$APP.$cljs$core$_deref$$($e$jscomp$247_event$jscomp$32$$):$e$jscomp$247_event$jscomp$32$$;return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$247_event$jscomp$32$$.deltaX,$e$jscomp$247_event$jscomp$32$$.deltaY)};
$app$common$geom$shapes$has_point_rect_QMARK_$$=function($h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$,$param49262$$){var $lines$jscomp$inline_8345_x$jscomp$inline_13455$$=$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$inline_13456$$=$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$,
$APP.$cljs$cst$1516$y$$),$w$jscomp$inline_13457_w__$1$jscomp$inline_13459$$=$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$,$APP.$cljs$cst$290$width$$);$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$=$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$,
$APP.$cljs$cst$1527$height$$);$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$,$y$jscomp$inline_13456$$)?($w$jscomp$inline_13457_w__$1$jscomp$inline_13459$$=Math.max($w$jscomp$inline_13457_w__$1$jscomp$inline_13459$$,.01),$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$=Math.max($h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$,.01),$lines$jscomp$inline_8345_x$jscomp$inline_13455$$=new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$,$y$jscomp$inline_13456$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$+$w$jscomp$inline_13457_w__$1$jscomp$inline_13459$$,$y$jscomp$inline_13456$$)],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$+$w$jscomp$inline_13457_w__$1$jscomp$inline_13459$$,$y$jscomp$inline_13456$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$+$w$jscomp$inline_13457_w__$1$jscomp$inline_13459$$,$y$jscomp$inline_13456$$+$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$+$w$jscomp$inline_13457_w__$1$jscomp$inline_13459$$,$y$jscomp$inline_13456$$+$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$,$y$jscomp$inline_13456$$+
$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$,$y$jscomp$inline_13456$$+$h$jscomp$inline_13458_h__$1$jscomp$inline_13460_param49261$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($lines$jscomp$inline_8345_x$jscomp$inline_13455$$,$y$jscomp$inline_13456$$)],
null)],null)):$lines$jscomp$inline_8345_x$jscomp$inline_13455$$=null;return $APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($param49262$$,$lines$jscomp$inline_8345_x$jscomp$inline_13455$$)};
$app$main$data$helpers$get_selrect$$=function($center$jscomp$29_selrect_transform$$,$shape$jscomp$150_width$jscomp$71$$){if($center$jscomp$29_selrect_transform$$!=null){var $map__49385__$1_transform$jscomp$57$$=$APP.$cljs$core$__destructure_map$$($center$jscomp$29_selrect_transform$$);$center$jscomp$29_selrect_transform$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49385__$1_transform$jscomp$57$$,$APP.$cljs$cst$1672$center$$);$shape$jscomp$150_width$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49385__$1_transform$jscomp$57$$,
$APP.$cljs$cst$290$width$$);var $height$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49385__$1_transform$jscomp$57$$,$APP.$cljs$cst$1527$height$$);$map__49385__$1_transform$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49385__$1_transform$jscomp$57$$,$APP.$cljs$cst$1294$transform$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$center__GT_rect$$.$cljs$core$IFn$_invoke$arity$3$($center$jscomp$29_selrect_transform$$,
$shape$jscomp$150_width$jscomp$71$$,$height$jscomp$64$$),$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$29_selrect_transform$$,$map__49385__$1_transform$jscomp$57$$)],null)}return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$150_width$jscomp$71$$?.selrect??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$150_width$jscomp$71$$,$APP.$cljs$cst$1610$selrect$$),$APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$150_width$jscomp$71$$)],
null)};
$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$=function($rect$jscomp$13_rect_points$$,$points$jscomp$44$$){$rect$jscomp$13_rect_points$$=$APP.$app$common$geom$rect$rect__GT_points$$($rect$jscomp$13_rect_points$$);var $rect_lines$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($rect$jscomp$13_rect_points$$),$points_lines$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($points$jscomp$44$$);return $APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($APP.$cljs$core$first$$($rect$jscomp$13_rect_points$$),
$points_lines$$)||$APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($APP.$cljs$core$first$$($points$jscomp$44$$),$rect_lines$$)||$app$common$geom$shapes$intersect$intersects_lines_QMARK_$$($rect_lines$$,$points_lines$$)};
$app$common$geom$point$normal_right$$=function($p__45805_x$jscomp$1050$$){var $map__45806__$1_y$jscomp$316$$=$APP.$cljs$core$__destructure_map$$($p__45805_x$jscomp$1050$$);$p__45805_x$jscomp$1050$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45806__$1_y$jscomp$316$$,$APP.$cljs$cst$1515$x$$);$map__45806__$1_y$jscomp$316$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__45806__$1_y$jscomp$316$$,$APP.$cljs$cst$1516$y$$);return $APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($map__45806__$1_y$jscomp$316$$,
-$p__45805_x$jscomp$1050$$))};
$app$main$ui$measurements$selection_size_badge_STAR_$$=function($badge_height_props_75312$$){var $shapes$jscomp$171$$=$badge_height_props_75312$$.shapes,$badge_bg_color_zoom$jscomp$58$$=$badge_height_props_75312$$.zoom;$badge_height_props_75312$$=16/$badge_bg_color_zoom$jscomp$58$$;var $badge_padding_x_badge_width$$=6/$badge_bg_color_zoom$jscomp$58$$,$badge_cy_badge_gap_offset$jscomp$196$$=8/$badge_bg_color_zoom$jscomp$58$$,$badge_radius$$=2/$badge_bg_color_zoom$jscomp$58$$,$badge_char_width_ep1_normal$jscomp$1$$=
6.5/$badge_bg_color_zoom$jscomp$58$$,$single_shape$$=function(){var $and__5023__auto__$jscomp$681$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$171$$),1);return $and__5023__auto__$jscomp$681$$?$APP.$cljs$core$first$$($shapes$jscomp$171$$):$and__5023__auto__$jscomp$681$$}();$badge_bg_color_zoom$jscomp$58$$=($APP.$cljs$core$truth_$$($single_shape$$)?$APP.$app$common$types$component$instance_head_QMARK_$$($single_shape$$):$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$component$instance_head_QMARK_$$,
$shapes$jscomp$171$$))?"var(--color-accent-secondary)":"var(--color-accent-tertiary)";var $badge_rot_rotation$jscomp$22$$=$APP.$cljs$core$truth_$$($single_shape$$)?$single_shape$$?.rotation??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($single_shape$$,$APP.$cljs$cst$1794$rotation$$):null,$has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$=$APP.$cljs$core$truth_$$($badge_rot_rotation$jscomp$22$$)?!$APP.$app$common$math$almost_zero_QMARK_$$($badge_rot_rotation$jscomp$22$$):$badge_rot_rotation$jscomp$22$$,
$selrect$jscomp$79$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$171$$),$shape_width$jscomp$1_text$jscomp$74$$=$APP.$cljs$core$truth_$$($single_shape$$)?function(){var $or__5025__auto__$jscomp$1048$$=$single_shape$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($single_shape$$,$APP.$cljs$cst$290$width$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1048$$)?$or__5025__auto__$jscomp$1048$$:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$79$$)}():
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$79$$),$badge_x_ep2_rot_offset_shape_height$jscomp$1$$=$APP.$cljs$core$truth_$$($single_shape$$)?function(){var $or__5025__auto__$jscomp$1049$$=$single_shape$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($single_shape$$,$APP.$cljs$cst$1527$height$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1049$$)?$or__5025__auto__$jscomp$1049$$:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$79$$)}():
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$79$$);$shape_width$jscomp$1_text$jscomp$74$$=""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_width$jscomp$1_text$jscomp$74$$)??"")+" x "+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($badge_x_ep2_rot_offset_shape_height$jscomp$1$$)??"");$badge_padding_x_badge_width$$=$APP.$cljs$core$count$$($shape_width$jscomp$1_text$jscomp$74$$)*$badge_char_width_ep1_normal$jscomp$1$$+
2*$badge_padding_x_badge_width$$;if($APP.$cljs$core$truth_$$($has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$)){var $edge$jscomp$1$$=$app$main$ui$measurements$get_edge_for_badge$$($badge_rot_rotation$jscomp$22$$);$has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$=$single_shape$$?.points??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($single_shape$$,$APP.$cljs$cst$1609$points$$);$has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$=$app$main$ui$measurements$get_edge_points$$($has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$,
$edge$jscomp$1$$);$badge_char_width_ep1_normal$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$,0,null);$badge_x_ep2_rot_offset_shape_height$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$,1,null);$has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$=$APP.$app$common$geom$point$lerp$$($badge_char_width_ep1_normal$jscomp$1$$,$badge_x_ep2_rot_offset_shape_height$jscomp$1$$,
.5);$badge_char_width_ep1_normal$jscomp$1$$=$app$common$geom$point$normal_right$$($APP.$app$common$geom$point$subtract$$($badge_x_ep2_rot_offset_shape_height$jscomp$1$$,$badge_char_width_ep1_normal$jscomp$1$$));$badge_x_ep2_rot_offset_shape_height$jscomp$1$$=function(){var $G__75320__$1$$=$edge$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$edge$jscomp$1$$.$fqn$:null;switch($G__75320__$1$$){case "bottom":return 0;case "right":return 270;case "top":return 180;case "left":return 90;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__75320__$1$$)].join(""));}}();$badge_rot_rotation$jscomp$22$$+=$badge_x_ep2_rot_offset_shape_height$jscomp$1$$;$badge_cy_badge_gap_offset$jscomp$196$$+=$badge_height_props_75312$$/2;$badge_x_ep2_rot_offset_shape_height$jscomp$1$$=-($badge_padding_x_badge_width$$/2);var $badge_y$$=-($badge_height_props_75312$$/2),$badge_cx$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$)+
$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($badge_char_width_ep1_normal$jscomp$1$$)*$badge_cy_badge_gap_offset$jscomp$196$$;$badge_cy_badge_gap_offset$jscomp$196$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($has_rotation_QMARK__mid_point_points$jscomp$102_vec__75317$$)+$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($badge_char_width_ep1_normal$jscomp$1$$)*$badge_cy_badge_gap_offset$jscomp$196$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-size-badge",
pointerEvents:"none",transform:"translate("+($badge_cx$$??"")+","+($badge_cy_badge_gap_offset$jscomp$196$$??"")+") rotate("+($badge_rot_rotation$jscomp$22$$??"")+")",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$badge_x_ep2_rot_offset_shape_height$jscomp$1$$,y:$badge_y$$,width:$badge_padding_x_badge_width$$,height:$badge_height_props_75312$$,rx:$badge_radius$$,ry:$badge_radius$$,style:{fill:$badge_bg_color_zoom$jscomp$58$$}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:0,y:0,textAnchor:"middle",dominantBaseline:"middle",
className:"main_ui_measurements__badge-text",children:$shape_width$jscomp$1_text$jscomp$74$$})]})}$badge_x_ep2_rot_offset_shape_height$jscomp$1$$=-($badge_padding_x_badge_width$$/2);$badge_y$$=-($badge_height_props_75312$$/2);$badge_cx$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$79$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$79$$)/2;$badge_cy_badge_gap_offset$jscomp$196$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$79$$)+
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$79$$)+$badge_cy_badge_gap_offset$jscomp$196$$+$badge_height_props_75312$$/2;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-size-badge",pointerEvents:"none",transform:"translate("+($badge_cx$$??"")+","+($badge_cy_badge_gap_offset$jscomp$196$$??"")+")",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$badge_x_ep2_rot_offset_shape_height$jscomp$1$$,y:$badge_y$$,width:$badge_padding_x_badge_width$$,height:$badge_height_props_75312$$,
rx:$badge_radius$$,ry:$badge_radius$$,style:{fill:$badge_bg_color_zoom$jscomp$58$$}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:0,y:0,textAnchor:"middle",dominantBaseline:"middle",className:"main_ui_measurements__badge-text",children:$shape_width$jscomp$1_text$jscomp$74$$})]})};
$app$main$data$persistence$discard_commit$$=function($commit_id$jscomp$2$$){typeof $app$main$data$persistence$discard_commit_55244$$==="undefined"&&($app$main$data$persistence$discard_commit_55244$$=function($commit_id$jscomp$3$$,$meta55245$$){this.$commit_id$=$commit_id$jscomp$3$$;this.$meta55245$=$meta55245$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$discard_commit_55244$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$persistence$discard_commit_55244$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3177$app_DOT_main_DOT_data_DOT_persistence_SLASH_discard_commit$$},$app$main$data$persistence$discard_commit_55244$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55246$$,$meta55245__$1$$){return new $app$main$data$persistence$discard_commit_55244$$(this.$commit_id$,$meta55245__$1$$)},$app$main$data$persistence$discard_commit_55244$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55245$},$app$main$data$persistence$discard_commit_55244$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$discard_commit_55244$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1656$$,$state$jscomp$187$$){var $self__$jscomp$3515$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$187$$,$APP.$cljs$cst$2186$persistence$$,function($pstate$jscomp$1$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($pstate$jscomp$1$$,
$APP.$cljs$cst$1489$queue$$,function($queue$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3515$$.$commit_id$,$APP.$cljs$core$peek$$($queue$$)))return $APP.$cljs$core$pop$$($queue$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("invalid state",$APP.$cljs$core$PersistentArrayMap$EMPTY$$);}),$APP.$cljs$cst$1801$index$$,$APP.$cljs$core$dissoc$$,$self__$jscomp$3515$$.$commit_id$)})});return new $app$main$data$persistence$discard_commit_55244$$($commit_id$jscomp$2$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$color$interpolate_color$$=function($a1$jscomp$6_c1$jscomp$22$$,$a2$jscomp$2_c2$jscomp$13$$,$offset$jscomp$95$$){if($offset$jscomp$95$$<=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($a1$jscomp$6_c1$jscomp$22$$,$APP.$cljs$cst$195$offset$$,$offset$jscomp$95$$);if($offset$jscomp$95$$>=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$2_c2$jscomp$13$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($a2$jscomp$2_c2$jscomp$13$$,$APP.$cljs$cst$195$offset$$,
$offset$jscomp$95$$);var $a$jscomp$349_tr_offset$$=($offset$jscomp$95$$-$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$))/($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$2_c2$jscomp$13$$)-$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$)),$b$jscomp$280_b1$jscomp$2_vec__45563$$=$APP.$app$common$types$color$hex__GT_rgb$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$)),
$r$jscomp$95_r1$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$280_b1$jscomp$2_vec__45563$$,0,null),$g$jscomp$132_g1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$280_b1$jscomp$2_vec__45563$$,1,null);$b$jscomp$280_b1$jscomp$2_vec__45563$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$280_b1$jscomp$2_vec__45563$$,2,null);var $b2_vec__45566$$=$APP.$app$common$types$color$hex__GT_rgb$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$2_c2$jscomp$13$$)),
$r2$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b2_vec__45566$$,0,null),$g2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b2_vec__45566$$,1,null);$b2_vec__45566$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b2_vec__45566$$,2,null);$a1$jscomp$6_c1$jscomp$22$$=$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$6_c1$jscomp$22$$);$a2$jscomp$2_c2$jscomp$13$$=$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$2_c2$jscomp$13$$);
$r$jscomp$95_r1$jscomp$12$$+=($r2$jscomp$11$$-$r$jscomp$95_r1$jscomp$12$$)*$a$jscomp$349_tr_offset$$;$g$jscomp$132_g1$$+=($g2$$-$g$jscomp$132_g1$$)*$a$jscomp$349_tr_offset$$;$b$jscomp$280_b1$jscomp$2_vec__45563$$+=($b2_vec__45566$$-$b$jscomp$280_b1$jscomp$2_vec__45563$$)*$a$jscomp$349_tr_offset$$;$a$jscomp$349_tr_offset$$=$a1$jscomp$6_c1$jscomp$22$$+($a2$jscomp$2_c2$jscomp$13$$-$a1$jscomp$6_c1$jscomp$22$$)*$a$jscomp$349_tr_offset$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1303$color$$,
$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$95_r1$jscomp$12$$,$g$jscomp$132_g1$$,$b$jscomp$280_b1$jscomp$2_vec__45563$$],null)),$APP.$cljs$cst$1740$opacity$$,$a$jscomp$349_tr_offset$$,$APP.$cljs$cst$1749$r$$,$r$jscomp$95_r1$jscomp$12$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$132_g1$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$280_b1$jscomp$2_vec__45563$$,$APP.$cljs$cst$746$alpha$$,$a$jscomp$349_tr_offset$$,$APP.$cljs$cst$195$offset$$,
$offset$jscomp$95$$],null)};
$app$common$types$color$interpolate_gradient$$=function($end$jscomp$54_stops$jscomp$1$$,$offset$jscomp$97$$){var $idx$jscomp$73$$=$APP.$app$common$data$index_of_pred$$($end$jscomp$54_stops$jscomp$1$$,function($p1__45589_SHARP_$$){return $offset$jscomp$97$$<=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($p1__45589_SHARP_$$)}),$start$jscomp$188$$=$idx$jscomp$73$$==null?$APP.$cljs$core$last$$($end$jscomp$54_stops$jscomp$1$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$73$$,0)?
$APP.$cljs$core$first$$($end$jscomp$54_stops$jscomp$1$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$54_stops$jscomp$1$$,$idx$jscomp$73$$-1);$end$jscomp$54_stops$jscomp$1$$=$idx$jscomp$73$$==null?$APP.$cljs$core$last$$($end$jscomp$54_stops$jscomp$1$$):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$54_stops$jscomp$1$$,$idx$jscomp$73$$);return $app$common$types$color$interpolate_color$$($start$jscomp$188$$,$end$jscomp$54_stops$jscomp$1$$,$offset$jscomp$97$$)};
$app$main$data$workspace$colors$update_colorpicker_add_stop$$=function($offset$jscomp$175$$){typeof $app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$=function($offset$jscomp$176$$,$meta71252$$){this.offset=$offset$jscomp$176$$;this.$meta71252$=$meta71252$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4244$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_stop$$},$app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71253$$,$meta71252__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$(this.offset,
$meta71252__$1$$)},$app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71252$},$app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2285$$,$state$jscomp$663$$){var $self__$jscomp$5331$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$663$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$34$$){var $stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$=$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$34$$);if(!$APP.$app$main$features$active_feature_QMARK_$$($state__$1$jscomp$34$$,"render-wasm/v1")||$APP.$cljs$core$count$$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$)<16){var $new_stop$jscomp$1$$=
$app$main$data$workspace$colors$split_color_components$$($app$common$types$color$interpolate_gradient$$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$,$self__$jscomp$5331$$.offset));$stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$,$new_stop$jscomp$1$$);$stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$));var $editing_stop$jscomp$1$$=$APP.$app$common$data$index_of_pred$$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$,function($p1__71250_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_stop$jscomp$1$$,$p1__71250_SHARP_$$)});return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$34$$,
$APP.$cljs$cst$4229$editing_stop$$,$editing_stop$jscomp$1$$),$APP.$cljs$cst$4231$current_color$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$,$editing_stop$jscomp$1$$)),$APP.$cljs$cst$1739$stops$$,$stops$jscomp$11_stops__$1$jscomp$3_stops__$2$jscomp$1$$)}return $state__$1$jscomp$34$$})});return new $app$main$data$workspace$colors$update_colorpicker_add_stop_71251$$($offset$jscomp$175$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$color$uniform_spread_QMARK_$$=function($stops$$){var $cs$jscomp$2_expect_vals$$=$APP.$cljs$core$count$$($stops$$),$from$jscomp$10$$=$APP.$cljs$core$first$$($stops$$),$to$jscomp$9$$=$APP.$cljs$core$last$$($stops$$);$cs$jscomp$2_expect_vals$$=$app$common$types$color$offset_spread$$($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$10$$),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$9$$),$cs$jscomp$2_expect_vals$$);return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$true_QMARK_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($ec_expected_offset$$,$stop$$){var $and__5023__auto__$jscomp$226$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($stop$$),$ec_expected_offset$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$226$$)?($ec_expected_offset$$=$app$common$types$color$interpolate_color$$($from$jscomp$10$$,$to$jscomp$9$$,$ec_expected_offset$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($ec_expected_offset$$),
$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($stop$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($ec_expected_offset$$),$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($stop$$))):$and__5023__auto__$jscomp$226$$},$cs$jscomp$2_expect_vals$$,$stops$$))};$app$common$types$color$hsv__GT_hex$$=function($hsv$$){return $APP.$app$common$types$color$rgb__GT_hex$$($app$common$types$color$hsv__GT_rgb$$($hsv$$))};
$cljs$tools$reader$resolve_symbol$$=function($s$jscomp$174$$){throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("resolve-symbol is not implemented",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$242$sym$$,$s$jscomp$174$$],null));};
$cljs$tools$reader$register_gensym$$=function($sym$jscomp$18$$){if($APP.$cljs$core$not$$($cljs$tools$reader$gensym_env$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Gensym literal not in syntax-quote",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],null));var $gs_or__5025__auto__$jscomp$58$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$tools$reader$gensym_env$$,$sym$jscomp$18$$);if($APP.$cljs$core$truth_$$($gs_or__5025__auto__$jscomp$58$$))return $gs_or__5025__auto__$jscomp$58$$;
$gs_or__5025__auto__$jscomp$58$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$name$$($sym$jscomp$18$$),0,$APP.$cljs$core$name$$($sym$jscomp$18$$).length-1),"__",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$tools$reader$impl$utils$last_id$$,$APP.$cljs$core$inc$$)),"__auto__"].join(""));$cljs$tools$reader$gensym_env$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$tools$reader$gensym_env$$,
$sym$jscomp$18$$,$gs_or__5025__auto__$jscomp$58$$);return $gs_or__5025__auto__$jscomp$58$$};
$cljs$tools$reader$register_arg$$=function($n$jscomp$175$$){if($APP.$cljs$core$truth_$$($cljs$tools$reader$arg_env$$)){var $g$jscomp$81_temp__5823__auto__$jscomp$24$$=$cljs$tools$reader$arg_env$$.call(null,$n$jscomp$175$$);if($APP.$cljs$core$truth_$$($g$jscomp$81_temp__5823__auto__$jscomp$24$$))return $g$jscomp$81_temp__5823__auto__$jscomp$24$$;$g$jscomp$81_temp__5823__auto__$jscomp$24$$=$cljs$tools$reader$garg$$($n$jscomp$175$$);$cljs$tools$reader$arg_env$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$tools$reader$arg_env$$,
$n$jscomp$175$$,$g$jscomp$81_temp__5823__auto__$jscomp$24$$);return $g$jscomp$81_temp__5823__auto__$jscomp$24$$}throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Arg literal not in #()",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],null));};
$cljs$tools$reader$check_eof_error$$=function($and__5023__auto__$jscomp$inline_8362_form$jscomp$11$$,$rdr$jscomp$76$$,$first_line$$){$and__5023__auto__$jscomp$inline_8362_form$jscomp$11$$===$cljs$tools$reader$READ_EOF$$&&($and__5023__auto__$jscomp$inline_8362_form$jscomp$11$$=$first_line$$<0,$APP.$cljs$tools$reader$impl$errors$throw_eof_error$$($rdr$jscomp$76$$,$and__5023__auto__$jscomp$inline_8362_form$jscomp$11$$?$first_line$$:$and__5023__auto__$jscomp$inline_8362_form$jscomp$11$$))};
$cljs$tools$reader$read_regex$$=function($rdr$jscomp$56$$){for(var $sb$jscomp$12$$=new $APP.$goog$string$StringBuffer$$,$ch_24963__$2_ch__$1$jscomp$2$$=$rdr$jscomp$56$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);;){if('"'===$ch_24963__$2_ch__$1$jscomp$2$$)return $APP.$cljs$core$re_pattern$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$12$$));if($ch_24963__$2_ch__$1$jscomp$2$$==null)return $APP.$cljs$tools$reader$impl$errors$throw_eof_reading$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$56$$,
$APP.$cljs$cst$214$regex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$sb$jscomp$12$$]));$sb$jscomp$12$$.append($ch_24963__$2_ch__$1$jscomp$2$$);"\\"===$ch_24963__$2_ch__$1$jscomp$2$$&&($ch_24963__$2_ch__$1$jscomp$2$$=$rdr$jscomp$56$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null),$ch_24963__$2_ch__$1$jscomp$2$$==null&&$APP.$cljs$tools$reader$impl$errors$throw_eof_reading$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$56$$,$APP.$cljs$cst$214$regex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$sb$jscomp$12$$])),
$sb$jscomp$12$$.append($ch_24963__$2_ch__$1$jscomp$2$$));$ch_24963__$2_ch__$1$jscomp$2$$=$rdr$jscomp$56$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null)}};
$cljs$tools$reader$read_token$$=function($rdr$jscomp$53$$,$ch$jscomp$26_kind$jscomp$11$$,$initch$jscomp$1$$){if($initch$jscomp$1$$==null)return $APP.$cljs$tools$reader$impl$errors$throw_eof_at_start$$($rdr$jscomp$53$$,$ch$jscomp$26_kind$jscomp$11$$);$APP.$cljs$tools$reader$sb$$.clear();for($ch$jscomp$26_kind$jscomp$11$$=$initch$jscomp$1$$;;){if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$26_kind$jscomp$11$$)||$cljs$tools$reader$macro_terminating_QMARK_$$($ch$jscomp$26_kind$jscomp$11$$)||
$ch$jscomp$26_kind$jscomp$11$$==null)return $ch$jscomp$26_kind$jscomp$11$$!=null&&$rdr$jscomp$53$$.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$(null,$ch$jscomp$26_kind$jscomp$11$$),$APP.$cljs$tools$reader$sb$$.toString();$APP.$cljs$tools$reader$sb$$.append($ch$jscomp$26_kind$jscomp$11$$);$ch$jscomp$26_kind$jscomp$11$$=$rdr$jscomp$53$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null)}};
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$=function($token$jscomp$19$$,$l$jscomp$74_length$jscomp$26$$,$base$jscomp$9$$){$l$jscomp$74_length$jscomp$26$$=1+$l$jscomp$74_length$jscomp$26$$;$APP.$cljs$core$count$$($token$jscomp$19$$)!==$l$jscomp$74_length$jscomp$26$$&&$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_literal$$($token$jscomp$19$$);for(var $i$jscomp$287$$=1,$G__24976_uc$$=0;;){if($i$jscomp$287$$===$l$jscomp$74_length$jscomp$26$$)return String.fromCharCode($G__24976_uc$$);
var $d$jscomp$101$$=$APP.$cljs$tools$reader$impl$utils$char_code$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$19$$,$i$jscomp$287$$),$base$jscomp$9$$);if($d$jscomp$101$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit_in_token$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($token$jscomp$19$$,$i$jscomp$287$$),$token$jscomp$19$$);$G__24976_uc$$=$d$jscomp$101$$+$G__24976_uc$$*$base$jscomp$9$$;$i$jscomp$287$$+=1}};
$cljs$tools$reader$read_char_STAR_$$=function($rdr$jscomp$58$$){var $c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$=$rdr$jscomp$58$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$!=null){$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$=$cljs$tools$reader$macro_terminating_QMARK_$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$)||$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$)?
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$):$cljs$tools$reader$read_token$$($rdr$jscomp$58$$,$APP.$cljs$cst$215$character$$,$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$);var $ic_len$jscomp$54_token_len_uc$jscomp$2$$=$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$.length;if(1===$ic_len$jscomp$54_token_len_uc$jscomp$2$$)return $c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$.charAt(0);
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,"newline"))return"\n";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,"space"))return" ";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,"tab"))return"\t";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,
"backspace"))return"\b";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,"formfeed"))return"\f";if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,"return"))return"\r";if($APP.$cljs$core$truth_$$($APP.$goog$string$internal$startsWith$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,"u")))return $c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$=
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,4,16),$ic_len$jscomp$54_token_len_uc$jscomp$2$$=$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$.charCodeAt(0),$ic_len$jscomp$54_token_len_uc$jscomp$2$$>55295&&$ic_len$jscomp$54_token_len_uc$jscomp$2$$<57344?$APP.$cljs$tools$reader$impl$errors$throw_invalid_character_literal$$($rdr$jscomp$58$$,$ic_len$jscomp$54_token_len_uc$jscomp$2$$.toString(16)):
$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$;if($APP.$cljs$core$truth_$$($APP.$goog$string$internal$startsWith$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,"o"))){--$ic_len$jscomp$54_token_len_uc$jscomp$2$$;if($ic_len$jscomp$54_token_len_uc$jscomp$2$$>3)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_octal_len$$($rdr$jscomp$58$$,$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$);$ic_len$jscomp$54_token_len_uc$jscomp$2$$=
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$04$$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,$ic_len$jscomp$54_token_len_uc$jscomp$2$$,8);$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,1);return parseInt($c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,8)<=255?$ic_len$jscomp$54_token_len_uc$jscomp$2$$:
$APP.$cljs$tools$reader$impl$errors$throw_bad_octal_number$$($rdr$jscomp$58$$)}return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$58$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unsupported character: ",$c$jscomp$142_ch$jscomp$31_token$jscomp$21_token$jscomp$inline_8364$$,"."]))}return $APP.$cljs$tools$reader$impl$errors$throw_eof_in_character$$($rdr$jscomp$58$$)};
$cljs$tools$reader$read_unmatched_delimiter$$=function($rdr$jscomp$55$$,$ch$jscomp$28$$){return $APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$55$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Unmatched delimiter ",$ch$jscomp$28$$,"."]))};
$cljs$tools$reader$read_keyword$$=function($reader$jscomp$35$$){var $ch$jscomp$35_token$jscomp$23$$=$reader$jscomp$35$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$35_token$jscomp$23$$))return $APP.$cljs$tools$reader$impl$errors$throw_single_colon$$($reader$jscomp$35$$);$ch$jscomp$35_token$jscomp$23$$=$cljs$tools$reader$read_token$$($reader$jscomp$35$$,$APP.$cljs$cst$221$keyword$$,$ch$jscomp$35_token$jscomp$23$$);
var $name$jscomp$121_s$jscomp$171$$=$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($ch$jscomp$35_token$jscomp$23$$);if($name$jscomp$121_s$jscomp$171$$!=null){var $ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$=$name$jscomp$121_s$jscomp$171$$.$cljs$core$IIndexed$_nth$arity$2$(null,0);$name$jscomp$121_s$jscomp$171$$=$name$jscomp$121_s$jscomp$171$$.$cljs$core$IIndexed$_nth$arity$2$(null,1);if(":"===$ch$jscomp$35_token$jscomp$23$$.charAt(0)){if($ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$!=
null)return $ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$,1)),$ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(null,$ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$),$APP.$cljs$core$truth_$$($ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$)?
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$),$name$jscomp$121_s$jscomp$171$$):$APP.$cljs$tools$reader$impl$errors$throw_invalid$$($reader$jscomp$35$$,$APP.$cljs$cst$221$keyword$$,[":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$35_token$jscomp$23$$)].join(""));$ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$=null;return $APP.$cljs$core$truth_$$($ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$)?
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$121_s$jscomp$171$$,1)):$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($reader$jscomp$35$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid token: :",$ch$jscomp$35_token$jscomp$23$$]))}return $APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$2$($ns$jscomp$19_sym$jscomp$inline_13462_temp__5823__auto__$jscomp$22$$,
$name$jscomp$121_s$jscomp$171$$)}return $APP.$cljs$tools$reader$impl$errors$throw_invalid$$($reader$jscomp$35$$,$APP.$cljs$cst$221$keyword$$,[":",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$35_token$jscomp$23$$)].join(""))};
$cljs$tools$reader$read_symbol$$=function($end_line$jscomp$inline_8373_rdr$jscomp$69$$,$JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$){var $column$jscomp$7_vec__24676$$=$cljs$tools$reader$starting_line_col_info$$($end_line$jscomp$inline_8373_rdr$jscomp$69$$),$JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$7_vec__24676$$,0,null);$column$jscomp$7_vec__24676$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$7_vec__24676$$,
1,null);$JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$=$cljs$tools$reader$read_token$$($end_line$jscomp$inline_8373_rdr$jscomp$69$$,$APP.$cljs$cst$219$symbol$$,$JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$);if($JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$==null)return null;switch($JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$){case "nil":return null;case "true":return!0;case "false":return!1;case "/":return $APP.$cljs$cst$220$_SLASH_$$;
default:var $JSCompiler_temp_const$jscomp$1531_p$jscomp$39$$=$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$);if($JSCompiler_temp_const$jscomp$1531_p$jscomp$39$$!=null){$JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1531_p$jscomp$39$$.$cljs$core$IIndexed$_nth$arity$2$(null,0),$JSCompiler_temp_const$jscomp$1531_p$jscomp$39$$.$cljs$core$IIndexed$_nth$arity$2$(null,
1));$JSCompiler_temp_const$jscomp$1531_p$jscomp$39$$=$JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$.$cljs$core$IWithMeta$_with_meta$arity$2$;if($JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$==null)$JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$=null;else{var $file$jscomp$inline_8370_filem$jscomp$inline_8371$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$($end_line$jscomp$inline_8373_rdr$jscomp$69$$);
$file$jscomp$inline_8370_filem$jscomp$inline_8371$$=$file$jscomp$inline_8370_filem$jscomp$inline_8371$$==null?null:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$file$jscomp$inline_8370_filem$jscomp$inline_8371$$],null);var $end_column$jscomp$inline_8374_vec__24669$jscomp$inline_8372$$=$cljs$tools$reader$ending_line_col_info$$($end_line$jscomp$inline_8373_rdr$jscomp$69$$);$end_line$jscomp$inline_8373_rdr$jscomp$69$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$inline_8374_vec__24669$jscomp$inline_8372$$,
0,null);$end_column$jscomp$inline_8374_vec__24669$jscomp$inline_8372$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$inline_8374_vec__24669$jscomp$inline_8372$$,1,null);$JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file$jscomp$inline_8370_filem$jscomp$inline_8371$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$209$line$$,$JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$,$APP.$cljs$cst$216$column$$,$column$jscomp$7_vec__24676$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$inline_8373_rdr$jscomp$69$$,$APP.$cljs$cst$218$end_column$$,$end_column$jscomp$inline_8374_vec__24669$jscomp$inline_8372$$],null)]))}$JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$=$JSCompiler_temp_const$jscomp$1531_p$jscomp$39$$.call($JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$,
null,$JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$)}else $JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$=$APP.$cljs$tools$reader$impl$errors$throw_invalid$$($end_line$jscomp$inline_8373_rdr$jscomp$69$$,$APP.$cljs$cst$219$symbol$$,$JSCompiler_temp_const$jscomp$1532_initch$jscomp$4_token$jscomp$22$$);return $JSCompiler_inline_result$jscomp$1533_JSCompiler_temp$jscomp$1530_line$jscomp$17$$}};
$app$main$data$exports$assets$show_workspace_export_frames_dialog$$=function($frames$jscomp$17$$){typeof $app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$==="undefined"&&($app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$=function($frames$jscomp$18$$,$meta72991$$){this.frames=$frames$jscomp$18$$;this.$meta72991$=$meta72991$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4875$app_DOT_main_DOT_data_DOT_exports_DOT_assets_SLASH_show_workspace_export_frames_dialog$$},$app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72992$$,$meta72991__$1$$){return new $app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$(this.frames,
$meta72991__$1$$)},$app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72991$},$app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2732_page$jscomp$112_page_name$jscomp$3$$,
$exports__$1$jscomp$6_state$jscomp$1030$$){var $file_id$jscomp$317$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($exports__$1$jscomp$6_state$jscomp$1030$$),$page_id$jscomp$347$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($exports__$1$jscomp$6_state$jscomp$1030$$);$_$jscomp$2732_page$jscomp$112_page_name$jscomp$3$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($exports__$1$jscomp$6_state$jscomp$1030$$);$_$jscomp$2732_page$jscomp$112_page_name$jscomp$3$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2732_page$jscomp$112_page_name$jscomp$3$$);$exports__$1$jscomp$6_state$jscomp$1030$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($frame$jscomp$42$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$3133$enabled$$,!0,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$347$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$317$$,$APP.$cljs$cst$2281$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$42$$),
$APP.$cljs$cst$1817$shape$$,$frame$jscomp$42$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$42$$)],null)},this.frames);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4876$export_frames$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1877$exports$$,$exports__$1$jscomp$6_state$jscomp$1030$$,$APP.$cljs$cst$1792$origin$$,"workspace:menu",$APP.$cljs$cst$725$name$$,
$_$jscomp$2732_page$jscomp$112_page_name$jscomp$3$$],null)))});return new $app$main$data$exports$assets$show_workspace_export_frames_dialog_72990$$($frames$jscomp$17$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$sort_colorpicker_stops$$=function(){typeof $app$main$data$workspace$colors$sort_colorpicker_stops_71258$$==="undefined"&&($app$main$data$workspace$colors$sort_colorpicker_stops_71258$$=function($meta71259$$){this.$meta71259$=$meta71259$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$sort_colorpicker_stops_71258$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$sort_colorpicker_stops_71258$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4248$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_sort_colorpicker_stops$$},$app$main$data$workspace$colors$sort_colorpicker_stops_71258$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71260$$,$meta71259__$1$$){return new $app$main$data$workspace$colors$sort_colorpicker_stops_71258$$($meta71259__$1$$)},$app$main$data$workspace$colors$sort_colorpicker_stops_71258$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71259$},
$app$main$data$workspace$colors$sort_colorpicker_stops_71258$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$sort_colorpicker_stops_71258$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2287$$,$state$jscomp$665$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$665$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$36$$){var $stop$jscomp$5_stops__$1$jscomp$5$$=function(){var $or__5025__auto__$jscomp$844$$=
$APP.$cljs$cst$4229$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$36$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$844$$)?$or__5025__auto__$jscomp$844$$:0}(),$stop__$1_stops$jscomp$14$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$split_color_components$$,$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$36$$)),$stop_val$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stop__$1_stops$jscomp$14$$,
$stop$jscomp$5_stops__$1$jscomp$5$$);$stop$jscomp$5_stops__$1$jscomp$5$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stop__$1_stops$jscomp$14$$));$stop__$1_stops$jscomp$14$$=$APP.$app$common$data$index_of_pred$$($stop$jscomp$5_stops__$1$jscomp$5$$,function($p1__71257_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__71257_SHARP_$$,$stop_val$$)});
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$36$$,$APP.$cljs$cst$4229$editing_stop$$,$stop__$1_stops$jscomp$14$$),$APP.$cljs$cst$1739$stops$$,$stop$jscomp$5_stops__$1$jscomp$5$$)})});return new $app$main$data$workspace$colors$sort_colorpicker_stops_71258$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$text$fix_gradients$$=function($data$jscomp$368$$){function $update_fill$$($fill$jscomp$15$$){return $APP.$app$common$data$update_in_when$$($fill$jscomp$15$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1754$fill_color_gradient$$,$APP.$cljs$cst$139$type$$],null),$fix_type$$)}function $fix_type$$($type$jscomp$485$$){return typeof $type$jscomp$485$$==="string"?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$485$$):
$type$jscomp$485$$}return $APP.$app$common$data$update_when$$($data$jscomp$368$$,$APP.$cljs$cst$1639$fills$$,function($fills$jscomp$22$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($update_fill$$,$fills$jscomp$22$$)})};
$app$common$text$build_style_index$$=function($G__68987_length$jscomp$49_result$jscomp$304$$,$G__68988_ranges$jscomp$4_ranges__$1$$){$G__68987_length$jscomp$49_result$jscomp$304$$=$APP.$cljs$core$transient$0$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$constantly$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($G__68987_length$jscomp$49_result$jscomp$304$$)));for($G__68988_ranges$jscomp$4_ranges__$1$$=$APP.$cljs$core$seq$$($G__68988_ranges$jscomp$4_ranges__$1$$);;){var $temp__5823__auto__$jscomp$176$$=
$APP.$cljs$core$first$$($G__68988_ranges$jscomp$4_ranges__$1$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$176$$)){var $map__68883$$=$temp__5823__auto__$jscomp$176$$,$map__68883__$1$$=$APP.$cljs$core$__destructure_map$$($map__68883$$),$item$jscomp$88$$=$map__68883__$1$$,$offset$jscomp$172$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68883__$1$$,$APP.$cljs$cst$195$offset$$),$length__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__68883__$1$$,$APP.$cljs$cst$255$length$$);
$G__68987_length$jscomp$49_result$jscomp$304$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$305$$,$ranges__$1$jscomp$1$$,$map__68883$jscomp$1$$,$map__68883__$1$jscomp$1$$,$item$jscomp$89$$){return function($result__$1$jscomp$35$$,$index$jscomp$291$$){var $prev$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result__$1$jscomp$35$$,$index$jscomp$291$$);return $APP.$cljs$core$assoc_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($result__$1$jscomp$35$$,
$index$jscomp$291$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($prev$jscomp$19$$,$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$89$$),$APP.$cljs$cst$108$val$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$89$$)))}}($G__68987_length$jscomp$49_result$jscomp$304$$,$G__68988_ranges$jscomp$4_ranges__$1$$,$map__68883$$,$map__68883__$1$$,$item$jscomp$88$$,$offset$jscomp$172$$,$length__$1$$,$temp__5823__auto__$jscomp$176$$),$G__68987_length$jscomp$49_result$jscomp$304$$,
$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($offset$jscomp$172$$,$offset$jscomp$172$$+$length__$1$$));$G__68988_ranges$jscomp$4_ranges__$1$$=$APP.$cljs$core$rest$$($G__68988_ranges$jscomp$4_ranges__$1$$)}else return $APP.$cljs$core$_persistent_BANG_$$($G__68987_length$jscomp$49_result$jscomp$304$$)}};
$app$render_wasm$text_editor$merge_exported_texts_into_content$$=function($content$jscomp$132$$,$exported_texts_new_paras$$){var $new_para_set_para_set$$=$APP.$cljs$core$first$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$132$$,$APP.$cljs$cst$342$children$$)),$orig_paras$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_para_set_para_set$$,$APP.$cljs$cst$342$children$$),$num_orig$$=$APP.$cljs$core$count$$($orig_paras$$),$last_orig_para$$=$APP.$cljs$core$seq$$($orig_paras$$)?
$APP.$cljs$core$last$$($orig_paras$$):null,$template_span$$=$APP.$cljs$core$truth_$$($last_orig_para$$)?$APP.$cljs$core$last$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($last_orig_para$$)):null;$exported_texts_new_paras$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($orig_para_para_idx$$,$exported_span_texts$$){$orig_para_para_idx$$=$orig_para_para_idx$$<$num_orig$$?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($orig_paras$$,$orig_para_para_idx$$):
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($last_orig_para$$,$APP.$cljs$cst$342$children$$);var $orig_spans$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($orig_para_para_idx$$,$APP.$cljs$cst$342$children$$),$num_orig_spans$$=$APP.$cljs$core$count$$($orig_spans$$),$last_orig_span$$=$APP.$cljs$core$seq$$($orig_spans$$)?$APP.$cljs$core$last$$($orig_spans$$):null;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($orig_para_para_idx$$,$APP.$cljs$cst$342$children$$,
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($orig_span_span_idx$$,$new_text$$){$orig_span_span_idx$$=$orig_span_span_idx$$<$num_orig_spans$$?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($orig_spans$$,$orig_span_span_idx$$):$APP.$cljs$core$truth_$$($last_orig_span$$)?$last_orig_span$$:$template_span$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($orig_span_span_idx$$,$APP.$cljs$cst$1593$text$$,$new_text$$)},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($exported_span_texts$$)),
$exported_span_texts$$))},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($exported_texts_new_paras$$)),$exported_texts_new_paras$$);$new_para_set_para_set$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($new_para_set_para_set$$,$APP.$cljs$cst$342$children$$,$exported_texts_new_paras$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($content$jscomp$132$$,$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$new_para_set_para_set$$],null))};
$app$common$types$variant$compare_properties$cljs$0core$0IFn$0_invoke$0arity$02$$=function($grouped$jscomp$1_props_list$jscomp$1$$){$grouped$jscomp$1_props_list$jscomp$1$$=$APP.$cljs$core$group_by$$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$grouped$jscomp$1_props_list$jscomp$1$$));return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$){var $name$jscomp$187$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$,
0,null);$JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$,1,null);$JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$,$JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$);
$JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_EQ_$$,$JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$))?$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$):!1;return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$name$jscomp$187$$,
$APP.$cljs$cst$260$value$$,$JSCompiler_inline_result$jscomp$1565_p__49344_vals$jscomp$inline_8377_values$jscomp$38$$],null)},$grouped$jscomp$1_props_list$jscomp$1$$)};
$app$common$types$color$uniform_spread$$=function($from$jscomp$11$$,$to$jscomp$10$$,$num_stops$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($offset$jscomp$96$$){return $app$common$types$color$interpolate_color$$($from$jscomp$11$$,$to$jscomp$10$$,$offset$jscomp$96$$)},$app$common$types$color$offset_spread$$($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$11$$),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$10$$),$num_stops$$))};
$app$main$data$workspace$colors$update_colorpicker_add_auto$$=function(){typeof $app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$=function($meta71243$$){this.$meta71243$=$meta71243$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4245$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_auto$$},$app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71244$$,$meta71243__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$($meta71243__$1$$)},$app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71243$},$app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2284$$,$state$jscomp$662$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$662$$,$APP.$cljs$cst$2247$colorpicker$$,function($map__71246__$1_p__71245$$){$map__71246__$1_p__71245$$=
$APP.$cljs$core$__destructure_map$$($map__71246__$1_p__71245$$);var $stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71246__$1_p__71245$$,$APP.$cljs$cst$1739$stops$$),$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71246__$1_p__71245$$,$APP.$cljs$cst$4229$editing_stop$$);if(!$APP.$app$main$features$active_feature_QMARK_$$($map__71246__$1_p__71245$$,"render-wasm/v1")||
$APP.$cljs$core$count$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$)<16){if($app$common$types$color$uniform_spread_QMARK_$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$))return $stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$split_color_components$$,$app$common$types$color$uniform_spread$$($APP.$cljs$core$first$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$),$APP.$cljs$core$last$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$),
$APP.$cljs$core$count$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$)+1)),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71246__$1_p__71245$$,$APP.$cljs$cst$4231$current_color$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$)),$APP.$cljs$cst$1739$stops$$,$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$);
var $index$jscomp$309_map__71249_map__71249__$1_to_offset$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$,$APP.$cljs$core$count$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$)-1)?$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$-1:$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$;$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,
$index$jscomp$309_map__71249_map__71249__$1_to_offset$$);$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$=$APP.$cljs$core$__destructure_map$$($editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$);$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$,$APP.$cljs$cst$195$offset$$);$index$jscomp$309_map__71249_map__71249__$1_to_offset$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,$index$jscomp$309_map__71249_map__71249__$1_to_offset$$+1);$index$jscomp$309_map__71249_map__71249__$1_to_offset$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$309_map__71249_map__71249__$1_to_offset$$);$index$jscomp$309_map__71249_map__71249__$1_to_offset$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$309_map__71249_map__71249__$1_to_offset$$,$APP.$cljs$cst$195$offset$$);
var $new_stop$$=$app$main$data$workspace$colors$split_color_components$$($app$common$types$color$interpolate_gradient$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$+($index$jscomp$309_map__71249_map__71249__$1_to_offset$$-$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$)/2));$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,
$new_stop$$);$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$));$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$=$APP.$app$common$data$index_of_pred$$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,function($p1__71241_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_stop$$,
$p1__71241_SHARP_$$)});return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71246__$1_p__71245$$,$APP.$cljs$cst$4229$editing_stop$$,$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$),$APP.$cljs$cst$4231$current_color$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$,$editing_stop_editing_stop__$1_from_offset_map__71248_map__71248__$1$$)),
$APP.$cljs$cst$1739$stops$$,$stops$jscomp$10_stops__$1$jscomp$2_stops__$2$$)}return $map__71246__$1_p__71245$$})});return new $app$main$data$workspace$colors$update_colorpicker_add_auto_71242$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$tokens_lib$update_tokens_group$$=function($active_tokens$$,$current_path$jscomp$1$$,$current_name$$,$new_name$jscomp$8$$){var $path_prefix$$=$APP.$cuerdas$core$replace$$($current_path$jscomp$1$$,$current_name$$,"");return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($new_token_obj_p__50032_token_obj$$){var $new_token_path_token_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_token_obj_p__50032_token_obj$$,0,null);$new_token_obj_p__50032_token_obj$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_token_obj_p__50032_token_obj$$,1,null);if($APP.$cuerdas$core$starts_with_QMARK_$$($new_token_path_token_path$$,$path_prefix$$)){$new_token_path_token_path$$=$APP.$cuerdas$core$replace$$($new_token_path_token_path$$,$current_name$$,$new_name$jscomp$8$$);var $G__50037$jscomp$inline_8379$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($new_token_obj_p__50032_token_obj$$,$APP.$cljs$cst$725$name$$,$new_token_path_token_path$$);$new_token_obj_p__50032_token_obj$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_token_obj_p__50032_token_obj$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__50037$jscomp$inline_8379$$,$APP.$cljs$cst$296$path$$,$APP.$cuerdas$core$replace$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_token_obj_p__50032_token_obj$$),$current_name$$,$new_name$jscomp$8$$)):$G__50037$jscomp$inline_8379$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$new_token_path_token_path$$,$new_token_obj_p__50032_token_obj$$],null)}return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$new_token_path_token_path$$,$new_token_obj_p__50032_token_obj$$],null)},$active_tokens$$)};$app$util$webapi$read_file_as_text$$=function($file$jscomp$8$$){return $APP.$app$util$webapi$file_reader$$(function($p1__44749_SHARP_$$){return $p1__44749_SHARP_$$.readAsText($file$jscomp$8$$)})};
$app$util$strings$matches_search$$=function($name$jscomp$324_nm$jscomp$2$$,$search_term_st$jscomp$1$$){if($APP.$cuerdas$core$empty_QMARK_$$($search_term_st$jscomp$1$$))return!0;$search_term_st$jscomp$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$lower$$($search_term_st$jscomp$1$$));$name$jscomp$324_nm$jscomp$2$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$lower$$($name$jscomp$324_nm$jscomp$2$$));return $APP.$cuerdas$core$includes_QMARK_$$($name$jscomp$324_nm$jscomp$2$$,
$search_term_st$jscomp$1$$)};
$app$common$types$variant$find_boolean_pair$$=function($p__49360$$){var $a$jscomp$366$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49360$$,0,null),$b$jscomp$298$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49360$$,1,null),$a_SINGLEQUOTE_$jscomp$3$$=$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$366$$)),$b_SINGLEQUOTE_$jscomp$1$$=$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$298$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($p__49360$$),
2)?$APP.$cljs$core$some$$(function($f$jscomp$779_p__49364$$){var $t$jscomp$88$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$779_p__49364$$,0,null);$f$jscomp$779_p__49364$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($f$jscomp$779_p__49364$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a_SINGLEQUOTE_$jscomp$3$$,$t$jscomp$88$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b_SINGLEQUOTE_$jscomp$1$$,$f$jscomp$779_p__49364$$)?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$a$jscomp$366$$,
!0,$b$jscomp$298$$,!1]):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b_SINGLEQUOTE_$jscomp$1$$,$t$jscomp$88$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($a_SINGLEQUOTE_$jscomp$3$$,$f$jscomp$779_p__49364$$)?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$b$jscomp$298$$,!0,$a$jscomp$366$$,!1]):null},$APP.$app$common$types$variant$boolean_pairs$$):null};
$app$common$types$file$get_shape_in_copy$$=function($file_data$jscomp$42$$,$main_shape$$,$root_copy$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__51750_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2055$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($p1__51750_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_shape$$))},$APP.$app$common$geom$shapes$tree_seq$get_children_seq$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_copy$$),
$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$42$$)))};
$app$util$text_editor$get_content_changes$$=function($old_state$$,$state$jscomp$568$$){var $old_blocks$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($old_state$$.getCurrentContent().getBlockMap().toJS(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!1])),$new_blocks$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$568$$.getCurrentContent().getBlockMap().toJS(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,
!1]));return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69055_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($new_blocks$$,$APP.$cljs$core$first$$($p1__69055_SHARP_$$))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($bstate_p__69059$$){var $bkey$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bstate_p__69059$$,0,null);$bstate_p__69059$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bstate_p__69059$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$bkey$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4067$old$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bstate_p__69059$$,"text"),$APP.$cljs$cst$4068$new$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_blocks$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$bkey$jscomp$1$$,"text"],null))],null)],null)})),$old_blocks$$),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69056_SHARP_$$){return!$APP.$cljs$core$contains_QMARK_$$($old_blocks$$,$APP.$cljs$core$first$$($p1__69056_SHARP_$$))}),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($bstate$jscomp$1_p__69064$$){var $bkey$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bstate$jscomp$1_p__69064$$,0,null);$bstate$jscomp$1_p__69064$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bstate$jscomp$1_p__69064$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$bkey$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4067$old$$,
null,$APP.$cljs$cst$4068$new$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bstate$jscomp$1_p__69064$$,"text")],null)],null)})),$new_blocks$$)]))};
$app$common$geom$shapes$intersect$overlaps_text_QMARK_$$=function($p__48940_position_data$jscomp$3$$,$rect$jscomp$16$$){var $map__48941__$1$$=$APP.$cljs$core$__destructure_map$$($p__48940_position_data$jscomp$3$$);$p__48940_position_data$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48941__$1$$,$APP.$cljs$cst$1899$position_data$$);if($p__48940_position_data$jscomp$3$$!=null&&$APP.$app$common$data$not_empty_QMARK_$$($p__48940_position_data$jscomp$3$$)){var $center$jscomp$24$$=
$APP.$app$common$geom$shapes$common$shape__GT_center$$($map__48941__$1$$);return $APP.$cljs$core$some$$(function($p1__48939_SHARP_$$){return $app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($rect$jscomp$16$$,$p1__48939_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$(function($rect_points$jscomp$3$$){return $APP.$app$common$geom$shapes$common$transform_points$cljs$0core$0IFn$0_invoke$0arity$03$$($rect_points$jscomp$3$$,
$center$jscomp$24$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($map__48941__$1$$))},$APP.$app$common$geom$rect$rect__GT_points$$,$APP.$app$common$geom$shapes$text$position_data__GT_rect$$),$p__48940_position_data$jscomp$3$$))}return $app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($rect$jscomp$16$$,$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($map__48941__$1$$))};
$app$common$geom$shapes$intersect$overlaps_QMARK_$$=function($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$,$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$){var $and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=
$APP.$cljs$cst$1660$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$);$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$)?
$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$:0)/2;$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$,
$APP.$cljs$cst$1515$x$$,$APP.$cljs$core$_$$,$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$),$APP.$cljs$cst$1516$y$$,$APP.$cljs$core$_$$,$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$),
$APP.$cljs$cst$290$width$$,$APP.$cljs$core$_PLUS_$$,2*$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$),$APP.$cljs$cst$1527$height$$,$APP.$cljs$core$_PLUS_$$,2*$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$);
if($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=$APP.$cljs$core$not$$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$))return $and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$;
if($APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$)||$APP.$app$common$files$helpers$bool_shape_QMARK_$$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$)){if($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=
$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$,$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$)))if($APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$))){var $JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$=
$APP.$cljs$core$count$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$))>100;$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=$APP.$app$common$geom$rect$rect__GT_points$$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$);
$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$);$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$?
($JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$=$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$),$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$=
$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$)):$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$=
$app$common$types$path$segment$path__GT_lines$$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$);$ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$))));
var $center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$=$app$common$geom$shapes$intersect$intersects_lines_QMARK_$$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$,$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$);
$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=$center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$?$center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$:$APP.$cljs$core$truth_$$(!0)?$app$common$geom$shapes$intersect$is_point_inside_nonzero_QMARK_$$($APP.$cljs$core$first$$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$),
$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$)||$app$common$geom$shapes$intersect$is_point_inside_nonzero_QMARK_$$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$,$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$):
!1}else $JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=null;else $JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$;
return $JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$}if($APP.$app$common$files$helpers$circle_shape_QMARK_$$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$)){if($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=
$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$,$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$))){$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=
$APP.$app$common$geom$rect$rect__GT_points$$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$);$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=$APP.$app$common$geom$shapes$intersect$points__GT_lines$cljs$0core$0IFn$0_invoke$0arity$02$$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$);
var $height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$=$APP.$cljs$core$__destructure_map$$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$);$center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$,
$APP.$cljs$cst$1515$x$$);var $ry$jscomp$inline_13493_y$jscomp$inline_13481$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$,$APP.$cljs$cst$1516$y$$);$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$,$APP.$cljs$cst$290$width$$);$height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$,
$APP.$cljs$cst$1527$height$$);$center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$+$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$/
2,$ry$jscomp$inline_13493_y$jscomp$inline_13481$$+$height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$/2);$ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1905$cx$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$),
$APP.$cljs$cst$1906$cy$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$),$APP.$cljs$cst$1889$rx$$,$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$/2,$APP.$cljs$cst$1890$ry$$,$height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$/
2,$APP.$cljs$cst$1294$transform$$,$APP.$cljs$cst$1793$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$)],null);if($JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$=$APP.$app$common$geom$shapes$intersect$is_point_inside_evenodd_QMARK_$$($center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$,
$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$))$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$;
else{$height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$=$APP.$cljs$core$first$$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$);var $map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$=
$APP.$cljs$core$__destructure_map$$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$);$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$,
$APP.$cljs$cst$1905$cx$$);$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$,$APP.$cljs$cst$1906$cy$$);$center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$,$APP.$cljs$cst$1889$rx$$);$ry$jscomp$inline_13493_y$jscomp$inline_13481$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$,
$APP.$cljs$cst$1890$ry$$);$map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$,$APP.$cljs$cst$1294$transform$$);var $center$jscomp$inline_13495$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$,
$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$);$map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$=$map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$!=
null?$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$inline_13495$$,$map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$):null;$height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$=$map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$!=
null?$APP.$app$common$geom$point$transform$$($height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$,$map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$):$height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$;$map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$=
$APP.$cljs$core$__destructure_map$$($height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$);$height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$,
$APP.$cljs$cst$1515$x$$);$map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$,$APP.$cljs$cst$1516$y$$);$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=
($and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$=$app$common$math$sq$$($height$jscomp$inline_13483_map__48923$jscomp$inline_13497_map__48938__$1$jscomp$inline_13479_point$jscomp$inline_13488_px$jscomp$inline_13499$$-$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$)/
($center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$*$center$jscomp$inline_13484_or__5025__auto__$jscomp$inline_13473_rx$jscomp$inline_13492_x$jscomp$inline_13480$$)+$app$common$math$sq$$($map__48922__$1$jscomp$inline_13489_map__48923__$1$jscomp$inline_13498_py$jscomp$inline_13500_transform$jscomp$inline_13494_transform__$1$jscomp$inline_13496$$-$JSCompiler_temp$jscomp$14321_cy$jscomp$inline_13491_or__5025__auto__$jscomp$inline_13486_path_lines$jscomp$inline_13471_points$jscomp$inline_14848_simple_QMARK_$jscomp$inline_13468_width$jscomp$inline_13482$$)/
($ry$jscomp$inline_13493_y$jscomp$inline_13481$$*$ry$jscomp$inline_13493_y$jscomp$inline_13481$$)<=1)?$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$:$app$common$geom$shapes$intersect$intersects_lines_ellipse_QMARK_$$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$,
$ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$)}}else $JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$=$and__5023__auto__$jscomp$256_cx$jscomp$inline_13490_or__5025__auto__$jscomp$363_or__5025__auto__$jscomp$inline_8381_or__5025__auto____$1$jscomp$inline_13487_rect_lines$jscomp$inline_13470_rect_points$jscomp$inline_13477_swidth$$;return $JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$}return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$)?
$app$common$geom$shapes$intersect$overlaps_text_QMARK_$$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$,$JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$):$app$common$geom$shapes$intersect$overlaps_rect_points_QMARK_$$($JSCompiler_temp$jscomp$11244_JSCompiler_temp$jscomp$11245_rect$jscomp$17_rect__$1_rect_lines$jscomp$inline_13478_rect_points$jscomp$inline_13469$$,
$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($ellipse_data$jscomp$inline_13485_shape$jscomp$122_start_point$jscomp$inline_13472$$))};$app$common$types$shape$interactions$remove_interactions$$=function($f$jscomp$778$$,$interactions$jscomp$4$$){return $APP.$cljs$core$not_empty$$($APP.$app$common$data$removev$$($f$jscomp$778$$,$interactions$jscomp$4$$))};
$app$main$data$workspace$colors$get_color_from_colorpicker_state$$=function($JSCompiler_temp$jscomp$1567_JSCompiler_temp$jscomp$1568_p__71218_stops$jscomp$9$$){var $map__71219__$1_opacity$jscomp$29$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1567_JSCompiler_temp$jscomp$1568_p__71218_stops$jscomp$9$$),$G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71219__$1_opacity$jscomp$29$$,$APP.$cljs$cst$139$type$$),
$JSCompiler_temp_const$jscomp$1576_current_color$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71219__$1_opacity$jscomp$29$$,$APP.$cljs$cst$4231$current_color$$);$JSCompiler_temp$jscomp$1567_JSCompiler_temp$jscomp$1568_p__71218_stops$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71219__$1_opacity$jscomp$29$$,$APP.$cljs$cst$1739$stops$$);var $gradient$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71219__$1_opacity$jscomp$29$$,$APP.$cljs$cst$1730$gradient$$);
$map__71219__$1_opacity$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71219__$1_opacity$jscomp$29$$,$APP.$cljs$cst$1740$opacity$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$,$APP.$cljs$cst$1303$color$$))$JSCompiler_temp$jscomp$1567_JSCompiler_temp$jscomp$1568_p__71218_stops$jscomp$9$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$clear_color_components$$($JSCompiler_temp_const$jscomp$1576_current_color$$),
$APP.$cljs$cst$195$offset$$);else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$,$APP.$cljs$cst$1617$image$$))$JSCompiler_temp$jscomp$1567_JSCompiler_temp$jscomp$1568_p__71218_stops$jscomp$9$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_temp_const$jscomp$1576_current_color$$,$APP.$cljs$cst$2698$hex$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$746$alpha$$,
$APP.$cljs$cst$1749$r$$,$APP.$cljs$cst$1750$g$$,$APP.$cljs$cst$1525$b$$,$APP.$cljs$cst$1907$h$$,$APP.$cljs$cst$4235$s$$,$APP.$cljs$cst$3723$v$$,$APP.$cljs$cst$1303$color$$]));else{$JSCompiler_temp_const$jscomp$1576_current_color$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_temp_const$jscomp$1574$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$1572$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1570$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1569$$=$APP.$cljs$cst$139$type$$;a:switch($G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$=$G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$ instanceof $APP.$cljs$core$Keyword$$?$G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$.$fqn$:null,$G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$){case "linear-gradient":$G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$=
$APP.$cljs$cst$287$linear$$;break a;case "radial-gradient":$G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$=$APP.$cljs$cst$1734$radial$$;break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$)].join(""));}$JSCompiler_temp$jscomp$1567_JSCompiler_temp$jscomp$1568_p__71218_stops$jscomp$9$$=$JSCompiler_temp_const$jscomp$1576_current_color$$.call($APP.$app$common$data$without_nils$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1740$opacity$$,$map__71219__$1_opacity$jscomp$29$$,$APP.$cljs$cst$1730$gradient$$,$JSCompiler_temp_const$jscomp$1574$$.call($APP.$cljs$core$dissoc$$,$JSCompiler_temp_const$jscomp$1572$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp_const$jscomp$1570$$.call($APP.$cljs$core$assoc$$,$gradient$jscomp$18$$,$JSCompiler_temp_const$jscomp$1569$$,$G__71220__$1$jscomp$inline_8383_JSCompiler_inline_result$jscomp$1578_type$jscomp$492$$),$APP.$cljs$cst$1739$stops$$,
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$clear_color_components$$,$JSCompiler_temp$jscomp$1567_JSCompiler_temp$jscomp$1568_p__71218_stops$jscomp$9$$)),$APP.$cljs$cst$2554$shape_id$$)],null))}return $JSCompiler_temp$jscomp$1567_JSCompiler_temp$jscomp$1568_p__71218_stops$jscomp$9$$};
$app$main$data$workspace$colors$colorpicker_onchange_runner$$=function($on_change$jscomp$5$$){typeof $app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$==="undefined"&&($app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$=function($on_change$jscomp$6$$,$meta71222$$){this.$on_change$=$on_change$jscomp$6$$;this.$meta71222$=$meta71222$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4236$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpicker_onchange_runner$$},$app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71223$$,$meta71222__$1$$){return new $app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$(this.$on_change$,
$meta71222__$1$$)},$app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71222$},$app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($G__71224__$1$jscomp$inline_8385__$jscomp$2278_temp__5825__auto__$jscomp$218$$,
$state$jscomp$657$$){$G__71224__$1$jscomp$inline_8385__$jscomp$2278_temp__5825__auto__$jscomp$218$$=$state$jscomp$657$$==null?null:$APP.$cljs$cst$2247$colorpicker$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$657$$);$G__71224__$1$jscomp$inline_8385__$jscomp$2278_temp__5825__auto__$jscomp$218$$=$G__71224__$1$jscomp$inline_8385__$jscomp$2278_temp__5825__auto__$jscomp$218$$==null?null:$app$main$data$workspace$colors$get_color_from_colorpicker_state$$($G__71224__$1$jscomp$inline_8385__$jscomp$2278_temp__5825__auto__$jscomp$218$$);
return $APP.$cljs$core$truth_$$($G__71224__$1$jscomp$inline_8385__$jscomp$2278_temp__5825__auto__$jscomp$218$$)?this.$on_change$.$cljs$core$IFn$_invoke$arity$1$?this.$on_change$.$cljs$core$IFn$_invoke$arity$1$($G__71224__$1$jscomp$inline_8385__$jscomp$2278_temp__5825__auto__$jscomp$218$$):this.$on_change$($G__71224__$1$jscomp$inline_8385__$jscomp$2278_temp__5825__auto__$jscomp$218$$):null});return new $app$main$data$workspace$colors$colorpicker_onchange_runner_71221$$($on_change$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$initialize_colorpicker$$=function($on_change$jscomp$7$$,$tab$$){typeof $app$main$data$workspace$colors$initialize_colorpicker_71225$$==="undefined"&&($app$main$data$workspace$colors$initialize_colorpicker_71225$$=function($on_change$jscomp$8$$,$tab$jscomp$1$$,$meta71226$$){this.$on_change$=$on_change$jscomp$8$$;this.tab=$tab$jscomp$1$$;this.$meta71226$=$meta71226$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$initialize_colorpicker_71225$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$initialize_colorpicker_71225$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4237$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_initialize_colorpicker$$},$app$main$data$workspace$colors$initialize_colorpicker_71225$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71227$$,$meta71226__$1$$){return new $app$main$data$workspace$colors$initialize_colorpicker_71225$$(this.$on_change$,
this.tab,$meta71226__$1$$)},$app$main$data$workspace$colors$initialize_colorpicker_71225$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71226$},$app$main$data$workspace$colors$initialize_colorpicker_71225$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$initialize_colorpicker_71225$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2279_stopper$jscomp$20$$,$___$1$jscomp$1506$$,$stream$jscomp$66$$){$_$jscomp$2279_stopper$jscomp$20$$=
$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4238$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_finalize_colorpicker$$),$stream$jscomp$66$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4237$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_initialize_colorpicker$$),$stream$jscomp$66$$));return $APP.$beicon$v2$core$take_until$$($_$jscomp$2279_stopper$jscomp$20$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$constantly$$($app$main$data$workspace$colors$colorpicker_onchange_runner$$(this.$on_change$)),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$debounce$$(20,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4239$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_gradient$$),$stream$jscomp$66$$)),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4240$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_color$$),
$stream$jscomp$66$$),$APP.$beicon$v2$core$debounce$$(20,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4241$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_gradient$$),$stream$jscomp$66$$)),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4242$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_stops$$),$stream$jscomp$66$$),
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4243$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_gradient_opacity$$),$stream$jscomp$66$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4244$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_stop$$),$stream$jscomp$66$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4245$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_add_auto$$),
$stream$jscomp$66$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4246$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_gradient_stop$$),$stream$jscomp$66$$))))},$app$main$data$workspace$colors$initialize_colorpicker_71225$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$initialize_colorpicker_71225$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2280$$,
$state$jscomp$658$$){var $self__$jscomp$5311$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$658$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$30$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$30$$,$APP.$cljs$cst$139$type$$,$self__$jscomp$5311$$.tab)})});return new $app$main$data$workspace$colors$initialize_colorpicker_71225$$($on_change$jscomp$7$$,$tab$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$materialize_color_components$$=function($map__71215__$1_p__71214$$){$map__71215__$1_p__71214$$=$APP.$cljs$core$__destructure_map$$($map__71215__$1_p__71214$$);var $hex$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71215__$1_p__71214$$,$APP.$cljs$cst$2698$hex$$),$alpha$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71215__$1_p__71214$$,$APP.$cljs$cst$746$alpha$$);return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71215__$1_p__71214$$,
$APP.$cljs$cst$1303$color$$,$hex$jscomp$6$$),$APP.$cljs$cst$1740$opacity$$,$alpha$jscomp$12$$))};
$app$main$data$workspace$colors$activate_colorpicker_gradient$$=function($type$jscomp$495$$){typeof $app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$==="undefined"&&($app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$=function($type$jscomp$496$$,$meta71295$$){this.type=$type$jscomp$496$$;this.$meta71295$=$meta71295$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4241$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_gradient$$},$app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71296$$,$meta71295__$1$$){return new $app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$(this.type,
$meta71295__$1$$)},$app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71295$},$app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2295$$,$state$jscomp$672$$){var $self__$jscomp$5365$$=
this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$672$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$42$$){var $G__71300_gradient$jscomp$21$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1735$start_x$$,.5,$APP.$cljs$cst$1736$start_y$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5365$$.type,$APP.$cljs$cst$4230$linear_gradient$$)?0:.5,$APP.$cljs$cst$1737$end_x$$,.5,$APP.$cljs$cst$1738$end_y$$,1,$APP.$cljs$cst$290$width$$,
1],null),$color$jscomp$101$$=$APP.$cljs$cst$4231$current_color$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$42$$);$G__71300_gradient$jscomp$21$$=$APP.$app$common$data$dissoc_in$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$42$$,$APP.$cljs$cst$139$type$$,$self__$jscomp$5365$$.type),$APP.$cljs$cst$1730$gradient$$,$G__71300_gradient$jscomp$21$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4231$current_color$$,$APP.$cljs$cst$1617$image$$],null));return $APP.$cljs$core$not$$($APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$42$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71300_gradient$jscomp$21$$,$APP.$cljs$cst$4229$editing_stop$$,0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1739$stops$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$app$main$data$workspace$colors$materialize_color_components$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$101$$,$APP.$cljs$cst$195$offset$$,0)),$app$main$data$workspace$colors$materialize_color_components$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$101$$,$APP.$cljs$cst$746$alpha$$,0),$APP.$cljs$cst$195$offset$$,1))],null)])):$G__71300_gradient$jscomp$21$$})});return new $app$main$data$workspace$colors$activate_colorpicker_gradient_71294$$($type$jscomp$495$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$util$text$content$to_dom$get_styles_from_attrs$$=function($node$jscomp$298$$,$attrs$jscomp$56_styles$jscomp$6$$){$attrs$jscomp$56_styles$jscomp$6$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$118$$,$key$jscomp$365$$){var $default_value$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$text$default_text_attrs$$,$key$jscomp$365$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$118$$,$key$jscomp$365$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$298$$,$key$jscomp$365$$,$default_value$jscomp$3$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$attrs$jscomp$56_styles$jscomp$6$$);var $fills$jscomp$18$$=$APP.$cljs$cst$1752$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$298$$)!=null||$APP.$cljs$cst$1753$fill_opacity$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$298$$)!=null||$APP.$cljs$cst$1754$fill_color_gradient$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$298$$)!=
null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$select_keys$$($node$jscomp$298$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1752$fill_color$$,$APP.$cljs$cst$1753$fill_opacity$$,$APP.$cljs$cst$1754$fill_color_gradient$$,$APP.$cljs$cst$1751$fill_color_ref_id$$,$APP.$cljs$cst$1645$fill_color_ref_file$$],
null)))],null):$APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$298$$)==null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1752$fill_color$$,"#000000",$APP.$cljs$cst$1753$fill_opacity$$,1],null)],null):$APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$298$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$56_styles$jscomp$6$$,
$APP.$cljs$cst$1639$fills$$,$fills$jscomp$18$$)};
$app$main$data$persistence$merge_commit$$=function($buffer$jscomp$80$$){return $APP.$beicon$v2$core$map$$(function($item$jscomp$56_p__55428$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$56_p__55428$$,0,null);var $rchg$jscomp$1_vec__55438$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$56_p__55428$$,1,null);$item$jscomp$56_p__55428$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($rchg$jscomp$1_vec__55438$$,0,null);var $uchg$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$app$main$data$persistence$xf_mapcat_undo$$,$rchg$jscomp$1_vec__55438$$);$rchg$jscomp$1_vec__55438$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$main$data$persistence$xf_mapcat_redo$$,$rchg$jscomp$1_vec__55438$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$56_p__55428$$,$APP.$cljs$cst$3161$undo_changes$$,
$uchg$jscomp$1$$),$APP.$cljs$cst$3157$redo_changes$$,$rchg$jscomp$1_vec__55438$$),$APP.$cljs$cst$3155$changes$$,$rchg$jscomp$1_vec__55438$$)},$APP.$beicon$v2$core$from$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$1649$file_id$$,$buffer$jscomp$80$$)))};
$app$common$path_names$sort_by_children$$=function($segments$jscomp$10$$,$separator$jscomp$7$$){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($path$jscomp$164_path_length_segment$jscomp$39$$){$path$jscomp$164_path_length_segment$jscomp$39$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$164_path_length_segment$jscomp$39$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,
$separator$jscomp$7$$]));$path$jscomp$164_path_length_segment$jscomp$39$$=$APP.$cljs$core$count$$($path$jscomp$164_path_length_segment$jscomp$39$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$164_path_length_segment$jscomp$39$$,1)?1:0},$segments$jscomp$10$$)};
$app$common$path_names$compact_path$$=function($last_item_path$jscomp$160$$){var $G__49244_other_items_path_split$$=$APP.$app$common$path_names$split_path$$($last_item_path$jscomp$160$$);$last_item_path$jscomp$160$$=$APP.$cljs$core$last$$($G__49244_other_items_path_split$$);var $merge_path$$=$APP.$cljs$core$truth_$$(!0)?$app$common$path_names$merge_path_item_with_dot$$:$APP.$app$common$path_names$merge_path_item$$;$G__49244_other_items_path_split$$=$APP.$cljs$core$seq$$($APP.$cljs$core$butlast$$($G__49244_other_items_path_split$$));
for(var $G__49245_other_path$$="";;){var $item$jscomp$45_temp__5823__auto__$jscomp$110$$=$APP.$cljs$core$first$$($G__49244_other_items_path_split$$);if($APP.$cljs$core$truth_$$($item$jscomp$45_temp__5823__auto__$jscomp$110$$)){var $G__49136$jscomp$inline_8390_full_path$$=$merge_path$$.$cljs$core$IFn$_invoke$arity$2$?$merge_path$$.$cljs$core$IFn$_invoke$arity$2$($G__49245_other_path$$,$item$jscomp$45_temp__5823__auto__$jscomp$110$$):$merge_path$$($G__49245_other_path$$,$item$jscomp$45_temp__5823__auto__$jscomp$110$$);
$G__49136$jscomp$inline_8390_full_path$$=$merge_path$$.$cljs$core$IFn$_invoke$arity$2$?$merge_path$$.$cljs$core$IFn$_invoke$arity$2$($G__49136$jscomp$inline_8390_full_path$$,$last_item_path$jscomp$160$$):$merge_path$$($G__49136$jscomp$inline_8390_full_path$$,$last_item_path$jscomp$160$$);if($APP.$cljs$core$count$$($G__49136$jscomp$inline_8390_full_path$$)>35)return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$merge_path$$.$cljs$core$IFn$_invoke$arity$2$?
$merge_path$$.$cljs$core$IFn$_invoke$arity$2$($G__49245_other_path$$,"..."):$merge_path$$($G__49245_other_path$$,"..."),$last_item_path$jscomp$160$$,!0],null);$G__49244_other_items_path_split$$=$APP.$cljs$core$next$$($G__49244_other_items_path_split$$);$G__49245_other_path$$=$merge_path$$.$cljs$core$IFn$_invoke$arity$2$?$merge_path$$.$cljs$core$IFn$_invoke$arity$2$($G__49245_other_path$$,$item$jscomp$45_temp__5823__auto__$jscomp$110$$):$merge_path$$($G__49245_other_path$$,$item$jscomp$45_temp__5823__auto__$jscomp$110$$)}else return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__49245_other_path$$,$last_item_path$jscomp$160$$,!1],null)}};
$app$common$data$reorder$$=function($v$jscomp$146_without_elem$$,$from_pos_from_pos__$1_insert_pos$$,$elem$jscomp$5_to_space_between_pos$$){var $max_space_pos_to_space_between_pos__$1$$=$APP.$cljs$core$count$$($v$jscomp$146_without_elem$$);$from_pos_from_pos__$1_insert_pos$$=$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$($max_space_pos_to_space_between_pos__$1$$-1,$from_pos_from_pos__$1_insert_pos$$));$max_space_pos_to_space_between_pos__$1$$=
$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$($max_space_pos_to_space_between_pos__$1$$,$elem$jscomp$5_to_space_between_pos$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_pos_from_pos__$1_insert_pos$$,$max_space_pos_to_space_between_pos__$1$$))return $v$jscomp$146_without_elem$$;$elem$jscomp$5_to_space_between_pos$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$146_without_elem$$,
$from_pos_from_pos__$1_insert_pos$$);$v$jscomp$146_without_elem$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$146_without_elem$$,0,$from_pos_from_pos__$1_insert_pos$$)),$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$146_without_elem$$,$from_pos_from_pos__$1_insert_pos$$+1));$from_pos_from_pos__$1_insert_pos$$=
$from_pos_from_pos__$1_insert_pos$$<$max_space_pos_to_space_between_pos__$1$$?$max_space_pos_to_space_between_pos__$1$$-1:$max_space_pos_to_space_between_pos__$1$$;return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$146_without_elem$$,0,$from_pos_from_pos__$1_insert_pos$$)),
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$elem$jscomp$5_to_space_between_pos$$],null)),$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$146_without_elem$$,$from_pos_from_pos__$1_insert_pos$$))};
$cljs$core$sorted_map$$=function($var_args$jscomp$244$$){for(var $JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$=[],$G__28781$jscomp$inline_8395_len__5749__auto___28773$$=arguments.length,$G__28782$jscomp$inline_8396_i__5750__auto___28774_out$jscomp$inline_8394$$=0;;)if($G__28782$jscomp$inline_8396_i__5750__auto___28774_out$jscomp$inline_8394$$<$G__28781$jscomp$inline_8395_len__5749__auto___28773$$)$JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$.push(arguments[$G__28782$jscomp$inline_8396_i__5750__auto___28774_out$jscomp$inline_8394$$]),
$G__28782$jscomp$inline_8396_i__5750__auto___28774_out$jscomp$inline_8394$$+=1;else break;a:{$JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$=$APP.$cljs$core$seq$$(0<$JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$.length?new $APP.$cljs$core$IndexedSeq$$($JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$.slice(0),0,null):null);for($G__28782$jscomp$inline_8396_i__5750__auto___28774_out$jscomp$inline_8394$$=
$APP.$cljs$core$PersistentTreeMap$EMPTY$$;;)if($JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$)$G__28781$jscomp$inline_8395_len__5749__auto___28773$$=$APP.$cljs$core$next$$($APP.$cljs$core$next$$($JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$)),$G__28782$jscomp$inline_8396_i__5750__auto___28774_out$jscomp$inline_8394$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__28782$jscomp$inline_8396_i__5750__auto___28774_out$jscomp$inline_8394$$,
$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$),$APP.$cljs$core$second$$($JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$)),$JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$=$G__28781$jscomp$inline_8395_len__5749__auto___28773$$;else{$JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$=$G__28782$jscomp$inline_8396_i__5750__auto___28774_out$jscomp$inline_8394$$;
break a}$JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$=void 0}return $JSCompiler_inline_result$jscomp$1582_args__5755__auto__$jscomp$6_in$$jscomp$inline_8393$$};$app$common$path_names$join_path_with_dot$$=function($path_vec$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" • ",$path_vec$$)};
$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$=function($node$jscomp$248_updated_split_element_name$$,$element$jscomp$57_split_path_token$jscomp$45$$,$new_name$jscomp$5$$){$element$jscomp$57_split_path_token$jscomp$45$$=$APP.$cljs$core$truth_$$($element$jscomp$57_split_path_token$jscomp$45$$)?$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$57_split_path_token$jscomp$45$$):$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$248_updated_split_element_name$$);
$element$jscomp$57_split_path_token$jscomp$45$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($element$jscomp$57_split_path_token$jscomp$45$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,"."]));$node$jscomp$248_updated_split_element_name$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($element$jscomp$57_split_path_token$jscomp$45$$,$APP.$cljs$cst$839$depth$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$248_updated_split_element_name$$),
$new_name$jscomp$5$$);return $APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($node$jscomp$248_updated_split_element_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,".",$APP.$cljs$cst$2014$with_spaces_QMARK_$$,!1]))};
$app$common$path_names$group_by_first_segment$$=function($segments$jscomp$11$$,$separator$jscomp$8$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$96$$,$segment$jscomp$40$$){var $first__49154_vec__49152$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$40$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,
$separator$jscomp$8$$])),$rest_path_seq__49153_seq__49153__$1$$=$APP.$cljs$core$seq$$($first__49154_vec__49152$$);$first__49154_vec__49152$$=$APP.$cljs$core$first$$($rest_path_seq__49153_seq__49153__$1$$);$rest_path_seq__49153_seq__49153__$1$$=$APP.$cljs$core$next$$($rest_path_seq__49153_seq__49153__$1$$);$rest_path_seq__49153_seq__49153__$1$$=$APP.$cljs$core$seq$$($rest_path_seq__49153_seq__49153__$1$$)?$APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rest_path_seq__49153_seq__49153__$1$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,$separator$jscomp$8$$,$APP.$cljs$cst$2014$with_spaces_QMARK_$$,!1])):null;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$96$$,$first__49154_vec__49152$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$truth_$$($rest_path_seq__49153_seq__49153__$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($segment$jscomp$40$$,
$APP.$cljs$cst$725$name$$,$rest_path_seq__49153_seq__49153__$1$$):$segment$jscomp$40$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$segments$jscomp$11$$)};
$app$common$path_names$sort_and_group_segments$$=function($segments$jscomp$12_sorted$$,$grouped_separator$jscomp$9$$){$segments$jscomp$12_sorted$$=$app$common$path_names$sort_by_children$$($segments$jscomp$12_sorted$$,$grouped_separator$jscomp$9$$);$grouped_separator$jscomp$9$$=$app$common$path_names$group_by_first_segment$$($segments$jscomp$12_sorted$$,$grouped_separator$jscomp$9$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($cljs$core$sorted_map$$(),$grouped_separator$jscomp$9$$)};
$app$common$path_names$build_tree_root$$=function($grouped_elements$jscomp$1_segments$jscomp$13$$){$grouped_elements$jscomp$1_segments$jscomp$13$$=$app$common$path_names$sort_and_group_segments$$($grouped_elements$jscomp$1_segments$jscomp$13$$,".");return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49192_remaining_segments$jscomp$2$$){var $segment_name$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49192_remaining_segments$jscomp$2$$,0,null);$p__49192_remaining_segments$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49192_remaining_segments$jscomp$2$$,1,null);return $app$common$path_names$build_tree_node$$($segment_name$jscomp$1$$,$p__49192_remaining_segments$jscomp$2$$,".",null,0)},$grouped_elements$jscomp$1_segments$jscomp$13$$)};
$app$common$path_names$butlast_path$$=function($path$jscomp$161_split$jscomp$3$$){$path$jscomp$161_split$jscomp$3$$=$APP.$app$common$path_names$split_path$$($path$jscomp$161_split$jscomp$3$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($path$jscomp$161_split$jscomp$3$$))?"":$APP.$app$common$path_names$join_path$$($APP.$cljs$core$butlast$$($path$jscomp$161_split$jscomp$3$$))};
$app$common$types$token$join_font_family$$=function($font_families$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$font_families$$)};
$app$main$data$workspace$texts$generate_typography_name$$=function($map__70584__$1_p__70583$$){$map__70584__$1_p__70583$$=$APP.$cljs$core$__destructure_map$$($map__70584__$1_p__70583$$);var $font_id$jscomp$32_map__70586_map__70586__$1_name$jscomp$335$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70584__$1_p__70583$$,$APP.$cljs$cst$1763$font_id$$),$font_variant_id$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70584__$1_p__70583$$,$APP.$cljs$cst$1765$font_variant_id$$);
$font_id$jscomp$32_map__70586_map__70586__$1_name$jscomp$335$$=$APP.$app$main$fonts$get_font_data$$($font_id$jscomp$32_map__70586_map__70586__$1_name$jscomp$335$$);$font_id$jscomp$32_map__70586_map__70586__$1_name$jscomp$335$$=$APP.$cljs$core$__destructure_map$$($font_id$jscomp$32_map__70586_map__70586__$1_name$jscomp$335$$);$font_id$jscomp$32_map__70586_map__70586__$1_name$jscomp$335$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$32_map__70586_map__70586__$1_name$jscomp$335$$,
$APP.$cljs$cst$725$name$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__70584__$1_p__70583$$,$APP.$cljs$cst$725$name$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($font_id$jscomp$32_map__70586_map__70586__$1_name$jscomp$335$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$stylize$cljs$0core$0IFn$0_invoke$0arity$04$$($font_variant_id$jscomp$16$$,$APP.$cuerdas$core$capital$$,$APP.$cuerdas$core$capital$$," "))].join(""))};
$app$common$types$path$get_handlers$$=function($content$jscomp$83_content__$1$jscomp$18$$){$content$jscomp$83_content__$1$jscomp$18$$=$APP.$app$common$types$path$impl$path_data$$($content$jscomp$83_content__$1$jscomp$18$$);return $APP.$app$common$types$path$segment$get_handlers$$($content$jscomp$83_content__$1$jscomp$18$$)};
$app$common$types$path$segment$is_curve_QMARK_$$=function($content$jscomp$34$$,$point$jscomp$29$$){var $handler_points_handlers$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$path$segment$get_handlers$$($content$jscomp$34$$),$point$jscomp$29$$);$handler_points_handlers$jscomp$4$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48117_SHARP_$$){return $APP.$app$common$types$path$segment$get_handler_point$$($content$jscomp$34$$,$APP.$cljs$core$first$$($p1__48117_SHARP_$$),
$APP.$cljs$core$second$$($p1__48117_SHARP_$$))},$handler_points_handlers$jscomp$4$$);return $APP.$cljs$core$some$$(function($p1__48118_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$29$$,$p1__48118_SHARP_$$)},$handler_points_handlers$jscomp$4$$)};
$cljs$core$dedupe$cljs$0core$0IFn$0_invoke$0arity$00$$=function(){return function($rf$jscomp$20$$){var $pa$jscomp$1$$=$APP.$cljs$core$volatile_BANG_$$($APP.$cljs$cst$104$cljs_DOT_core_SLASH_none$$);return function(){function $G__29593__2$$($result$jscomp$74$$,$input$jscomp$46$$){var $prior$$=$APP.$cljs$core$_deref$$($pa$jscomp$1$$);$APP.$cljs$core$_vreset_BANG_$$($pa$jscomp$1$$,$input$jscomp$46$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prior$$,$input$jscomp$46$$)?$result$jscomp$74$$:
$rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$?$rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$74$$,$input$jscomp$46$$):$rf$jscomp$20$$($result$jscomp$74$$,$input$jscomp$46$$)}function $G__29593__1$$($result$jscomp$73$$){return $rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$?$rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$73$$):$rf$jscomp$20$$($result$jscomp$73$$)}function $G__29593__0$$(){return $rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$0$?$rf$jscomp$20$$.$cljs$core$IFn$_invoke$arity$0$():
$rf$jscomp$20$$()}var $G__29593$$=null;$G__29593$$=function($result$jscomp$75$$,$input$jscomp$47$$){switch(arguments.length){case 0:return $G__29593__0$$.call(this);case 1:return $G__29593__1$$.call(this,$result$jscomp$75$$);case 2:return $G__29593__2$$.call(this,$result$jscomp$75$$,$input$jscomp$47$$)}throw Error("Invalid arity: "+arguments.length);};$G__29593$$.$cljs$core$IFn$_invoke$arity$0$=$G__29593__0$$;$G__29593$$.$cljs$core$IFn$_invoke$arity$1$=$G__29593__1$$;$G__29593$$.$cljs$core$IFn$_invoke$arity$2$=
$G__29593__2$$;return $G__29593$$}()}};
$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$=function($token_type$jscomp$8$$,$new_name$jscomp$27$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$=function($token_type$jscomp$9$$,$new_name$jscomp$28$$,$meta72971$$){this.$token_type$=$token_type$jscomp$9$$;this.$new_name$=$new_name$jscomp$28$$;this.$meta72971$=$meta72971$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4777$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_nested_token_path$$},$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72972$$,$meta72971__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$(this.$token_type$,this.$new_name$,$meta72971__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72971$},$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2681$$,$state$jscomp$986$$){var $type_str$$=$APP.$cljs$core$name$$(this.$token_type$),$segments$jscomp$14$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$new_name$,"."),$n_groups$$=$APP.$cljs$core$count$$($segments$jscomp$14$$)-1;return $n_groups$$>0?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$986$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,
$APP.$cljs$cst$4775$folded_token_paths$$],null),function($paths$jscomp$6$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ps$jscomp$24$$,$i$jscomp$512$$){return $APP.$app$main$data$workspace$tokens$library_edit$remove_path$$([$type_str$$,".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(".",$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$512$$,$segments$jscomp$14$$)))].join(""),$ps$jscomp$24$$)},
$APP.$cljs$core$truth_$$($paths$jscomp$6$$)?$paths$jscomp$6$$:$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$n_groups$$+1))}):$state$jscomp$986$$});return new $app$main$data$workspace$tokens$library_edit$toggle_nested_token_path_72970$$($token_type$jscomp$8$$,$new_name$jscomp$27$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$update_colorpicker_stops$$=function($stops$jscomp$12$$){typeof $app$main$data$workspace$colors$update_colorpicker_stops_71254$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_stops_71254$$=function($stops$jscomp$13$$,$meta71255$$){this.stops=$stops$jscomp$13$$;this.$meta71255$=$meta71255$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_stops_71254$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_stops_71254$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4242$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_stops$$},$app$main$data$workspace$colors$update_colorpicker_stops_71254$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71256$$,$meta71255__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_stops_71254$$(this.stops,
$meta71255__$1$$)},$app$main$data$workspace$colors$update_colorpicker_stops_71254$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71255$},$app$main$data$workspace$colors$update_colorpicker_stops_71254$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_stops_71254$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2286$$,$state$jscomp$664$$){var $self__$jscomp$5335$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$664$$,
$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$35$$){var $or__5025__auto__$jscomp$inline_8398_stop$jscomp$4$$=$APP.$cljs$cst$4229$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$35$$);$or__5025__auto__$jscomp$inline_8398_stop$jscomp$4$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8398_stop$jscomp$4$$)?$or__5025__auto__$jscomp$inline_8398_stop$jscomp$4$$:0;var $cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$=$APP.$app$main$features$active_feature_QMARK_$$($state__$1$jscomp$35$$,
"render-wasm/v1");$cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$split_color_components$$,$cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$?$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(16,$self__$jscomp$5335$$.stops):$self__$jscomp$5335$$.stops);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$35$$,$APP.$cljs$cst$4231$current_color$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$,$or__5025__auto__$jscomp$inline_8398_stop$jscomp$4$$)),$APP.$cljs$cst$1739$stops$$,$cap_stops_QMARK_$jscomp$2_stops__$1$jscomp$4$$)})});return new $app$main$data$workspace$colors$update_colorpicker_stops_71254$$($stops$jscomp$12$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$update_recent_font$$=function($state$jscomp$300$$,$file_id$jscomp$78$$,$font$jscomp$36$$){var $xform$jscomp$32$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__56055_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$36$$,$p1__56055_SHARP_$$)}),$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(3));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$300$$,
$file_id$jscomp$78$$,function($p1__56056_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$font$jscomp$36$$],null),$xform$jscomp$32$$,$p1__56056_SHARP_$$)})};
$app$common$path_names$inside_path_QMARK_$$=function($child$jscomp$67_child_path$$,$parent$jscomp$186_parent_path$$){$child$jscomp$67_child_path$$=$APP.$app$common$path_names$split_path$$($child$jscomp$67_child_path$$);$parent$jscomp$186_parent_path$$=$APP.$app$common$path_names$split_path$$($parent$jscomp$186_parent_path$$);return $APP.$cljs$core$count$$($parent$jscomp$186_parent_path$$)<=$APP.$cljs$core$count$$($child$jscomp$67_child_path$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$186_parent_path$$,
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($parent$jscomp$186_parent_path$$),$child$jscomp$67_child_path$$))};
$app$main$data$workspace$texts$focus_editor$$=function(){typeof $app$main$data$workspace$texts$focus_editor_70212$$==="undefined"&&($app$main$data$workspace$texts$focus_editor_70212$$=function($meta70213$$){this.$meta70213$=$meta70213$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$focus_editor_70212$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$focus_editor_70212$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4070$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_focus_editor$$},$app$main$data$workspace$texts$focus_editor_70212$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70214$$,$meta70213__$1$$){return new $app$main$data$workspace$texts$focus_editor_70212$$($meta70213__$1$$)},$app$main$data$workspace$texts$focus_editor_70212$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70213$},$app$main$data$workspace$texts$focus_editor_70212$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$focus_editor_70212$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $editor$jscomp$2$$=$APP.$cljs$cst$2229$workspace_editor$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),$element$jscomp$71$$=$APP.$cljs$core$truth_$$($editor$jscomp$2$$)?$editor$jscomp$2$$.element:null,$and__5023__auto__$jscomp$inline_13502$$=
$editor$jscomp$2$$!=null;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13502$$?$editor$jscomp$2$$.focus:$and__5023__auto__$jscomp$inline_13502$$)?$editor$jscomp$2$$.focus():$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($element$jscomp$71$$)?$element$jscomp$71$$.focus:$element$jscomp$71$$)?$element$jscomp$71$$.focus():null})});return new $app$main$data$workspace$texts$focus_editor_70212$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$create_version$$=function(){typeof $app$main$data$workspace$versions$create_version_73657$$==="undefined"&&($app$main$data$workspace$versions$create_version_73657$$=function($meta73658$$){this.$meta73658$=$meta73658$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$create_version_73657$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$create_version_73657$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5140$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_create_version$$},$app$main$data$workspace$versions$create_version_73657$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73659$$,$meta73658__$1$$){return new $app$main$data$workspace$versions$create_version_73657$$($meta73658__$1$$)},$app$main$data$workspace$versions$create_version_73657$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73658$},$app$main$data$workspace$versions$create_version_73657$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$create_version_73657$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2818$$,$state$jscomp$1091$$){var $label$jscomp$32$$=$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$time$now$$(),$APP.$cljs$cst$5141$localized_date$$),$file_id$jscomp$328$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1091$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2545$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$,
$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-version"],null))),$APP.$beicon$v2$core$mapcat$$(function($id$jscomp$855_map__73664__$1_p__73663$$){$id$jscomp$855_map__73664__$1_p__73663$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$855_map__73664__$1_p__73663$$);$id$jscomp$855_map__73664__$1_p__73663$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$855_map__73664__$1_p__73663$$,
$APP.$cljs$cst$266$id$$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2160$editing$$,$id$jscomp$855_map__73664__$1_p__73663$$],null)),$app$main$data$workspace$versions$fetch_versions$$())},$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5142$create_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$328$$,$APP.$cljs$cst$2296$label$$,$label$jscomp$32$$],null))},$APP.$app$main$data$persistence$wait_persisted$cljs$0core$0IFn$0_invoke$0arity$01$$(null))))});return new $app$main$data$workspace$versions$create_version_73657$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$refs$workspace_grid_edition_id$$=function($id$jscomp$226$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50350_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__50350_SHARP_$$,$id$jscomp$226$$)},$APP.$app$main$refs$workspace_grid_edition$$)};
$app$main$refs$workspace_thumbnail_rendered_at$$=function($object_id$jscomp$1$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50344_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__50344_SHARP_$$,$APP.$cljs$cst$2244$thumbnails_meta$$),$object_id$jscomp$1$$),$APP.$cljs$cst$2245$rendered_at$$)},$APP.$app$main$store$state$$)};
$app$main$refs$workspace_token_in_selected_set$$=function($token_id$jscomp$13$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$){var $JSCompiler_inline_result$jscomp$1528_temp__5825__auto__$jscomp$inline_8402$$=$APP.$app$main$data$workspace$tokens$selected_set$get_selected_token_set_id$$($G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1528_temp__5825__auto__$jscomp$inline_8402$$)?
($G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$),$G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$=$G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$,
$APP.$cljs$cst$2147$tokens_lib$$),$JSCompiler_inline_result$jscomp$1528_temp__5825__auto__$jscomp$inline_8402$$=$G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$==null?null:$APP.$app$common$types$tokens_lib$get_token$$($G__50125$jscomp$inline_8403_G__50125__$1$jscomp$inline_8404_p1__50337_SHARP_$$,$JSCompiler_inline_result$jscomp$1528_temp__5825__auto__$jscomp$inline_8402$$,$token_id$jscomp$13$$)):$JSCompiler_inline_result$jscomp$1528_temp__5825__auto__$jscomp$inline_8402$$=
null;return $JSCompiler_inline_result$jscomp$1528_temp__5825__auto__$jscomp$inline_8402$$},$APP.$app$main$store$state$$)};
$app$main$refs$grid_layout_child_QMARK_$$=function($ids$jscomp$32$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$173$$){return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$grid_layout_immediate_child_QMARK_$$,$objects$jscomp$173$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$173$$),$ids$jscomp$32$$))},$APP.$app$main$refs$workspace_page_objects$$,
$APP.$cljs$core$_EQ_$$)};
$app$main$refs$flex_layout_child_QMARK_$$=function($ids$jscomp$31$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$172$$){return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$flex_layout_immediate_child_QMARK_$$,$objects$jscomp$172$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$172$$),$ids$jscomp$31$$))},$APP.$app$main$refs$workspace_page_objects$$,
$APP.$cljs$core$_EQ_$$)};
$app$main$refs$all_layout_child_QMARK_$$=function($ids$jscomp$30$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$171$$){return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$,$objects$jscomp$171$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$171$$),$ids$jscomp$30$$))},$APP.$app$main$refs$workspace_page_objects$$,
$APP.$cljs$core$_EQ_$$)};
$app$main$refs$is_layout_child_QMARK_$$=function($ids$jscomp$29$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($objects$jscomp$170$$){return $APP.$cljs$core$some$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$,$objects$jscomp$170$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$170$$),$ids$jscomp$29$$))},$APP.$app$main$refs$workspace_page_objects$$)};
$app$main$refs$shape_parents$$=function($id$jscomp$218$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$164$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$164$$)),$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$164$$,$id$jscomp$218$$))},$APP.$app$main$refs$workspace_page_objects$$,
$APP.$cljs$core$_EQ_$$)};$app$main$refs$objects_by_id$$=function($ids$jscomp$26$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__50260_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($p1__50260_SHARP_$$)),$ids$jscomp$26$$)},$APP.$app$main$refs$workspace_page_objects$$,$APP.$cljs$core$_EQ_$$)};
$app$main$refs$object_by_id$$=function($id$jscomp$217$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__50259_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__50259_SHARP_$$,$id$jscomp$217$$)},$APP.$app$main$refs$workspace_page_objects$$)};
$app$main$refs$token_sets_at_path_all_active$$=function($group_path$jscomp$4$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($lib$jscomp$7$$){return $APP.$cljs$core$truth_$$($lib$jscomp$7$$)?$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$($lib$jscomp$7$$,$group_path$jscomp$4$$):null},$APP.$app$main$refs$tokens_lib$$)};
$app$main$refs$workspace_token_theme$$=function($id$jscomp$224$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($lib$jscomp$5$$){return $APP.$cljs$core$truth_$$($lib$jscomp$5$$)?$APP.$app$common$types$tokens_lib$get_theme$$($lib$jscomp$5$$,$id$jscomp$224$$):null},$APP.$app$main$refs$tokens_lib$$)};
$app$main$data$modal$allow_click_outside_BANG_$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$update$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2350$allow_click_outside$$,!0],null)))};$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$=function($props$jscomp$88$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$($props$jscomp$88$$))};
$app$common$types$shape$interactions$has_direction_QMARK_$$=function($G__49112_interaction$jscomp$27$$){$G__49112_interaction$jscomp$27$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__49112_interaction$jscomp$27$$));var $fexpr__49111$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1972$push$$,null,$APP.$cljs$cst$1974$slide$$,null],null),null);return $fexpr__49111$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__49111$$.$cljs$core$IFn$_invoke$arity$1$($G__49112_interaction$jscomp$27$$):$fexpr__49111$$($G__49112_interaction$jscomp$27$$)};
$app$common$types$shape$interactions$has_easing_QMARK_$$=function($G__49104_interaction$jscomp$23$$){$G__49104_interaction$jscomp$23$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__49104_interaction$jscomp$23$$));var $fexpr__49103$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1972$push$$,null,$APP.$cljs$cst$1973$dissolve$$,null,$APP.$cljs$cst$1974$slide$$,
null],null),null);return $fexpr__49103$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49103$$.$cljs$core$IFn$_invoke$arity$1$($G__49104_interaction$jscomp$23$$):$fexpr__49103$$($G__49104_interaction$jscomp$23$$)};
$app$common$types$shape$interactions$has_duration_QMARK_$$=function($G__49100_interaction$jscomp$21$$){$G__49100_interaction$jscomp$21$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($G__49100_interaction$jscomp$21$$));var $fexpr__49099$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1972$push$$,null,$APP.$cljs$cst$1973$dissolve$$,null,$APP.$cljs$cst$1974$slide$$,
null],null),null);return $fexpr__49099$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49099$$.$cljs$core$IFn$_invoke$arity$1$($G__49100_interaction$jscomp$21$$):$fexpr__49099$$($G__49100_interaction$jscomp$21$$)};
$app$common$types$shape$interactions$has_animation_QMARK_$$=function($G__49092_interaction$jscomp$19$$){$G__49092_interaction$jscomp$19$$=$APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($G__49092_interaction$jscomp$19$$);var $fexpr__49091$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1957$navigate$$,null,$APP.$cljs$cst$1958$close_overlay$$,null,$APP.$cljs$cst$1960$toggle_overlay$$,null,$APP.$cljs$cst$1962$open_overlay$$,
null],null),null);return $fexpr__49091$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49091$$.$cljs$core$IFn$_invoke$arity$1$($G__49092_interaction$jscomp$19$$):$fexpr__49091$$($G__49092_interaction$jscomp$19$$)};
$app$common$types$shape$interactions$has_overlay_opts$$=function($G__49069_interaction$jscomp$11$$){$G__49069_interaction$jscomp$11$$=$APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($G__49069_interaction$jscomp$11$$);var $fexpr__49068$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1960$toggle_overlay$$,null,$APP.$cljs$cst$1962$open_overlay$$,null],null),null);return $fexpr__49068$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__49068$$.$cljs$core$IFn$_invoke$arity$1$($G__49069_interaction$jscomp$11$$):
$fexpr__49068$$($G__49069_interaction$jscomp$11$$)};$app$common$types$shape$interactions$destination_QMARK_$$=function($interaction$jscomp$5$$){var $and__5023__auto__$jscomp$262$$=$APP.$app$common$types$shape$interactions$has_destination$$($interaction$jscomp$5$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$262$$)?$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$5$$)!=null:$and__5023__auto__$jscomp$262$$};
$app$main$data$workspace$bool$bool__GT_group$$=function($param49202$jscomp$inline_8407_shape$jscomp$451$$,$objects$jscomp$350$$){var $param49201$jscomp$inline_8406$$=$APP.$app$common$data$without_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($param49202$jscomp$inline_8407_shape$jscomp$451$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1613$group$$),$APP.$cljs$cst$1896$bool_type$$),$APP.$app$common$types$path$bool$group_style_properties$$);
$param49202$jscomp$inline_8407_shape$jscomp$451$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$350$$),$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($param49202$jscomp$inline_8407_shape$jscomp$451$$));return $APP.$app$common$geom$shapes$transforms$update_group_selrect$$($param49201$jscomp$inline_8406$$,$param49202$jscomp$inline_8407_shape$jscomp$451$$)};
$app$common$types$modifiers$change_orientation_modifiers$$=function($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$,$orientation$jscomp$1_shape_transform$$){var $shape_transform_inv_width$jscomp$60$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$),$height$jscomp$53_new_height$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$),$new_width_scalev$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orientation$jscomp$1_shape_transform$$,$APP.$cljs$cst$1815$horiz$$)?$shape_transform_inv_width$jscomp$60$$>$height$jscomp$53_new_height$$?$shape_transform_inv_width$jscomp$60$$:$height$jscomp$53_new_height$$:$shape_transform_inv_width$jscomp$60$$<$height$jscomp$53_new_height$$?$shape_transform_inv_width$jscomp$60$$:$height$jscomp$53_new_height$$;$height$jscomp$53_new_height$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orientation$jscomp$1_shape_transform$$,
$APP.$cljs$cst$1815$horiz$$)?$shape_transform_inv_width$jscomp$60$$<$height$jscomp$53_new_height$$?$shape_transform_inv_width$jscomp$60$$:$height$jscomp$53_new_height$$:$shape_transform_inv_width$jscomp$60$$>$height$jscomp$53_new_height$$?$shape_transform_inv_width$jscomp$60$$:$height$jscomp$53_new_height$$;$orientation$jscomp$1_shape_transform$$=$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$);$shape_transform_inv_width$jscomp$60$$=
$APP.$cljs$cst$1793$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$);var $shape_center$jscomp$1$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$),$map__48716_sr_width$jscomp$2$$=$APP.$app$common$types$modifiers$safe_size_rect$$($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$),$map__48716__$1_sr_height$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__48716_sr_width$jscomp$2$$);
$map__48716_sr_width$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48716__$1_sr_height$jscomp$2$$,$APP.$cljs$cst$290$width$$);$map__48716__$1_sr_height$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48716__$1_sr_height$jscomp$2$$,$APP.$cljs$cst$1527$height$$);$G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$modifiers$safe_size_rect$$($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$));
$G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$=$orientation$jscomp$1_shape_transform$$!=null?$APP.$app$common$geom$matrix$transform_point_center$$($G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$,$shape_center$jscomp$1$$,$orientation$jscomp$1_shape_transform$$):$G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$;$new_width_scalev$$=$APP.$app$common$geom$point$divide$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($new_width_scalev$$,
$height$jscomp$53_new_height$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($map__48716_sr_width$jscomp$2$$,$map__48716__$1_sr_height$jscomp$2$$));return $APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($new_width_scalev$$,$G__48717$jscomp$inline_13504_origin$jscomp$16_shape$jscomp$75$$,$orientation$jscomp$1_shape_transform$$,$shape_transform_inv_width$jscomp$60$$)};
$app$main$data$workspace$transforms$rotation_modifiers$$=function($angle$jscomp$34$$,$shapes$jscomp$97$$,$center$jscomp$50$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69324_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($p1__69324_SHARP_$$,$APP.$cljs$cst$1628$blocked$$,!1)}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69325_SHARP_$$){return $APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__69325_SHARP_$$)))}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69326_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__69326_SHARP_$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1816$modifiers$$,$APP.$app$common$types$modifiers$rotation_modifiers$$($p1__69326_SHARP_$$,
$center$jscomp$50$$,$angle$jscomp$34$$)],null)],null)})),$shapes$jscomp$97$$)};
$app$common$types$modifiers$resize_parent$cljs$0core$0IFn$0_invoke$0arity$05$$=function($vector$jscomp$13$$,$origin$jscomp$8$$,$transform$jscomp$32$$,$transform_inverse$jscomp$3$$){var $modifiers$jscomp$3_order$jscomp$9$$=$APP.$app$common$types$modifiers$empty$$(),$G__48662_modifiers__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($modifiers$jscomp$3_order$jscomp$9$$)?$modifiers$jscomp$3_order$jscomp$9$$:$APP.$app$common$types$modifiers$empty$$();$modifiers$jscomp$3_order$jscomp$9$$=($G__48662_modifiers__$1$jscomp$2$$?.$last_order$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48662_modifiers__$1$jscomp$2$$,$APP.$cljs$cst$1782$last_order$$))+1;$G__48662_modifiers__$1$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48662_modifiers__$1$jscomp$2$$,$APP.$cljs$cst$1782$last_order$$,$modifiers$jscomp$3_order$jscomp$9$$);return $APP.$app$common$types$modifiers$resize_vec_QMARK_$$($vector$jscomp$13$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48662_modifiers__$1$jscomp$2$$,$APP.$cljs$cst$1783$geometry_parent$$,
$APP.$app$common$types$modifiers$maybe_add_resize$$,new $APP.$app$common$types$modifiers$GeometricOperation$$($modifiers$jscomp$3_order$jscomp$9$$,$APP.$cljs$cst$1805$resize$$,$vector$jscomp$13$$,$origin$jscomp$8$$,$transform$jscomp$32$$,$transform_inverse$jscomp$3$$,null,null,null,null,null)):$G__48662_modifiers__$1$jscomp$2$$};
$app$common$types$modifiers$move_parent$cljs$0core$0IFn$0_invoke$0arity$02$$=function($modifiers$jscomp$1_order$jscomp$7$$,$vector$jscomp$11$$){var $G__48655_modifiers__$1$$=$APP.$cljs$core$truth_$$($modifiers$jscomp$1_order$jscomp$7$$)?$modifiers$jscomp$1_order$jscomp$7$$:$APP.$app$common$types$modifiers$empty$$();$modifiers$jscomp$1_order$jscomp$7$$=($G__48655_modifiers__$1$$?.$last_order$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48655_modifiers__$1$$,$APP.$cljs$cst$1782$last_order$$))+
1;$G__48655_modifiers__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48655_modifiers__$1$$,$APP.$cljs$cst$1782$last_order$$,$modifiers$jscomp$1_order$jscomp$7$$);return $APP.$app$common$types$modifiers$move_vec_QMARK_$$($vector$jscomp$11$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__48655_modifiers__$1$$,$APP.$cljs$cst$1783$geometry_parent$$,$APP.$app$common$types$modifiers$maybe_add_move$$,new $APP.$app$common$types$modifiers$GeometricOperation$$($modifiers$jscomp$1_order$jscomp$7$$,
$APP.$cljs$cst$1804$move$$,$vector$jscomp$11$$,null,null,null,null,null,null,null,null)):$G__48655_modifiers__$1$$};
$app$util$dom$prevent_default_context_menu$$=function($event$jscomp$23$$){var $target$jscomp$112$$=$event$jscomp$23$$==null?null:$event$jscomp$23$$.target,$tag$jscomp$47$$=function(){var $G__46201__$1$$=$target$jscomp$112$$==null?null:$target$jscomp$112$$.tagName;return $G__46201__$1$$==null?null:$G__46201__$1$$.toLowerCase()}();return $APP.$cljs$core$truth_$$(function(){var $fexpr__46203$jscomp$inline_8409_or__5025__auto__$jscomp$301$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,["input",null,"textarea",null],null),null);$fexpr__46203$jscomp$inline_8409_or__5025__auto__$jscomp$301$$=$fexpr__46203$jscomp$inline_8409_or__5025__auto__$jscomp$301$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__46203$jscomp$inline_8409_or__5025__auto__$jscomp$301$$.$cljs$core$IFn$_invoke$arity$1$($tag$jscomp$47$$):$fexpr__46203$jscomp$inline_8409_or__5025__auto__$jscomp$301$$($tag$jscomp$47$$);return $APP.$cljs$core$truth_$$($fexpr__46203$jscomp$inline_8409_or__5025__auto__$jscomp$301$$)?$fexpr__46203$jscomp$inline_8409_or__5025__auto__$jscomp$301$$:
$target$jscomp$112$$==null?null:$target$jscomp$112$$.isContentEditable}())?null:$event$jscomp$23$$.preventDefault()};
$app$common$types$tokens_lib$group_by_type$$=function($tokens$jscomp$4_tokens_SINGLEQUOTE_$$){$tokens$jscomp$4_tokens_SINGLEQUOTE_$$=$APP.$cljs$core$map_QMARK_$$($tokens$jscomp$4_tokens_SINGLEQUOTE_$$)||$APP.$app$common$data$ordered_map_QMARK_$$($tokens$jscomp$4_tokens_SINGLEQUOTE_$$)?$APP.$cljs$core$vals$$($tokens$jscomp$4_tokens_SINGLEQUOTE_$$):$tokens$jscomp$4_tokens_SINGLEQUOTE_$$;return $APP.$cljs$core$group_by$$($APP.$cljs$cst$139$type$$,$tokens$jscomp$4_tokens_SINGLEQUOTE_$$)};
$app$main$ui$hooks$resize$use_resize_observer$$=function($callback$jscomp$91_node_ref$$){var $prev_val_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$observer_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$callback__$1$$=$app$main$ui$hooks$use_ref_callback$$($callback$jscomp$91_node_ref$$);$callback$jscomp$91_node_ref$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$337$$){if($node$jscomp$337$$!=null){var $G__71589_71608_observer_71601$$=$APP.$rumext$v2$ref_val$$($observer_ref$$),
$prev_val_71602$$=$APP.$rumext$v2$ref_val$$($prev_val_ref$$);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prev_val_71602$$,$node$jscomp$337$$)&&$G__71589_71608_observer_71601$$!=null&&($APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2694$action$$,"disconnect"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4615$js_SLASH_prev_val$$,$prev_val_71602$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4616$js_SLASH_node$$,$node$jscomp$337$$],null)],null)}),null,"app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$,!1),$G__71589_71608_observer_71601$$.disconnect(),
$APP.$rumext$v2$set_ref_val_BANG_$$($observer_ref$$,null));if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prev_val_71602$$,$node$jscomp$337$$)&&$node$jscomp$337$$!=null){var $observer_71607__$1$$=new ResizeObserver(function(){var $G__71587$$=$APP.$app$main$ui$hooks$resize$last_resize_type$$,$G__71588$$=$APP.$app$util$dom$get_client_size$$($node$jscomp$337$$);return $callback__$1$$.$cljs$core$IFn$_invoke$arity$2$?$callback__$1$$.$cljs$core$IFn$_invoke$arity$2$($G__71587$$,$G__71588$$):
$callback__$1$$($G__71587$$,$G__71588$$)});$APP.$rumext$v2$set_ref_val_BANG_$$($observer_ref$$,$observer_71607__$1$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2694$action$$,
"observe"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4616$js_SLASH_node$$,$node$jscomp$337$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4617$js_SLASH_observer$$,$observer_71607__$1$$],null)],null)}),null,"app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$,!1);$observer_71607__$1$$.observe($node$jscomp$337$$);$G__71589_71608_observer_71601$$=$APP.$app$main$ui$hooks$resize$last_resize_type$$;
var $G__71590_71609$$=$APP.$app$util$dom$get_client_size$$($node$jscomp$337$$);$callback__$1$$.$cljs$core$IFn$_invoke$arity$2$?$callback__$1$$.$cljs$core$IFn$_invoke$arity$2$($G__71589_71608_observer_71601$$,$G__71590_71609$$):$callback__$1$$($G__71589_71608_observer_71601$$,$G__71590_71609$$)}return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_val_ref$$,$node$jscomp$337$$)}return null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){var $temp__5825__auto__$jscomp$230$$=
$APP.$rumext$v2$ref_val$$($observer_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$230$$)?($APP.$app$common$logging$enabled_QMARK_$$("app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2694$action$$,
"disconnect"],null)],null)}),null,"app.main.ui.hooks.resize",$APP.$cljs$cst$1160$debug$$,!1),$temp__5825__auto__$jscomp$230$$.disconnect()):null}});return $callback$jscomp$91_node_ref$$};
$app$main$data$persistence$update_file_revn$$=function($file_id$jscomp$40$$,$revn$jscomp$1$$){typeof $app$main$data$persistence$update_file_revn_55197$$==="undefined"&&($app$main$data$persistence$update_file_revn_55197$$=function($file_id$jscomp$41$$,$revn$jscomp$2$$,$meta55198$$){this.$file_id$=$file_id$jscomp$41$$;this.$revn$=$revn$jscomp$2$$;this.$meta55198$=$meta55198$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$update_file_revn_55197$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$update_file_revn_55197$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3176$app_DOT_main_DOT_data_DOT_persistence_SLASH_update_file_revn$$},$app$main$data$persistence$update_file_revn_55197$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55199$$,$meta55198__$1$$){return new $app$main$data$persistence$update_file_revn_55197$$(this.$file_id$,this.$revn$,$meta55198__$1$$)},$app$main$data$persistence$update_file_revn_55197$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55198$},$app$main$data$persistence$update_file_revn_55197$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$update_file_revn_55197$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1654$$,$state$jscomp$186$$){var $self__$jscomp$3510$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"update-file-revn"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1649$file_id$$,""+($self__$jscomp$3510$$.$file_id$??"")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2279$revn$$,$self__$jscomp$3510$$.$revn$],
null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);return $app$main$data$helpers$update_file$cljs$0core$0IFn$0_invoke$0arity$03$$($state$jscomp$186$$,$self__$jscomp$3510$$.$file_id$,function($p1__55196_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__55196_SHARP_$$,$APP.$cljs$cst$2279$revn$$,$APP.$cljs$core$max$$,$self__$jscomp$3510$$.$revn$)})},$app$main$data$persistence$update_file_revn_55197$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$persistence$update_file_revn_55197$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$persistence$revn_data$$,$APP.$cljs$core$update$$,this.$file_id$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$max$$,0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$revn$]))});return new $app$main$data$persistence$update_file_revn_55197$$($file_id$jscomp$40$$,
$revn$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$update_status$$=function($status$jscomp$14$$){typeof $app$main$data$persistence$update_status_55170$$==="undefined"&&($app$main$data$persistence$update_status_55170$$=function($status$jscomp$15$$,$meta55171$$){this.status=$status$jscomp$15$$;this.$meta55171$=$meta55171$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$update_status_55170$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$persistence$update_status_55170$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3173$app_DOT_main_DOT_data_DOT_persistence_SLASH_update_status$$},$app$main$data$persistence$update_status_55170$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55172$$,$meta55171__$1$$){return new $app$main$data$persistence$update_status_55170$$(this.status,$meta55171__$1$$)},$app$main$data$persistence$update_status_55170$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55171$},$app$main$data$persistence$update_status_55170$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$update_status_55170$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1653$$,$state$jscomp$185$$){var $self__$jscomp$3506$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$185$$,$APP.$cljs$cst$2186$persistence$$,function($pstate$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",
$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"update-status"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1869$from$$,$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($pstate$$)],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1870$to$$,$self__$jscomp$3506$$.status],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$144$trace$$,!1);var $status__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$3506$$.status,$APP.$cljs$cst$111$pending$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($pstate$$),$APP.$cljs$cst$3174$saving$$)?
$APP.$cljs$cst$109$status$$.$cljs$core$IFn$_invoke$arity$1$($pstate$$):$self__$jscomp$3506$$.status,$G__55194$$=function(){var $G__55195$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($pstate$$,$APP.$cljs$cst$109$status$$,$status__$1$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status__$1$$,$APP.$cljs$cst$849$error$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__55195$$,$APP.$cljs$cst$3175$run_id$$):$G__55195$$}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($status__$1$$,
$APP.$cljs$cst$3172$saved$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__55194$$,$APP.$cljs$cst$3175$run_id$$):$G__55194$$})});return new $app$main$data$persistence$update_status_55170$$($status$jscomp$14$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$persist_commit$$=function($commit_id$jscomp$4$$){typeof $app$main$data$persistence$persist_commit_55318$$==="undefined"&&($app$main$data$persistence$persist_commit_55318$$=function($commit_id$jscomp$5$$,$meta55319$$){this.$commit_id$=$commit_id$jscomp$5$$;this.$meta55319$=$meta55319$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$persist_commit_55318$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$persistence$persist_commit_55318$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3180$app_DOT_main_DOT_data_DOT_persistence_SLASH_persist_commit$$},$app$main$data$persistence$persist_commit_55318$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55320$$,$meta55319__$1$$){return new $app$main$data$persistence$persist_commit_55318$$(this.$commit_id$,$meta55319__$1$$)},$app$main$data$persistence$persist_commit_55318$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta55319$},$app$main$data$persistence$persist_commit_55318$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$persist_commit_55318$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1660_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$176$$,$state$jscomp$191$$){var $self__$jscomp$3528$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&
$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"persist-commit"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3170$commit_id$$,""+($self__$jscomp$3528$$.$commit_id$??"")],null)],null)}),
null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);$_$jscomp$1660_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$176$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$191$$,$APP.$cljs$cst$2186$persistence$$),$APP.$cljs$cst$1801$index$$),$self__$jscomp$3528$$.$commit_id$);if($APP.$cljs$core$truth_$$($_$jscomp$1660_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$176$$)){var $map__55365__$1$$=
$APP.$cljs$core$__destructure_map$$($_$jscomp$1660_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$176$$),$file_id$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55365__$1$$,$APP.$cljs$cst$1649$file_id$$),$file_revn$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55365__$1$$,$APP.$cljs$cst$3163$file_revn$$);$_$jscomp$1660_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$176$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55365__$1$$,
$APP.$cljs$cst$3167$file_vern$$);var $changes$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55365__$1$$,$APP.$cljs$cst$3155$changes$$),$features__$1$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55365__$1$$,$APP.$cljs$cst$227$features$$),$sid$$=$APP.$cljs$cst$2343$session_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$191$$),$revn$jscomp$3$$=function(){var $y__5111__auto__$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$data$persistence$revn_data$$),
$file_id$jscomp$42$$,0);return $file_revn$jscomp$2$$>$y__5111__auto__$jscomp$57$$?$file_revn$jscomp$2$$:$y__5111__auto__$jscomp$57$$}();$_$jscomp$1660_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$176$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$227$features$$,$APP.$cljs$cst$2343$session_id$$,$APP.$cljs$cst$2279$revn$$,$APP.$cljs$cst$2588$vern$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$3170$commit_id$$,$APP.$cljs$cst$3155$changes$$,$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$1574$created_at$$],
[$features__$1$jscomp$11$$,$sid$$,$revn$jscomp$3$$,$_$jscomp$1660_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$176$$,$file_id$jscomp$42$$,$self__$jscomp$3528$$.$commit_id$,$APP.$cljs$core$vec$$($changes$jscomp$5$$),$APP.$cljs$cst$1792$origin$$.$cljs$core$IFn$_invoke$arity$1$($map__55365__$1$$),$APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($map__55365__$1$$)]);var $permissions$jscomp$2$$=$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$191$$);
return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$348$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$348$$)?$APP.$cljs$core$not$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$191$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$2225$read_only_QMARK_$$],
null))):$and__5023__auto__$jscomp$348$$}())?$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($cause$jscomp$50$$){return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3181$authentication$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($cause$jscomp$50$$))?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3182$app_DOT_main_DOT_data_DOT_persistence_SLASH_error$$,
$cause$jscomp$50$$),$app$main$data$persistence$update_status$$($APP.$cljs$cst$849$error$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$discard_persistence_state$$()),$APP.$beicon$v2$core$throw$0$$($cause$jscomp$50$$))},$APP.$beicon$v2$core$mapcat$$(function($map__55380__$1_p__55379$$){$map__55380__$1_p__55379$$=$APP.$cljs$core$__destructure_map$$($map__55380__$1_p__55379$$);var $revn__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55380__$1_p__55379$$,$APP.$cljs$cst$2279$revn$$),
$lagged$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55380__$1_p__55379$$,$APP.$cljs$cst$3183$lagged$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"changes persisted"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3170$commit_id$$,""+($self__$jscomp$3528$$.$commit_id$??"")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3183$lagged$$,$APP.$cljs$core$count$$($lagged$$)],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3184$app_DOT_main_DOT_data_DOT_persistence_SLASH_commit_persisted$$,
$map__55365__$1$$),$app$main$data$persistence$update_file_revn$$($file_id$jscomp$42$$,$revn__$1$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2274$update_file$$,$_$jscomp$1660_file_vern$jscomp$2_params$jscomp$182_temp__5825__auto__$jscomp$176$$))):null}return null});return new $app$main$data$persistence$persist_commit_55318$$($commit_id$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$append_commit$$=function($p__55250$$){var $map__55251__$1$$=$APP.$cljs$core$__destructure_map$$($p__55250$$),$id$jscomp$350$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__55251__$1$$,$APP.$cljs$cst$266$id$$),$run_id$$=$APP.$app$common$uuid$next$$();typeof $app$main$data$persistence$append_commit_55252$$==="undefined"&&($app$main$data$persistence$append_commit_55252$$=function($p__55250$jscomp$1$$,$map__55251$jscomp$1$$,$commit$jscomp$7$$,$id$jscomp$351$$,
$run_id$jscomp$1$$,$meta55253$$){this.$p__55250$=$p__55250$jscomp$1$$;this.$map__55251$=$map__55251$jscomp$1$$;this.commit=$commit$jscomp$7$$;this.id=$id$jscomp$351$$;this.$run_id$=$run_id$jscomp$1$$;this.$meta55253$=$meta55253$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$append_commit_55252$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$append_commit_55252$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3178$app_DOT_main_DOT_data_DOT_persistence_SLASH_append_commit$$},$app$main$data$persistence$append_commit_55252$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55254$$,$meta55253__$1$$){return new $app$main$data$persistence$append_commit_55252$$(this.$p__55250$,this.$map__55251$,this.commit,this.id,this.$run_id$,$meta55253__$1$$)},$app$main$data$persistence$append_commit_55252$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55253$},
$app$main$data$persistence$append_commit_55252$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$append_commit_55252$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1657$$,$state$jscomp$188$$){var $self__$jscomp$3519$$=this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"append-commit"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1583$method$$,"update"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3170$commit_id$$,""+($self__$jscomp$3519$$.id??"")],null)],
null)}),null,"app.main.data.persistence",$APP.$cljs$cst$144$trace$$,!1);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$188$$,$APP.$cljs$cst$2186$persistence$$,function($pstate$jscomp$2$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($pstate$jscomp$2$$,$APP.$cljs$cst$3175$run_id$$,$APP.$app$common$data$nilv$$,$self__$jscomp$3519$$.$run_id$),
$APP.$cljs$cst$1489$queue$$,$APP.$app$main$data$persistence$queue_conj$$,$self__$jscomp$3519$$.id),$APP.$cljs$cst$1801$index$$,$APP.$cljs$core$assoc$$,$self__$jscomp$3519$$.id,$self__$jscomp$3519$$.commit)})},$app$main$data$persistence$append_commit_55252$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$append_commit_55252$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1658_pstate$jscomp$3$$,$state$jscomp$189$$){$_$jscomp$1658_pstate$jscomp$3$$=
$APP.$cljs$cst$2186$persistence$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$189$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$run_id$,$APP.$cljs$cst$3175$run_id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$1658_pstate$jscomp$3$$))?(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$run_persistence_task$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$persistence$run_persistence_task$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$persistence$run_persistence_task$$(),
$app$main$data$persistence$update_status$$($APP.$cljs$cst$3174$saving$$)):null});return new $app$main$data$persistence$append_commit_55252$$($p__55250$$,$map__55251__$1$$,$map__55251__$1$$,$id$jscomp$350$$,$run_id$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$persistence$initialize_persistence$$=function(){typeof $app$main$data$persistence$initialize_persistence_55455$$==="undefined"&&($app$main$data$persistence$initialize_persistence_55455$$=function($meta55456$$){this.$meta55456$=$meta55456$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$initialize_persistence_55455$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$initialize_persistence_55455$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3186$app_DOT_main_DOT_data_DOT_persistence_SLASH_initialize_persistence$$},$app$main$data$persistence$initialize_persistence_55455$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55457$$,$meta55456__$1$$){return new $app$main$data$persistence$initialize_persistence_55455$$($meta55456__$1$$)},$app$main$data$persistence$initialize_persistence_55455$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55456$},$app$main$data$persistence$initialize_persistence_55455$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$initialize_persistence_55455$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1663_stoper_s$jscomp$1$$,$___$1$jscomp$996_local_commits_s$$,$stream$jscomp$29$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"initialize persistence"],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);$_$jscomp$1663_stoper_s$jscomp$1$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3186$app_DOT_main_DOT_data_DOT_persistence_SLASH_initialize_persistence$$),$stream$jscomp$29$$);$___$1$jscomp$996_local_commits_s$$=
$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$cljs$core$empty_QMARK_$$),$APP.$beicon$v2$core$filter$$(function($p1__55452_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2894$local$$,$APP.$cljs$cst$193$source$$.$cljs$core$IFn$_invoke$arity$1$($p1__55452_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$changes$commit_QMARK_$$,$stream$jscomp$29$$)))));
var $notifier_s$$=$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,
"persistence beat"],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$144$trace$$,!1);return null},$APP.$beicon$v2$core$debounce$$(3E3,$___$1$jscomp$996_local_commits_s$$)),$APP.$beicon$v2$core$filter$$(function($p1__55453_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__55453_SHARP_$$,$APP.$cljs$cst$2545$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$)},$stream$jscomp$29$$));return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$(function(){return $APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3187$app_DOT_main_DOT_data_DOT_persistence_SLASH_persistence_notification$$)},
$notifier_s$$),$APP.$beicon$v2$core$take_until$$($_$jscomp$1663_stoper_s$jscomp$1$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$persistence$update_status$$($APP.$cljs$cst$111$pending$$)},$APP.$beicon$v2$core$debounce$$(200,$___$1$jscomp$996_local_commits_s$$))),$APP.$beicon$v2$core$finalize$$(function(){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"finalize persistence: changes watcher"],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1);return null},$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$delay$$(100,$_$jscomp$1663_stoper_s$jscomp$1$$),$APP.$beicon$v2$core$map$$($app$main$data$persistence$append_commit$$,$APP.$beicon$v2$core$mapcat$$($app$main$data$persistence$merge_commit$$,
$APP.$beicon$v2$core$buffer_until$$($notifier_s$$,$___$1$jscomp$996_local_commits_s$$))))),$APP.$beicon$v2$core$take_until$$($_$jscomp$1663_stoper_s$jscomp$1$$,$APP.$beicon$v2$core$mapcat$$(function($file_id$jscomp$43_p__55465$$){var $file_revn$jscomp$3_map__55466__$1$$=$APP.$cljs$core$__destructure_map$$($file_id$jscomp$43_p__55465$$);$file_id$jscomp$43_p__55465$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_revn$jscomp$3_map__55466__$1$$,$APP.$cljs$cst$1649$file_id$$);$file_revn$jscomp$3_map__55466__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file_revn$jscomp$3_map__55466__$1$$,$APP.$cljs$cst$3163$file_revn$$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$update_file_revn$$($file_id$jscomp$43_p__55465$$,$file_revn$jscomp$3_map__55466__$1$$))},$APP.$beicon$v2$core$filter$$(function($p1__55454_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3188$remote$$,$APP.$cljs$cst$193$source$$.$cljs$core$IFn$_invoke$arity$1$($p1__55454_SHARP_$$))},
$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$changes$commit_QMARK_$$,$stream$jscomp$29$$))))))});return new $app$main$data$persistence$initialize_persistence_55455$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$cljs$tools$reader$impl$utils$ReaderConditional$$=function($splicing_QMARK_$$,$form$jscomp$7$$,$__meta$$,$__extmap$$,$__hash$jscomp$51$$){this.$splicing_QMARK_$=$splicing_QMARK_$$;this.form=$form$jscomp$7$$;this.$__meta$=$__meta$$;this.$__extmap$=$__extmap$$;this.$__hash$=$__hash$jscomp$51$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$cljs$tools$reader$impl$utils$reader_conditional$$=function($form$jscomp$9$$,$splicing_QMARK_$jscomp$2$$){return new $cljs$tools$reader$impl$utils$ReaderConditional$$($splicing_QMARK_$jscomp$2$$,$form$jscomp$9$$,null,null,null)};
$cljs$tools$reader$add_meta$$=function($form$jscomp$19$$,$ret$jscomp$62$$){return function(){var $and__5023__auto__$jscomp$39$$=$form$jscomp$19$$!=null?$form$jscomp$19$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$form$jscomp$19$$.$cljs$core$IWithMeta$$?!0:!1:!1;return $and__5023__auto__$jscomp$39$$?$APP.$cljs$core$seq$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$meta$$($form$jscomp$19$$),$APP.$cljs$cst$209$line$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$216$column$$,
$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$218$end_column$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$193$source$$]))):$and__5023__auto__$jscomp$39$$}()?new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$236$cljs_DOT_core_SLASH_with_meta$$,new $APP.$cljs$core$List$$(null,$ret$jscomp$62$$,new $APP.$cljs$core$List$$(null,function(){var $G__24867$$=$APP.$cljs$core$meta$$($form$jscomp$19$$);return $cljs$tools$reader$syntax_quote_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$syntax_quote_STAR_$$.$cljs$core$IFn$_invoke$arity$1$($G__24867$$):
$cljs$tools$reader$syntax_quote_STAR_$$($G__24867$$)}(),null,1,null),2,null),3,null):$ret$jscomp$62$$};
$cljs$tools$reader$syntax_quote_coll$$=function($type$jscomp$177$$,$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$){a:{$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$=$APP.$cljs$core$seq$$($G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$);for(var $G__25224$jscomp$inline_8417_r$jscomp$inline_8413_ret$jscomp$inline_8415$$=
$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;)if($G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$){var $item$jscomp$inline_8414$$=$APP.$cljs$core$first$$($G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$);$G__25224$jscomp$inline_8417_r$jscomp$inline_8413_ret$jscomp$inline_8415$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__25224$jscomp$inline_8417_r$jscomp$inline_8413_ret$jscomp$inline_8415$$,
$cljs$tools$reader$unquote_QMARK_$$($item$jscomp$inline_8414$$)?new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$235$clojure_DOT_core_SLASH_list$$,new $APP.$cljs$core$List$$(null,$APP.$cljs$core$second$$($item$jscomp$inline_8414$$),null,1,null),2,null):$cljs$tools$reader$unquote_splicing_QMARK_$$($item$jscomp$inline_8414$$)?$APP.$cljs$core$second$$($item$jscomp$inline_8414$$):new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$235$clojure_DOT_core_SLASH_list$$,new $APP.$cljs$core$List$$(null,$cljs$tools$reader$syntax_quote_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?
$cljs$tools$reader$syntax_quote_STAR_$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$inline_8414$$):$cljs$tools$reader$syntax_quote_STAR_$$($item$jscomp$inline_8414$$),null,1,null),2,null));$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$=$APP.$cljs$core$next$$($G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$)}else{$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$=
$APP.$cljs$core$seq$$($APP.$cljs$core$_persistent_BANG_$$($G__25224$jscomp$inline_8417_r$jscomp$inline_8413_ret$jscomp$inline_8415$$));break a}$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$=void 0}$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$=new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$237$cljs_DOT_core_SLASH_sequence$$,new $APP.$cljs$core$List$$(null,
$APP.$cljs$core$cons$$($APP.$cljs$cst$238$cljs_DOT_core_SLASH_concat$$,$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$),null,1,null),2,null);return $APP.$cljs$core$truth_$$($type$jscomp$177$$)?new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$239$cljs_DOT_core_SLASH_apply$$,new $APP.$cljs$core$List$$(null,$type$jscomp$177$$,new $APP.$cljs$core$List$$(null,$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$,
null,1,null),2,null),3,null):$G__25223$jscomp$inline_8416_JSCompiler_inline_result$jscomp$1586_coll$jscomp$822_res$jscomp$12_s__$1$jscomp$inline_8412$$};
$cljs$tools$reader$syntax_quote_STAR_$$=function($form$jscomp$20$$){if($APP.$cljs$core$special_symbol_QMARK_$$($form$jscomp$20$$))var $JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$167$quote$$,new $APP.$cljs$core$List$$(null,$form$jscomp$20$$,null,
1,null),2,null);else if($form$jscomp$20$$ instanceof $APP.$cljs$core$Symbol$$)$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$167$quote$$,new $APP.$cljs$core$List$$(null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$40$$=$APP.$cljs$core$not$$($APP.$cljs$core$namespace$$($form$jscomp$20$$));
return $and__5023__auto__$jscomp$40$$?$APP.$goog$string$internal$endsWith$$($APP.$cljs$core$name$$($form$jscomp$20$$),"#"):$and__5023__auto__$jscomp$40$$}())?$cljs$tools$reader$register_gensym$$($form$jscomp$20$$):function(){var $csym_sym$jscomp$19$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($form$jscomp$20$$);return $APP.$cljs$core$truth_$$($APP.$goog$string$internal$endsWith$$($csym_sym$jscomp$19$$,"."))?($csym_sym$jscomp$19$$=$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($csym_sym$jscomp$19$$,
0,$csym_sym$jscomp$19$$.length-1)),$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($cljs$tools$reader$resolve_symbol$$.call(null,$csym_sym$jscomp$19$$)),"."].join(""))):$cljs$tools$reader$resolve_symbol$$.call(null,$form$jscomp$20$$)}(),null,1,null),2,null);else if($cljs$tools$reader$unquote_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
$APP.$cljs$core$second$$($form$jscomp$20$$);else{if($cljs$tools$reader$unquote_splicing_QMARK_$$($form$jscomp$20$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("unquote-splice not in list",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],null));if($APP.$cljs$core$coll_QMARK_$$($form$jscomp$20$$))if($form$jscomp$20$$!=null&&($form$jscomp$20$$.$cljs$lang$protocol_mask$partition0$$&67108864||$APP.$cljs$core$PROTOCOL_SENTINEL$$===
$form$jscomp$20$$.$cljs$core$IRecord$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=$form$jscomp$20$$;else if($APP.$cljs$core$map_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
$cljs$tools$reader$syntax_quote_coll$$($APP.$cljs$core$count$$($form$jscomp$20$$)>=16?$APP.$cljs$cst$240$cljs_DOT_core_SLASH_hash_map$$:$APP.$cljs$cst$241$cljs_DOT_core_SLASH_array_map$$,$cljs$tools$reader$flatten_map$$($form$jscomp$20$$));else if($APP.$cljs$core$vector_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$243$cljs_DOT_core_SLASH_vec$$,new $APP.$cljs$core$List$$(null,$cljs$tools$reader$syntax_quote_coll$$(null,$form$jscomp$20$$),null,1,null),2,null);else if($APP.$cljs$core$set_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
$cljs$tools$reader$syntax_quote_coll$$($APP.$cljs$cst$244$cljs_DOT_core_SLASH_hash_set$$,$form$jscomp$20$$);else if($APP.$cljs$core$seq_QMARK_$$($form$jscomp$20$$)||$APP.$cljs$core$list_QMARK_$$($form$jscomp$20$$))$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=function(){var $seq$jscomp$1$$=$APP.$cljs$core$seq$$($form$jscomp$20$$);
return $seq$jscomp$1$$?$cljs$tools$reader$syntax_quote_coll$$(null,$seq$jscomp$1$$):$APP.$cljs$core$list$$($APP.$cljs$cst$245$cljs_DOT_core_SLASH_list$$)}();else throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Unknown Collection type",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$246$unsupported_operation$$],null));else $JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$=
$form$jscomp$20$$ instanceof $APP.$cljs$core$Keyword$$||typeof $form$jscomp$20$$==="number"||typeof $form$jscomp$20$$==="string"||$form$jscomp$20$$==null||$form$jscomp$20$$ instanceof Boolean||$form$jscomp$20$$===!0||$form$jscomp$20$$===!1||$form$jscomp$20$$ instanceof RegExp?$form$jscomp$20$$:new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$167$quote$$,new $APP.$cljs$core$List$$(null,$form$jscomp$20$$,null,1,null),2,null)}return $cljs$tools$reader$add_meta$$($form$jscomp$20$$,$JSCompiler_temp$jscomp$1587_JSCompiler_temp$jscomp$1588_JSCompiler_temp$jscomp$1589_JSCompiler_temp$jscomp$1591_JSCompiler_temp$jscomp$1592_JSCompiler_temp$jscomp$1593_JSCompiler_temp$jscomp$1594_JSCompiler_temp$jscomp$1595_JSCompiler_temp$jscomp$1596$$)};
$app$util$theme$add_color_scheme_listener_BANG_$$=function($f$jscomp$847$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$theme$color_scheme_listeners_STAR_$$,$APP.$cljs$core$conj$$,$f$jscomp$847$$);return function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$theme$color_scheme_listeners_STAR_$$,$APP.$cljs$core$disj$$,$f$jscomp$847$$)}};
$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$=function($or__5025__auto__$jscomp$936_state$jscomp$978_value$jscomp$727$$){$or__5025__auto__$jscomp$936_state$jscomp$978_value$jscomp$727$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($or__5025__auto__$jscomp$936_state$jscomp$978_value$jscomp$727$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$4768$unfolded_token_types$$],
null));$or__5025__auto__$jscomp$936_state$jscomp$978_value$jscomp$727$$=$APP.$cljs$cst$925$types$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$936_state$jscomp$978_value$jscomp$727$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$936_state$jscomp$978_value$jscomp$727$$)?$or__5025__auto__$jscomp$936_state$jscomp$978_value$jscomp$727$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$};
$app$common$logic$tokens$toggle_token_set_group$$=function($group_path$jscomp$7_sets_names$$,$tokens_lib$jscomp$24$$,$tokens_lib_theme$$){var $deactivate_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2132$all$$,null,$APP.$cljs$cst$2133$partial$$,null],null),null),$app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$($tokens_lib$jscomp$24$$,$group_path$jscomp$7_sets_names$$));$group_path$jscomp$7_sets_names$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$tokens_lib$get_name$$,$app$common$types$tokens_lib$get_sets_at_path$$($tokens_lib$jscomp$24$$,$group_path$jscomp$7_sets_names$$)));return $deactivate_QMARK_$$?$app$common$types$tokens_lib$disable_sets$$($tokens_lib_theme$$,$group_path$jscomp$7_sets_names$$):$app$common$types$tokens_lib$enable_sets$$($tokens_lib_theme$$,$group_path$jscomp$7_sets_names$$)};
$app$common$files$tokens$shapes_ids_by_applied_attributes$$=function($token$jscomp$79$$,$shapes$jscomp$126$$,$token_attributes$jscomp$2$$){var $conj_STAR_$jscomp$1$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result$jscomp$323$$,$shape$jscomp$766$$){var $shape_id$jscomp$132$$=$shape$jscomp$766$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$766$$,
$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($result__$1$jscomp$40$$,$attr$jscomp$58$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($result__$1$jscomp$40$$,$attr$jscomp$58$$,$conj_STAR_$jscomp$1$$,$shape_id$jscomp$132$$)},$result$jscomp$323$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72113_SHARP_$$){return $APP.$app$common$files$tokens$token_attribute_applied_QMARK_$$($token$jscomp$79$$,$shape$jscomp$766$$,
$p1__72113_SHARP_$$)},$token_attributes$jscomp$2$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$shapes$jscomp$126$$)};
$app$main$data$workspace$select_assets$$=function($file_id$jscomp$291$$,$assets_ids$$,$type$jscomp$541$$){typeof $app$main$data$workspace$select_assets_72125$$==="undefined"&&($app$main$data$workspace$select_assets_72125$$=function($file_id$jscomp$292$$,$assets_ids$jscomp$1$$,$type$jscomp$542$$,$meta72126$$){this.$file_id$=$file_id$jscomp$292$$;this.$assets_ids$=$assets_ids$jscomp$1$$;this.type=$type$jscomp$542$$;this.$meta72126$=$meta72126$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$select_assets_72125$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_assets_72125$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4569$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_assets$$},$app$main$data$workspace$select_assets_72125$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72127$$,$meta72126__$1$$){return new $app$main$data$workspace$select_assets_72125$$(this.$file_id$,
this.$assets_ids$,this.type,$meta72126__$1$$)},$app$main$data$workspace$select_assets_72125$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72126$},$app$main$data$workspace$select_assets_72125$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_assets_72125$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2596$$,$state$jscomp$924$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$924$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$1938$selected$$,this.$file_id$,this.type],null),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,this.$assets_ids$))});return new $app$main$data$workspace$select_assets_72125$$($file_id$jscomp$291$$,$assets_ids$$,$type$jscomp$541$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$check_in_asset$$=function($items$jscomp$51_items__$1$jscomp$6$$,$element$jscomp$72$$){$items$jscomp$51_items__$1$jscomp$6$$=$APP.$cljs$core$truth_$$($items$jscomp$51_items__$1$jscomp$6$$)?$items$jscomp$51_items__$1$jscomp$6$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$;return $APP.$cljs$core$contains_QMARK_$$($items$jscomp$51_items__$1$jscomp$6$$,$element$jscomp$72$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$51_items__$1$jscomp$6$$,$element$jscomp$72$$):
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($items$jscomp$51_items__$1$jscomp$6$$,$element$jscomp$72$$)};
$app$main$data$workspace$toggle_selected_assets$$=function($file_id$jscomp$287$$,$asset_id$jscomp$15$$,$type$jscomp$537$$){typeof $app$main$data$workspace$toggle_selected_assets_72110$$==="undefined"&&($app$main$data$workspace$toggle_selected_assets_72110$$=function($file_id$jscomp$288$$,$asset_id$jscomp$16$$,$type$jscomp$538$$,$meta72111$$){this.$file_id$=$file_id$jscomp$288$$;this.$asset_id$=$asset_id$jscomp$16$$;this.type=$type$jscomp$538$$;this.$meta72111$=$meta72111$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$toggle_selected_assets_72110$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$toggle_selected_assets_72110$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4567$app_DOT_main_DOT_data_DOT_workspace_SLASH_toggle_selected_assets$$},$app$main$data$workspace$toggle_selected_assets_72110$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72112$$,
$meta72111__$1$$){return new $app$main$data$workspace$toggle_selected_assets_72110$$(this.$file_id$,this.$asset_id$,this.type,$meta72111__$1$$)},$app$main$data$workspace$toggle_selected_assets_72110$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72111$},$app$main$data$workspace$toggle_selected_assets_72110$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$toggle_selected_assets_72110$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2594$$,$state$jscomp$922$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$922$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$1938$selected$$,this.$file_id$,this.type],null),$app$main$data$workspace$check_in_asset$$,this.$asset_id$)});return new $app$main$data$workspace$toggle_selected_assets_72110$$($file_id$jscomp$287$$,$asset_id$jscomp$15$$,
$type$jscomp$537$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$select_track_cells$$=function($grid_id$jscomp$17$$,$type$jscomp$509$$,$index$jscomp$353$$){typeof $app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$=function($grid_id$jscomp$18$$,$type$jscomp$510$$,$index$jscomp$354$$,$meta71181$$){this.$grid_id$=$grid_id$jscomp$18$$;this.type=$type$jscomp$510$$;this.index=$index$jscomp$354$$;this.$meta71181$=$meta71181$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4458$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_select_track_cells$$},$app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71182$$,$meta71181__$1$$){return new $app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$(this.$grid_id$,this.type,this.index,$meta71181__$1$$)},$app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71181$},$app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$,$state$jscomp$834$$){$_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$834$$);$_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$,
this.$grid_id$);$_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$,this.index):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$,
this.index);$_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$834$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2248$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1938$selected$$],null),$_$jscomp$2483_cells$jscomp$22_objects$jscomp$629_parent$jscomp$277_selected$jscomp$90$$)});return new $app$main$data$workspace$grid_layout$editor$select_track_cells_71180$$($grid_id$jscomp$17$$,$type$jscomp$509$$,$index$jscomp$353$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$hover_grid_cell$$=function($grid_id$$,$cell_id$$,$add_to_set$$){typeof $app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$=function($grid_id$jscomp$1$$,$cell_id$jscomp$1$$,$add_to_set$jscomp$1$$,$meta71096$$){this.$grid_id$=$grid_id$jscomp$1$$;this.$cell_id$=$cell_id$jscomp$1$$;this.$add_to_set$=$add_to_set$jscomp$1$$;this.$meta71096$=$meta71096$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4450$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_hover_grid_cell$$},$app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71097$$,$meta71096__$1$$){return new $app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$(this.$grid_id$,this.$cell_id$,this.$add_to_set$,$meta71096__$1$$)},$app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71096$},$app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2474$$,$state$jscomp$825$$){var $self__$jscomp$5949$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$825$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,$self__$jscomp$5949$$.$grid_id$,$APP.$cljs$cst$2212$hover$$],null),function($hover_set_hover_set__$1$$){$hover_set_hover_set__$1$$=$APP.$cljs$core$truth_$$($hover_set_hover_set__$1$$)?$hover_set_hover_set__$1$$:
$APP.$cljs$core$PersistentHashSet$EMPTY$$;return $APP.$cljs$core$truth_$$($self__$jscomp$5949$$.$add_to_set$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($hover_set_hover_set__$1$$,$self__$jscomp$5949$$.$cell_id$):$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($hover_set_hover_set__$1$$,$self__$jscomp$5949$$.$cell_id$)})});return new $app$main$data$workspace$grid_layout$editor$hover_grid_cell_71095$$($grid_id$$,$cell_id$$,$add_to_set$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$guides$set_hover_guide$$=function($id$jscomp$720$$,$hover_QMARK_$$){typeof $app$main$data$workspace$guides$set_hover_guide_70564$$==="undefined"&&($app$main$data$workspace$guides$set_hover_guide_70564$$=function($id$jscomp$721$$,$hover_QMARK_$jscomp$1$$,$meta70565$$){this.id=$id$jscomp$721$$;this.$hover_QMARK_$=$hover_QMARK_$jscomp$1$$;this.$meta70565$=$meta70565$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$guides$set_hover_guide_70564$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$set_hover_guide_70564$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4364$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_set_hover_guide$$},$app$main$data$workspace$guides$set_hover_guide_70564$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70566$$,$meta70565__$1$$){return new $app$main$data$workspace$guides$set_hover_guide_70564$$(this.id,this.$hover_QMARK_$,$meta70565__$1$$)},
$app$main$data$workspace$guides$set_hover_guide_70564$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70565$},$app$main$data$workspace$guides$set_hover_guide_70564$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$set_hover_guide_70564$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2406_sconj$$,$state$jscomp$772$$){$_$jscomp$2406_sconj$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$);var $sdisj$jscomp$1$$=$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$disj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$truth_$$(this.$hover_QMARK_$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$772$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4360$workspace_guides$$,$APP.$cljs$cst$2212$hover$$],null),$_$jscomp$2406_sconj$$,
this.id):$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$772$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4360$workspace_guides$$,$APP.$cljs$cst$2212$hover$$],null),$sdisj$jscomp$1$$,this.id)});return new $app$main$data$workspace$guides$set_hover_guide_70564$$($id$jscomp$720$$,$hover_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$deselect_all$$=function(){typeof $app$main$data$workspace$path$selection$deselect_all_69950$$==="undefined"&&($app$main$data$workspace$path$selection$deselect_all_69950$$=function($meta69951$$){this.$meta69951$=$meta69951$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$deselect_all_69950$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$deselect_all_69950$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4310$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_deselect_all$$},$app$main$data$workspace$path$selection$deselect_all_69950$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69952$$,$meta69951__$1$$){return new $app$main$data$workspace$path$selection$deselect_all_69950$$($meta69951__$1$$)},$app$main$data$workspace$path$selection$deselect_all_69950$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69951$},$app$main$data$workspace$path$selection$deselect_all_69950$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$deselect_all_69950$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2343_id$jscomp$688$$,$state$jscomp$725$$){$_$jscomp$2343_id$jscomp$688$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$725$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$725$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,
$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2343_id$jscomp$688$$,$APP.$cljs$cst$4308$selected_points$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$)});return new $app$main$data$workspace$path$selection$deselect_all_69950$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$path_handler_enter$$=function($index$jscomp$325$$,$prefix$jscomp$53$$){typeof $app$main$data$workspace$path$selection$path_handler_enter_69907$$==="undefined"&&($app$main$data$workspace$path$selection$path_handler_enter_69907$$=function($index$jscomp$326$$,$prefix$jscomp$54$$,$meta69908$$){this.index=$index$jscomp$326$$;this.prefix=$prefix$jscomp$54$$;this.$meta69908$=$meta69908$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$selection$path_handler_enter_69907$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_handler_enter_69907$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4304$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_handler_enter$$},$app$main$data$workspace$path$selection$path_handler_enter_69907$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69909$$,
$meta69908__$1$$){return new $app$main$data$workspace$path$selection$path_handler_enter_69907$$(this.index,this.prefix,$meta69908__$1$$)},$app$main$data$workspace$path$selection$path_handler_enter_69907$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69908$},$app$main$data$workspace$path$selection$path_handler_enter_69907$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_handler_enter_69907$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2339_id$jscomp$684$$,$state$jscomp$721$$){$_$jscomp$2339_id$jscomp$684$$=$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$721$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$721$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2339_id$jscomp$684$$,$APP.$cljs$cst$4305$hover_handlers$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.index,this.prefix],null))});return new $app$main$data$workspace$path$selection$path_handler_enter_69907$$($index$jscomp$325$$,$prefix$jscomp$53$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$path_pointer_enter$$=function($position$jscomp$139$$){typeof $app$main$data$workspace$path$selection$path_pointer_enter_69884$$==="undefined"&&($app$main$data$workspace$path$selection$path_pointer_enter_69884$$=function($position$jscomp$140$$,$meta69885$$){this.position=$position$jscomp$140$$;this.$meta69885$=$meta69885$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$path_pointer_enter_69884$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_pointer_enter_69884$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4301$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_path_pointer_enter$$},$app$main$data$workspace$path$selection$path_pointer_enter_69884$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69886$$,$meta69885__$1$$){return new $app$main$data$workspace$path$selection$path_pointer_enter_69884$$(this.position,
$meta69885__$1$$)},$app$main$data$workspace$path$selection$path_pointer_enter_69884$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69885$},$app$main$data$workspace$path$selection$path_pointer_enter_69884$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$path_pointer_enter_69884$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2337_id$jscomp$682$$,$state$jscomp$719$$){$_$jscomp$2337_id$jscomp$682$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$719$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$719$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2337_id$jscomp$682$$,$APP.$cljs$cst$4302$hover_points$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),
this.position)});return new $app$main$data$workspace$path$selection$path_pointer_enter_69884$$($position$jscomp$139$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$cleanup_unlinked_libraries$$=function($file_id$jscomp$189$$,$libraries$jscomp$85$$){typeof $app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$==="undefined"&&($app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$=function($file_id$jscomp$190$$,$libraries$jscomp$86$$,$meta70173$$){this.$file_id$=$file_id$jscomp$190$$;this.libraries=$libraries$jscomp$86$$;this.$meta70173$=$meta70173$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4056$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_cleanup_unlinked_libraries$$},$app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70174$$,$meta70173__$1$$){return new $app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$(this.$file_id$,this.libraries,$meta70173__$1$$)},$app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70173$},$app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2170$$,$state$jscomp$546$$){var $self__$jscomp$4964$$=this,$linked_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$self__$jscomp$4964$$.libraries);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$546$$,$APP.$cljs$cst$1933$files$$,function($files$jscomp$13$$){return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$132$$,
$id$jscomp$607$$,$file$jscomp$68$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2188$library_of$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$68$$),$self__$jscomp$4964$$.$file_id$)&&!$APP.$cljs$core$contains_QMARK_$$($linked_ids$$,$id$jscomp$607$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$607$$,$self__$jscomp$4964$$.$file_id$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$132$$,$id$jscomp$607$$):$acc$jscomp$132$$},
$files$jscomp$13$$,$files$jscomp$13$$)})});return new $app$main$data$workspace$libraries$cleanup_unlinked_libraries_70172$$($file_id$jscomp$189$$,$libraries$jscomp$85$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$unlink_file_from_library$$=function($file_id$jscomp$191$$,$library_id$jscomp$52$$){typeof $app$main$data$workspace$libraries$detach_library_70179$$==="undefined"&&($app$main$data$workspace$libraries$detach_library_70179$$=function($file_id$jscomp$192$$,$library_id$jscomp$53$$,$meta70180$$){this.$file_id$=$file_id$jscomp$192$$;this.$library_id$=$library_id$jscomp$53$$;this.$meta70180$=$meta70180$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4057$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_library$$},$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70181$$,$meta70180__$1$$){return new $app$main$data$workspace$libraries$detach_library_70179$$(this.$file_id$,
this.$library_id$,$meta70180__$1$$)},$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70180$},$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"detach-library",$APP.$cljs$cst$1649$file_id$$,this.$file_id$,$APP.$cljs$cst$4033$library_id$$,this.$library_id$],null)},$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2172$$,$state$jscomp$547$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$547$$,$APP.$cljs$cst$1933$files$$,
$APP.$cljs$core$dissoc$$,this.$library_id$)},$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_library_70179$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$4970$$=this;return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$libraries$cleanup_unlinked_libraries$$,$self__$jscomp$4970$$.$file_id$),
$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4058$get_file_libraries$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$4970$$.$file_id$],null))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4059$unlink_file_from_library$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$self__$jscomp$4970$$.$file_id$,$APP.$cljs$cst$4033$library_id$$,
$self__$jscomp$4970$$.$library_id$],null))))});return new $app$main$data$workspace$libraries$detach_library_70179$$($file_id$jscomp$191$$,$library_id$jscomp$52$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$render_wasm$rulers_state$display_state$$=function($layout$jscomp$5_p__53360$$){var $base_objects$jscomp$1_map__53361__$1$$=$APP.$cljs$core$__destructure_map$$($layout$jscomp$5_p__53360$$);$layout$jscomp$5_p__53360$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$1_map__53361__$1$$,$APP.$cljs$cst$1620$layout$$);var $selected_shapes$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$1_map__53361__$1$$,$APP.$cljs$cst$3050$selected_shapes$$);
$base_objects$jscomp$1_map__53361__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$1_map__53361__$1$$,$APP.$cljs$cst$3051$base_objects$$);return $APP.$app$render_wasm$rulers_state$display_state_STAR_$$($layout$jscomp$5_p__53360$$,$selected_shapes$jscomp$1$$,$base_objects$jscomp$1_map__53361__$1$$)};
$app$main$refs$parents_by_ids$$=function($ids$jscomp$27$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects$jscomp$163$$){var $parent_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__50261_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$163$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p1__50261_SHARP_$$,$APP.$cljs$cst$1624$parent_id$$],null))}),$ids$jscomp$27$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__50262_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$163$$,$p1__50262_SHARP_$$)}),$parent_ids$$)},$APP.$app$main$refs$workspace_page_objects$$,$APP.$cljs$core$_EQ_$$)};
$app$main$data$workspace$path$edition$move_selected_path_point$$=function($from_point$jscomp$1$$,$to_point$$){typeof $app$main$data$workspace$path$edition$move_point_70107$$==="undefined"&&($app$main$data$workspace$path$edition$move_point_70107$$=function($from_point$jscomp$2$$,$to_point$jscomp$1$$,$meta70108$$){this.$from_point$=$from_point$jscomp$2$$;this.$to_point$=$to_point$jscomp$1$$;this.$meta70108$=$meta70108$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$edition$move_point_70107$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$move_point_70107$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4320$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_move_point$$},$app$main$data$workspace$path$edition$move_point_70107$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70109$$,$meta70108__$1$$){return new $app$main$data$workspace$path$edition$move_point_70107$$(this.$from_point$,
this.$to_point$,$meta70108__$1$$)},$app$main$data$workspace$path$edition$move_point_70107$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70108$},$app$main$data$workspace$path$edition$move_point_70107$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$move_point_70107$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2351_id$jscomp$695$$,$state$jscomp$733$$){$_$jscomp$2351_id$jscomp$695$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$733$$);var $content$jscomp$213_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$733$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$]));var $G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$=this.$to_point$;$G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$4270$shift_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$(this.$to_point$))?$APP.$app$common$types$path$helpers$position_fixed_angle$$($G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$,this.$from_point$):$G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$;$G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$=$APP.$app$common$geom$point$subtract$$($G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$,
this.$from_point$);$content$jscomp$213_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$data$workspace$path$edition$modify_content_point$$,$content$jscomp$213_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$,$G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$);$G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$733$$,
$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1940$edit_path$$),$_$jscomp$2351_id$jscomp$695$$),$APP.$cljs$cst$4308$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);var $modifiers$jscomp$103$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$733$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1940$edit_path$$),
$_$jscomp$2351_id$jscomp$695$$),$APP.$cljs$cst$1941$content_modifiers$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);$content$jscomp$213_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$213_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$,$modifiers$jscomp$103$$,$G__70115$jscomp$inline_8421_delta$jscomp$51_points$jscomp$90_to_point__$1$$);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$733$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2351_id$jscomp$695$$,$APP.$cljs$cst$4318$moving_nodes$$],null),!0),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2351_id$jscomp$695$$,$APP.$cljs$cst$1941$content_modifiers$$],null),$content$jscomp$213_modifiers__$1$jscomp$16_modifiers_reducer$jscomp$1$$)});
return new $app$main$data$workspace$path$edition$move_point_70107$$($from_point$jscomp$1$$,$to_point$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$modify_handler$$=function($id$jscomp$691$$,$index$jscomp$329$$,$prefix$jscomp$57$$,$dx$jscomp$23$$,$dy$jscomp$23$$,$match_opposite_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$path$edition$modify_handler_70046$$==="undefined"&&($app$main$data$workspace$path$edition$modify_handler_70046$$=function($id$jscomp$692$$,$index$jscomp$330$$,$prefix$jscomp$58$$,$dx$jscomp$24$$,$dy$jscomp$24$$,$match_opposite_QMARK_$jscomp$2$$,$meta70047$$){this.id=$id$jscomp$692$$;
this.index=$index$jscomp$330$$;this.prefix=$prefix$jscomp$58$$;this.dx=$dx$jscomp$24$$;this.dy=$dy$jscomp$24$$;this.$match_opposite_QMARK_$=$match_opposite_QMARK_$jscomp$2$$;this.$meta70047$=$meta70047$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$modify_handler_70046$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$modify_handler_70046$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4315$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_modify_handler$$},$app$main$data$workspace$path$edition$modify_handler_70046$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70048$$,$meta70047__$1$$){return new $app$main$data$workspace$path$edition$modify_handler_70046$$(this.id,this.index,this.prefix,this.dx,this.dy,this.$match_opposite_QMARK_$,$meta70047__$1$$)},$app$main$data$workspace$path$edition$modify_handler_70046$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70047$},$app$main$data$workspace$path$edition$modify_handler_70046$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$modify_handler_70046$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2348_modifiers$jscomp$101$$,$state$jscomp$730$$){var $content$jscomp$209_point$jscomp$72$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$730$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$]));$_$jscomp$2348_modifiers$jscomp$101$$=$APP.$app$main$data$workspace$path$helpers$move_handler_modifiers$$($content$jscomp$209_point$jscomp$72$$,this.index,this.prefix,!1,this.$match_opposite_QMARK_$,this.dx,this.dy);var $cy$jscomp$19_vec__70053$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.prefix,$APP.$cljs$cst$1827$c1$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1821$c1x$$,$APP.$cljs$cst$1822$c1y$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1823$c2x$$,$APP.$cljs$cst$1824$c2y$$],null),$cx$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cy$jscomp$19_vec__70053$$,0,null);$cy$jscomp$19_vec__70053$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cy$jscomp$19_vec__70053$$,1,null);$content$jscomp$209_point$jscomp$72$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$209_point$jscomp$72$$,
this.index),$APP.$cljs$cst$1435$params$$),$cx$jscomp$18$$)+this.dx,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$209_point$jscomp$72$$,this.index),$APP.$cljs$cst$1435$params$$),$cy$jscomp$19_vec__70053$$)+this.dy);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$730$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,this.id,$APP.$cljs$cst$1941$content_modifiers$$],null),$APP.$cljs$core$merge$$,$_$jscomp$2348_modifiers$jscomp$101$$),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,this.id,$APP.$cljs$cst$4316$moving_handler$$],null),$content$jscomp$209_point$jscomp$72$$)});return new $app$main$data$workspace$path$edition$modify_handler_70046$$($id$jscomp$691$$,
$index$jscomp$329$$,$prefix$jscomp$57$$,$dx$jscomp$23$$,$dy$jscomp$23$$,$match_opposite_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$select_node_area$$=function($initial_set$jscomp$4$$,$remove_QMARK_$jscomp$8$$){typeof $app$main$data$workspace$path$selection$select_node_area_69926$$==="undefined"&&($app$main$data$workspace$path$selection$select_node_area_69926$$=function($initial_set$jscomp$5$$,$remove_QMARK_$jscomp$9$$,$meta69927$$){this.$initial_set$=$initial_set$jscomp$5$$;this.$remove_QMARK_$=$remove_QMARK_$jscomp$9$$;this.$meta69927$=$meta69927$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$select_node_area_69926$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$select_node_area_69926$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4307$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_select_node_area$$},$app$main$data$workspace$path$selection$select_node_area_69926$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69928$$,$meta69927__$1$$){return new $app$main$data$workspace$path$selection$select_node_area_69926$$(this.$initial_set$,this.$remove_QMARK_$,$meta69927__$1$$)},$app$main$data$workspace$path$selection$select_node_area_69926$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69927$},$app$main$data$workspace$path$selection$select_node_area_69926$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$select_node_area_69926$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2341_id$jscomp$686$$,$state$jscomp$723$$){var $selected_point_QMARK__selrect$jscomp$74_xform$jscomp$37$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$723$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1610$selrect$$);$_$jscomp$2341_id$jscomp$686$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$723$$,$APP.$cljs$cst$1937$workspace_local$$),
$APP.$cljs$cst$2207$edition$$);var $content$jscomp$208_positions$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($state$jscomp$723$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$]));$selected_point_QMARK__selrect$jscomp$74_xform$jscomp$37$$=$selected_point_QMARK__selrect$jscomp$74_xform$jscomp$37$$!=null?$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$geom$shapes$has_point_rect_QMARK_$$,
$selected_point_QMARK__selrect$jscomp$74_xform$jscomp$37$$):$APP.$cljs$core$constantly$$(!1);$selected_point_QMARK__selrect$jscomp$74_xform$jscomp$37$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69925_SHARP_$$){return!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1818$command$$.$cljs$core$IFn$_invoke$arity$1$($p1__69925_SHARP_$$),$APP.$cljs$cst$1856$close_path$$)}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$point$point$$,
$APP.$cljs$cst$1435$params$$)),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($selected_point_QMARK__selrect$jscomp$74_xform$jscomp$37$$));$content$jscomp$208_positions$$=$APP.$cljs$core$truth_$$(this.$remove_QMARK_$)?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$disj$$,this.$initial_set$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$selected_point_QMARK__selrect$jscomp$74_xform$jscomp$37$$,$content$jscomp$208_positions$$)):
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(this.$initial_set$,$selected_point_QMARK__selrect$jscomp$74_xform$jscomp$37$$,$content$jscomp$208_positions$$);return $_$jscomp$2341_id$jscomp$686$$!=null?$APP.$cljs$core$assoc_in$$($state$jscomp$723$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2341_id$jscomp$686$$,$APP.$cljs$cst$4308$selected_points$$],null),$content$jscomp$208_positions$$):
$state$jscomp$723$$});return new $app$main$data$workspace$path$selection$select_node_area_69926$$($initial_set$jscomp$4$$,$remove_QMARK_$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$handle_area_selection$$=function($append_QMARK_$jscomp$2$$,$remove_QMARK_$jscomp$10$$){typeof $app$main$data$workspace$path$selection$handle_area_selection_69998$$==="undefined"&&($app$main$data$workspace$path$selection$handle_area_selection_69998$$=function($append_QMARK_$jscomp$3$$,$remove_QMARK_$jscomp$11$$,$valid_rect_QMARK_$jscomp$1$$,$meta69999$$){this.$append_QMARK_$=$append_QMARK_$jscomp$3$$;this.$remove_QMARK_$=$remove_QMARK_$jscomp$11$$;this.$valid_rect_QMARK_$=
$valid_rect_QMARK_$jscomp$1$$;this.$meta69999$=$meta69999$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$selection$handle_area_selection_69998$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$handle_area_selection_69998$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4313$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_handle_area_selection$$},
$app$main$data$workspace$path$selection$handle_area_selection_69998$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70000$$,$meta69999__$1$$){return new $app$main$data$workspace$path$selection$handle_area_selection_69998$$(this.$append_QMARK_$,this.$remove_QMARK_$,this.$valid_rect_QMARK_$,$meta69999__$1$$)},$app$main$data$workspace$path$selection$handle_area_selection_69998$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69999$},$app$main$data$workspace$path$selection$handle_area_selection_69998$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$handle_area_selection_69998$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2346_id$jscomp$689$$,$selrect_stream$jscomp$1_state$jscomp$728$$,$stopper$jscomp$26_stream$jscomp$77$$){var $self__$jscomp$5539$$=this;$_$jscomp$2346_id$jscomp$689$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_stream$jscomp$1_state$jscomp$728$$,$APP.$cljs$cst$1937$workspace_local$$),
$APP.$cljs$cst$2207$edition$$);var $zoom$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_stream$jscomp$1_state$jscomp$728$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2204$zoom$$,1);$stopper$jscomp$26_stream$jscomp$77$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stopper$jscomp$26_stream$jscomp$77$$,null);var $from_p$jscomp$13$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$),
$initial_set$jscomp$6$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$851$$=$self__$jscomp$5539$$.$append_QMARK_$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$851$$)?$or__5025__auto__$jscomp$851$$:$self__$jscomp$5539$$.$remove_QMARK_$}())?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect_stream$jscomp$1_state$jscomp$728$$,
$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1940$edit_path$$),$_$jscomp$2346_id$jscomp$689$$),$APP.$cljs$cst$4308$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$):$APP.$cljs$core$PersistentHashSet$EMPTY$$;$selrect_stream$jscomp$1_state$jscomp$728$$=$APP.$beicon$v2$core$take_until$$($stopper$jscomp$26_stream$jscomp$77$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5539$$.$valid_rect_QMARK_$,$zoom$jscomp$33$$),$APP.$beicon$v2$core$map$$(function($p1__69983_SHARP_$$){return $APP.$app$common$geom$rect$points__GT_rect$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_p$jscomp$13$$,$p1__69983_SHARP_$$],null))},$APP.$app$main$streams$mouse_position$$)));return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$852$$=$self__$jscomp$5539$$.$append_QMARK_$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$852$$)?$or__5025__auto__$jscomp$852$$:$self__$jscomp$5539$$.$remove_QMARK_$}())?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$selection$deselect_all$$()),
$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$workspace$path$selection$update_area_selection$$,$selrect_stream$jscomp$1_state$jscomp$728$$),$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$path$selection$select_node_area$$($initial_set$jscomp$6$$,$self__$jscomp$5539$$.$remove_QMARK_$)},$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$($APP.$cljs$core$last$$,
$APP.$beicon$v2$core$buffer_time$cljs$0core$0IFn$0_invoke$0arity$02$$(100,$selrect_stream$jscomp$1_state$jscomp$728$$))))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$selection$clear_area_selection$$()))});return new $app$main$data$workspace$path$selection$handle_area_selection_69998$$($append_QMARK_$jscomp$2$$,$remove_QMARK_$jscomp$10$$,function($zoom$jscomp$32$$,$p__69992_width$jscomp$151$$){var $height$jscomp$135_map__69994__$1$$=$APP.$cljs$core$__destructure_map$$($p__69992_width$jscomp$151$$);
$p__69992_width$jscomp$151$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$135_map__69994__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$135_map__69994__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$135_map__69994__$1$$,$APP.$cljs$cst$1527$height$$);return $p__69992_width$jscomp$151$$>10/$zoom$jscomp$32$$||$height$jscomp$135_map__69994__$1$$>10/$zoom$jscomp$32$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$geom$shapes$transforms$update_shapes_geometry$$=function($objects$jscomp$106$$,$ids$jscomp$17$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects__$1$jscomp$1$$,$id$jscomp$153$$){var $shape$jscomp$114_shape__$1$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$1$$,$id$jscomp$153$$),$children$jscomp$164$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects__$1$jscomp$1$$,
$id$jscomp$153$$);$shape$jscomp$114_shape__$1$jscomp$6$$=$APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$114_shape__$1$jscomp$6$$)?$APP.$app$common$geom$shapes$transforms$update_mask_selrect$$($shape$jscomp$114_shape__$1$jscomp$6$$,$children$jscomp$164$$):$APP.$app$common$files$helpers$bool_shape_QMARK_$$($shape$jscomp$114_shape__$1$jscomp$6$$)?$APP.$app$common$types$path$update_bool_shape$$($shape$jscomp$114_shape__$1$jscomp$6$$,$objects__$1$jscomp$1$$):
$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$114_shape__$1$jscomp$6$$)?$APP.$app$common$geom$shapes$transforms$update_group_selrect$$($shape$jscomp$114_shape__$1$jscomp$6$$,$children$jscomp$164$$):$shape$jscomp$114_shape__$1$jscomp$6$$;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects__$1$jscomp$1$$,$id$jscomp$153$$,$shape$jscomp$114_shape__$1$jscomp$6$$)},$objects$jscomp$106$$,$ids$jscomp$17$$)};
$app$common$geom$shapes$update_shapes_geometry$$=function($param49242$$,$param49243$$){return $app$common$geom$shapes$transforms$update_shapes_geometry$$($param49242$$,$param49243$$)};
$app$main$data$workspace$shape_layout$copy_grid_tracks$$=function($grid_id$jscomp$19$$,$type$jscomp$533$$){typeof $app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$==="undefined"&&($app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$=function($grid_id$jscomp$20$$,$type$jscomp$534$$,$meta71585$$){this.$grid_id$=$grid_id$jscomp$20$$;this.type=$type$jscomp$534$$;this.$meta71585$=$meta71585$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4484$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_copy_grid_tracks$$},$app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71586$$,$meta71585__$1$$){return new $app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$(this.$grid_id$,
this.type,$meta71585__$1$$)},$app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71585$},$app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$,
$state$jscomp$845$$){$_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$845$$);var $grid$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$,this.$grid_id$);$_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$845$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1938$selected$$],null));$_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71583_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$7$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$p1__71583_SHARP_$$],null))},$_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$);$_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$);
var $last_column$jscomp$14_map__71591__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$);$_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$14_map__71591__$1$$,$APP.$cljs$cst$1720$first_row$$);var $last_row$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$14_map__71591__$1$$,
$APP.$cljs$cst$1722$last_row$$),$first_column$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$14_map__71591__$1$$,$APP.$cljs$cst$1721$first_column$$);$last_column$jscomp$14_map__71591__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$14_map__71591__$1$$,$APP.$cljs$cst$1723$last_column$$);$_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,
$APP.$cljs$cst$1661$row$$)?$APP.$cljs$core$vec$$($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$-1,$last_row$jscomp$14$$)):$APP.$cljs$core$vec$$($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($first_column$jscomp$14$$-1,$last_column$jscomp$14_map__71591__$1$$));return $APP.$cljs$core$assoc_in$$($state$jscomp$845$$,new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$4485$copied_tracks$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4486$track_indices$$,$_$jscomp$2505_cells$jscomp$27_first_row$jscomp$14_map__71591_objects$jscomp$646_selected$jscomp$96_track_indices$$,$APP.$cljs$cst$139$type$$,this.type,$APP.$cljs$cst$4487$grid_id$$,this.$grid_id$],null))});return new $app$main$data$workspace$shape_layout$copy_grid_tracks_71584$$($grid_id$jscomp$19$$,
$type$jscomp$533$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$add_to_selection$cljs$0core$0IFn$0_invoke$0arity$03$$=function($grid_id$jscomp$3$$,$cell_id$jscomp$3$$,$shift_QMARK_$jscomp$29$$){typeof $app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$=function($grid_id$jscomp$4$$,$cell_id$jscomp$4$$,$shift_QMARK_$jscomp$30$$,$meta71107$$){this.$grid_id$=$grid_id$jscomp$4$$;this.$cell_id$=$cell_id$jscomp$4$$;this.$shift_QMARK_$=
$shift_QMARK_$jscomp$30$$;this.$meta71107$=$meta71107$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4451$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_add_to_selection$$},
$app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71108$$,$meta71107__$1$$){return new $app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$(this.$grid_id$,this.$cell_id$,this.$shift_QMARK_$,$meta71107__$1$$)},$app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71107$},$app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$,$state$jscomp$826$$){var $self__$jscomp$5953$$=this;if($APP.$cljs$core$truth_$$($self__$jscomp$5953$$.$shift_QMARK_$)){$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$826$$);var $grid$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$,$self__$jscomp$5953$$.$grid_id$);$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$=function(){var $or__5025__auto__$jscomp$871$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$826$$,$APP.$cljs$cst$2248$workspace_grid_edition$$),$self__$jscomp$5953$$.$grid_id$),$APP.$cljs$cst$1938$selected$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$871$$)?$or__5025__auto__$jscomp$871$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$}();$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5953$$.$cell_id$],null));$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71102_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$4$$,
$APP.$cljs$cst$1701$layout_grid_cells$$),$p1__71102_SHARP_$$)},$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$);$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$);
var $last_column$jscomp$9_map__71111__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$);$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$9_map__71111__$1$$,$APP.$cljs$cst$1720$first_row$$);var $last_row$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$9_map__71111__$1$$,$APP.$cljs$cst$1722$last_row$$),$first_column$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$9_map__71111__$1$$,$APP.$cljs$cst$1721$first_column$$);$last_column$jscomp$9_map__71111__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$9_map__71111__$1$$,$APP.$cljs$cst$1723$last_column$$);$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$app$common$types$shape$layout$cells_in_area$$($grid$jscomp$4$$,$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$,$last_row$jscomp$9$$,$first_column$jscomp$9$$,$last_column$jscomp$9_map__71111__$1$$));return $APP.$cljs$core$assoc_in$$($state$jscomp$826$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,$self__$jscomp$5953$$.$grid_id$,$APP.$cljs$cst$1938$selected$$],null),$_$jscomp$2475_cells$jscomp$21_first_row$jscomp$9_map__71111_new_selected_objects$jscomp$626_selected$jscomp$88_selected__$1$jscomp$9$$)}return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$826$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$2248$workspace_grid_edition$$,$self__$jscomp$5953$$.$grid_id$,$APP.$cljs$cst$1938$selected$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$self__$jscomp$5953$$.$cell_id$)});return new $app$main$data$workspace$grid_layout$editor$add_to_selection_71106$$($grid_id$jscomp$3$$,$cell_id$jscomp$3$$,$shift_QMARK_$jscomp$29$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$shape$layout$valid_area_cells_QMARK_$$=function($cells$jscomp$17$$){var $map__48465$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$17$$),$map__48465__$1$$=$APP.$cljs$core$__destructure_map$$($map__48465$$),$first_row$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48465__$1$$,$APP.$cljs$cst$1720$first_row$$),$last_row$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48465__$1$$,$APP.$cljs$cst$1722$last_row$$),
$first_column$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48465__$1$$,$APP.$cljs$cst$1721$first_column$$),$last_column$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48465__$1$$,$APP.$cljs$cst$1723$last_column$$),$cell_coords$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__48465__$1$$,$APP.$cljs$cst$1724$cell_coords$$);return $APP.$cljs$core$every_QMARK_$$(function($p1__48464_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($cell_coords$jscomp$5$$,
$p1__48464_SHARP_$$)},function(){return function $app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48466$$($s__48467$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__48467__$1$$=$s__48467$$;;){var $fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$=$APP.$cljs$core$seq$$($s__48467__$1$$);if($fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$){var $xs__6385__auto__$jscomp$9$$=$fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$,$r$jscomp$83$$=$APP.$cljs$core$first$$($xs__6385__auto__$jscomp$9$$);
if($fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$=$APP.$cljs$core$seq$$(function($s__48467__$1$jscomp$1$$,$r$jscomp$84$$,$xs__6385__auto__$jscomp$10$$,$temp__5825__auto__$jscomp$121$$,$map__48465$jscomp$1$$,$map__48465__$1$jscomp$1$$,$first_row$jscomp$7$$,$last_row$jscomp$7$$,$first_column$jscomp$7$$,$last_column$jscomp$7$$,$cell_coords$jscomp$6$$){return function $app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48466_$_iter__48468$$($s__48469$$){return new $APP.$cljs$core$LazySeq$$(null,
function($s__48467__$1$jscomp$2$$,$r$jscomp$85$$){return function(){for(;;){var $s__48469__$2_temp__5825__auto____$1$jscomp$6$$=$APP.$cljs$core$seq$$($s__48469$$);if($s__48469__$2_temp__5825__auto____$1$jscomp$6$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__48469__$2_temp__5825__auto____$1$jscomp$6$$)){var $JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$=$APP.$cljs$core$_chunked_first$$($s__48469__$2_temp__5825__auto____$1$jscomp$6$$),$size__5502__auto__$jscomp$14$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$),
$b__48471_c$jscomp$264$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$14$$);a:{for(var $i__48470$jscomp$inline_8423$$=0;;)if($i__48470$jscomp$inline_8423$$<$size__5502__auto__$jscomp$14$$){var $c$jscomp$inline_8424$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$,$i__48470$jscomp$inline_8423$$);$b__48471_c$jscomp$264$$.add(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$85$$,$c$jscomp$inline_8424$$],
null));$i__48470$jscomp$inline_8423$$+=1}else{$JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$=!0;break a}$JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$=void 0}return $JSCompiler_inline_result$jscomp$1599_c__5501__auto__$jscomp$14$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__48471_c$jscomp$264$$),$app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48466_$_iter__48468$$($APP.$cljs$core$_chunked_rest$$($s__48469__$2_temp__5825__auto____$1$jscomp$6$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__48471_c$jscomp$264$$),null)}$b__48471_c$jscomp$264$$=$APP.$cljs$core$first$$($s__48469__$2_temp__5825__auto____$1$jscomp$6$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$85$$,$b__48471_c$jscomp$264$$],null),$app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48466_$_iter__48468$$($APP.$cljs$core$rest$$($s__48469__$2_temp__5825__auto____$1$jscomp$6$$)))}return null}}}($s__48467__$1$jscomp$1$$,
$r$jscomp$84$$,$xs__6385__auto__$jscomp$10$$,$temp__5825__auto__$jscomp$121$$,$map__48465$jscomp$1$$,$map__48465__$1$jscomp$1$$,$first_row$jscomp$7$$,$last_row$jscomp$7$$,$first_column$jscomp$7$$,$last_column$jscomp$7$$,$cell_coords$jscomp$6$$),null,null)}}($s__48467__$1$$,$r$jscomp$83$$,$xs__6385__auto__$jscomp$9$$,$fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$,$map__48465$$,$map__48465__$1$$,$first_row$jscomp$6$$,$last_row$jscomp$6$$,$first_column$jscomp$6$$,$last_column$jscomp$6$$,
$cell_coords$jscomp$5$$)($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($first_column$jscomp$6$$,$last_column$jscomp$6$$+1))))return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($fs__5500__auto__$jscomp$3_temp__5825__auto__$jscomp$120$$,$app$common$types$shape$layout$valid_area_cells_QMARK__$_iter__48466$$($APP.$cljs$core$rest$$($s__48467__$1$$)));$s__48467__$1$$=$APP.$cljs$core$rest$$($s__48467__$1$$)}else return null}},null,null)}($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($first_row$jscomp$6$$,
$last_row$jscomp$6$$+1))}())};
$app$common$types$shape$layout$duplicate_cells$$=function($shape$jscomp$62$$,$prop$jscomp$15_to_cells$$,$from_index$jscomp$2_vec__48112$$,$shape__$1_to_index$$,$ids_map$$){var $vec__48109$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$15_to_cells$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1663$column_span$$,$APP.$cljs$cst$1661$row$$,$APP.$cljs$cst$1662$row_span$$],null):new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1662$row_span$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1663$column_span$$],null),$prop_span$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48109$$,0,null),$prop_other$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48109$$,1,null),$prop_other_span$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__48109$$,2,null),$from_cells$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$15_to_cells$$,
$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$62$$,$from_index$jscomp$2_vec__48112$$):$app$common$types$shape$layout$cells_by_column$$($shape$jscomp$62$$,$from_index$jscomp$2_vec__48112$$):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$62$$,
$from_index$jscomp$2_vec__48112$$):$app$common$types$shape$layout$cells_by_row$$($shape$jscomp$62$$,$from_index$jscomp$2_vec__48112$$);$prop$jscomp$15_to_cells$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$15_to_cells$$,$APP.$cljs$cst$216$column$$)?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_column$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$62$$,$shape__$1_to_index$$):$app$common$types$shape$layout$cells_by_column$$($shape$jscomp$62$$,
$shape__$1_to_index$$):$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$?$app$common$types$shape$layout$cells_by_row$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$62$$,$shape__$1_to_index$$):$app$common$types$shape$layout$cells_by_row$$($shape$jscomp$62$$,$shape__$1_to_index$$);var $to_cells_idx$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($prop_other$jscomp$1$$,$prop$jscomp$15_to_cells$$);$from_index$jscomp$2_vec__48112$$=function(){for(var $G__48600_from_cells__$1$$=
$APP.$cljs$core$seq$$($from_cells$$),$G__48601_matched$jscomp$2$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$,$G__48602_result$jscomp$158$$=$shape$jscomp$62$$;;){var $cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$=$APP.$cljs$core$first$$($G__48600_from_cells__$1$$);if($APP.$cljs$core$truth_$$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$)){var $G__48119$jscomp$inline_13509_G__48120$jscomp$inline_13510$$=$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($to_cells_idx$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$,$prop_other$jscomp$1$$)),$APP.$cljs$core$select_keys$$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prop_other_span$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1682$align_self$$,$APP.$cljs$cst$1683$justify_self$$],null)));$G__48119$jscomp$inline_13509_G__48120$jscomp$inline_13510$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1679$area$$,$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48119$jscomp$inline_13509_G__48120$jscomp$inline_13510$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1678$manual$$):$G__48119$jscomp$inline_13509_G__48120$jscomp$inline_13510$$;$cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$,
$prop_span$jscomp$3$$),1)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__48119$jscomp$inline_13509_G__48120$jscomp$inline_13510$$,$APP.$cljs$cst$1619$shapes$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($ids_map$$,$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$))):$G__48119$jscomp$inline_13509_G__48120$jscomp$inline_13510$$;$G__48600_from_cells__$1$$=$APP.$cljs$core$rest$$($G__48600_from_cells__$1$$);$G__48601_matched$jscomp$2$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__48601_matched$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$));$G__48602_result$jscomp$158$$=$APP.$cljs$core$assoc_in$$($G__48602_result$jscomp$158$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$)],
null),$cell$jscomp$4_match_cell_temp__5823__auto__$jscomp$99$$)}else return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__48602_result$jscomp$158$$,$G__48601_matched$jscomp$2$$],null)}}();$shape__$1_to_index$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_index$jscomp$2_vec__48112$$,0,null);var $matched$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from_index$jscomp$2_vec__48112$$,1,null);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($shape__$2$jscomp$1$$,
$cell$jscomp$5$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape__$2$jscomp$1$$,$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$5$$))},$shape__$1_to_index$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$143_map__48123__$1_p__48122$$){$id$jscomp$143_map__48123__$1_p__48122$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$143_map__48123__$1_p__48122$$);$id$jscomp$143_map__48123__$1_p__48122$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$143_map__48123__$1_p__48122$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$contains_QMARK_$$($matched$jscomp$1$$,$id$jscomp$143_map__48123__$1_p__48122$$)},$prop$jscomp$15_to_cells$$))};
$app$common$types$shape_tree$get_root_shapes$$=function($objects$jscomp$140$$){return $APP.$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$140$$,function($result$jscomp$211$$,$shape$jscomp$214$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$214$$)?$result$jscomp$211$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$211$$,$shape$jscomp$214$$)})};
$app$common$types$shape_tree$get_root_frames_ids$$=function($objects$jscomp$138$$){return $APP.$app$common$files$helpers$reduce_objects$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$138$$,function($result$jscomp$209$$,$shape$jscomp$212$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$212$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$209$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$212$$)):
$result$jscomp$209$$})};$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$=function($svg_data$jscomp$3$$,$pos$jscomp$102$$,$objects$jscomp$363$$){var $selected$jscomp$34$$=$APP.$cljs$core$PersistentHashSet$EMPTY$$;return $APP.$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$app$common$uuid$next$$(),$svg_data$jscomp$3$$,$pos$jscomp$102$$,$objects$jscomp$363$$,$APP.$app$common$uuid$zero$$,null,$selected$jscomp$34$$,!1)};
$app$common$geom$shapes$fit_frame$fit_frame_modifiers$$=function($new_origin_objects$jscomp$114$$,$p__48859_resize_v_selrect$jscomp$21$$){var $center$jscomp$28_map__48861__$1$$=$APP.$cljs$core$__destructure_map$$($p__48859_resize_v_selrect$jscomp$21$$),$id$jscomp$155_ids$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48861__$1$$,$APP.$cljs$cst$266$id$$),$transform$jscomp$56_transform__$1$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48861__$1$$,
$APP.$cljs$cst$1294$transform$$),$transform_inverse$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48861__$1$$,$APP.$cljs$cst$1793$transform_inverse$$);$p__48859_resize_v_selrect$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48861__$1$$,$APP.$cljs$cst$1610$selrect$$);var $origin$jscomp$18_points$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48861__$1$$,$APP.$cljs$cst$1609$points$$),
$show_content$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($center$jscomp$28_map__48861__$1$$,$APP.$cljs$cst$1884$show_content$$),$bounds$jscomp$8_children$jscomp$167$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($new_origin_objects$jscomp$114$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$28_map__48861__$1$$));if($APP.$app$common$data$not_empty_QMARK_$$($bounds$jscomp$8_children$jscomp$167$$)){$id$jscomp$155_ids$jscomp$19$$=
$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($new_origin_objects$jscomp$114$$,$id$jscomp$155_ids$jscomp$19$$);$center$jscomp$28_map__48861__$1$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($center$jscomp$28_map__48861__$1$$);var $transform_inverse__$1$$=$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$28_map__48861__$1$$,$transform_inverse$jscomp$12$$);$transform$jscomp$56_transform__$1$jscomp$3$$=$APP.$app$common$geom$matrix$transform_in$$($center$jscomp$28_map__48861__$1$$,
$transform$jscomp$56_transform__$1$jscomp$3$$);var $tr_objects$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__48854_SHARP_$$,$p2__48855_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__48854_SHARP_$$,$p2__48855_SHARP_$$,$APP.$app$common$geom$shapes$transforms$apply_transform$$,$transform_inverse__$1$$)},$new_origin_objects$jscomp$114$$,$id$jscomp$155_ids$jscomp$19$$);$bounds$jscomp$8_children$jscomp$167$$=$APP.$app$common$geom$rect$join_rects$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48857_SHARP_$$){return $APP.$app$common$geom$shapes$bounds$get_object_bounds$$.$cljs$core$IFn$_invoke$arity$3$($tr_objects$$,
$p1__48857_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1929$ignore_shadow_margin_QMARK_$$,$show_content$$,$APP.$cljs$cst$1928$ignore_margin_QMARK_$$,!1],null))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__48856_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tr_objects$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__48856_SHARP_$$))},$bounds$jscomp$8_children$jscomp$167$$)));$new_origin_objects$jscomp$114$$=
$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$8_children$jscomp$167$$),$transform$jscomp$56_transform__$1$jscomp$3$$);$origin$jscomp$18_points$jscomp$47$$=$APP.$cljs$core$first$$($origin$jscomp$18_points$jscomp$47$$);$p__48859_resize_v_selrect$jscomp$21$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$8_children$jscomp$167$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($p__48859_resize_v_selrect$jscomp$21$$),
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$8_children$jscomp$167$$)/$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($p__48859_resize_v_selrect$jscomp$21$$));return $app$common$types$modifiers$move_parent$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$modifiers$resize_parent$cljs$0core$0IFn$0_invoke$0arity$05$$($p__48859_resize_v_selrect$jscomp$21$$,$origin$jscomp$18_points$jscomp$47$$,$transform$jscomp$56_transform__$1$jscomp$3$$,$transform_inverse__$1$$),
$APP.$app$common$geom$point$subtract$$($new_origin_objects$jscomp$114$$,$origin$jscomp$18_points$jscomp$47$$))}return null};$app$common$files$helpers$component_touched_QMARK_$$=function($objects$jscomp$43$$,$root_id$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,$APP.$cljs$cst$1631$touched$$),$APP.$app$common$files$helpers$get_children_with_self$$($objects$jscomp$43$$,$root_id$$)))};
$app$util$text$content$to_dom$get_paragraph_styles$$=function($font_size$jscomp$7_paragraph$jscomp$6$$){var $styles$jscomp$7$$=$app$util$text$content$to_dom$get_styles_from_attrs$$($font_size$jscomp$7_paragraph$jscomp$6$$,$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$text$paragraph_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_node_attrs$$])));$font_size$jscomp$7_paragraph$jscomp$6$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__53618_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",
$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($p1__53618_SHARP_$$))},$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$7_paragraph$jscomp$6$$)))?"0":$APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$2$($styles$jscomp$7$$,$APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$));var $line_height$jscomp$6_line_height__$1$jscomp$1$$=$APP.$cljs$cst$1771$line_height$$.$cljs$core$IFn$_invoke$arity$1$($styles$jscomp$7$$);
$line_height$jscomp$6_line_height__$1$jscomp$1$$=$line_height$jscomp$6_line_height__$1$jscomp$1$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$line_height$jscomp$6_line_height__$1$jscomp$1$$)?$line_height$jscomp$6_line_height__$1$jscomp$1$$:$APP.$cljs$cst$1771$line_height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($styles$jscomp$7$$,$APP.$cljs$cst$1766$font_size$$,
$font_size$jscomp$7_paragraph$jscomp$6$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1771$line_height$$,$line_height$jscomp$6_line_height__$1$jscomp$1$$]))};
$app$main$data$workspace$layout$ensure_layout$$=function($name$jscomp$322$$){typeof $app$main$data$workspace$layout$ensure_layout_67340$$==="undefined"&&($app$main$data$workspace$layout$ensure_layout_67340$$=function($name$jscomp$323$$,$meta67341$$){this.name=$name$jscomp$323$$;this.$meta67341$=$meta67341$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$layout$ensure_layout_67340$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$layout$ensure_layout_67340$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3783$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_ensure_layout$$},$app$main$data$workspace$layout$ensure_layout_67340$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67342$$,$meta67341__$1$$){return new $app$main$data$workspace$layout$ensure_layout_67340$$(this.name,$meta67341__$1$$)},$app$main$data$workspace$layout$ensure_layout_67340$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67341$},$app$main$data$workspace$layout$ensure_layout_67340$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$layout$ensure_layout_67340$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1996$$,$state$jscomp$416$$){var $self__$jscomp$4454$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$416$$,$APP.$cljs$cst$2217$workspace_layout$$,function($stored$$){var $todel$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$layout$presets$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4454$$.name,$APP.$cljs$cst$3779$del$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$),$toadd$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$layout$presets$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$self__$jscomp$4454$$.name,$APP.$cljs$cst$3780$add$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($stored$$,$todel$$),$toadd$$)})});return new $app$main$data$workspace$layout$ensure_layout_67340$$($name$jscomp$322$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$initialize_workspace_layout$$=function($lname$jscomp$1$$){typeof $app$main$data$workspace$initialize_layout_71823$$==="undefined"&&($app$main$data$workspace$initialize_layout_71823$$=function($lname$jscomp$2$$,$meta71824$$){this.$lname$=$lname$jscomp$2$$;this.$meta71824$=$meta71824$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$initialize_layout_71823$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$initialize_layout_71823$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4523$app_DOT_main_DOT_data_DOT_workspace_SLASH_initialize_layout$$},$app$main$data$workspace$initialize_layout_71823$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71825$$,$meta71824__$1$$){return new $app$main$data$workspace$initialize_layout_71823$$(this.$lname$,$meta71824__$1$$)},$app$main$data$workspace$initialize_layout_71823$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71824$},$app$main$data$workspace$initialize_layout_71823$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_layout_71823$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2544$$,$state$jscomp$884$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$884$$,$APP.$cljs$cst$2217$workspace_layout$$,function($p1__71821_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__71821_SHARP_$$)?
$p1__71821_SHARP_$$:$APP.$app$main$data$workspace$layout$default_layout$$}),$APP.$cljs$cst$2196$workspace_global$$,function($p1__71822_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__71822_SHARP_$$)?$p1__71822_SHARP_$$:$APP.$app$main$data$workspace$layout$default_global$$})},$app$main$data$workspace$initialize_layout_71823$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$initialize_layout_71823$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8428$$=this.$lname$;$JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8428$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8428$$)?$APP.$cljs$core$contains_QMARK_$$($APP.$app$main$data$workspace$layout$presets$$,this.$lname$):$JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8428$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1606_and__5023__auto__$jscomp$inline_8428$$)?
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$layout$ensure_layout$$(this.$lname$)):(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$layout$ensure_layout$$($APP.$cljs$cst$3777$layers$$))});return new $app$main$data$workspace$initialize_layout_71823$$($lname$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$variant$same_variant_QMARK_$$=function($components$jscomp$1_variant_ids$$){$components$jscomp$1_variant_ids$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2016$variant_id$$,$components$jscomp$1_variant_ids$$));var $not_blank_QMARK_$$=$APP.$cljs$core$complement$$($APP.$cuerdas$core$blank_QMARK_$$),$and__5023__auto__$jscomp$267$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($components$jscomp$1_variant_ids$$));
return $and__5023__auto__$jscomp$267$$?$not_blank_QMARK_$$($APP.$cljs$core$first$$($components$jscomp$1_variant_ids$$)):$and__5023__auto__$jscomp$267$$};
$app$main$data$workspace$select_single_asset$$=function($file_id$jscomp$289$$,$asset_id$jscomp$17$$,$type$jscomp$539$$){typeof $app$main$data$workspace$select_single_asset_72122$$==="undefined"&&($app$main$data$workspace$select_single_asset_72122$$=function($file_id$jscomp$290$$,$asset_id$jscomp$18$$,$type$jscomp$540$$,$meta72123$$){this.$file_id$=$file_id$jscomp$290$$;this.$asset_id$=$asset_id$jscomp$18$$;this.type=$type$jscomp$540$$;this.$meta72123$=$meta72123$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$select_single_asset_72122$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_single_asset_72122$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4568$app_DOT_main_DOT_data_DOT_workspace_SLASH_select_single_asset$$},$app$main$data$workspace$select_single_asset_72122$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72124$$,$meta72123__$1$$){return new $app$main$data$workspace$select_single_asset_72122$$(this.$file_id$,
this.$asset_id$,this.type,$meta72123__$1$$)},$app$main$data$workspace$select_single_asset_72122$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72123$},$app$main$data$workspace$select_single_asset_72122$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$select_single_asset_72122$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2595$$,$state$jscomp$923$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$923$$,
new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$1938$selected$$,this.$file_id$,this.type],null),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.$asset_id$]))});return new $app$main$data$workspace$select_single_asset_72122$$($file_id$jscomp$289$$,$asset_id$jscomp$17$$,$type$jscomp$539$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$set_selection$$=function($grid_id$jscomp$5$$,$cell_id$jscomp$5$$){typeof $app$main$data$workspace$grid_layout$editor$set_selection_71118$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$set_selection_71118$$=function($grid_id$jscomp$6$$,$cell_id$jscomp$6$$,$meta71119$$){this.$grid_id$=$grid_id$jscomp$6$$;this.$cell_id$=$cell_id$jscomp$6$$;this.$meta71119$=$meta71119$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$grid_layout$editor$set_selection_71118$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$set_selection_71118$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4452$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_set_selection$$},$app$main$data$workspace$grid_layout$editor$set_selection_71118$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71120$$,
$meta71119__$1$$){return new $app$main$data$workspace$grid_layout$editor$set_selection_71118$$(this.$grid_id$,this.$cell_id$,$meta71119__$1$$)},$app$main$data$workspace$grid_layout$editor$set_selection_71118$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71119$},$app$main$data$workspace$grid_layout$editor$set_selection_71118$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$set_selection_71118$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2476$$,$state$jscomp$827$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$827$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$1938$selected$$],null),$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.$cell_id$]))});return new $app$main$data$workspace$grid_layout$editor$set_selection_71118$$($grid_id$jscomp$5$$,$cell_id$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$selection$select_node$$=function($position$jscomp$143$$,$shift_QMARK_$jscomp$22$$){typeof $app$main$data$workspace$path$selection$select_node_69942$$==="undefined"&&($app$main$data$workspace$path$selection$select_node_69942$$=function($position$jscomp$144$$,$shift_QMARK_$jscomp$23$$,$meta69943$$){this.position=$position$jscomp$144$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$23$$;this.$meta69943$=$meta69943$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$selection$select_node_69942$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$select_node_69942$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4309$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_selection_SLASH_select_node$$},$app$main$data$workspace$path$selection$select_node_69942$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69944$$,$meta69943__$1$$){return new $app$main$data$workspace$path$selection$select_node_69942$$(this.position,
this.$shift_QMARK_$,$meta69943__$1$$)},$app$main$data$workspace$path$selection$select_node_69942$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69943$},$app$main$data$workspace$path$selection$select_node_69942$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$selection$select_node_69942$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2342_id$jscomp$687$$,$state$jscomp$724$$){$_$jscomp$2342_id$jscomp$687$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$724$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2207$edition$$);var $selected_points$jscomp$2_selected_points__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$724$$,$APP.$cljs$cst$1937$workspace_local$$),
$APP.$cljs$cst$1940$edit_path$$),$_$jscomp$2342_id$jscomp$687$$),$APP.$cljs$cst$4308$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);var $JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8430$$=this.$shift_QMARK_$;$JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8430$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8430$$)?$APP.$cljs$core$contains_QMARK_$$($selected_points$jscomp$2_selected_points__$1$jscomp$1$$,
this.position):$JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8430$$;$selected_points$jscomp$2_selected_points__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1607_and__5023__auto__$jscomp$inline_8430$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($selected_points$jscomp$2_selected_points__$1$jscomp$1$$,this.position):$APP.$cljs$core$truth_$$(this.$shift_QMARK_$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($selected_points$jscomp$2_selected_points__$1$jscomp$1$$,
this.position):$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.position]);return $_$jscomp$2342_id$jscomp$687$$!=null?$APP.$cljs$core$assoc_in$$($state$jscomp$724$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$2342_id$jscomp$687$$,$APP.$cljs$cst$4308$selected_points$$],null),$selected_points$jscomp$2_selected_points__$1$jscomp$1$$):$state$jscomp$724$$});return new $app$main$data$workspace$path$selection$select_node_69942$$($position$jscomp$143$$,
$shift_QMARK_$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$=function($objects$jscomp$235$$,$focus$jscomp$4$$){return $APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focus$jscomp$4$$),$APP.$rumext$v2$adapt$$($objects$jscomp$235$$)],function(){return $APP.$app$common$files$focus$focus_objects$$($objects$jscomp$235$$,$focus$jscomp$4$$)})};
$app$main$data$workspace$shape_layout$hover_layout_track$$=function($ids$jscomp$234$$,$type$jscomp$529$$,$index$jscomp$361$$,$hover_QMARK_$jscomp$2$$){typeof $app$main$data$workspace$shape_layout$hover_layout_track_71465$$==="undefined"&&($app$main$data$workspace$shape_layout$hover_layout_track_71465$$=function($ids$jscomp$235$$,$type$jscomp$530$$,$index$jscomp$362$$,$hover_QMARK_$jscomp$3$$,$meta71466$$){this.ids=$ids$jscomp$235$$;this.type=$type$jscomp$530$$;this.index=$index$jscomp$362$$;this.$hover_QMARK_$=
$hover_QMARK_$jscomp$3$$;this.$meta71466$=$meta71466$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$hover_layout_track_71465$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$hover_layout_track_71465$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4475$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_hover_layout_track$$},
$app$main$data$workspace$shape_layout$hover_layout_track_71465$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71467$$,$meta71466__$1$$){return new $app$main$data$workspace$shape_layout$hover_layout_track_71465$$(this.ids,this.type,this.index,this.$hover_QMARK_$,$meta71466__$1$$)},$app$main$data$workspace$shape_layout$hover_layout_track_71465$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71466$},$app$main$data$workspace$shape_layout$hover_layout_track_71465$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$hover_layout_track_71465$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2497_highlighted$jscomp$1_objects$jscomp$638_shape$jscomp$740$$,$G__71468__$1_G__71468__$2_state$jscomp$842$$){$_$jscomp$2497_highlighted$jscomp$1_objects$jscomp$638_shape$jscomp$740$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($G__71468__$1_G__71468__$2_state$jscomp$842$$);$_$jscomp$2497_highlighted$jscomp$1_objects$jscomp$638_shape$jscomp$740$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2497_highlighted$jscomp$1_objects$jscomp$638_shape$jscomp$740$$,$APP.$cljs$core$first$$(this.ids));$_$jscomp$2497_highlighted$jscomp$1_objects$jscomp$638_shape$jscomp$740$$=$APP.$cljs$core$truth_$$(this.$hover_QMARK_$)?$APP.$cljs$core$set$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.type,$APP.$cljs$cst$1661$row$$)?$APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2497_highlighted$jscomp$1_objects$jscomp$638_shape$jscomp$740$$,
this.index):$APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2497_highlighted$jscomp$1_objects$jscomp$638_shape$jscomp$740$$,this.index)):null;$G__71468__$1_G__71468__$2_state$jscomp$842$$=$APP.$cljs$core$truth_$$(this.$hover_QMARK_$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__71468__$1_G__71468__$2_state$jscomp$842$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,
$APP.$cljs$core$first$$(this.ids),$APP.$cljs$cst$4476$hover_track$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.type,this.index],null)):$G__71468__$1_G__71468__$2_state$jscomp$842$$;$G__71468__$1_G__71468__$2_state$jscomp$842$$=$APP.$cljs$core$not$$(this.$hover_QMARK_$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__71468__$1_G__71468__$2_state$jscomp$842$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,$APP.$cljs$core$first$$(this.ids),$APP.$cljs$cst$4476$hover_track$$],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$disj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.type,this.index],null)):$G__71468__$1_G__71468__$2_state$jscomp$842$$;
return $APP.$cljs$core$assoc_in$$($G__71468__$1_G__71468__$2_state$jscomp$842$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4366$highlighted$$],null),$_$jscomp$2497_highlighted$jscomp$1_objects$jscomp$638_shape$jscomp$740$$)});return new $app$main$data$workspace$shape_layout$hover_layout_track_71465$$($ids$jscomp$234$$,$type$jscomp$529$$,$index$jscomp$361$$,$hover_QMARK_$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$highlight$clear_search_match_highlight$$=function($match_ids$jscomp$2_match_ids__$1$jscomp$1$$){$match_ids$jscomp$2_match_ids__$1$jscomp$1$$=$APP.$cljs$core$set$$($match_ids$jscomp$2_match_ids__$1$jscomp$1$$);typeof $app$main$data$workspace$highlight$clear_search_match_highlight_70574$$==="undefined"&&($app$main$data$workspace$highlight$clear_search_match_highlight_70574$$=function($match_ids$jscomp$3$$,$meta70575$$){this.$match_ids$=$match_ids$jscomp$3$$;this.$meta70575$=
$meta70575$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$highlight$clear_search_match_highlight_70574$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$clear_search_match_highlight_70574$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4370$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_clear_search_match_highlight$$},$app$main$data$workspace$highlight$clear_search_match_highlight_70574$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70576$$,$meta70575__$1$$){return new $app$main$data$workspace$highlight$clear_search_match_highlight_70574$$(this.$match_ids$,$meta70575__$1$$)},$app$main$data$workspace$highlight$clear_search_match_highlight_70574$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70575$},$app$main$data$workspace$highlight$clear_search_match_highlight_70574$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$clear_search_match_highlight_70574$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2410$$,$state$jscomp$776$$){var $self__$jscomp$5743$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$776$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4366$highlighted$$],null),function($p1__70568_SHARP_$$){return $APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($p1__70568_SHARP_$$)?
$p1__70568_SHARP_$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$self__$jscomp$5743$$.$match_ids$)}),$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$4369$search_match_highlight$$)});return new $app$main$data$workspace$highlight$clear_search_match_highlight_70574$$($match_ids$jscomp$2_match_ids__$1$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$highlight$set_search_match_highlight$$=function($current_id$jscomp$6$$,$match_ids_match_ids__$1$$){$match_ids_match_ids__$1$$=$APP.$cljs$core$set$$($match_ids_match_ids__$1$$);typeof $app$main$data$workspace$highlight$set_search_match_highlight_70554$$==="undefined"&&($app$main$data$workspace$highlight$set_search_match_highlight_70554$$=function($current_id$jscomp$7$$,$match_ids$jscomp$1$$,$meta70555$$){this.$current_id$=$current_id$jscomp$7$$;this.$match_ids$=$match_ids$jscomp$1$$;
this.$meta70555$=$meta70555$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$highlight$set_search_match_highlight_70554$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$set_search_match_highlight_70554$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4368$app_DOT_main_DOT_data_DOT_workspace_DOT_highlight_SLASH_set_search_match_highlight$$},
$app$main$data$workspace$highlight$set_search_match_highlight_70554$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70556$$,$meta70555__$1$$){return new $app$main$data$workspace$highlight$set_search_match_highlight_70554$$(this.$current_id$,this.$match_ids$,$meta70555__$1$$)},$app$main$data$workspace$highlight$set_search_match_highlight_70554$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70555$},$app$main$data$workspace$highlight$set_search_match_highlight_70554$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$highlight$set_search_match_highlight_70554$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2409_highlighted$$,$state$jscomp$775$$){$_$jscomp$2409_highlighted$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$clojure$set$difference$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$775$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4366$highlighted$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.$match_ids$),this.$current_id$);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$775$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4369$search_match_highlight$$],null),this.$current_id$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4366$highlighted$$],null),$_$jscomp$2409_highlighted$$)});return new $app$main$data$workspace$highlight$set_search_match_highlight_70554$$($current_id$jscomp$6$$,$match_ids_match_ids__$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$streams$move_handler_stream$$=function($start_point$jscomp$3$$,$node$jscomp$334$$,$handler$jscomp$39$$,$opposite$jscomp$3$$,$points$jscomp$86_vec__69820$$){var $zoom$jscomp$30$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$2204$zoom$$],null),1),$ranges$jscomp$7$$=
$APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$1$($points$jscomp$86_vec__69820$$),$d_pos$jscomp$1$$=10/$zoom$jscomp$30$$;$points$jscomp$86_vec__69820$$=$app$main$data$workspace$path$streams$get_angle$$($node$jscomp$334$$,$handler$jscomp$39$$,$opposite$jscomp$3$$);var $initial_angle$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($points$jscomp$86_vec__69820$$,0,null);return $APP.$beicon$v2$core$map$$(function($delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$){var $position$jscomp$125$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$,0,null);$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$,1,null);if($APP.$cljs$core$truth_$$($delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$)){$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$=
$APP.$app$common$geom$point$subtract$$($position$jscomp$125$$,$start_point$jscomp$3$$);$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$=$APP.$app$common$geom$point$add$$($handler$jscomp$39$$,$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$);var $rot_sign$jscomp$1_vec__69827$$=$app$main$data$workspace$path$streams$get_angle$$($node$jscomp$334$$,$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$,$opposite$jscomp$3$$),$rot_angle$jscomp$1_rot_handler$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($rot_sign$jscomp$1_vec__69827$$,0,null);$rot_sign$jscomp$1_vec__69827$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($rot_sign$jscomp$1_vec__69827$$,1,null);var $and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$;if($and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$=
$rot_angle$jscomp$1_rot_handler$$!=null)$and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$=$APP.$cljs$cst$4271$alt_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$125$$),$and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$)?
$and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$:180-$initial_angle$jscomp$1$$>.1,$and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$)?180-
$rot_angle$jscomp$1_rot_handler$$<=5:$and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$;$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13512_and__5023__auto____$1$jscomp$inline_13513_or__5025__auto__$jscomp$inline_13514_snap_opposite_angle_QMARK_$$)?($rot_angle$jscomp$1_rot_handler$$=$APP.$app$common$geom$point$rotate$$($delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$,
$node$jscomp$334$$,180-$rot_sign$jscomp$1_vec__69827$$*$rot_angle$jscomp$1_rot_handler$$),$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($rot_angle$jscomp$1_rot_handler$$,$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$)):$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$=$APP.$app$main$snap$get_snap_delta$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$],null),$ranges$jscomp$7$$,$d_pos$jscomp$1$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$position$jscomp$125$$,$APP.$app$common$geom$point$add$$($position$jscomp$125$$,$delta$jscomp$50_handler__$1_p__69823_snap$jscomp$2_snap_toggled$jscomp$1$$)]))}return $position$jscomp$125$$},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$path$streams$snap_toggled_stream$$(),
$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$04$$(function($position$jscomp$126$$,$shift_QMARK_$jscomp$14$$,$alt_QMARK_$jscomp$8$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($position$jscomp$126$$,$APP.$cljs$cst$4270$shift_QMARK_$$,$shift_QMARK_$jscomp$14$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4271$alt_QMARK_$$,$alt_QMARK_$jscomp$8$$]))},$APP.$sub$jscomp$inline_5658$$,$APP.$sub$jscomp$inline_5661$$,$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$path$streams$to_pixel_snap$$,
$APP.$app$main$streams$mouse_position$$))))};
$app$main$data$workspace$path$streams$move_points_stream$$=function($start_point$jscomp$2$$,$selected_points$jscomp$1$$,$points$jscomp$85$$){var $zoom$jscomp$29$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$2204$zoom$$],null),1),$ranges$jscomp$6$$=$APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$85$$,
$selected_points$jscomp$1$$),$d_pos$$=10/$zoom$jscomp$29$$;return $APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$04$$(function($position$jscomp$124$$,$shift_QMARK_$jscomp$13$$,$alt_QMARK_$jscomp$7$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($position$jscomp$124$$,$APP.$cljs$cst$4270$shift_QMARK_$$,$shift_QMARK_$jscomp$13$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4271$alt_QMARK_$$,$alt_QMARK_$jscomp$7$$]))},$APP.$sub$jscomp$inline_5658$$,
$APP.$sub$jscomp$inline_5661$$,$APP.$beicon$v2$core$map$$(function($moved_points_p__69813_snap$jscomp$1_snap_toggled$$){var $position$jscomp$123$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($moved_points_p__69813_snap$jscomp$1_snap_toggled$$,0,null);$moved_points_p__69813_snap$jscomp$1_snap_toggled$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($moved_points_p__69813_snap$jscomp$1_snap_toggled$$,1,null);if($APP.$cljs$core$truth_$$($moved_points_p__69813_snap$jscomp$1_snap_toggled$$)){var $delta$jscomp$49$$=
$APP.$app$common$geom$point$subtract$$($position$jscomp$123$$,$start_point$jscomp$2$$);$moved_points_p__69813_snap$jscomp$1_snap_toggled$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69805_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__69805_SHARP_$$,$delta$jscomp$49$$)},$selected_points$jscomp$1$$);$moved_points_p__69813_snap$jscomp$1_snap_toggled$$=$APP.$app$main$snap$get_snap_delta$$($moved_points_p__69813_snap$jscomp$1_snap_toggled$$,$ranges$jscomp$6$$,$d_pos$$);
return $APP.$app$common$geom$point$add$$($position$jscomp$123$$,$moved_points_p__69813_snap$jscomp$1_snap_toggled$$)}return $position$jscomp$123$$},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$path$streams$snap_toggled_stream$$(),$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$path$streams$to_pixel_snap$$,$APP.$app$main$streams$mouse_position$$))))};
$app$common$attrs$get_text_attrs_multi$$=function($content$jscomp$150_map__55578__$1_p__55577$$,$attrs$jscomp$65_text_node_attrs$$){$content$jscomp$150_map__55578__$1_p__55577$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$150_map__55578__$1_p__55577$$);$content$jscomp$150_map__55578__$1_p__55577$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$150_map__55578__$1_p__55577$$,$APP.$cljs$cst$1642$content$$);var $root_attrs$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($APP.$app$common$types$text$text_valign_attrs$$),
$attrs$jscomp$65_text_node_attrs$$),$paragraph_attrs$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($APP.$app$common$types$text$paragraph_attrs$$),$attrs$jscomp$65_text_node_attrs$$);$attrs$jscomp$65_text_node_attrs$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($APP.$app$common$types$text$text_node_attrs$$),$attrs$jscomp$65_text_node_attrs$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_text_attrs$$,
$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_root_node_QMARK_$$,$content$jscomp$150_map__55578__$1_p__55577$$),$root_attrs$$),$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_paragraph_node_QMARK_$$,$content$jscomp$150_map__55578__$1_p__55577$$),
$paragraph_attrs$$),$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$content$jscomp$150_map__55578__$1_p__55577$$),$attrs$jscomp$65_text_node_attrs$$)]))};
$app$common$types$shape$layout$duplicate_column_at$$=function($G__48140_shape$jscomp$66$$,$objects$jscomp$91$$,$source_index$jscomp$1$$,$target_index$jscomp$1$$,$ids_map$jscomp$4$$){var $value$jscomp$399$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48140_shape$jscomp$66$$,$APP.$cljs$cst$1700$layout_grid_columns$$),$source_index$jscomp$1$$),$adjusted_source$jscomp$1$$=$target_index$jscomp$1$$<=$source_index$jscomp$1$$?$source_index$jscomp$1$$+
1:$source_index$jscomp$1$$;$G__48140_shape$jscomp$66$$=$app$common$types$shape$layout$duplicate_cells$$($APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$remove_cell_areas_after$$($G__48140_shape$jscomp$66$$,$APP.$cljs$cst$216$column$$,$source_index$jscomp$1$$),$value$jscomp$399$$,$target_index$jscomp$1$$),$APP.$cljs$cst$216$column$$,$adjusted_source$jscomp$1$$,$target_index$jscomp$1$$,$ids_map$jscomp$4$$);return $APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48140_shape$jscomp$66$$,$objects$jscomp$91$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48140_shape$jscomp$66$$,$objects$jscomp$91$$)};
$app$common$types$shape$layout$duplicate_row_at$$=function($G__48137_shape$jscomp$65$$,$objects$jscomp$90$$,$source_index$$,$target_index$$,$ids_map$jscomp$3$$){var $value$jscomp$398$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48137_shape$jscomp$65$$,$APP.$cljs$cst$1699$layout_grid_rows$$),$source_index$$),$adjusted_source$$=$target_index$$<=$source_index$$?$source_index$$+1:$source_index$$;$G__48137_shape$jscomp$65$$=$app$common$types$shape$layout$duplicate_cells$$($APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$remove_cell_areas_after$$($G__48137_shape$jscomp$65$$,
$APP.$cljs$cst$1661$row$$,$source_index$$),$value$jscomp$398$$,$target_index$$),$APP.$cljs$cst$1661$row$$,$adjusted_source$$,$target_index$$,$ids_map$jscomp$3$$);return $APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48137_shape$jscomp$65$$,$objects$jscomp$90$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48137_shape$jscomp$65$$,$objects$jscomp$90$$)};
$app$main$data$workspace$interactions$get_target_frame$$=function($from_shape$jscomp$1_state$jscomp$788$$,$position$jscomp$155_target_frame$jscomp$6$$){var $objects$jscomp$618$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($from_shape$jscomp$1_state$jscomp$788$$),$from_frame_id_from_id$jscomp$1$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($from_shape$jscomp$1_state$jscomp$788$$));$from_shape$jscomp$1_state$jscomp$788$$=
$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($from_shape$jscomp$1_state$jscomp$788$$,$from_frame_id_from_id$jscomp$1$$);$from_frame_id_from_id$jscomp$1$$=$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from_shape$jscomp$1_state$jscomp$788$$)?$from_frame_id_from_id$jscomp$1$$:$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($from_shape$jscomp$1_state$jscomp$788$$);$position$jscomp$155_target_frame$jscomp$6$$=$APP.$cljs$core$last$$($APP.$app$common$types$shape_tree$get_frames_by_position$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$618$$,
$position$jscomp$155_target_frame$jscomp$6$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$155_target_frame$jscomp$6$$),$APP.$app$common$uuid$zero$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$155_target_frame$jscomp$6$$),$from_frame_id_from_id$jscomp$1$$)?$position$jscomp$155_target_frame$jscomp$6$$:null};
$app$main$data$workspace$interactions$move_edit_interaction$$=function($_initial_pos$$,$position$jscomp$156$$){typeof $app$main$data$workspace$interactions$move_edit_interaction_70746$$==="undefined"&&($app$main$data$workspace$interactions$move_edit_interaction_70746$$=function($_initial_pos$jscomp$1$$,$position$jscomp$157$$,$meta70747$$){this.$_initial_pos$=$_initial_pos$jscomp$1$$;this.position=$position$jscomp$157$$;this.$meta70747$=$meta70747$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$move_edit_interaction_70746$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$move_edit_interaction_70746$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4383$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_move_edit_interaction$$},$app$main$data$workspace$interactions$move_edit_interaction_70746$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70748$$,$meta70747__$1$$){return new $app$main$data$workspace$interactions$move_edit_interaction_70746$$(this.$_initial_pos$,this.position,$meta70747__$1$$)},$app$main$data$workspace$interactions$move_edit_interaction_70746$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70747$},$app$main$data$workspace$interactions$move_edit_interaction_70746$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$move_edit_interaction_70746$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2424_end_frame$$,$state$jscomp$789$$){$_$jscomp$2424_end_frame$$=$app$main$data$workspace$interactions$get_target_frame$$($state$jscomp$789$$,this.position);return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$789$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4384$draw_interaction_to$$],null),this.position),new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4385$draw_interaction_to_frame$$],null),$_$jscomp$2424_end_frame$$)});return new $app$main$data$workspace$interactions$move_edit_interaction_70746$$($_initial_pos$$,$position$jscomp$156$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$update_colorpicker$$=function($p__71231$$){var $map__71232__$1$$=$APP.$cljs$core$__destructure_map$$($p__71231$$),$gradient$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71232__$1$$,$APP.$cljs$cst$1730$gradient$$);typeof $app$main$data$workspace$colors$update_colorpicker_71233$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_71233$$=function($p__71231$jscomp$1$$,$map__71232$jscomp$1$$,$data$jscomp$385$$,$gradient$jscomp$20$$,
$meta71234$$){this.$p__71231$=$p__71231$jscomp$1$$;this.$map__71232$=$map__71232$jscomp$1$$;this.data=$data$jscomp$385$$;this.gradient=$gradient$jscomp$20$$;this.$meta71234$=$meta71234$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_71233$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_71233$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4247$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker$$},$app$main$data$workspace$colors$update_colorpicker_71233$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71235$$,$meta71234__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_71233$$(this.$p__71231$,this.$map__71232$,this.data,this.gradient,$meta71234__$1$$)},$app$main$data$workspace$colors$update_colorpicker_71233$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71234$},$app$main$data$workspace$colors$update_colorpicker_71233$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_71233$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2282$$,$state$jscomp$660$$){var $self__$jscomp$5319$$=this,$shape_id$jscomp$109$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$660$$));
return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$660$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$31$$){var $current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$=$APP.$cljs$cst$4231$current_color$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$31$$);if($self__$jscomp$5319$$.gradient!=null){$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$=$APP.$cljs$cst$4229$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$31$$);
$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$=$APP.$cljs$core$truth_$$($current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$)?$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$:0;var $new_stops$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$data$workspace$colors$split_color_components$$,$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5319$$.gradient)),$new_gradient$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5319$$.gradient,
$APP.$cljs$cst$1739$stops$$),$APP.$cljs$cst$2554$shape_id$$,$shape_id$jscomp$109$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$31$$),$new_stops$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($state__$1$jscomp$31$$),$new_gradient$$)?$state__$1$jscomp$31$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$31$$,
$APP.$cljs$cst$1740$opacity$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5319$$.data)),$APP.$cljs$cst$4231$current_color$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_stops$$,$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$)),$APP.$cljs$cst$1739$stops$$,$new_stops$$),$APP.$cljs$cst$1730$gradient$$,$new_gradient$$),$APP.$cljs$cst$4229$editing_stop$$,$current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$)}return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$==
null||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5319$$.data),$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$))||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5319$$.data),$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$1_or__5025__auto__$jscomp$inline_13516_stop$jscomp$3$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$31$$,$APP.$cljs$cst$4231$current_color$$,$app$main$data$workspace$colors$split_color_components$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5319$$.data,$APP.$cljs$cst$1730$gradient$$))):$state__$1$jscomp$31$$,$APP.$cljs$cst$4229$editing_stop$$),$APP.$cljs$cst$1730$gradient$$),$APP.$cljs$cst$1739$stops$$)})});return new $app$main$data$workspace$colors$update_colorpicker_71233$$($p__71231$$,$map__71232__$1$$,
$map__71232__$1$$,$gradient$jscomp$19$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$copy_selected_text$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_text_70811$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_text_70811$$=function($meta70812$$){this.$meta70812$=$meta70812$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_text_70811$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_text_70811$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4175$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_text$$},$app$main$data$workspace$clipboard$copy_selected_text_70811$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70813$$,$meta70812__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_text_70811$$($meta70812__$1$$)},$app$main$data$workspace$clipboard$copy_selected_text_70811$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70812$},$app$main$data$workspace$clipboard$copy_selected_text_70811$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_text_70811$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2233_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$,$objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$){$_$jscomp$2233_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$);
$objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$);$_$jscomp$2233_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$getf$$($objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$),
$APP.$app$common$files$helpers$selected_with_children$$($objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$,$_$jscomp$2233_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$)));$_$jscomp$2233_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$_$jscomp$2233_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$);
var $objects__$1$jscomp$22$$=$APP.$app$common$files$helpers$selected_subtree$$($objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$,$_$jscomp$2233_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$);$objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects__$1$jscomp$22$$,
$_$jscomp$2233_selected$jscomp$68_selected__$1$jscomp$6_text_shapes$$));$objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$654_shape$jscomp$676$$){$id$jscomp$654_shape$jscomp$676$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$22$$,$id$jscomp$654_shape$jscomp$676$$);return $APP.$app$common$types$text$content__GT_text$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$654_shape$jscomp$676$$))},
$objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$));return $APP.$app$util$clipboard$to_clipboard$$($objects$jscomp$589_selected__$2_state$jscomp$618_text$jscomp$55$$)});return new $app$main$data$workspace$clipboard$copy_selected_text_70811$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$specialized_panel$open_specialized_panel$$=function(){typeof $app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$==="undefined"&&($app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$=function($type$jscomp$477$$,$meta67550$$){this.type=$type$jscomp$477$$;this.$meta67550$=$meta67550$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3815$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_open_specialized_panel$$},$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67551$$,$meta67550__$1$$){return new $app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$(this.type,
$meta67550__$1$$)},$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67550$},$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2017_objects$jscomp$383_page_id$jscomp$140_selected_shapes$jscomp$3$$,
$state$jscomp$437$$){$_$jscomp$2017_objects$jscomp$383_page_id$jscomp$140_selected_shapes$jscomp$3$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$437$$);$_$jscomp$2017_objects$jscomp$383_page_id$jscomp$140_selected_shapes$jscomp$3$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$437$$,$_$jscomp$2017_objects$jscomp$383_page_id$jscomp$140_selected_shapes$jscomp$3$$);var $selected_ids$jscomp$2$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$437$$);
$_$jscomp$2017_objects$jscomp$383_page_id$jscomp$140_selected_shapes$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2017_objects$jscomp$383_page_id$jscomp$140_selected_shapes$jscomp$3$$),$selected_ids$jscomp$2$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$437$$,$APP.$cljs$cst$2250$specialized_panel$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,this.type,$APP.$cljs$cst$1619$shapes$$,
$_$jscomp$2017_objects$jscomp$383_page_id$jscomp$140_selected_shapes$jscomp$3$$],null))},$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2018$$,$___$1$jscomp$1296$$,$stream$jscomp$43$$){return $APP.$beicon$v2$core$map$$($app$main$data$workspace$specialized_panel$clear_specialized_panel$$,
$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($app$main$data$workspace$specialized_panel$interrupt_QMARK_$$,$stream$jscomp$43$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3816$app_DOT_main_DOT_data_DOT_workspace_DOT_common_SLASH_undo$$),$stream$jscomp$43$$))))});return new $app$main$data$workspace$specialized_panel$open_specialized_panel_67549$$($APP.$cljs$cst$4027$component_swap$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$set_rotation_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$=function($angle$jscomp$30$$,$shapes$jscomp$88$$,$center$jscomp$46$$){typeof $app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$==="undefined"&&($app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$=function($angle$jscomp$31$$,$shapes$jscomp$89$$,$center$jscomp$47$$,$meta69086$$){this.angle=$angle$jscomp$31$$;this.shapes=$shapes$jscomp$89$$;this.$center$=$center$jscomp$47$$;this.$meta69086$=
$meta69086$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3911$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_set_rotation_modifiers$$},$app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69087$$,$meta69086__$1$$){return new $app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$(this.angle,this.shapes,this.$center$,$meta69086__$1$$)},$app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69086$},$app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2058_modif_tree$jscomp$51_objects$jscomp$475$$,$state$jscomp$460$$){var $self__$jscomp$4604$$=this;$_$jscomp$2058_modif_tree$jscomp$51_objects$jscomp$475$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$460$$);var $ids$jscomp$107$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$xf_rotation_shape$$,$self__$jscomp$4604$$.shapes);$_$jscomp$2058_modif_tree$jscomp$51_objects$jscomp$475$$=
$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$build_modif_tree$$($ids$jscomp$107$$,$_$jscomp$2058_modif_tree$jscomp$51_objects$jscomp$475$$,function($shape$jscomp$539$$){return $APP.$app$common$types$modifiers$rotation_modifiers$$($shape$jscomp$539$$,$self__$jscomp$4604$$.$center$,$self__$jscomp$4604$$.angle)}),$_$jscomp$2058_modif_tree$jscomp$51_objects$jscomp$475$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$460$$,
$APP.$cljs$cst$1939$workspace_modifiers$$,$_$jscomp$2058_modif_tree$jscomp$51_objects$jscomp$475$$)});return new $app$main$data$workspace$modifiers$set_rotation_modifiers_69085$$($angle$jscomp$30$$,$shapes$jscomp$88$$,$center$jscomp$46$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$calculate_update_modifiers$$=function($old_modif_tree$jscomp$1$$,$objects__$1$jscomp$19_state$jscomp$453$$,$ignore_constraints$jscomp$13$$,$ignore_snap_pixel$jscomp$2_snap_pixel_QMARK_$jscomp$2$$,$modif_tree$jscomp$32$$){var $objects$jscomp$471$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($objects__$1$jscomp$19_state$jscomp$453$$);$ignore_snap_pixel$jscomp$2_snap_pixel_QMARK_$jscomp$2$$=$APP.$cljs$core$not$$($ignore_snap_pixel$jscomp$2_snap_pixel_QMARK_$jscomp$2$$)&&
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2217$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($objects__$1$jscomp$19_state$jscomp$453$$),$APP.$cljs$cst$2218$snap_pixel_grid$$);$objects__$1$jscomp$19_state$jscomp$453$$=$APP.$app$main$data$workspace$modifiers$apply_text_modifiers$$($objects$jscomp$471$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$19_state$jscomp$453$$,$APP.$cljs$cst$2246$workspace_text_modifier$$));return $APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($old_modif_tree$jscomp$1$$,
$modif_tree$jscomp$32$$,$objects__$1$jscomp$19_state$jscomp$453$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3885$ignore_constraints$$,$ignore_constraints$jscomp$13$$,$APP.$cljs$cst$3886$snap_pixel_QMARK_$$,$ignore_snap_pixel$jscomp$2_snap_pixel_QMARK_$jscomp$2$$],null))};
$app$main$data$workspace$modifiers$update_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$=function($modif_tree$jscomp$35$$){typeof $app$main$data$workspace$modifiers$update_modifiers_68893$$==="undefined"&&($app$main$data$workspace$modifiers$update_modifiers_68893$$=function($modif_tree$jscomp$36$$,$ignore_constraints$jscomp$16$$,$ignore_snap_pixel$jscomp$4$$,$meta68894$$){this.$modif_tree$=$modif_tree$jscomp$36$$;this.$ignore_constraints$=$ignore_constraints$jscomp$16$$;this.$ignore_snap_pixel$=$ignore_snap_pixel$jscomp$4$$;
this.$meta68894$=$meta68894$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$modifiers$update_modifiers_68893$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$update_modifiers_68893$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3897$app_DOT_main_DOT_data_DOT_workspace_DOT_modifiers_SLASH_update_modifiers$$},$app$main$data$workspace$modifiers$update_modifiers_68893$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_68895$$,$meta68894__$1$$){return new $app$main$data$workspace$modifiers$update_modifiers_68893$$(this.$modif_tree$,this.$ignore_constraints$,this.$ignore_snap_pixel$,$meta68894__$1$$)},$app$main$data$workspace$modifiers$update_modifiers_68893$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta68894$},$app$main$data$workspace$modifiers$update_modifiers_68893$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$modifiers$update_modifiers_68893$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2049$$,$state$jscomp$454$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$454$$,$APP.$cljs$cst$1939$workspace_modifiers$$,$app$main$data$workspace$modifiers$calculate_update_modifiers$$,$state$jscomp$454$$,this.$ignore_constraints$,this.$ignore_snap_pixel$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.$modif_tree$]))});return new $app$main$data$workspace$modifiers$update_modifiers_68893$$($modif_tree$jscomp$35$$,!1,!0,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$commit_update_text_modifier$$=function(){typeof $app$main$data$workspace$texts$commit_update_text_modifier_70447$$==="undefined"&&($app$main$data$workspace$texts$commit_update_text_modifier_70447$$=function($meta70448$$){this.$meta70448$=$meta70448$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$commit_update_text_modifier_70447$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$commit_update_text_modifier_70447$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4091$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_update_text_modifier$$},$app$main$data$workspace$texts$commit_update_text_modifier_70447$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70449$$,$meta70448__$1$$){return new $app$main$data$workspace$texts$commit_update_text_modifier_70447$$($meta70448__$1$$)},$app$main$data$workspace$texts$commit_update_text_modifier_70447$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70448$},$app$main$data$workspace$texts$commit_update_text_modifier_70447$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_update_text_modifier_70447$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2199_ids$jscomp$150_modif_tree$jscomp$60$$,$state$jscomp$590$$){$_$jscomp$2199_ids$jscomp$150_modif_tree$jscomp$60$$=$APP.$cljs$cst$4092$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_ids$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$590$$);
$_$jscomp$2199_ids$jscomp$150_modif_tree$jscomp$60$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($_$jscomp$2199_ids$jscomp$150_modif_tree$jscomp$60$$,$APP.$app$common$types$modifiers$reflow$$());return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$update_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2199_ids$jscomp$150_modif_tree$jscomp$60$$))});return new $app$main$data$workspace$texts$commit_update_text_modifier_70447$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$shape$layout$reorder_grid_tracks$$=function($parent$jscomp$148$$,$prop$jscomp$16$$,$from_index$jscomp$3$$,$to_index$jscomp$1$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$148$$,$prop$jscomp$16$$,function($tracks$$){var $tr$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tracks$$,$from_index$jscomp$3$$);return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$app$common$data$vec_without_nils$$($APP.$app$common$data$insert_at_index$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($tracks$$),
$from_index$jscomp$3$$,null),$to_index$jscomp$1$$+1,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,$tr$jscomp$1$$],null)],null))))})};
$app$common$types$shape$layout$reorder_grid_track$$=function($parent$jscomp$150_parent__$1$jscomp$40$$,$G__48173_from_index$jscomp$4$$,$to_index$jscomp$2$$,$move_content_QMARK__move_content_QMARK___$1$$,$tracks_props$$,$prop$jscomp$18$$){var $from_track$jscomp$1$$=$G__48173_from_index$jscomp$4$$+1,$to_track$jscomp$1$$=$to_index$jscomp$2$$<$G__48173_from_index$jscomp$4$$?$to_index$jscomp$2$$+2:$to_index$jscomp$2$$+1;$move_content_QMARK__move_content_QMARK___$1$$=$APP.$cljs$core$truth_$$($move_content_QMARK__move_content_QMARK___$1$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_track$jscomp$1$$,$to_track$jscomp$1$$):$move_content_QMARK__move_content_QMARK___$1$$;$parent$jscomp$150_parent__$1$jscomp$40$$=$APP.$cljs$core$truth_$$($move_content_QMARK__move_content_QMARK___$1$$)?$app$common$types$shape$layout$remove_cell_areas_after$$($app$common$types$shape$layout$remove_cell_areas$$($parent$jscomp$150_parent__$1$jscomp$40$$,$prop$jscomp$18$$,$G__48173_from_index$jscomp$4$$),$prop$jscomp$18$$,$to_index$jscomp$2$$):
$parent$jscomp$150_parent__$1$jscomp$40$$;$G__48173_from_index$jscomp$4$$=$app$common$types$shape$layout$reorder_grid_tracks$$($parent$jscomp$150_parent__$1$jscomp$40$$,$tracks_props$$,$G__48173_from_index$jscomp$4$$,$to_index$jscomp$2$$);return $APP.$cljs$core$truth_$$($move_content_QMARK__move_content_QMARK___$1$$)?$app$common$types$shape$layout$swap_track_content$$($G__48173_from_index$jscomp$4$$,$prop$jscomp$18$$,$from_track$jscomp$1$$,$to_track$jscomp$1$$):$G__48173_from_index$jscomp$4$$};
$cljs$tools$reader$read_dispatch$$=function($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,$pending_forms$$){$_$jscomp$169_temp__5823__auto__$jscomp$21$$=$rdr$jscomp$54$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($APP.$cljs$core$truth_$$($_$jscomp$169_temp__5823__auto__$jscomp$21$$)){var $temp__5823__auto____$1$jscomp$2$$=$cljs$tools$reader$dispatch_macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$dispatch_macros$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$169_temp__5823__auto__$jscomp$21$$):
$cljs$tools$reader$dispatch_macros$$($_$jscomp$169_temp__5823__auto__$jscomp$21$$);if($APP.$cljs$core$truth_$$($temp__5823__auto____$1$jscomp$2$$))return $temp__5823__auto____$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$4$?$temp__5823__auto____$1$jscomp$2$$.$cljs$core$IFn$_invoke$arity$4$($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,$pending_forms$$):$temp__5823__auto____$1$jscomp$2$$($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,
$pending_forms$$);$rdr$jscomp$54$$.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$(null,$_$jscomp$169_temp__5823__auto__$jscomp$21$$);return $cljs$tools$reader$read_tagged$$.$cljs$core$IFn$_invoke$arity$4$?$cljs$tools$reader$read_tagged$$.$cljs$core$IFn$_invoke$arity$4$($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,$pending_forms$$):$cljs$tools$reader$read_tagged$$($rdr$jscomp$54$$,$_$jscomp$169_temp__5823__auto__$jscomp$21$$,$opts$jscomp$58$$,$pending_forms$$)}return $APP.$cljs$tools$reader$impl$errors$throw_eof_at_dispatch$$($rdr$jscomp$54$$)};
$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$=function($rdr$jscomp$57$$,$initch$jscomp$2$$,$base$jscomp$10$$,$length$jscomp$27$$,$exact_QMARK_$$){for(var $i$jscomp$288$$=1,$G__24981_uc$jscomp$1$$=$APP.$cljs$tools$reader$impl$utils$char_code$$($initch$jscomp$2$$,$base$jscomp$10$$);;){if($G__24981_uc$jscomp$1$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit$$($rdr$jscomp$57$$,$initch$jscomp$2$$);if($i$jscomp$288$$!==$length$jscomp$27$$){var $ch$jscomp$30$$=
$rdr$jscomp$57$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null);var $JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$=$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$30$$);$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$||($JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$=
$cljs$tools$reader$macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$macros$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$30$$):$cljs$tools$reader$macros$$($ch$jscomp$30$$),$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$)?$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$:
$ch$jscomp$30$$==null);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$))return $APP.$cljs$core$truth_$$($exact_QMARK_$$)?$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_len$$($rdr$jscomp$57$$,$i$jscomp$288$$,$length$jscomp$27$$):String.fromCharCode($G__24981_uc$jscomp$1$$);$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$=
$APP.$cljs$tools$reader$impl$utils$char_code$$($ch$jscomp$30$$,$base$jscomp$10$$);$rdr$jscomp$57$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$===-1)return $APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_digit$$($rdr$jscomp$57$$,$ch$jscomp$30$$);$G__24981_uc$jscomp$1$$=$JSCompiler_inline_result$jscomp$1613_d$jscomp$102_or__5025__auto__$jscomp$inline_8435_or__5025__auto____$1$jscomp$inline_8436$$+
$G__24981_uc$jscomp$1$$*$base$jscomp$10$$;$i$jscomp$288$$+=1}else return String.fromCharCode($G__24981_uc$jscomp$1$$)}};
$cljs$tools$reader$read_delimited$$=function($kind$jscomp$13$$,$delim$jscomp$1$$,$rdr$jscomp$62$$,$opts$jscomp$63$$,$pending_forms$jscomp$5$$){var $_STAR_read_delim_STAR__orig_val__24610$$=$cljs$tools$reader$_STAR_read_delim_STAR_$$;$cljs$tools$reader$_STAR_read_delim_STAR_$$=!0;try{a:{for(var $vec__24606$jscomp$inline_8443$$=$cljs$tools$reader$starting_line_col_info$$($rdr$jscomp$62$$),$start_line$jscomp$inline_8444$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__24606$jscomp$inline_8443$$,
0,null),$start_column$jscomp$inline_8445$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__24606$jscomp$inline_8443$$,1,null),$delim__$1$jscomp$inline_8446$$=$APP.$cljs$tools$reader$impl$utils$char$0$$($delim$jscomp$1$$),$a$jscomp$inline_8447$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;){var $form$jscomp$inline_8448$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($rdr$jscomp$62$$,
!1,$cljs$tools$reader$READ_EOF$$,$delim__$1$jscomp$inline_8446$$,$opts$jscomp$63$$,$pending_forms$jscomp$5$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$62$$,!1,$cljs$tools$reader$READ_EOF$$,$delim__$1$jscomp$inline_8446$$,$opts$jscomp$63$$,$pending_forms$jscomp$5$$);if($form$jscomp$inline_8448$$===$cljs$tools$reader$READ_FINISHED$$){var $JSCompiler_inline_result$jscomp$1614$$=$APP.$cljs$core$_persistent_BANG_$$($a$jscomp$inline_8447$$);break a}if($form$jscomp$inline_8448$$===$cljs$tools$reader$READ_EOF$$){$JSCompiler_inline_result$jscomp$1614$$=
$APP.$cljs$tools$reader$impl$errors$throw_eof_delimited$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$62$$,$kind$jscomp$13$$,$start_line$jscomp$inline_8444$$,$start_column$jscomp$inline_8445$$,$APP.$cljs$core$count$$($a$jscomp$inline_8447$$));break a}$a$jscomp$inline_8447$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($a$jscomp$inline_8447$$,$form$jscomp$inline_8448$$)}$JSCompiler_inline_result$jscomp$1614$$=void 0}return $JSCompiler_inline_result$jscomp$1614$$}finally{$cljs$tools$reader$_STAR_read_delim_STAR_$$=
$_STAR_read_delim_STAR__orig_val__24610$$}};
$cljs$tools$reader$read_list$$=function($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$,$_$jscomp$170_start_line$jscomp$1$$,$end_line_opts$jscomp$64$$,$end_column_pending_forms$jscomp$6_vec__24619$$){var $start_column$jscomp$1_vec__24616$$=$cljs$tools$reader$starting_line_col_info$$($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$);$_$jscomp$170_start_line$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$1_vec__24616$$,0,
null);$start_column$jscomp$1_vec__24616$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$1_vec__24616$$,1,null);var $JSCompiler_temp_const$jscomp$1615_the_list$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$201$list$$,")",$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$,$end_line_opts$jscomp$64$$,$end_column_pending_forms$jscomp$6_vec__24619$$);$end_column_pending_forms$jscomp$6_vec__24619$$=$cljs$tools$reader$ending_line_col_info$$($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$);
$end_line_opts$jscomp$64$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column_pending_forms$jscomp$6_vec__24619$$,0,null);$end_column_pending_forms$jscomp$6_vec__24619$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column_pending_forms$jscomp$6_vec__24619$$,1,null);$JSCompiler_temp_const$jscomp$1615_the_list$$=$APP.$cljs$core$empty_QMARK_$$($JSCompiler_temp_const$jscomp$1615_the_list$$)?$APP.$cljs$core$List$EMPTY$$:$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$list$$,
$JSCompiler_temp_const$jscomp$1615_the_list$$);if($APP.$cljs$core$truth_$$($_$jscomp$170_start_line$jscomp$1$$)){var $JSCompiler_temp_const$jscomp$1617$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$;$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$);$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$=
$JSCompiler_temp_const$jscomp$1617$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$170_start_line$jscomp$1$$,
$APP.$cljs$cst$216$column$$,$start_column$jscomp$1_vec__24616$$,$APP.$cljs$cst$217$end_line$$,$end_line_opts$jscomp$64$$,$APP.$cljs$cst$218$end_column$$,$end_column_pending_forms$jscomp$6_vec__24619$$],null)]))}else $JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$=null;return $APP.$cljs$core$with_meta$$($JSCompiler_temp_const$jscomp$1615_the_list$$,$JSCompiler_temp$jscomp$1616_rdr$jscomp$63_temp__5825__auto__$jscomp$inline_8450$$)};
$cljs$tools$reader$read_vector$$=function($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$,$_$jscomp$171_start_line$jscomp$2$$,$opts$jscomp$65_the_vector$$,$end_line$jscomp$1_pending_forms$jscomp$7$$){var $start_column$jscomp$2_vec__24629$$=$cljs$tools$reader$starting_line_col_info$$($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$);$_$jscomp$171_start_line$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$2_vec__24629$$,
0,null);$start_column$jscomp$2_vec__24629$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$2_vec__24629$$,1,null);$opts$jscomp$65_the_vector$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$200$vector$$,"]",$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$,$opts$jscomp$65_the_vector$$,$end_line$jscomp$1_pending_forms$jscomp$7$$);var $end_column$jscomp$1_vec__24632$$=$cljs$tools$reader$ending_line_col_info$$($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$);
$end_line$jscomp$1_pending_forms$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$1_vec__24632$$,0,null);$end_column$jscomp$1_vec__24632$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$1_vec__24632$$,1,null);if($APP.$cljs$core$truth_$$($_$jscomp$171_start_line$jscomp$2$$)){var $JSCompiler_temp_const$jscomp$1621$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$;$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$=
$APP.$cljs$tools$reader$reader_types$get_file_name$$($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$);$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$=$JSCompiler_temp_const$jscomp$1621$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$208$file$$,$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$171_start_line$jscomp$2$$,$APP.$cljs$cst$216$column$$,$start_column$jscomp$2_vec__24629$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$1_pending_forms$jscomp$7$$,$APP.$cljs$cst$218$end_column$$,$end_column$jscomp$1_vec__24632$$],null)]))}else $JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$=
null;return $APP.$cljs$core$with_meta$$($opts$jscomp$65_the_vector$$,$JSCompiler_temp$jscomp$1620_rdr$jscomp$64_temp__5825__auto__$jscomp$inline_8452$$)};
$cljs$tools$reader$read_map$$=function($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$,$_$jscomp$172_start_line$jscomp$3$$,$end_line$jscomp$2_opts$jscomp$66$$,$end_column$jscomp$2_pending_forms$jscomp$8_vec__24644$$){var $start_column$jscomp$3_vec__24641$$=$cljs$tools$reader$starting_line_col_info$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$);$_$jscomp$172_start_line$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$3_vec__24641$$,
0,null);$start_column$jscomp$3_vec__24641$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$3_vec__24641$$,1,null);var $JSCompiler_temp_const$jscomp$1624_the_map$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$202$map$$,"}",$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$,$end_line$jscomp$2_opts$jscomp$66$$,$end_column$jscomp$2_pending_forms$jscomp$8_vec__24644$$),$JSCompiler_temp_const$jscomp$1626_map_count$$=$APP.$cljs$core$count$$($JSCompiler_temp_const$jscomp$1624_the_map$$),
$ks$jscomp$19$$=$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$JSCompiler_temp_const$jscomp$1624_the_map$$),$key_set$$=$APP.$cljs$core$set$$($ks$jscomp$19$$);$end_column$jscomp$2_pending_forms$jscomp$8_vec__24644$$=$cljs$tools$reader$ending_line_col_info$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$);$end_line$jscomp$2_opts$jscomp$66$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$2_pending_forms$jscomp$8_vec__24644$$,
0,null);$end_column$jscomp$2_pending_forms$jscomp$8_vec__24644$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$2_pending_forms$jscomp$8_vec__24644$$,1,null);!$APP.$cljs$core$even_QMARK_$$($JSCompiler_temp_const$jscomp$1626_map_count$$)&&$APP.$cljs$tools$reader$impl$errors$throw_odd_map$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$,$_$jscomp$172_start_line$jscomp$3$$,$start_column$jscomp$3_vec__24641$$,$JSCompiler_temp_const$jscomp$1624_the_map$$);
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($key_set$$),$APP.$cljs$core$count$$($ks$jscomp$19$$))||$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$,$APP.$cljs$cst$202$map$$,$ks$jscomp$19$$);$JSCompiler_temp_const$jscomp$1624_the_map$$=$JSCompiler_temp_const$jscomp$1626_map_count$$<=2*$APP.$cljs$core$PersistentArrayMap$HASHMAP_THRESHOLD$$?$APP.$cljs$core$PersistentArrayMap$fromArray$$($APP.$cljs$core$to_array$$($JSCompiler_temp_const$jscomp$1624_the_map$$),
!0,!0):$APP.$cljs$core$PersistentHashMap$fromArray$$($APP.$cljs$core$to_array$$($JSCompiler_temp_const$jscomp$1624_the_map$$));$APP.$cljs$core$truth_$$($_$jscomp$172_start_line$jscomp$3$$)?($JSCompiler_temp_const$jscomp$1626_map_count$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$),
$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$=$JSCompiler_temp_const$jscomp$1626_map_count$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$],null):null,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$172_start_line$jscomp$3$$,$APP.$cljs$cst$216$column$$,$start_column$jscomp$3_vec__24641$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$2_opts$jscomp$66$$,$APP.$cljs$cst$218$end_column$$,$end_column$jscomp$2_pending_forms$jscomp$8_vec__24644$$],null)]))):$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$=null;return $APP.$cljs$core$with_meta$$($JSCompiler_temp_const$jscomp$1624_the_map$$,
$JSCompiler_temp$jscomp$1625_rdr$jscomp$65_temp__5825__auto__$jscomp$inline_8454$$)};
$cljs$tools$reader$read_number$$=function($rdr$jscomp$66$$,$initch$jscomp$3$$){for(var $sb$jscomp$13$$=function(){var $G__24656$$=new $APP.$goog$string$StringBuffer$$;$G__24656$$.append($initch$jscomp$3$$);return $G__24656$$}(),$ch$jscomp$32$$=$rdr$jscomp$66$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);;){if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$=$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$32$$);
if($or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$)return $or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$;$or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$=$cljs$tools$reader$macros$$.$cljs$core$IFn$_invoke$arity$1$?$cljs$tools$reader$macros$$.$cljs$core$IFn$_invoke$arity$1$($ch$jscomp$32$$):$cljs$tools$reader$macros$$($ch$jscomp$32$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$)?$or__5025__auto__$jscomp$53_or__5025__auto____$1$jscomp$14$$:
$ch$jscomp$32$$==null}())){var $G__25032_s$jscomp$170$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$13$$);$ch$jscomp$32$$!=null&&$rdr$jscomp$66$$.$cljs$tools$reader$reader_types$IPushbackReader$unread$arity$2$(null,$ch$jscomp$32$$);var $G__25033_or__5025__auto__$jscomp$52$$=$APP.$cljs$tools$reader$impl$commons$match_number$$($G__25032_s$jscomp$170$$);return $APP.$cljs$core$truth_$$($G__25033_or__5025__auto__$jscomp$52$$)?$G__25033_or__5025__auto__$jscomp$52$$:$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$66$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid number: ",$G__25032_s$jscomp$170$$,"."]))}$G__25032_s$jscomp$170$$=function(){var $G__24659$$=$sb$jscomp$13$$;$G__24659$$.append($ch$jscomp$32$$);return $G__24659$$}();$G__25033_or__5025__auto__$jscomp$52$$=$rdr$jscomp$66$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);$sb$jscomp$13$$=$G__25032_s$jscomp$170$$;$ch$jscomp$32$$=$G__25033_or__5025__auto__$jscomp$52$$}};
$cljs$tools$reader$escape_char$$=function($rdr$jscomp$67$$){var $ch$jscomp$33_ch__$1$jscomp$3$$=$rdr$jscomp$67$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);switch($ch$jscomp$33_ch__$1$jscomp$3$$){case "t":return"\t";case "r":return"\r";case "n":return"\n";case "\\":return"\\";case '"':return'"';case "b":return"\b";case "f":return"\f";case "u":return $ch$jscomp$33_ch__$1$jscomp$3$$=$rdr$jscomp$67$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null),-1===parseInt($ch$jscomp$33_ch__$1$jscomp$3$$|
0,16)?$APP.$cljs$tools$reader$impl$errors$throw_invalid_unicode_escape$$($rdr$jscomp$67$$,$ch$jscomp$33_ch__$1$jscomp$3$$):$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$67$$,$ch$jscomp$33_ch__$1$jscomp$3$$,16,4,!0);default:return $APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($ch$jscomp$33_ch__$1$jscomp$3$$)?($ch$jscomp$33_ch__$1$jscomp$3$$=$cljs$tools$reader$read_unicode_char$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$67$$,$ch$jscomp$33_ch__$1$jscomp$3$$,
8,3,!1),($ch$jscomp$33_ch__$1$jscomp$3$$|0)>255?$APP.$cljs$tools$reader$impl$errors$throw_bad_octal_number$$($rdr$jscomp$67$$):$ch$jscomp$33_ch__$1$jscomp$3$$):$APP.$cljs$tools$reader$impl$errors$throw_bad_escape_char$$($rdr$jscomp$67$$,$ch$jscomp$33_ch__$1$jscomp$3$$)}};
$cljs$tools$reader$read_string_STAR_$$=function($reader$jscomp$34$$){for(var $sb$jscomp$15$$=new $APP.$goog$string$StringBuffer$$,$ch$jscomp$34$$=$reader$jscomp$34$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);;){if($ch$jscomp$34$$==null)return $APP.$cljs$tools$reader$impl$errors$throw_eof_reading$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($reader$jscomp$34$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(['"',$sb$jscomp$15$$]));switch($ch$jscomp$34$$){case "\\":var $G__25056_G__25058$$=
function(){var $G__24667$$=$sb$jscomp$15$$;$G__24667$$.append($cljs$tools$reader$escape_char$$($reader$jscomp$34$$));return $G__24667$$}(),$G__25057_G__25059$$=$reader$jscomp$34$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);$sb$jscomp$15$$=$G__25056_G__25058$$;$ch$jscomp$34$$=$G__25057_G__25059$$;continue;case '"':return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb$jscomp$15$$);default:$G__25056_G__25058$$=function(){var $G__24668$$=$sb$jscomp$15$$;$G__24668$$.append($ch$jscomp$34$$);
return $G__24668$$}();$G__25057_G__25059$$=$reader$jscomp$34$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);$sb$jscomp$15$$=$G__25056_G__25058$$;$ch$jscomp$34$$=$G__25057_G__25059$$;continue}break}};
$cljs$tools$reader$wrapping_reader$$=function($sym$jscomp$16$$){return function($rdr$jscomp$70$$,$_$jscomp$174$$,$opts$jscomp$69$$,$pending_forms$jscomp$11$$){return new $APP.$cljs$core$List$$(null,$sym$jscomp$16$$,new $APP.$cljs$core$List$$(null,$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$70$$,!0,null,$opts$jscomp$69$$,$pending_forms$jscomp$11$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$70$$,
!0,null,$opts$jscomp$69$$,$pending_forms$jscomp$11$$),null,1,null),2,null)}};
$cljs$tools$reader$read_meta$$=function($m__$1$jscomp$2_rdr$jscomp$71$$,$_$jscomp$175_line$jscomp$18$$,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$){var $column$jscomp$8_vec__24707$$=$cljs$tools$reader$starting_line_col_info$$($m__$1$jscomp$2_rdr$jscomp$71$$);$_$jscomp$175_line$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$8_vec__24707$$,0,null);$column$jscomp$8_vec__24707$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$8_vec__24707$$,
1,null);var $m$jscomp$79$$=$APP.$cljs$tools$reader$impl$utils$desugar_meta$$($cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($m__$1$jscomp$2_rdr$jscomp$71$$,!0,null,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$):$cljs$tools$reader$read_STAR_$$($m__$1$jscomp$2_rdr$jscomp$71$$,!0,null,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$));$APP.$cljs$core$map_QMARK_$$($m$jscomp$79$$)||$APP.$cljs$tools$reader$impl$errors$throw_bad_metadata$$($m__$1$jscomp$2_rdr$jscomp$71$$,
$m$jscomp$79$$);$o$jscomp$133_opts$jscomp$70$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($m__$1$jscomp$2_rdr$jscomp$71$$,!0,null,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$):$cljs$tools$reader$read_STAR_$$($m__$1$jscomp$2_rdr$jscomp$71$$,!0,null,$o$jscomp$133_opts$jscomp$70$$,$pending_forms$jscomp$12$$);return $o$jscomp$133_opts$jscomp$70$$!=null&&($o$jscomp$133_opts$jscomp$70$$.$cljs$lang$protocol_mask$partition0$$&
131072||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$133_opts$jscomp$70$$.$cljs$core$IMeta$$)?($m__$1$jscomp$2_rdr$jscomp$71$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($_$jscomp$175_line$jscomp$18$$)?$APP.$cljs$core$seq_QMARK_$$($o$jscomp$133_opts$jscomp$70$$):$_$jscomp$175_line$jscomp$18$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($m$jscomp$79$$,$APP.$cljs$cst$209$line$$,$_$jscomp$175_line$jscomp$18$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$216$column$$,
$column$jscomp$8_vec__24707$$])):$m$jscomp$79$$,$o$jscomp$133_opts$jscomp$70$$!=null&&($o$jscomp$133_opts$jscomp$70$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$o$jscomp$133_opts$jscomp$70$$.$cljs$core$IWithMeta$$)?$APP.$cljs$core$with_meta$$($o$jscomp$133_opts$jscomp$70$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$meta$$($o$jscomp$133_opts$jscomp$70$$),$m__$1$jscomp$2_rdr$jscomp$71$$]))):
$o$jscomp$133_opts$jscomp$70$$.$meta$=$m__$1$jscomp$2_rdr$jscomp$71$$):$APP.$cljs$tools$reader$impl$errors$throw_bad_metadata_target$$($m__$1$jscomp$2_rdr$jscomp$71$$,$o$jscomp$133_opts$jscomp$70$$)};
$cljs$tools$reader$read_set$$=function($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$,$_$jscomp$176_start_line$jscomp$4$$,$opts$jscomp$71_the_set$$,$end_line$jscomp$4_pending_forms$jscomp$13$$){var $start_column$jscomp$4_start_column__$1_vec__24717$$=$cljs$tools$reader$starting_line_col_info$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$);$_$jscomp$176_start_line$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$4_start_column__$1_vec__24717$$,
0,null);$start_column$jscomp$4_start_column__$1_vec__24717$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$4_start_column__$1_vec__24717$$,1,null);$start_column$jscomp$4_start_column__$1_vec__24717$$=$APP.$cljs$core$truth_$$($start_column$jscomp$4_start_column__$1_vec__24717$$)?$start_column$jscomp$4_start_column__$1_vec__24717$$-1|0:null;var $JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$203$set$$,"}",$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$,
$opts$jscomp$71_the_set$$,$end_line$jscomp$4_pending_forms$jscomp$13$$);$opts$jscomp$71_the_set$$=$APP.$cljs$core$set$$($JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$);var $end_column$jscomp$4_vec__24720$$=$cljs$tools$reader$ending_line_col_info$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$);$end_line$jscomp$4_pending_forms$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$4_vec__24720$$,0,null);$end_column$jscomp$4_vec__24720$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$4_vec__24720$$,1,null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$),$APP.$cljs$core$count$$($opts$jscomp$71_the_set$$))||$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$,
$APP.$cljs$cst$203$set$$,$JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$)]));$APP.$cljs$core$truth_$$($_$jscomp$176_start_line$jscomp$4$$)?($JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$=$APP.$cljs$tools$reader$reader_types$get_file_name$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$),$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$=
$JSCompiler_temp_const$jscomp$1630_coll$jscomp$821$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$],null):null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$176_start_line$jscomp$4$$,
$APP.$cljs$cst$216$column$$,$start_column$jscomp$4_start_column__$1_vec__24717$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$4_pending_forms$jscomp$13$$,$APP.$cljs$cst$218$end_column$$,$end_column$jscomp$4_vec__24720$$],null)]))):$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$=null;return $APP.$cljs$core$with_meta$$($opts$jscomp$71_the_set$$,$JSCompiler_temp$jscomp$1629_rdr$jscomp$72_temp__5825__auto__$jscomp$inline_8456$$)};
$cljs$tools$reader$read_discard$$=function($rdr$jscomp$73$$,$_$jscomp$177$$,$opts$jscomp$72$$,$pending_forms$jscomp$14$$){$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$73$$,!0,null,$opts$jscomp$72$$,$pending_forms$jscomp$14$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$73$$,!0,null,$opts$jscomp$72$$,$pending_forms$jscomp$14$$);return $rdr$jscomp$73$$};
$cljs$tools$reader$read_symbolic_value$$=function($rdr$jscomp$74$$,$_$jscomp$178_sym$jscomp$17$$,$opts$jscomp$73$$,$pending_forms$jscomp$15$$){$_$jscomp$178_sym$jscomp$17$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$74$$,!0,null,$opts$jscomp$73$$,$pending_forms$jscomp$15$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$74$$,!0,null,$opts$jscomp$73$$,$pending_forms$jscomp$15$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$222$NaN$$,
$_$jscomp$178_sym$jscomp$17$$)?Number.NaN:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$223$_Inf$$,$_$jscomp$178_sym$jscomp$17$$)?Number.NEGATIVE_INFINITY:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$224$Inf$$,$_$jscomp$178_sym$jscomp$17$$)?Number.POSITIVE_INFINITY:$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$74$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["Invalid token: ##",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$178_sym$jscomp$17$$)].join("")]))};
$cljs$tools$reader$read_suppress$$=function($first_line$jscomp$2$$,$rdr$jscomp$79$$,$opts$jscomp$75$$,$pending_forms$jscomp$16$$){var $_STAR_suppress_read_STAR__orig_val__24736$$=$cljs$tools$reader$_STAR_suppress_read_STAR_$$;$cljs$tools$reader$_STAR_suppress_read_STAR_$$=!0;try{var $form$jscomp$14$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($rdr$jscomp$79$$,!1,$cljs$tools$reader$READ_EOF$$,")",$opts$jscomp$75$$,
$pending_forms$jscomp$16$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$79$$,!1,$cljs$tools$reader$READ_EOF$$,")",$opts$jscomp$75$$,$pending_forms$jscomp$16$$);$cljs$tools$reader$check_eof_error$$($form$jscomp$14$$,$rdr$jscomp$79$$,$first_line$jscomp$2$$);return $form$jscomp$14$$===$cljs$tools$reader$READ_FINISHED$$?$cljs$tools$reader$READ_FINISHED$$:null}finally{$cljs$tools$reader$_STAR_suppress_read_STAR_$$=$_STAR_suppress_read_STAR__orig_val__24736$$}};
$cljs$tools$reader$read_cond_delimited$$=function($rdr$jscomp$81$$,$elementsToAdd$jscomp$inline_13527_splicing$$,$opts$jscomp$77_result$jscomp$80$$,$pending_forms$jscomp$18$$){var $first_line$jscomp$4$$=$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($rdr$jscomp$81$$)?$APP.$cljs$tools$reader$reader_types$get_line_number$$($rdr$jscomp$81$$):-1;a:{for(var $G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$=
$cljs$tools$reader$NO_MATCH$$,$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$=null;;)if($G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$===$cljs$tools$reader$NO_MATCH$$){$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$=
$first_line$jscomp$4$$;$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$=$rdr$jscomp$81$$;var $G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$=$opts$jscomp$77_result$jscomp$80$$,$pending_forms$jscomp$inline_13521$$=$pending_forms$jscomp$18$$,$feature$jscomp$inline_13522_feature$jscomp$inline_14854$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,
!1,$cljs$tools$reader$READ_EOF$$,")",$G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$,$pending_forms$jscomp$inline_13521$$):$cljs$tools$reader$read_STAR_$$($G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,!1,$cljs$tools$reader$READ_EOF$$,")",$G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$,$pending_forms$jscomp$inline_13521$$);$cljs$tools$reader$check_eof_error$$($feature$jscomp$inline_13522_feature$jscomp$inline_14854$$,$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,
$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($feature$jscomp$inline_13522_feature$jscomp$inline_14854$$,$cljs$tools$reader$READ_FINISHED$$))$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$=
$cljs$tools$reader$READ_FINISHED$$;else{var $rdr$jscomp$inline_14850_rdr$jscomp$inline_14853$$=$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,$form$jscomp$inline_14851_opts$jscomp$inline_14855$$=$feature$jscomp$inline_13522_feature$jscomp$inline_14854$$;$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$tools$reader$RESERVED_FEATURES$$,$form$jscomp$inline_14851_opts$jscomp$inline_14855$$))&&$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$inline_14850_rdr$jscomp$inline_14853$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Feature name ",$form$jscomp$inline_14851_opts$jscomp$inline_14855$$," is reserved"]));$rdr$jscomp$inline_14850_rdr$jscomp$inline_14853$$=$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$;$form$jscomp$inline_14851_opts$jscomp$inline_14855$$=$G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$;($feature$jscomp$inline_13522_feature$jscomp$inline_14854$$ instanceof $APP.$cljs$core$Keyword$$?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,$feature$jscomp$inline_13522_feature$jscomp$inline_14854$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$inline_14851_opts$jscomp$inline_14855$$,$APP.$cljs$cst$227$features$$),$feature$jscomp$inline_13522_feature$jscomp$inline_14854$$):$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$inline_14850_rdr$jscomp$inline_14853$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Feature should be a keyword: ",$feature$jscomp$inline_13522_feature$jscomp$inline_14854$$])))?($G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,!1,$cljs$tools$reader$READ_EOF$$,")",$G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$,
$pending_forms$jscomp$inline_13521$$):$cljs$tools$reader$read_STAR_$$($G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,!1,$cljs$tools$reader$READ_EOF$$,")",$G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$,$pending_forms$jscomp$inline_13521$$),$cljs$tools$reader$check_eof_error$$($G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$,$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,
$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$),$G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$===$cljs$tools$reader$READ_FINISHED$$&&($G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$<0?$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["read-cond requires an even number of forms"])):$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["read-cond starting on line ",$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$,
" requires an even number of forms"]))),$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$=$G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$):($G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$=$cljs$tools$reader$read_suppress$$($G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$,
$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$,$G__24765$jscomp$inline_13523_opts$jscomp$inline_13520$$,$pending_forms$jscomp$inline_13521$$),$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$=$APP.$cljs$core$truth_$$($G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$)?
$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$:$cljs$tools$reader$NO_MATCH$$)}if($G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$===$cljs$tools$reader$READ_FINISHED$$){$opts$jscomp$77_result$jscomp$80$$=$cljs$tools$reader$READ_FINISHED$$;
break a}$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$=null}else if($G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$!==$cljs$tools$reader$READ_FINISHED$$)$G__25182$jscomp$inline_8462_finished$jscomp$inline_8459_rdr$jscomp$inline_13519_rdr$jscomp$inline_14858$$=$cljs$tools$reader$read_suppress$$($first_line$jscomp$4$$,$rdr$jscomp$81$$,$opts$jscomp$77_result$jscomp$80$$,$pending_forms$jscomp$18$$);
else{$opts$jscomp$77_result$jscomp$80$$=$G__25181$jscomp$inline_8461_first_line$jscomp$inline_13518_first_line$jscomp$inline_14859_match$jscomp$inline_8460_matched$jscomp$inline_8458_or__5025__auto__$jscomp$inline_13524$$;break a}$opts$jscomp$77_result$jscomp$80$$=void 0}return $opts$jscomp$77_result$jscomp$80$$===$cljs$tools$reader$READ_FINISHED$$?$rdr$jscomp$81$$:$APP.$cljs$core$truth_$$($elementsToAdd$jscomp$inline_13527_splicing$$)?$opts$jscomp$77_result$jscomp$80$$!=null&&($opts$jscomp$77_result$jscomp$80$$.$cljs$lang$protocol_mask$partition0$$&
16777216||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$opts$jscomp$77_result$jscomp$80$$.$cljs$core$ISequential$$)?($elementsToAdd$jscomp$inline_13527_splicing$$=$APP.$cljs$core$to_array$$($opts$jscomp$77_result$jscomp$80$$),$APP.$goog$partial$$($module$contents$goog$array_splice$$,$pending_forms$jscomp$18$$,0,0).apply(null,$elementsToAdd$jscomp$inline_13527_splicing$$),$rdr$jscomp$81$$):$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$81$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Spliced form list in read-cond-splicing must implement ISequential"])):
$opts$jscomp$77_result$jscomp$80$$};
$cljs$tools$reader$read_cond$$=function($rdr$jscomp$82$$,$_$jscomp$179_splicing$jscomp$1$$,$opts$jscomp$78$$,$pending_forms$jscomp$19$$){if($APP.$cljs$core$not$$(function(){if($APP.$cljs$core$truth_$$($opts$jscomp$78$$)){var $G__24805$$=$APP.$cljs$cst$228$read_cond$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$78$$),$fexpr__24804$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$229$preserve$$,null,$APP.$cljs$cst$230$allow$$,null],null),
null);return $fexpr__24804$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__24804$$.$cljs$core$IFn$_invoke$arity$1$($G__24805$$):$fexpr__24804$$($G__24805$$)}return $opts$jscomp$78$$}()))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Conditional read not allowed",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$231$runtime_exception$$],null));var $ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$=$rdr$jscomp$82$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);
if($APP.$cljs$core$truth_$$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$))if($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$=($_$jscomp$179_splicing$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,"@"))?$rdr$jscomp$82$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null):$ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,
$_$jscomp$179_splicing$jscomp$1$$&&($APP.$cljs$core$truth_$$($cljs$tools$reader$_STAR_read_delim_STAR_$$)||$APP.$cljs$tools$reader$impl$errors$reader_error$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($rdr$jscomp$82$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["cond-splice not in list"]))),$ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$=$APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$)?
$APP.$cljs$tools$reader$impl$commons$read_past$$($rdr$jscomp$82$$):$ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,$APP.$cljs$core$truth_$$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$)){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,"("))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("read-cond body must be a list",new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$231$runtime_exception$$],null));var $_STAR_suppress_read_STAR__orig_val__24817$$=$cljs$tools$reader$_STAR_suppress_read_STAR_$$;$cljs$tools$reader$_STAR_suppress_read_STAR_$$=function(){var $or__5025__auto__$jscomp$56$$=$cljs$tools$reader$_STAR_suppress_read_STAR_$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$56$$)?$or__5025__auto__$jscomp$56$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$229$preserve$$,$APP.$cljs$cst$228$read_cond$$.$cljs$core$IFn$_invoke$arity$1$($opts$jscomp$78$$))}();
try{return $APP.$cljs$core$truth_$$($cljs$tools$reader$_STAR_suppress_read_STAR_$$)?$cljs$tools$reader$impl$utils$reader_conditional$$($cljs$tools$reader$read_list$$($rdr$jscomp$82$$,$ch__$1$jscomp$4_temp__5823__auto__$jscomp$23_temp__5823__auto____$1$jscomp$3$$,$opts$jscomp$78$$,$pending_forms$jscomp$19$$),$_$jscomp$179_splicing$jscomp$1$$):$cljs$tools$reader$read_cond_delimited$$($rdr$jscomp$82$$,$_$jscomp$179_splicing$jscomp$1$$,$opts$jscomp$78$$,$pending_forms$jscomp$19$$)}finally{$cljs$tools$reader$_STAR_suppress_read_STAR_$$=
$_STAR_suppress_read_STAR__orig_val__24817$$}}else return $APP.$cljs$tools$reader$impl$errors$throw_eof_in_character$$($rdr$jscomp$82$$);else return $APP.$cljs$tools$reader$impl$errors$throw_eof_in_character$$($rdr$jscomp$82$$)};
$cljs$tools$reader$read_fn$$=function($i$jscomp$inline_14863_rdr$jscomp$83$$,$_$jscomp$180_arg_env_orig_val__24835$$,$G__25198$jscomp$inline_14865_opts$jscomp$79$$,$JSCompiler_temp_const$jscomp$inline_14866_pending_forms$jscomp$20$$){if($APP.$cljs$core$truth_$$($cljs$tools$reader$arg_env$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Nested #()s are not allowed",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],null));
$_$jscomp$180_arg_env_orig_val__24835$$=$cljs$tools$reader$arg_env$$;$cljs$tools$reader$arg_env$$=$cljs$core$sorted_map$$();try{$APP.$cljs$tools$reader$reader_types$unread$$($i$jscomp$inline_14863_rdr$jscomp$83$$,"(");var $form$jscomp$15$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($i$jscomp$inline_14863_rdr$jscomp$83$$,!0,null,$G__25198$jscomp$inline_14865_opts$jscomp$79$$,$JSCompiler_temp_const$jscomp$inline_14866_pending_forms$jscomp$20$$):
$cljs$tools$reader$read_STAR_$$($i$jscomp$inline_14863_rdr$jscomp$83$$,!0,null,$G__25198$jscomp$inline_14865_opts$jscomp$79$$,$JSCompiler_temp_const$jscomp$inline_14866_pending_forms$jscomp$20$$);var $JSCompiler_temp_const$jscomp$inline_14868_rargs$$=$APP.$cljs$core$_rseq$$($cljs$tools$reader$arg_env$$);if($JSCompiler_temp_const$jscomp$inline_14868_rargs$$){var $higharg$jscomp$inline_14861$$=$APP.$cljs$core$key$$($APP.$cljs$core$first$$($JSCompiler_temp_const$jscomp$inline_14868_rargs$$));a:{$i$jscomp$inline_14863_rdr$jscomp$83$$=
1;for(var $args$jscomp$inline_14864$$=$APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$);;){if($i$jscomp$inline_14863_rdr$jscomp$83$$>$higharg$jscomp$inline_14861$$){var $args$jscomp$inline_14862$$=$APP.$cljs$core$_persistent_BANG_$$($args$jscomp$inline_14864$$);break a}$G__25198$jscomp$inline_14865_opts$jscomp$79$$=$i$jscomp$inline_14863_rdr$jscomp$83$$+1;$JSCompiler_temp_const$jscomp$inline_14866_pending_forms$jscomp$20$$=$APP.$cljs$core$conj_BANG_$$;var $JSCompiler_temp_const$jscomp$inline_14867$$=
$JSCompiler_temp_const$jscomp$inline_14866_pending_forms$jscomp$20$$.$cljs$core$IFn$_invoke$arity$2$;$JSCompiler_temp_const$jscomp$inline_14868_rargs$$=$args$jscomp$inline_14864$$;var $or__5025__auto__$jscomp$inline_14870$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cljs$tools$reader$arg_env$$,$i$jscomp$inline_14863_rdr$jscomp$83$$);var $JSCompiler_inline_result$jscomp$inline_14869$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_14870$$)?$or__5025__auto__$jscomp$inline_14870$$:
$cljs$tools$reader$garg$$($i$jscomp$inline_14863_rdr$jscomp$83$$);var $G__25199$jscomp$inline_14871$$=$JSCompiler_temp_const$jscomp$inline_14867$$.call($JSCompiler_temp_const$jscomp$inline_14866_pending_forms$jscomp$20$$,$JSCompiler_temp_const$jscomp$inline_14868_rargs$$,$JSCompiler_inline_result$jscomp$inline_14869$$);$i$jscomp$inline_14863_rdr$jscomp$83$$=$G__25198$jscomp$inline_14865_opts$jscomp$79$$;$args$jscomp$inline_14864$$=$G__25199$jscomp$inline_14871$$}$args$jscomp$inline_14862$$=void 0}var $JSCompiler_temp$jscomp$14356$$=
$APP.$cljs$core$truth_$$($cljs$tools$reader$arg_env$$.call(null,-1))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($args$jscomp$inline_14862$$,$APP.$cljs$cst$148$_AMPERSAND_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$tools$reader$arg_env$$.call(null,-1)])):$args$jscomp$inline_14862$$}else $JSCompiler_temp$jscomp$14356$$=$APP.$cljs$core$PersistentVector$EMPTY$$;return new $APP.$cljs$core$List$$(null,$APP.$cljs$cst$162$fn_STAR_$$,new $APP.$cljs$core$List$$(null,
$JSCompiler_temp$jscomp$14356$$,new $APP.$cljs$core$List$$(null,$form$jscomp$15$$,null,1,null),2,null),3,null)}finally{$cljs$tools$reader$arg_env$$=$_$jscomp$180_arg_env_orig_val__24835$$}};
$cljs$tools$reader$read_arg$$=function($n$jscomp$176_rdr$jscomp$84$$,$ch$jscomp$37_pct$$,$opts$jscomp$80$$,$pending_forms$jscomp$21$$){if($cljs$tools$reader$arg_env$$==null)return $cljs$tools$reader$read_symbol$$($n$jscomp$176_rdr$jscomp$84$$,$ch$jscomp$37_pct$$);$ch$jscomp$37_pct$$=$n$jscomp$176_rdr$jscomp$84$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null);if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$37_pct$$)||$cljs$tools$reader$macro_terminating_QMARK_$$($ch$jscomp$37_pct$$)||
$ch$jscomp$37_pct$$==null)return $cljs$tools$reader$register_arg$$(1);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ch$jscomp$37_pct$$,"\x26"))return $n$jscomp$176_rdr$jscomp$84$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null),$cljs$tools$reader$register_arg$$(-1);$n$jscomp$176_rdr$jscomp$84$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($n$jscomp$176_rdr$jscomp$84$$,!0,null,$opts$jscomp$80$$,
$pending_forms$jscomp$21$$):$cljs$tools$reader$read_STAR_$$($n$jscomp$176_rdr$jscomp$84$$,!0,null,$opts$jscomp$80$$,$pending_forms$jscomp$21$$);if($APP.$cljs$core$integer_QMARK_$$($n$jscomp$176_rdr$jscomp$84$$))return $cljs$tools$reader$register_arg$$($n$jscomp$176_rdr$jscomp$84$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("Arg literal must be %, %\x26 or %integer",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$232$illegal_state$$],
null));};
$cljs$tools$reader$read_unquote$$=function($JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$,$JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$,$opts$jscomp$81$$,$pending_forms$jscomp$22$$){$JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$=$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null);$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("@",
$JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$)?($JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$=$cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$233$clojure_DOT_core_SLASH_unquote_splicing$$),$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null),$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$=$JSCompiler_temp_const$jscomp$1639_comma_temp__5823__auto__$jscomp$25$$($JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$,
"@",$opts$jscomp$81$$,$pending_forms$jscomp$22$$)):$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$=$cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$234$clojure_DOT_core_SLASH_unquote$$)($JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$,"~",$opts$jscomp$81$$,$pending_forms$jscomp$22$$):$JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$=null;return $JSCompiler_temp$jscomp$1637_JSCompiler_temp$jscomp$1638_rdr$jscomp$85$$};
$cljs$tools$reader$read_syntax_quote$$=function($rdr$jscomp$86$$,$backquote_gensym_env_orig_val__24883$$,$opts$jscomp$82$$,$pending_forms$jscomp$23$$){$backquote_gensym_env_orig_val__24883$$=$cljs$tools$reader$gensym_env$$;$cljs$tools$reader$gensym_env$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;try{return $cljs$tools$reader$syntax_quote_STAR_$$($cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($rdr$jscomp$86$$,!0,
null,$opts$jscomp$82$$,$pending_forms$jscomp$23$$):$cljs$tools$reader$read_STAR_$$($rdr$jscomp$86$$,!0,null,$opts$jscomp$82$$,$pending_forms$jscomp$23$$))}finally{$cljs$tools$reader$gensym_env$$=$backquote_gensym_env_orig_val__24883$$}};
$cljs$tools$reader$read_namespaced_map$$=function($rdr$jscomp$87$$,$_$jscomp$181_start_line$jscomp$5$$,$end_line$jscomp$5_opts$jscomp$83$$,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$){var $start_column$jscomp$5_vec__24887$$=$cljs$tools$reader$starting_line_col_info$$($rdr$jscomp$87$$);$_$jscomp$181_start_line$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$5_vec__24887$$,0,null);$start_column$jscomp$5_vec__24887$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_column$jscomp$5_vec__24887$$,
1,null);var $token$jscomp$24$$=$cljs$tools$reader$read_token$$($rdr$jscomp$87$$,$APP.$cljs$cst$247$namespaced_map$$,$APP.$cljs$tools$reader$reader_types$read_char$$($rdr$jscomp$87$$)),$keys$jscomp$20_temp__5823__auto__$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$24$$,":")?null.name:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(":",$APP.$cljs$core$first$$($token$jscomp$24$$))?function(){var $G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=
$token$jscomp$24$$==null?null:$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$24$$,1);$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$==null?null:$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$);
$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$==null?null:$APP.$cljs$tools$reader$impl$utils$second_SINGLEQUOTE_$$($G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$);$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=
$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$==null?null:$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$);if($G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$==null)$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=
null;else{var $G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(null,$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$);if($APP.$cljs$core$truth_$$($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$))$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=
$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$;else{$cljs$core$NS_CACHE$$==null&&($cljs$core$NS_CACHE$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$));$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cljs$core$NS_CACHE$$),$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$);if($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$!=null)$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=
$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$;else{$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$);
var $G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$);for(var $sb$jscomp$inline_15135$$=new $APP.$goog$string$StringBuffer$$,$i_30057$jscomp$inline_15136$$=
0;;)if($i_30057$jscomp$inline_15136$$<$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$.length){var $c_30058$jscomp$inline_15137$$=$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$.charAt($i_30057$jscomp$inline_15136$$),$sub_30059$jscomp$inline_15138$$=$APP.$module$contents$goog$object_get$$($cljs$core$CHAR_MAP$$,
$c_30058$jscomp$inline_15137$$);$sub_30059$jscomp$inline_15138$$!=null?$sb$jscomp$inline_15135$$.append($sub_30059$jscomp$inline_15138$$):$sb$jscomp$inline_15135$$.append($c_30058$jscomp$inline_15137$$);$i_30057$jscomp$inline_15136$$+=1}else break;$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$=$sb$jscomp$inline_15135$$.toString();$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$=
$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$===".."?"_DOT__DOT_":$APP.$cljs$core$truth_$$($cljs$core$js_reserved_QMARK_$$($G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$))?[$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$,
"$"].join(""):$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$;c:{$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$ instanceof
$APP.$cljs$core$Symbol$$?$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$):$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$).split(".");for($G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$=
$APP.$goog$global$$;;){if($G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$==null){$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=null;break c}if($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$==
null){$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$;break c}$G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$=
$APP.$module$contents$goog$object_get$$($G__30104$jscomp$inline_15091_ctxt$jscomp$inline_15090_name$jscomp$inline_15134_name_SINGLEQUOTE_$jscomp$inline_15086_name_SINGLEQUOTE___$1$jscomp$inline_15087$$,$APP.$cljs$core$first$$($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$));$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=
$APP.$cljs$core$next$$($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$)}$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=void 0}$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$==
null?$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=null:($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$=new $cljs$core$Namespace$$($G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$,
$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cljs$core$NS_CACHE$$,$APP.$cljs$core$assoc$$,$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$,$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$),
$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=$G__30105$jscomp$inline_15092_name$jscomp$inline_15085_new_ns$jscomp$inline_13543_ns_obj$jscomp$inline_13542_or__5025__auto__$jscomp$inline_8469_the_ns$jscomp$inline_13541_xs$jscomp$inline_15089$$)}$G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$=$APP.$cljs$core$truth_$$($G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$)?
$APP.$cljs$core$symbol$$.$cljs$core$IFn$_invoke$arity$1$($G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$.name):null}}return $G__24891__$1_G__24891__$2_G__24891__$3_G__24891__$4_JSCompiler_temp$jscomp$1541_temp__5825__auto__$jscomp$inline_8470$$}():function(){var $G__24892__$1$$=$token$jscomp$24$$==null?null:$APP.$cljs$tools$reader$impl$commons$parse_symbol$$($token$jscomp$24$$);return $G__24892__$1$$==null?null:$APP.$cljs$tools$reader$impl$utils$second_SINGLEQUOTE_$$($G__24892__$1$$)}();
if($APP.$cljs$core$truth_$$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$)){if($APP.$cljs$tools$reader$impl$commons$read_past$$($rdr$jscomp$87$$)==="{"){$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$=$cljs$tools$reader$read_delimited$$($APP.$cljs$cst$247$namespaced_map$$,"}",$rdr$jscomp$87$$,$end_line$jscomp$5_opts$jscomp$83$$,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$);var $end_column$jscomp$5_vec__24894$$=$cljs$tools$reader$ending_line_col_info$$($rdr$jscomp$87$$);$end_line$jscomp$5_opts$jscomp$83$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$5_vec__24894$$,0,null);$end_column$jscomp$5_vec__24894$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end_column$jscomp$5_vec__24894$$,1,null);$APP.$cljs$core$odd_QMARK_$$($APP.$cljs$core$count$$($items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$))&&$APP.$cljs$tools$reader$impl$errors$throw_odd_map$$($rdr$jscomp$87$$,null,null,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$);$keys$jscomp$20_temp__5823__auto__$jscomp$26$$=
$APP.$cljs$tools$reader$impl$utils$namespace_keys$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$),$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$));$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$=$APP.$cljs$core$take_nth$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$APP.$cljs$core$rest$$($items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$));$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($APP.$cljs$core$set$$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$)),
$APP.$cljs$core$count$$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$))||$APP.$cljs$tools$reader$impl$errors$throw_dup_keys$$($rdr$jscomp$87$$,$APP.$cljs$cst$247$namespaced_map$$,$keys$jscomp$20_temp__5823__auto__$jscomp$26$$);return $APP.$cljs$core$with_meta$$($APP.$cljs$core$zipmap$$($keys$jscomp$20_temp__5823__auto__$jscomp$26$$,$items$jscomp$6_pending_forms$jscomp$24_vals$jscomp$8$$),$APP.$cljs$core$truth_$$($_$jscomp$181_start_line$jscomp$5$$)?$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $temp__5825__auto__$jscomp$51$$=
$APP.$cljs$tools$reader$reader_types$get_file_name$$($rdr$jscomp$87$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$51$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$208$file$$,$temp__5825__auto__$jscomp$51$$],null):null}(),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$209$line$$,$_$jscomp$181_start_line$jscomp$5$$,$APP.$cljs$cst$216$column$$,$start_column$jscomp$5_vec__24887$$,$APP.$cljs$cst$217$end_line$$,$end_line$jscomp$5_opts$jscomp$83$$,$APP.$cljs$cst$218$end_column$$,
$end_column$jscomp$5_vec__24894$$],null)])):null)}return $APP.$cljs$tools$reader$impl$errors$throw_ns_map_no_map$$($rdr$jscomp$87$$,$token$jscomp$24$$)}return $APP.$cljs$tools$reader$impl$errors$throw_bad_ns$$($rdr$jscomp$87$$,$token$jscomp$24$$)};
$cljs$tools$reader$macros$$=function($ch$jscomp$40$$){switch($ch$jscomp$40$$){case '"':return $cljs$tools$reader$read_string_STAR_$$;case ":":return $cljs$tools$reader$read_keyword$$;case ";":return $APP.$cljs$tools$reader$impl$commons$read_comment$$;case "'":return $cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$167$quote$$);case "@":return $cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$248$clojure_DOT_core_SLASH_deref$$);case "^":return $cljs$tools$reader$read_meta$$;case "`":return $cljs$tools$reader$read_syntax_quote$$;
case "~":return $cljs$tools$reader$read_unquote$$;case "(":return $cljs$tools$reader$read_list$$;case ")":return $cljs$tools$reader$read_unmatched_delimiter$$;case "[":return $cljs$tools$reader$read_vector$$;case "]":return $cljs$tools$reader$read_unmatched_delimiter$$;case "{":return $cljs$tools$reader$read_map$$;case "}":return $cljs$tools$reader$read_unmatched_delimiter$$;case "\\":return $cljs$tools$reader$read_char_STAR_$$;case "%":return $cljs$tools$reader$read_arg$$;case "#":return $cljs$tools$reader$read_dispatch$$;
default:return null}};
$cljs$tools$reader$dispatch_macros$$=function($ch$jscomp$41$$){switch($ch$jscomp$41$$){case "^":return $cljs$tools$reader$read_meta$$;case "'":return $cljs$tools$reader$wrapping_reader$$($APP.$cljs$cst$166$var$$);case "(":return $cljs$tools$reader$read_fn$$;case "{":return $cljs$tools$reader$read_set$$;case "\x3c":return $APP.$cljs$tools$reader$impl$commons$throwing_reader$$("Unreadable form");case "\x3d":return $APP.$cljs$tools$reader$impl$commons$throwing_reader$$("read-eval not supported");case '"':return $cljs$tools$reader$read_regex$$;
case "!":return $APP.$cljs$tools$reader$impl$commons$read_comment$$;case "_":return $cljs$tools$reader$read_discard$$;case "?":return $cljs$tools$reader$read_cond$$;case ":":return $cljs$tools$reader$read_namespaced_map$$;case "#":return $cljs$tools$reader$read_symbolic_value$$;default:return null}};
$cljs$tools$reader$read_tagged$$=function($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,$G__24904_initch$jscomp$6_tag$jscomp$18$$,$opts$jscomp$84$$,$pending_forms$jscomp$25$$){$G__24904_initch$jscomp$6_tag$jscomp$18$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$):$cljs$tools$reader$read_STAR_$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,
!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$);$G__24904_initch$jscomp$6_tag$jscomp$18$$ instanceof $APP.$cljs$core$Symbol$$||$APP.$cljs$tools$reader$impl$errors$throw_bad_reader_tag$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,$G__24904_initch$jscomp$6_tag$jscomp$18$$);if($APP.$cljs$core$truth_$$($cljs$tools$reader$_STAR_suppress_read_STAR_$$))return $G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,
!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$):$cljs$tools$reader$read_STAR_$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$),new $cljs$core$TaggedLiteral$$($G__24904_initch$jscomp$6_tag$jscomp$18$$,$G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$);var $f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$=$APP.$cljs$tools$reader$_STAR_data_readers_STAR_$$.call(null,$G__24904_initch$jscomp$6_tag$jscomp$18$$);
$f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$=$APP.$cljs$core$truth_$$($f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$)?$f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$:$APP.$cljs$tools$reader$default_data_readers$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$tools$reader$default_data_readers$$.$cljs$core$IFn$_invoke$arity$1$($G__24904_initch$jscomp$6_tag$jscomp$18$$):(0,$APP.$cljs$tools$reader$default_data_readers$$)($G__24904_initch$jscomp$6_tag$jscomp$18$$);
return $APP.$cljs$core$truth_$$($f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$)?($G__24904_initch$jscomp$6_tag$jscomp$18$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$):$cljs$tools$reader$read_STAR_$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,
$pending_forms$jscomp$25$$),$f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$1$($G__24904_initch$jscomp$6_tag$jscomp$18$$):$f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$($G__24904_initch$jscomp$6_tag$jscomp$18$$)):$APP.$cljs$core$truth_$$(null)?($f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$=
null,$G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$=$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$?$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$):$cljs$tools$reader$read_STAR_$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,!0,null,$opts$jscomp$84$$,$pending_forms$jscomp$25$$),$f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$2$?
$f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$.$cljs$core$IFn$_invoke$arity$2$($G__24904_initch$jscomp$6_tag$jscomp$18$$,$G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$):$f$jscomp$337_or__5025__auto__$jscomp$inline_8472_temp__5823__auto__$jscomp$27$$($G__24904_initch$jscomp$6_tag$jscomp$18$$,$G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$)):$APP.$cljs$tools$reader$impl$errors$throw_unknown_reader_tag$$($G__24909_form$jscomp$inline_13546_rdr$jscomp$88$$,$G__24904_initch$jscomp$6_tag$jscomp$18$$)};
$cljs$tools$reader$read_STAR_$$=function($var_args$jscomp$326$$){switch(arguments.length){case 5:return $cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4]);case 6:return $cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$(arguments[0],arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$05$$=function($reader$jscomp$37$$,$eof_error_QMARK_$jscomp$1$$,$sentinel$jscomp$2$$,$opts$jscomp$86$$,$pending_forms$jscomp$27$$){return $cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$($reader$jscomp$37$$,$eof_error_QMARK_$jscomp$1$$,$sentinel$jscomp$2$$,null,$opts$jscomp$86$$,$pending_forms$jscomp$27$$)};
$cljs$tools$reader$read_STAR_$cljs$0core$0IFn$0_invoke$0arity$06$$=function($reader$jscomp$38$$,$e$jscomp$128_eof_error_QMARK_$jscomp$2$$,$d$jscomp$103_sentinel$jscomp$3$$,$return_on$jscomp$1$$,$opts$jscomp$87$$,$pending_forms$jscomp$28$$){try{a:{for(;;){if($pending_forms$jscomp$28$$.length==0){var $ch$jscomp$inline_13554$$=$reader$jscomp$38$$.$cljs$tools$reader$reader_types$Reader$read_char$arity$1$(null);if($APP.$cljs$tools$reader$impl$utils$whitespace_QMARK_$$($ch$jscomp$inline_13554$$))continue;
else{if($ch$jscomp$inline_13554$$==null){var $JSCompiler_inline_result$jscomp$11256$$=$e$jscomp$128_eof_error_QMARK_$jscomp$2$$?$APP.$cljs$tools$reader$impl$errors$throw_eof_error$$($reader$jscomp$38$$,null):$d$jscomp$103_sentinel$jscomp$3$$;break a}if($ch$jscomp$inline_13554$$===$return_on$jscomp$1$$){$JSCompiler_inline_result$jscomp$11256$$=$cljs$tools$reader$READ_FINISHED$$;break a}if($APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($ch$jscomp$inline_13554$$)||("+"===$ch$jscomp$inline_13554$$||
"-"===$ch$jscomp$inline_13554$$)&&$APP.$cljs$tools$reader$impl$utils$numeric_QMARK_$$($reader$jscomp$38$$.$cljs$tools$reader$reader_types$Reader$peek_char$arity$1$(null))){$JSCompiler_inline_result$jscomp$11256$$=$cljs$tools$reader$read_number$$($reader$jscomp$38$$,$ch$jscomp$inline_13554$$);break a}var $f$jscomp$inline_13555$$=$cljs$tools$reader$macros$$($ch$jscomp$inline_13554$$);if($f$jscomp$inline_13555$$!=null){var $res$jscomp$inline_13556$$=$f$jscomp$inline_13555$$.$cljs$core$IFn$_invoke$arity$4$?
$f$jscomp$inline_13555$$.$cljs$core$IFn$_invoke$arity$4$($reader$jscomp$38$$,$ch$jscomp$inline_13554$$,$opts$jscomp$87$$,$pending_forms$jscomp$28$$):$f$jscomp$inline_13555$$($reader$jscomp$38$$,$ch$jscomp$inline_13554$$,$opts$jscomp$87$$,$pending_forms$jscomp$28$$);if($res$jscomp$inline_13556$$===$reader$jscomp$38$$)continue;else{$JSCompiler_inline_result$jscomp$11256$$=$res$jscomp$inline_13556$$;break a}}else{$JSCompiler_inline_result$jscomp$11256$$=$cljs$tools$reader$read_symbol$$($reader$jscomp$38$$,
$ch$jscomp$inline_13554$$);break a}}}else{var $form$jscomp$inline_13557$$=$pending_forms$jscomp$28$$[0];Array.prototype.splice.call($pending_forms$jscomp$28$$,0,1);$JSCompiler_inline_result$jscomp$11256$$=$form$jscomp$inline_13557$$;break a}break}$JSCompiler_inline_result$jscomp$11256$$=void 0}return $JSCompiler_inline_result$jscomp$11256$$}catch($e24921$$){if($e24921$$ instanceof Error){$e$jscomp$128_eof_error_QMARK_$jscomp$2$$=$e24921$$;if($e$jscomp$128_eof_error_QMARK_$jscomp$2$$ instanceof $APP.$cljs$core$ExceptionInfo$$){$d$jscomp$103_sentinel$jscomp$3$$=
$APP.$cljs$core$ex_data$$($e$jscomp$128_eof_error_QMARK_$jscomp$2$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$206$reader_exception$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$103_sentinel$jscomp$3$$)))throw $e$jscomp$128_eof_error_QMARK_$jscomp$2$$;throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$128_eof_error_QMARK_$jscomp$2$$.message,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$206$reader_exception$$],null),$d$jscomp$103_sentinel$jscomp$3$$,$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($reader$jscomp$38$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$209$line$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$(null),$APP.$cljs$cst$216$column$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$(null),$APP.$cljs$cst$208$file$$,
$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_file_name$arity$1$(null)],null):null])),$e$jscomp$128_eof_error_QMARK_$jscomp$2$$);}throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$128_eof_error_QMARK_$jscomp$2$$.message,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$206$reader_exception$$],
null),$APP.$cljs$tools$reader$reader_types$indexing_reader_QMARK_$$($reader$jscomp$38$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$209$line$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_line_number$arity$1$(null),$APP.$cljs$cst$216$column$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_column_number$arity$1$(null),$APP.$cljs$cst$208$file$$,$reader$jscomp$38$$.$cljs$tools$reader$reader_types$IndexingReader$get_file_name$arity$1$(null)],
null):null])),$e$jscomp$128_eof_error_QMARK_$jscomp$2$$);}throw $e24921$$;}};
$app$main$data$workspace$libraries$go_to_component_file$$=function($file_id$jscomp$155$$,$component$jscomp$79$$,$update_layout_QMARK_$jscomp$2$$){typeof $app$main$data$workspace$libraries$nav_to_component_file_69848$$==="undefined"&&($app$main$data$workspace$libraries$nav_to_component_file_69848$$=function($file_id$jscomp$156$$,$component$jscomp$80$$,$update_layout_QMARK_$jscomp$3$$,$meta69849$$){this.$file_id$=$file_id$jscomp$156$$;this.component=$component$jscomp$80$$;this.$update_layout_QMARK_$=
$update_layout_QMARK_$jscomp$3$$;this.$meta69849$=$meta69849$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$nav_to_component_file_69848$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$nav_to_component_file_69848$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4005$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_nav_to_component_file$$},
$app$main$data$workspace$libraries$nav_to_component_file_69848$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69850$$,$meta69849__$1$$){return new $app$main$data$workspace$libraries$nav_to_component_file_69848$$(this.$file_id$,this.component,this.$update_layout_QMARK_$,$meta69849__$1$$)},$app$main$data$workspace$libraries$nav_to_component_file_69848$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69849$},$app$main$data$workspace$libraries$nav_to_component_file_69848$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$nav_to_component_file_69848$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2136_params$jscomp$281$$,$state$jscomp$520$$){$_$jscomp$2136_params$jscomp$281$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$router$get_params$$($state$jscomp$520$$),
$APP.$cljs$cst$1649$file_id$$,this.$file_id$),$APP.$cljs$cst$2051$page_id$$,$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$(this.component)),$APP.$cljs$cst$1632$component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$(this.component)),$APP.$cljs$cst$4006$update_layout$$,this.$update_layout_QMARK_$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2543$workspace$$,$_$jscomp$2136_params$jscomp$281$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2467$app_DOT_main_DOT_router_SLASH_new_window$$,!0])))});return new $app$main$data$workspace$libraries$nav_to_component_file_69848$$($file_id$jscomp$155$$,$component$jscomp$79$$,$update_layout_QMARK_$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$show_component_in_assets$$=function($component_id$jscomp$86$$){typeof $app$main$data$workspace$show_component_in_assets_72134$$==="undefined"&&($app$main$data$workspace$show_component_in_assets_72134$$=function($component_id$jscomp$87$$,$meta72135$$){this.$component_id$=$component_id$jscomp$87$$;this.$meta72135$=$meta72135$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$show_component_in_assets_72134$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_component_in_assets_72134$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4571$app_DOT_main_DOT_data_DOT_workspace_SLASH_show_component_in_assets$$},$app$main$data$workspace$show_component_in_assets_72134$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72136$$,$meta72135__$1$$){return new $app$main$data$workspace$show_component_in_assets_72134$$(this.$component_id$,$meta72135__$1$$)},
$app$main$data$workspace$show_component_in_assets_72134$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72135$},$app$main$data$workspace$show_component_in_assets_72134$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_component_in_assets_72134$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2598_component$jscomp$93_fdata$jscomp$18$$,$cpath$jscomp$4_paths$jscomp$2_state$jscomp$926$$){var $file_id$jscomp$295$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($cpath$jscomp$4_paths$jscomp$2_state$jscomp$926$$);$_$jscomp$2598_component$jscomp$93_fdata$jscomp$18$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($cpath$jscomp$4_paths$jscomp$2_state$jscomp$926$$,$file_id$jscomp$295$$);$_$jscomp$2598_component$jscomp$93_fdata$jscomp$18$$=$app$common$files$variant$get_primary_component$$($_$jscomp$2598_component$jscomp$93_fdata$jscomp$18$$,this.$component_id$);
$cpath$jscomp$4_paths$jscomp$2_state$jscomp$926$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2598_component$jscomp$93_fdata$jscomp$18$$);var $cpath__$1$jscomp$1$$=$APP.$app$common$path_names$split_path$$($cpath$jscomp$4_paths$jscomp$2_state$jscomp$926$$);$cpath$jscomp$4_paths$jscomp$2_state$jscomp$926$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($i$jscomp$511$$){return $APP.$app$common$path_names$join_path$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$511$$+
1,$cpath__$1$jscomp$1$$))},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$count$$($cpath__$1$jscomp$1$$)));return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__72133_SHARP_$$){return $app$main$data$workspace$set_assets_group_open$$($file_id$jscomp$295$$,$APP.$cljs$cst$1643$components$$,$p1__72133_SHARP_$$,!0)},$cpath$jscomp$4_paths$jscomp$2_state$jscomp$926$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1620$layout$$,
$APP.$cljs$cst$3767$assets$$])),$app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$295$$,$APP.$cljs$cst$3585$library$$,!0),$app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$295$$,$APP.$cljs$cst$1643$components$$,!0),$app$main$data$workspace$select_single_asset$$($file_id$jscomp$295$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2598_component$jscomp$93_fdata$jscomp$18$$),$APP.$cljs$cst$1643$components$$)))},$app$main$data$workspace$show_component_in_assets_72134$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$show_component_in_assets_72134$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2599_file_id$jscomp$296$$,$component$jscomp$94_fdata$jscomp$19_state$jscomp$927$$){$_$jscomp$2599_file_id$jscomp$296$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$94_fdata$jscomp$19_state$jscomp$927$$);$component$jscomp$94_fdata$jscomp$19_state$jscomp$927$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$94_fdata$jscomp$19_state$jscomp$927$$,
$_$jscomp$2599_file_id$jscomp$296$$);$component$jscomp$94_fdata$jscomp$19_state$jscomp$927$$=$app$common$files$variant$get_primary_component$$($component$jscomp$94_fdata$jscomp$19_state$jscomp$927$$,this.$component_id$);var $wrapper_id$$=["component-shape-id-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$94_fdata$jscomp$19_state$jscomp$927$$))].join("");return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $element$jscomp$inline_8474$$=
$APP.$goog$dom$getElement$$($wrapper_id$$);return $APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($element$jscomp$inline_8474$$,!1)})});return new $app$main$data$workspace$show_component_in_assets_72134$$($component_id$jscomp$86$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$common$go_to_feedback$$=function(){typeof $app$main$data$common$go_to_feedback_52707$$==="undefined"&&($app$main$data$common$go_to_feedback_52707$$=function($meta52708$$){this.$meta52708$=$meta52708$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$common$go_to_feedback_52707$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_feedback_52707$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$2519$app_DOT_main_DOT_data_DOT_common_SLASH_go_to_feedback$$},$app$main$data$common$go_to_feedback_52707$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_52709$$,$meta52708__$1$$){return new $app$main$data$common$go_to_feedback_52707$$($meta52708__$1$$)},$app$main$data$common$go_to_feedback_52707$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta52708$},$app$main$data$common$go_to_feedback_52707$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$common$go_to_feedback_52707$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2520$settings_feedback$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2467$app_DOT_main_DOT_router_SLASH_new_window$$,!0,$APP.$cljs$cst$2469$app_DOT_main_DOT_router_SLASH_window_name$$,
"penpot-feedback"])))});return new $app$main$data$common$go_to_feedback_52707$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$rasterizer$render_node$$=function($data$jscomp$328_node$jscomp$306_p__67839$$){var $map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$=$APP.$cljs$core$__destructure_map$$($data$jscomp$328_node$jscomp$306_p__67839$$);$data$jscomp$328_node$jscomp$306_p__67839$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$,$APP.$cljs$cst$3817$node$$);var $styles$jscomp$10_styles__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$,
$APP.$cljs$cst$2951$styles$$),$width$jscomp$113_width__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$,$APP.$cljs$cst$290$width$$);$map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$,$APP.$cljs$cst$828$result$$);$width$jscomp$113_width__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($width$jscomp$113_width__$1$jscomp$2$$,
$APP.$app$util$dom$get_attribute$$($data$jscomp$328_node$jscomp$306_p__67839$$,"width"));$styles$jscomp$10_styles__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($styles$jscomp$10_styles__$1$jscomp$1$$,"");$data$jscomp$328_node$jscomp$306_p__67839$$=$data$jscomp$328_node$jscomp$306_p__67839$$!=null?(new XMLSerializer).serializeToString($data$jscomp$328_node$jscomp$306_p__67839$$):null;$map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$,
"blob");return $APP.$app$main$rasterizer$render$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$142$data$$,$data$jscomp$328_node$jscomp$306_p__67839$$,$APP.$cljs$cst$2951$styles$$,$styles$jscomp$10_styles__$1$jscomp$1$$,$APP.$cljs$cst$290$width$$,$width$jscomp$113_width__$1$jscomp$2$$,$APP.$cljs$cst$828$result$$,$map__67840__$1_result$jscomp$284_result__$1$jscomp$33$$],null))};
$app$util$text_editor$setup_block_styles$$=function($state$jscomp$561$$,$blocks$$,$attrs$jscomp$109$$){return $APP.$cljs$core$empty_QMARK_$$($blocks$$)?$state$jscomp$561$$:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$23$$,$block_key$jscomp$1$$){return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.updateBlockData($state__$1$jscomp$23$$,$block_key$jscomp$1$$,$APP.$cljs$core$clj__GT_js$$($attrs$jscomp$109$$))},$state$jscomp$561$$,$blocks$$)};
$app$common$types$fills$prepend$$=function($fills$jscomp$8_fills__$1$jscomp$2$$,$fill$jscomp$7$$){$fills$jscomp$8_fills__$1$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$fill$jscomp$7$$],null),$fills$jscomp$8_fills__$1$jscomp$2$$);return $APP.$cljs$core$contains_QMARK_$$($APP.$app$common$flags$_STAR_current_STAR_$$,$APP.$cljs$cst$1761$frontend_binary_fills$$)?$APP.$app$common$types$fills$impl$from_plain$$($fills$jscomp$8_fills__$1$jscomp$2$$):
$fills$jscomp$8_fills__$1$jscomp$2$$};
$app$main$data$workspace$media$create_shapes_svg$$=function($file_id$jscomp$108$$,$objects$jscomp$367$$,$pos$jscomp$103$$,$svg_data$jscomp$20$$){return $APP.$beicon$v2$core$map$$(function($children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$){$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$=$app$common$files$shapes_builder$create_svg_shapes$cljs$0core$0IFn$0_invoke$0arity$07$$($children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$,$pos$jscomp$103$$,
$objects$jscomp$367$$);var $root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$,0,null);$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$,1,null);var $frame_shape$jscomp$1$$=
$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1624$parent_id$$,$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1639$fills$$,$APP.$cljs$cst$1527$height$$],[$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$103$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$),
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$)),$APP.$cljs$cst$1611$frame$$,$APP.$app$common$uuid$zero$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$103$$),$APP.$app$common$types$fills$create$$(),$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$))])),
$root_svg_shape__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$,$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$1$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1624$parent_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$1$$)]));$root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67902_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__67902_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_svg_shape__$1$$))},$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$));$root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($root_svg_shape__$1$$,
$APP.$cljs$cst$1619$shapes$$,$root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$);$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67903_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__67903_SHARP_$$,$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$1$$))},$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$);
$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$root_svg_shape_root_svg_shape__$2_shapes$jscomp$62$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$]));return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_shape$jscomp$1$$,$children$jscomp$214_children__$1$jscomp$25_children__$2_svg_data__$1$jscomp$2_vec__67904$$],null)},function($svg_data__$1$jscomp$1$$){return $APP.$beicon$v2$core$map$$(function($p1__67900_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($svg_data__$1$jscomp$1$$,$APP.$cljs$cst$3726$image_data$$,$p1__67900_SHARP_$$)},$APP.$app$main$data$workspace$svg_upload$upload_images$$($svg_data__$1$jscomp$1$$,$file_id$jscomp$108$$))}($svg_data$jscomp$20$$))};
$app$main$data$workspace$bool$group__GT_bool$$=function($type$jscomp$455$$,$group$jscomp$31$$,$objects$jscomp$347$$){var $head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$347$$),$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$31$$));$head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$455$$,$APP.$cljs$cst$2035$difference$$)?
$APP.$cljs$core$first$$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$):$APP.$cljs$core$last$$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$);$head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$=$APP.$cljs$core$contains_QMARK_$$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$,$APP.$cljs$cst$1898$svg_attrs$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$,
$APP.$cljs$cst$1639$fills$$,$APP.$app$common$types$path$bool$get_default_fills$$()):$head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$;return $APP.$app$common$types$path$update_bool_shape$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($group$jscomp$31$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1615$bool$$),
$APP.$cljs$cst$1896$bool_type$$,$type$jscomp$455$$),$APP.$cljs$core$select_keys$$($head$jscomp$19_head__$1$jscomp$3_shapes$jscomp$58$$,$APP.$app$common$types$path$bool$style_properties$$)])),$objects$jscomp$347$$)};
$app$main$data$workspace$comments$handle_interrupt$$=function(){typeof $app$main$data$workspace$comments$handle_interrupt_70398$$==="undefined"&&($app$main$data$workspace$comments$handle_interrupt_70398$$=function($meta70399$$){this.$meta70399$=$meta70399$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$handle_interrupt_70398$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$handle_interrupt_70398$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4342$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_handle_interrupt$$},$app$main$data$workspace$comments$handle_interrupt_70398$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70400$$,$meta70399__$1$$){return new $app$main$data$workspace$comments$handle_interrupt_70398$$($meta70399__$1$$)},$app$main$data$workspace$comments$handle_interrupt_70398$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70399$},$app$main$data$workspace$comments$handle_interrupt_70398$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$handle_interrupt_70398$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2377_local$jscomp$9$$,$comments_mode_QMARK__state$jscomp$752$$){$_$jscomp$2377_local$jscomp$9$$=$APP.$cljs$cst$2241$comments_local$$.$cljs$core$IFn$_invoke$arity$1$($comments_mode_QMARK__state$jscomp$752$$);$comments_mode_QMARK__state$jscomp$752$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3489$comments$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($comments_mode_QMARK__state$jscomp$752$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2197$workspace_drawing$$,$APP.$cljs$cst$2205$tool$$],null)));return $APP.$cljs$core$truth_$$($APP.$cljs$cst$3488$draft$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2377_local$jscomp$9$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$()):$APP.$cljs$core$truth_$$($APP.$cljs$cst$3487$open$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2377_local$jscomp$9$$))?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$close_thread$$()):
$comments_mode_QMARK__state$jscomp$752$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$edition$clear_edition_mode$$()):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$comments$handle_interrupt_70398$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$comments$initialize_comments$$=function($file_id$jscomp$218$$){typeof $app$main$data$workspace$comments$initialize_comments_70382$$==="undefined"&&($app$main$data$workspace$comments$initialize_comments_70382$$=function($file_id$jscomp$219$$,$meta70383$$){this.$file_id$=$file_id$jscomp$219$$;this.$meta70383$=$meta70383$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$comments$initialize_comments_70382$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$initialize_comments_70382$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4340$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_initialize_comments$$},$app$main$data$workspace$comments$initialize_comments_70382$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70384$$,$meta70383__$1$$){return new $app$main$data$workspace$comments$initialize_comments_70382$$(this.$file_id$,$meta70383__$1$$)},
$app$main$data$workspace$comments$initialize_comments_70382$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70383$},$app$main$data$workspace$comments$initialize_comments_70382$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$comments$initialize_comments_70382$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2376_stopper_s$jscomp$4$$,$___$1$jscomp$1600$$,$stream$jscomp$84$$){$_$jscomp$2376_stopper_s$jscomp$4$$=
$APP.$beicon$v2$core$filter$$(function($p1__70379_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4341$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_finalize$$,$p1__70379_SHARP_$$)},$stream$jscomp$84$$);return $APP.$beicon$v2$core$take_until$$($_$jscomp$2376_stopper_s$jscomp$4$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$comments$retrieve_comment_threads$$(this.$file_id$)),$APP.$beicon$v2$core$map$$($app$main$data$workspace$comments$handle_comment_layer_click$$,
$APP.$beicon$v2$core$map$$($APP.$cljs$core$first$$,$APP.$beicon$v2$core$filter$$(function($p__70391_space$jscomp$2$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70391_space$jscomp$2$$,0,null);$p__70391_space$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__70391_space$jscomp$2$$,1,null);return $APP.$cljs$core$not$$($p__70391_space$jscomp$2$$)},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5676$$,$APP.$beicon$v2$core$switch_map$$(function(){return $APP.$beicon$v2$core$take$$($APP.$app$main$streams$mouse_position$$)},
$APP.$beicon$v2$core$filter$$($app$util$mouse$mouse_click_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$mouse_event_QMARK_$$,$stream$jscomp$84$$))))))),$APP.$beicon$v2$core$map$$($app$main$data$workspace$comments$handle_interrupt$$,$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$common$interrupt_QMARK_$$,$stream$jscomp$84$$))))});return new $app$main$data$workspace$comments$initialize_comments_70382$$($file_id$jscomp$218$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$deselect_all$$=function($var_args$jscomp$1211$$){switch(arguments.length){case 0:return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$();case 1:return $APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$01$$(arguments[0]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$render_wasm$api$set_focus_mode$$=function($cause54382_55146_entries$jscomp$15_fn_54381_55145$$){if($APP.$cljs$core$empty_QMARK_$$($cause54382_55146_entries$jscomp$15_fn_54381_55145$$))return null;var $code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$=16*$APP.$cljs$core$count$$($cause54382_55146_entries$jscomp$15_fn_54381_55145$$),$heap$jscomp$13$$=$APP.$app$render_wasm$mem$get_heap_u32$$();$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$=
$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$);$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($offset__$1$jscomp$10$$,$id$jscomp$335$$){return $APP.$app$render_wasm$mem$heap32$write_uuid$$($offset__$1$jscomp$10$$,$heap$jscomp$13$$,$id$jscomp$335$$)},$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$,
$cause54382_55146_entries$jscomp$15_fn_54381_55145$$);$cause54382_55146_entries$jscomp$15_fn_54381_55145$$=$APP.$app$render_wasm$wasm$internal_module$$._set_focus_mode;try{$cause54382_55146_entries$jscomp$15_fn_54381_55145$$()}catch($e54383$$){$cause54382_55146_entries$jscomp$15_fn_54381_55145$$=$e54383$$;$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$=
$APP.$cljs$core$truth_$$($code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$)?$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$():
null;$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto___55150$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___55150$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_focus_mode",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___55150$$,$APP.$cljs$cst$273$code$$,$code__53067__auto___55149_code_num__53066__auto___55148_offset$jscomp$156_read_code_fn__53065__auto___55147_size$jscomp$109$$],null),$cause54382_55146_entries$jscomp$15_fn_54381_55145$$);
}return $APP.$app$render_wasm$api$request_render$$("set-focus-mode")};$app$main$data$workspace$viewport_wasm$maybe_view_interaction_end_BANG_$$=function($state$jscomp$345$$){return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$345$$,"render-wasm/v1")&&!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$345$$)?$APP.$app$render_wasm$api$finalize_view_interaction_BANG_$$():null};
$app$main$data$workspace$viewport$finish_panning$$=function(){typeof $app$main$data$workspace$viewport$finish_panning_71354$$==="undefined"&&($app$main$data$workspace$viewport$finish_panning_71354$$=function($meta71355$$){this.$meta71355$=$meta71355$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$finish_panning_71354$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$finish_panning_71354$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4521$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_finish_panning$$},$app$main$data$workspace$viewport$finish_panning_71354$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71356$$,$meta71355__$1$$){return new $app$main$data$workspace$viewport$finish_panning_71354$$($meta71355__$1$$)},$app$main$data$workspace$viewport$finish_panning_71354$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71355$},$app$main$data$workspace$viewport$finish_panning_71354$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$finish_panning_71354$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2542$$,$state$jscomp$882$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$882$$,$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3110$panning$$)},$app$main$data$workspace$viewport$finish_panning_71354$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$viewport$finish_panning_71354$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2543$$,$state$jscomp$883$$){return $app$main$data$workspace$viewport_wasm$maybe_view_interaction_end_BANG_$$($state$jscomp$883$$)});return new $app$main$data$workspace$viewport$finish_panning_71354$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$zoom$finish_zooming$$=function(){typeof $app$main$data$workspace$zoom$finish_zooming_66448$$==="undefined"&&($app$main$data$workspace$zoom$finish_zooming_66448$$=function($meta66449$$){this.$meta66449$=$meta66449$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$finish_zooming_66448$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$finish_zooming_66448$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3640$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_finish_zooming$$},$app$main$data$workspace$zoom$finish_zooming_66448$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66450$$,$meta66449__$1$$){return new $app$main$data$workspace$zoom$finish_zooming_66448$$($meta66449__$1$$)},$app$main$data$workspace$zoom$finish_zooming_66448$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66449$},$app$main$data$workspace$zoom$finish_zooming_66448$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$finish_zooming_66448$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1925$$,$state$jscomp$361$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$361$$,$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3111$zooming$$)},$app$main$data$workspace$zoom$finish_zooming_66448$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$finish_zooming_66448$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function($_$jscomp$1926$$,$state$jscomp$362$$){return $app$main$data$workspace$viewport_wasm$maybe_view_interaction_end_BANG_$$($state$jscomp$362$$)});return new $app$main$data$workspace$zoom$finish_zooming_66448$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$viewport$start_panning$$=function(){typeof $app$main$data$workspace$viewport$start_panning_71351$$==="undefined"&&($app$main$data$workspace$viewport$start_panning_71351$$=function($meta71352$$){this.$meta71352$=$meta71352$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$start_panning_71351$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$start_panning_71351$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4520$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_start_panning$$},$app$main$data$workspace$viewport$start_panning_71351$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71353$$,$meta71352__$1$$){return new $app$main$data$workspace$viewport$start_panning_71351$$($meta71352__$1$$)},$app$main$data$workspace$viewport$start_panning_71351$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71352$},$app$main$data$workspace$viewport$start_panning_71351$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$start_panning_71351$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2541_stopper$jscomp$38$$,$state$jscomp$881$$,$stream$jscomp$95$$){$_$jscomp$2541_stopper$jscomp$38$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4521$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_finish_panning$$),$stream$jscomp$95$$);var $zoom$jscomp$42$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$881$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$2204$zoom$$],null));return!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$881$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$881$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,
$APP.$cljs$cst$3110$panning$$],null)))?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$viewport$activate_panning$$()),$APP.$beicon$v2$core$map$$(function($event$jscomp$105$$){var $delta$jscomp$55$$=$event$jscomp$105$$.$movement$;return $APP.$app$main$data$workspace$viewport$update_viewport_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,function($p1__71349_SHARP_$$){return $p1__71349_SHARP_$$-$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$55$$)/
$zoom$jscomp$42$$},$APP.$cljs$cst$1516$y$$,function($p1__71350_SHARP_$$){return $p1__71350_SHARP_$$-$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$55$$)/$zoom$jscomp$42$$}],null))},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$4522$af$$,$APP.$beicon$v2$core$take_until$$($_$jscomp$2541_stopper$jscomp$38$$,$APP.$beicon$v2$core$filter$$(function($p1__71348_SHARP_$$){return $p1__71348_SHARP_$$.$movement$!=null},$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$pointer_event_QMARK_$$,
$stream$jscomp$95$$)))))):null});return new $app$main$data$workspace$viewport$start_panning_71351$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$viewport$initialize_viewport$$=function($p__71282$$){function $initialize$$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$,$local$jscomp$18_local__$1$$){var $page_id$jscomp$269_vx$jscomp$2$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$);$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$,$page_id$jscomp$269_vx$jscomp$2$$);$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$=$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$,
$APP.$app$common$uuid$zero$$,null);$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$);$local$jscomp$18_local__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($local$jscomp$18_local__$1$$,$APP.$cljs$cst$2211$vport$$,$map__71283__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2204$zoom$$,
1,$APP.$cljs$cst$3630$zoom_inverse$$,1,$APP.$cljs$cst$3803$hide_toolbar$$,!1]));if($APP.$cljs$core$not$$($APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$)))||$APP.$cljs$core$not$$($APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$))))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local$jscomp$18_local__$1$$,
$APP.$cljs$cst$1942$vbox$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__71283__$1$$,$APP.$cljs$cst$1515$x$$,0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1516$y$$,0])));if($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$)>$width$jscomp$157$$||$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$)>
$height$jscomp$140$$){var $srect__$1$jscomp$4$$=$APP.$app$common$geom$align$adjust_to_viewport$cljs$0core$0IFn$0_invoke$0arity$03$$($map__71283__$1$$,$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$256$padding$$,40,$APP.$cljs$cst$3474$min_zoom$$,.01],null));$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$=
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__71283__$1$$)/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($srect__$1$jscomp$4$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local$jscomp$18_local__$1$$,$APP.$cljs$cst$2204$zoom$$,$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$),
$APP.$cljs$cst$3630$zoom_inverse$$,1/$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$),$APP.$cljs$cst$1942$vbox$$,function($vbox$jscomp$27$$){return $APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$vbox$jscomp$27$$,$srect__$1$jscomp$4$$])))})}$page_id$jscomp$269_vx$jscomp$2$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$)+
($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$)-$width$jscomp$157$$)/2;$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$)+($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$)-
$height$jscomp$140$$)/2;$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$=$APP.$app$common$geom$rect$update_rect$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71283__$1$$,$APP.$cljs$cst$1515$x$$,$page_id$jscomp$269_vx$jscomp$2$$),$APP.$cljs$cst$1516$y$$,$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$),
$APP.$cljs$cst$1681$position$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local$jscomp$18_local__$1$$,$APP.$cljs$cst$1942$vbox$$,$objects$jscomp$665_shapes$jscomp$124_srect$jscomp$9_state$jscomp$870_vbox$jscomp$26_vy$jscomp$3_zoom$jscomp$41$$)}function $update_STAR_$$($map__71293__$1_p__71292$$){$map__71293__$1_p__71292$$=$APP.$cljs$core$__destructure_map$$($map__71293__$1_p__71292$$);var $vport$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71293__$1_p__71292$$,
$APP.$cljs$cst$2211$vport$$),$wprop$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$6$$)/$width$jscomp$157$$,$hprop$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$6$$)/$height$jscomp$140$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71293__$1_p__71292$$,$APP.$cljs$cst$2211$vport$$,$map__71283__$1$$),$APP.$cljs$cst$1942$vbox$$,function($vbox$jscomp$25$$){return $APP.$app$common$geom$rect$update_rect$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($vbox$jscomp$25$$,
$APP.$cljs$cst$290$width$$,function($p1__71277_SHARP_$$){return $p1__71277_SHARP_$$/$wprop$$}),$APP.$cljs$cst$1527$height$$,function($p1__71278_SHARP_$$){return $p1__71278_SHARP_$$/$hprop$$}),$APP.$cljs$cst$874$size$$)})}var $map__71283__$1$$=$APP.$cljs$core$__destructure_map$$($p__71282$$),$width$jscomp$157$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71283__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$140$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71283__$1$$,
$APP.$cljs$cst$1527$height$$);typeof $app$main$data$workspace$viewport$initialize_viewport_71297$$==="undefined"&&($app$main$data$workspace$viewport$initialize_viewport_71297$$=function($p__71282$jscomp$1$$,$map__71283$jscomp$1$$,$size$jscomp$130$$,$width$jscomp$158$$,$height$jscomp$141$$,$update_STAR_$jscomp$1$$,$initialize$jscomp$1$$,$setup$jscomp$1$$,$meta71298$$){this.$p__71282$=$p__71282$jscomp$1$$;this.$map__71283$=$map__71283$jscomp$1$$;this.size=$size$jscomp$130$$;this.width=$width$jscomp$158$$;
this.height=$height$jscomp$141$$;this.$update_STAR_$=$update_STAR_$jscomp$1$$;this.initialize=$initialize$jscomp$1$$;this.$setup$=$setup$jscomp$1$$;this.$meta71298$=$meta71298$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$initialize_viewport_71297$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$initialize_viewport_71297$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4515$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_initialize_viewport$$},$app$main$data$workspace$viewport$initialize_viewport_71297$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71299$$,$meta71298__$1$$){return new $app$main$data$workspace$viewport$initialize_viewport_71297$$(this.$p__71282$,this.$map__71283$,this.size,this.width,this.height,this.$update_STAR_$,this.initialize,this.$setup$,$meta71298__$1$$)},$app$main$data$workspace$viewport$initialize_viewport_71297$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71298$},$app$main$data$workspace$viewport$initialize_viewport_71297$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$initialize_viewport_71297$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2532$$,$state$jscomp$872$$){var $self__$jscomp$6169$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$872$$,$APP.$cljs$cst$1937$workspace_local$$,function($local$jscomp$20$$){return $self__$jscomp$6169$$.$setup$.$cljs$core$IFn$_invoke$arity$2$?
$self__$jscomp$6169$$.$setup$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$872$$,$local$jscomp$20$$):$self__$jscomp$6169$$.$setup$($state$jscomp$872$$,$local$jscomp$20$$)})},$app$main$data$workspace$viewport$initialize_viewport_71297$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$initialize_viewport_71297$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2533$$,$state$jscomp$873$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$873$$)});
return new $app$main$data$workspace$viewport$initialize_viewport_71297$$($p__71282$$,$map__71283__$1$$,$map__71283__$1$$,$width$jscomp$157$$,$height$jscomp$140$$,$update_STAR_$$,$initialize$$,function($state$jscomp$871$$,$local$jscomp$19$$){var $JSCompiler_inline_result$jscomp$1645_and__5023__auto__$jscomp$inline_8478$$=$APP.$cljs$cst$1942$vbox$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$19$$);$JSCompiler_inline_result$jscomp$1645_and__5023__auto__$jscomp$inline_8478$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1645_and__5023__auto__$jscomp$inline_8478$$)?
$APP.$cljs$cst$2211$vport$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$19$$):$JSCompiler_inline_result$jscomp$1645_and__5023__auto__$jscomp$inline_8478$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1645_and__5023__auto__$jscomp$inline_8478$$)?$update_STAR_$$($local$jscomp$19$$):$initialize$$($state$jscomp$871$$,$local$jscomp$19$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$viewport$sync_wasm_workspace_viewport$$=function(){typeof $app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$==="undefined"&&($app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$=function($meta71274$$){this.$meta71274$=$meta71274$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4514$app_DOT_main_DOT_data_DOT_workspace_DOT_viewport_SLASH_sync_wasm_workspace_viewport$$},$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71275$$,$meta71274__$1$$){return new $app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$($meta71274__$1$$)},
$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71274$},$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2531$$,$state$jscomp$869$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$869$$)});
return new $app$main$data$workspace$viewport$sync_wasm_workspace_viewport_71273$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid_layout$editor$locate_board$$=function($grid_id$jscomp$15$$){typeof $app$main$data$workspace$grid_layout$editor$locate_board_71167$$==="undefined"&&($app$main$data$workspace$grid_layout$editor$locate_board_71167$$=function($grid_id$jscomp$16$$,$meta71168$$){this.$grid_id$=$grid_id$jscomp$16$$;this.$meta71168$=$meta71168$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$editor$locate_board_71167$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$locate_board_71167$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4457$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_editor_SLASH_locate_board$$},$app$main$data$workspace$grid_layout$editor$locate_board_71167$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71169$$,$meta71168__$1$$){return new $app$main$data$workspace$grid_layout$editor$locate_board_71167$$(this.$grid_id$,
$meta71168__$1$$)},$app$main$data$workspace$grid_layout$editor$locate_board_71167$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71168$},$app$main$data$workspace$grid_layout$editor$locate_board_71167$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$locate_board_71167$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2481_objects$jscomp$628$$,$state$jscomp$832$$){$_$jscomp$2481_objects$jscomp$628$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$832$$);var $srect$jscomp$8$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2481_objects$jscomp$628$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$grid_id$,$APP.$cljs$cst$1610$selrect$$],null));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$832$$,$APP.$cljs$cst$1937$workspace_local$$,function($map__71174__$1_p__71173$$){$map__71174__$1_p__71173$$=
$APP.$cljs$core$__destructure_map$$($map__71174__$1_p__71173$$);var $y__$1_zoom$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71174__$1_p__71173$$,$APP.$cljs$cst$2204$zoom$$),$vport$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71174__$1_p__71173$$,$APP.$cljs$cst$2211$vport$$),$height$jscomp$139_map__71175__$1$$=$APP.$cljs$core$__destructure_map$$($srect$jscomp$8$$),$x$jscomp$1213_x__$1$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$139_map__71175__$1$$,
$APP.$cljs$cst$1515$x$$),$y$jscomp$446$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$139_map__71175__$1$$,$APP.$cljs$cst$1516$y$$),$srect__$1$jscomp$3_width$jscomp$155$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$139_map__71175__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$139_map__71175__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$139_map__71175__$1$$,$APP.$cljs$cst$1527$height$$);$x$jscomp$1213_x__$1$jscomp$29$$=
$x$jscomp$1213_x__$1$jscomp$29$$+$srect__$1$jscomp$3_width$jscomp$155$$/2+-($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$5$$)/2/$y__$1_zoom$jscomp$40$$);$y__$1_zoom$jscomp$40$$=$y$jscomp$446$$+$height$jscomp$139_map__71175__$1$$/2+-($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$5$$)/2/$y__$1_zoom$jscomp$40$$);$srect__$1$jscomp$3_width$jscomp$155$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($x$jscomp$1213_x__$1$jscomp$29$$,
$y__$1_zoom$jscomp$40$$,$srect__$1$jscomp$3_width$jscomp$155$$,$height$jscomp$139_map__71175__$1$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($map__71174__$1_p__71173$$,$APP.$cljs$cst$1942$vbox$$,$APP.$cljs$core$merge$$,$APP.$cljs$core$select_keys$$($srect__$1$jscomp$3_width$jscomp$155$$,new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1528$x1$$,$APP.$cljs$cst$1530$x2$$,
$APP.$cljs$cst$1529$y1$$,$APP.$cljs$cst$1531$y2$$],null)))})},$app$main$data$workspace$grid_layout$editor$locate_board_71167$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$editor$locate_board_71167$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2482$$,$state$jscomp$833$$){return $APP.$app$main$data$workspace$viewport_wasm$maybe_sync_workspace_local_viewport_BANG_$$($state$jscomp$833$$)});return new $app$main$data$workspace$grid_layout$editor$locate_board_71167$$($grid_id$jscomp$15$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$zoom$start_zooming$$=function($pt$jscomp$24$$){typeof $app$main$data$workspace$zoom$start_zooming_66442$$==="undefined"&&($app$main$data$workspace$zoom$start_zooming_66442$$=function($pt$jscomp$25$$,$meta66443$$){this.pt=$pt$jscomp$25$$;this.$meta66443$=$meta66443$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$zoom$start_zooming_66442$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$zoom$start_zooming_66442$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3639$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_start_zooming$$},$app$main$data$workspace$zoom$start_zooming_66442$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66444$$,$meta66443__$1$$){return new $app$main$data$workspace$zoom$start_zooming_66442$$(this.pt,$meta66443__$1$$)},$app$main$data$workspace$zoom$start_zooming_66442$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta66443$},$app$main$data$workspace$zoom$start_zooming_66442$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$zoom$start_zooming_66442$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1924_stopper$jscomp$6$$,$state$jscomp$360$$,$stream$jscomp$38$$){var $self__$jscomp$4238$$=this;$_$jscomp$1924_stopper$jscomp$6$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3640$app_DOT_main_DOT_data_DOT_workspace_DOT_zoom_SLASH_finish_zooming$$),
$stream$jscomp$38$$);return!$APP.$app$main$data$workspace$viewport_wasm$render_context_lost_QMARK_$$($state$jscomp$360$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$360$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$3111$zooming$$],null)))?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)(function($s$jscomp$548$$){$app$main$data$workspace$viewport_wasm$maybe_view_interaction_start_BANG_$$($s$jscomp$548$$);
return $s$jscomp$548$$}),(0,$APP.$beicon$v2$core$of$$)(function($p1__66440_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__66440_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$3111$zooming$$],null),!0)}),$APP.$beicon$v2$core$map$$(function($delta$jscomp$31_scale$jscomp$27$$){$delta$jscomp$31_scale$jscomp$27$$=1+$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$31_scale$jscomp$27$$)/
100;return $APP.$app$main$data$workspace$zoom$set_zoom$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$4238$$.pt,$delta$jscomp$31_scale$jscomp$27$$)},$APP.$beicon$v2$core$take_until$$($_$jscomp$1924_stopper$jscomp$6$$,$APP.$beicon$v2$core$map$$($app$util$mouse$get_pointer_movement$$,$APP.$beicon$v2$core$filter$$(function($p1__66441_SHARP_$$){return $p1__66441_SHARP_$$.$movement$!=null},$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$pointer_event_QMARK_$$,$stream$jscomp$38$$)))))):null});return new $app$main$data$workspace$zoom$start_zooming_66442$$($pt$jscomp$24$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$util$text_editor$insert_text$$=function($state$jscomp$563$$,$text$jscomp$53$$,$attrs$jscomp$111$$){var $style$jscomp$42$$=$APP.$app$common$text$attrs_to_styles$$($attrs$jscomp$111$$);return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.insertText($state$jscomp$563$$,$text$jscomp$53$$,$APP.$cljs$core$clj__GT_js$$($attrs$jscomp$111$$),$APP.$cljs$core$clj__GT_js$$($style$jscomp$42$$))};
$app$util$text_editor$apply_block_styles_to_content$$=function($$__$1$jscomp$21_state$jscomp$562$$,$blocks$jscomp$1$$){if($APP.$cljs$core$empty_QMARK_$$($blocks$jscomp$1$$))return $$__$1$jscomp$21_state$jscomp$562$$;var $selection$jscomp$8$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getSelection($$__$1$jscomp$21_state$jscomp$562$$);$$__$1$jscomp$21_state$jscomp$562$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($state__$1$jscomp$24$$,$bkey$$){var $attrs$jscomp$110$$=
$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.getBlockData($state__$1$jscomp$24$$,$bkey$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0]));return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.applyInlineStyle($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.selectBlock($state__$1$jscomp$24$$,$bkey$$),$APP.$app$common$text$attrs_to_styles$$($attrs$jscomp$110$$))},
$$__$1$jscomp$21_state$jscomp$562$$,$blocks$jscomp$1$$);return $APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.setSelection($$__$1$jscomp$21_state$jscomp$562$$,$selection$jscomp$8$$)};
$app$util$worker$ask_buffered_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$=function($message$jscomp$70_message$jscomp$inline_8481$$,$transfer$jscomp$8$$){var $worker$jscomp$9$$=$APP.$app$main$worker$instance$$;$message$jscomp$70_message$jscomp$inline_8481$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3135$sender_id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$3137$payload$$,$message$jscomp$70_message$jscomp$inline_8481$$,$APP.$cljs$cst$3138$buffer_QMARK_$$,!0,$APP.$cljs$cst$3148$transfer$$,
$transfer$jscomp$8$$],null);return $APP.$app$util$worker$send_message_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($worker$jscomp$9$$,$message$jscomp$70_message$jscomp$inline_8481$$,null)};
$app$main$snap$get_snap_points$$=function($page_id$jscomp$166$$,$frame_id$jscomp$85$$,$remove_snap_QMARK_$jscomp$1$$,$zoom$jscomp$15$$,$point$jscomp$57_value$jscomp$568$$,$coord$jscomp$7$$){$point$jscomp$57_value$jscomp$568$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$57_value$jscomp$568$$,$coord$jscomp$7$$);var $vbox$jscomp$19$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$vbox$$);return $APP.$beicon$v2$core$map$$($APP.$app$main$snap$remove_from_snap_points$$($remove_snap_QMARK_$jscomp$1$$),
$APP.$beicon$v2$core$take$$($APP.$app$main$worker$ask_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$3139$cmd$$,$APP.$cljs$cst$3917$index_SLASH_query_snap$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$166$$,$APP.$cljs$cst$1612$frame_id$$,$frame_id$jscomp$85$$,$APP.$cljs$cst$2062$axis$$,$coord$jscomp$7$$,$APP.$cljs$cst$3918$bounds$$,$vbox$jscomp$19$$,$APP.$cljs$cst$3919$ranges$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$57_value$jscomp$568$$-.5/$zoom$jscomp$15$$,$point$jscomp$57_value$jscomp$568$$+.5/$zoom$jscomp$15$$],null)],null)],null))))};
$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$=function($initial_set$jscomp$2$$,$remove_QMARK_$jscomp$6$$,$ignore_groups_QMARK_$jscomp$3$$,$buffered_QMARK_$$){typeof $app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$==="undefined"&&($app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$=function($initial_set$jscomp$3$$,$remove_QMARK_$jscomp$7$$,$ignore_groups_QMARK_$jscomp$4$$,$buffered_QMARK_$jscomp$1$$,
$meta67387$$){this.$initial_set$=$initial_set$jscomp$3$$;this.$remove_QMARK_$=$remove_QMARK_$jscomp$7$$;this.$ignore_groups_QMARK_$=$ignore_groups_QMARK_$jscomp$4$$;this.$buffered_QMARK_$=$buffered_QMARK_$jscomp$1$$;this.$meta67387$=$meta67387$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3656$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_select_shapes_by_current_selrect$$},$app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67388$$,$meta67387__$1$$){return new $app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$(this.$initial_set$,this.$remove_QMARK_$,this.$ignore_groups_QMARK_$,this.$buffered_QMARK_$,$meta67387__$1$$)},$app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67387$},$app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1942$$,$state$jscomp$376$$){var $self__$jscomp$4292$$=this,$page_id$jscomp$112$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$376$$),
$objects$jscomp$324$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$376$$,$page_id$jscomp$112$$),$selrect$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$376$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1610$selrect$$),$ask_worker$$=$APP.$cljs$core$truth_$$($self__$jscomp$4292$$.$buffered_QMARK_$)?$app$main$worker$ask_buffered_BANG_$$:$APP.$app$main$worker$ask_BANG_$$,
$filter_objs$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$complement$$(function($id$jscomp$495$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$324$$,$id$jscomp$495$$),$APP.$cljs$cst$1628$blocked$$,!1)})),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$helpers$hidden_parent_QMARK_$$,
$objects$jscomp$324$$)));return $selrect$jscomp$46$$!=null?$APP.$beicon$v2$core$map$$($APP.$app$main$data$workspace$selection$select_shapes$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$truth_$$($self__$jscomp$4292$$.$remove_QMARK_$)?function($p1__67381_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$disj$$,$self__$jscomp$4292$$.$initial_set$,$p1__67381_SHARP_$$)}:function($p1__67382_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$4292$$.$initial_set$,
$filter_objs$$,$p1__67382_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__67380_SHARP_$$){return $APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$324$$,$p1__67380_SHARP_$$)},$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,function(){var $G__67404$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$3139$cmd$$,$APP.$cljs$cst$3657$index_SLASH_query_selection$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$112$$,$APP.$cljs$cst$1616$rect$$,$selrect$jscomp$46$$,
$APP.$cljs$cst$3658$include_frames_QMARK_$$,!0,$APP.$cljs$cst$3659$ignore_groups_QMARK_$$,$self__$jscomp$4292$$.$ignore_groups_QMARK_$,$APP.$cljs$cst$3660$full_frame_QMARK_$$,!0,$APP.$cljs$cst$3661$using_selrect_QMARK_$$,!0],null);return $ask_worker$$.$cljs$core$IFn$_invoke$arity$1$?$ask_worker$$.$cljs$core$IFn$_invoke$arity$1$($G__67404$$):$ask_worker$$($G__67404$$)}())))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$selection$select_shapes_by_current_selrect_67386$$($initial_set$jscomp$2$$,
$remove_QMARK_$jscomp$6$$,$ignore_groups_QMARK_$jscomp$3$$,$buffered_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$=function($initial_set$jscomp$1$$,$remove_QMARK_$jscomp$5$$,$ignore_groups_QMARK_$jscomp$2$$){return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$($initial_set$jscomp$1$$,$remove_QMARK_$jscomp$5$$,$ignore_groups_QMARK_$jscomp$2$$,!0)};
$app$main$data$workspace$selection$select_shapes_by_current_selrect$$=function($var_args$jscomp$1212$$){switch(arguments.length){case 3:return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$(arguments[0],arguments[1],arguments[2]);case 4:return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};
$app$main$data$workspace$selection$handle_area_selection$$=function($append_QMARK_$$,$remove_QMARK_$jscomp$3$$,$ignore_groups_QMARK_$$){typeof $app$main$data$workspace$selection$handle_area_selection_67263$$==="undefined"&&($app$main$data$workspace$selection$handle_area_selection_67263$$=function($append_QMARK_$jscomp$1$$,$remove_QMARK_$jscomp$4$$,$ignore_groups_QMARK_$jscomp$1$$,$meta67264$$){this.$append_QMARK_$=$append_QMARK_$jscomp$1$$;this.$remove_QMARK_$=$remove_QMARK_$jscomp$4$$;this.$ignore_groups_QMARK_$=$ignore_groups_QMARK_$jscomp$1$$;
this.$meta67264$=$meta67264$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$selection$handle_area_selection_67263$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$handle_area_selection_67263$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3642$app_DOT_main_DOT_data_DOT_workspace_DOT_selection_SLASH_handle_area_selection$$},$app$main$data$workspace$selection$handle_area_selection_67263$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_67265$$,$meta67264__$1$$){return new $app$main$data$workspace$selection$handle_area_selection_67263$$(this.$append_QMARK_$,this.$remove_QMARK_$,this.$ignore_groups_QMARK_$,$meta67264__$1$$)},$app$main$data$workspace$selection$handle_area_selection_67263$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67264$},$app$main$data$workspace$selection$handle_area_selection_67263$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$selection$handle_area_selection_67263$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1928_stopper$jscomp$7$$,$init_selrect_selrect_stream_state$jscomp$364$$,$init_position_stream$jscomp$39$$){var $self__$jscomp$4251$$=this,$zoom$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($init_selrect_selrect_stream_state$jscomp$364$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2204$zoom$$,1);$_$jscomp$1928_stopper$jscomp$7$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($init_position_stream$jscomp$39$$,
null);$init_position_stream$jscomp$39$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);var $initial_set$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$708$$=$self__$jscomp$4251$$.$append_QMARK_$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$708$$)?$or__5025__auto__$jscomp$708$$:$self__$jscomp$4251$$.$remove_QMARK_$}())?$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($init_selrect_selrect_stream_state$jscomp$364$$):
$APP.$linked$set$empty_linked_set$$;$init_selrect_selrect_stream_state$jscomp$364$$=$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($init_position_stream$jscomp$39$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($init_position_stream$jscomp$39$$,$APP.$cljs$cst$1515$x$$),$init_position_stream$jscomp$39$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($init_position_stream$jscomp$39$$,$APP.$cljs$cst$1516$y$$),0,0);$init_selrect_selrect_stream_state$jscomp$364$$=
$APP.$beicon$v2$core$take_until$$($_$jscomp$1928_stopper$jscomp$7$$,$APP.$beicon$v2$core$filter$$(function($p1__67258_SHARP_$$){return($p1__67258_SHARP_$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__67258_SHARP_$$,$APP.$cljs$cst$290$width$$))>10/$zoom$jscomp$11$$||($p1__67258_SHARP_$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__67258_SHARP_$$,$APP.$cljs$cst$1527$height$$))>10/$zoom$jscomp$11$$},$APP.$beicon$v2$core$scan$cljs$0core$0IFn$0_invoke$0arity$03$$(function($selrect$jscomp$45_selrect__$1$jscomp$2$$,
$p__67279_space_QMARK_$$){var $delta$jscomp$32_selrect__$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67279_space_QMARK_$$,0,null);$p__67279_space_QMARK_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67279_space_QMARK_$$,1,null);$selrect$jscomp$45_selrect__$1$jscomp$2$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($selrect$jscomp$45_selrect__$1$jscomp$2$$,$APP.$cljs$cst$1530$x2$$,$APP.$cljs$core$_PLUS_$$,
$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$32_selrect__$2$$)),$APP.$cljs$cst$1531$y2$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$32_selrect__$2$$));$delta$jscomp$32_selrect__$2$$=$p__67279_space_QMARK_$$?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($selrect$jscomp$45_selrect__$1$jscomp$2$$,$APP.$cljs$cst$1528$x1$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$32_selrect__$2$$)),
$APP.$cljs$cst$1529$y1$$,$APP.$cljs$core$_PLUS_$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($delta$jscomp$32_selrect__$2$$)):$selrect$jscomp$45_selrect__$1$jscomp$2$$;return $APP.$app$common$geom$rect$update_rect$$($delta$jscomp$32_selrect__$2$$,$APP.$cljs$cst$3643$corners$$)},$init_selrect_selrect_stream_state$jscomp$364$$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5676$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,
$APP.$beicon$v2$core$map$$(function($p__67284_to$jscomp$22$$){var $from$jscomp$20$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67284_to$jscomp$22$$,0,null);$p__67284_to$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67284_to$jscomp$22$$,1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($from$jscomp$20$$)?$p__67284_to$jscomp$22$$:$from$jscomp$20$$)?$APP.$app$common$geom$point$subtract$$($p__67284_to$jscomp$22$$,$from$jscomp$20$$):null},$APP.$beicon$v2$core$buffer$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$streams$mouse_position$$)))))));
return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$709$$=$self__$jscomp$4251$$.$append_QMARK_$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$709$$)?$or__5025__auto__$jscomp$709$$:$self__$jscomp$4251$$.$remove_QMARK_$}())?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$?$APP.$app$main$data$workspace$selection$deselect_all$cljs$0core$0IFn$0_invoke$0arity$00$$():
$app$main$data$workspace$selection$deselect_all$$()),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$map$$($app$main$data$workspace$selection$update_selrect$$,$init_selrect_selrect_stream_state$jscomp$364$$),$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$?$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$03$$($initial_set$$,$self__$jscomp$4251$$.$remove_QMARK_$,
$self__$jscomp$4251$$.$ignore_groups_QMARK_$):$app$main$data$workspace$selection$select_shapes_by_current_selrect$$($initial_set$$,$self__$jscomp$4251$$.$remove_QMARK_$,$self__$jscomp$4251$$.$ignore_groups_QMARK_$)},$APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$map$$($APP.$cljs$core$last$$,$APP.$beicon$v2$core$buffer_time$cljs$0core$0IFn$0_invoke$0arity$02$$(100,$init_selrect_selrect_stream_state$jscomp$364$$)))),
$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$?$app$main$data$workspace$selection$select_shapes_by_current_selrect$cljs$0core$0IFn$0_invoke$0arity$04$$($initial_set$$,$self__$jscomp$4251$$.$remove_QMARK_$,$self__$jscomp$4251$$.$ignore_groups_QMARK_$,!1):$app$main$data$workspace$selection$select_shapes_by_current_selrect$$($initial_set$$,$self__$jscomp$4251$$.$remove_QMARK_$,$self__$jscomp$4251$$.$ignore_groups_QMARK_$,
!1)},$APP.$beicon$v2$core$last$$($init_selrect_selrect_stream_state$jscomp$364$$))),$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2340$async$$,(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$selection$update_selrect$$(null))))});return new $app$main$data$workspace$selection$handle_area_selection_67263$$($append_QMARK_$$,$remove_QMARK_$jscomp$3$$,$ignore_groups_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$text$parse_draft_styles$$=function($styles$jscomp$14$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($item$jscomp$87$$){var $v$jscomp$594_vec__68876$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$87$$,$APP.$cljs$cst$1921$style$$),"$$$",3);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$594_vec__68876$$,0,null);var $k$jscomp$650$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$594_vec__68876$$,
1,null);$v$jscomp$594_vec__68876$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$594_vec__68876$$,2,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$302$key$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$650$$),$APP.$cljs$cst$108$val$$,$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$594_vec__68876$$),$APP.$cljs$cst$195$offset$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$87$$,
$APP.$cljs$cst$195$offset$$),$APP.$cljs$cst$255$length$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$87$$,$APP.$cljs$cst$255$length$$)],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__68874_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__68874_SHARP_$$,$APP.$cljs$cst$1921$style$$),"PENPOT$$$")},$styles$jscomp$14$$))};
$app$common$text$convert_from_draft$$=function($content$jscomp$171$$){function $split_texts$$($children$jscomp$243_text$jscomp$50$$,$styles$jscomp$15$$,$data$jscomp$369$$){var $cpoints$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,Array.from($children$jscomp$243_text$jscomp$50$$));$children$jscomp$243_text$jscomp$50$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($attrs$jscomp$inline_8491_p1__68889_SHARP_$$){var $start$jscomp$inline_8488_text$jscomp$inline_8490$$=
$APP.$cljs$core$ffirst$$($attrs$jscomp$inline_8491_p1__68889_SHARP_$$),$end$jscomp$inline_8489$$=$APP.$cljs$core$first$$($APP.$cljs$core$last$$($attrs$jscomp$inline_8491_p1__68889_SHARP_$$))+1;$start$jscomp$inline_8488_text$jscomp$inline_8490$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($cpoints$jscomp$2$$,$start$jscomp$inline_8488_text$jscomp$inline_8490$$,$end$jscomp$inline_8489$$));$attrs$jscomp$inline_8491_p1__68889_SHARP_$$=
$APP.$cljs$core$second$$($APP.$cljs$core$first$$($attrs$jscomp$inline_8491_p1__68889_SHARP_$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$text$fix_gradients$$($attrs$jscomp$inline_8491_p1__68889_SHARP_$$),$APP.$cljs$cst$1593$text$$,$start$jscomp$inline_8488_text$jscomp$inline_8490$$)},$cljs$core$partition_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$second$$,$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$text$build_style_index$$($APP.$cljs$core$count$$($cpoints$jscomp$2$$),
$app$common$text$parse_draft_styles$$($styles$jscomp$15$$)))));return $APP.$cljs$core$empty_QMARK_$$($children$jscomp$243_text$jscomp$50$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$243_text$jscomp$50$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$369$$,$APP.$cljs$cst$1593$text$$,"")):$children$jscomp$243_text$jscomp$50$$}return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"root",$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,"paragraph-set",$APP.$cljs$cst$342$children$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($block$jscomp$1_data$jscomp$370$$){var $key$jscomp$386$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($block$jscomp$1_data$jscomp$370$$,$APP.$cljs$cst$302$key$$),$text$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($block$jscomp$1_data$jscomp$370$$,
$APP.$cljs$cst$1593$text$$),$styles$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($block$jscomp$1_data$jscomp$370$$,$APP.$cljs$cst$4061$inlineStyleRanges$$);$block$jscomp$1_data$jscomp$370$$=$app$common$text$fix_gradients$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($block$jscomp$1_data$jscomp$370$$,$APP.$cljs$cst$142$data$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($block$jscomp$1_data$jscomp$370$$,
$APP.$cljs$cst$302$key$$,$key$jscomp$386$$),$APP.$cljs$cst$139$type$$,"paragraph"),$APP.$cljs$cst$342$children$$,$split_texts$$($text$jscomp$51$$,$styles$jscomp$16$$,$block$jscomp$1_data$jscomp$370$$))},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$171$$,$APP.$cljs$cst$4062$blocks$$))],null)],null)],null)};
$app$util$text_editor$export_content$$=function($content$jscomp$176$$){return $app$common$text$convert_from_draft$$($APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.convertToRaw($content$jscomp$176$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0])))};
$app$util$text$content$to_dom$set_styles$$=function($element$jscomp$67$$,$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$){for(var $G__53662_seq__53519_seq__53519__$1$$=$APP.$cljs$core$seq$$($G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$),$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$=null,$count__53521$$=0,$i__53522$$=0;;)if($i__53522$$<$count__53521$$){var $G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$=
$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__53522$$);$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$,0,null);$G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$,
1,null);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$)){var $style_encode_53656_vec__53542_53655$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$);$style_encode_53656_vec__53542_53655$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($style_encode_53656_vec__53542_53655$$,
0,null);$G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$=$style_encode_53656_vec__53542_53655$$.$cljs$core$IFn$_invoke$arity$1$?$style_encode_53656_vec__53542_53655$$.$cljs$core$IFn$_invoke$arity$1$($G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$):$style_encode_53656_vec__53542_53655$$($G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$);$APP.$app$util$dom$set_style_BANG_$$($element$jscomp$67$$,$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$),
$G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$)}else $APP.$app$util$dom$set_style_BANG_$$($element$jscomp$67$$,$APP.$app$util$text$content$styles$get_style_name$$($G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$),$APP.$app$util$text$content$styles$normalize_style_value$$($G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$,$G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$));$i__53522$$+=1}else if($G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$=
$APP.$cljs$core$seq$$($G__53662_seq__53519_seq__53519__$1$$))$G__53662_seq__53519_seq__53519__$1$$=$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__53662_seq__53519_seq__53519__$1$$)?($c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$=$APP.$cljs$core$_chunked_first$$($G__53662_seq__53519_seq__53519__$1$$),$G__53662_seq__53519_seq__53519__$1$$=$APP.$cljs$core$_chunked_rest$$($G__53662_seq__53519_seq__53519__$1$$),
$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$=$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$,$G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$),$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$=
$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$,$count__53521$$=$G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$):($c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$=$APP.$cljs$core$first$$($G__53662_seq__53519_seq__53519__$1$$),$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$,
0,null),$G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$,1,null),$APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$)?($c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,$G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$),$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$,0,null),$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$=
$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$.$cljs$core$IFn$_invoke$arity$1$?$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$.$cljs$core$IFn$_invoke$arity$1$($G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$):$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$($G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$),
$APP.$app$util$dom$set_style_BANG_$$($element$jscomp$67$$,$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$),$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$)):$APP.$app$util$dom$set_style_BANG_$$($element$jscomp$67$$,$APP.$app$util$text$content$styles$get_style_name$$($G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$),
$APP.$app$util$text$content$styles$normalize_style_value$$($G__53663_style_name$jscomp$6_styles$jscomp$5_temp__5825__auto__$jscomp$167$$,$G__53664_style_encoded_value_53657_style_value$jscomp$2_vec__53538$$)),$G__53662_seq__53519_seq__53519__$1$$=$APP.$cljs$core$next$$($G__53662_seq__53519_seq__53519__$1$$),$c__5548__auto__$jscomp$17_chunk__53520_style_encode_53667_style_encoded_value_53668_vec__53546_vec__53549_53666$$=null,$count__53521$$=0),$i__53522$$=0;else break};
$app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$=function($element$jscomp$68_tag$jscomp$67$$,$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$,$c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$){$element$jscomp$68_tag$jscomp$67$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$($element$jscomp$68_tag$jscomp$67$$);
$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$=$APP.$cljs$core$seq$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$);for(var $G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$=null,$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=
0,$G__53596_53700_child_53712_i__53568_53677$$=0;;)if($G__53596_53700_child_53712_i__53568_53677$$<$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$){var $attr_value_53680_vec__53586_53678$$=$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__53596_53700_child_53712_i__53568_53677$$),$attr_name_53679$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value_53680_vec__53586_53678$$,
0,null);$attr_value_53680_vec__53586_53678$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value_53680_vec__53586_53678$$,1,null);var $G__53589_53681$$=$attr_name_53679$$;switch($G__53589_53681$$ instanceof $APP.$cljs$core$Keyword$$?$G__53589_53681$$.$fqn$:null){case "data":$app$util$text$content$to_dom$set_dataset$$($element$jscomp$68_tag$jscomp$67$$,$attr_value_53680_vec__53586_53678$$);break;case "style":$app$util$text$content$to_dom$set_styles$$($element$jscomp$68_tag$jscomp$67$$,
$attr_value_53680_vec__53586_53678$$);break;default:$APP.$app$util$dom$set_attribute_BANG_$$($element$jscomp$68_tag$jscomp$67$$,$APP.$cljs$core$name$$($attr_name_53679$$),$attr_value_53680_vec__53586_53678$$)}$G__53596_53700_child_53712_i__53568_53677$$+=1}else if($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$=$APP.$cljs$core$seq$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$))$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=
$APP.$cljs$core$_chunked_first$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$),$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$=$APP.$cljs$core$_chunked_rest$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$),$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$=
$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$,$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=$APP.$cljs$core$count$$($G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$);else{$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=$APP.$cljs$core$first$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$);
$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$,0,null);$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$,
1,null);$G__53596_53700_child_53712_i__53568_53677$$=$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$;switch($G__53596_53700_child_53712_i__53568_53677$$ instanceof $APP.$cljs$core$Keyword$$?$G__53596_53700_child_53712_i__53568_53677$$.$fqn$:null){case "data":$app$util$text$content$to_dom$set_dataset$$($element$jscomp$68_tag$jscomp$67$$,$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$);break;case "style":$app$util$text$content$to_dom$set_styles$$($element$jscomp$68_tag$jscomp$67$$,
$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$);break;default:$APP.$app$util$dom$set_attribute_BANG_$$($element$jscomp$68_tag$jscomp$67$$,$APP.$cljs$core$name$$($G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$),$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$)}$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$=
$APP.$cljs$core$next$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$);$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$=null;$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=0}$G__53596_53700_child_53712_i__53568_53677$$=0}else break;$c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$=
$APP.$cljs$core$seq$$($c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$);$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$=null;for($G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$=0;;)if($G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$<
$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$)$G__53596_53700_child_53712_i__53568_53677$$=$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$),$APP.$app$util$dom$append_child_BANG_$$($element$jscomp$68_tag$jscomp$67$$,$G__53596_53700_child_53712_i__53568_53677$$),
$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$+=1;else if($c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$=$APP.$cljs$core$seq$$($c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$))$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$=$c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$)?($c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$=$APP.$cljs$core$_chunked_first$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$),$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=
$APP.$cljs$core$_chunked_rest$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$),$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$=$c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$,$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$=$APP.$cljs$core$count$$($c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$),
$c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$=$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$):($c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$=$APP.$cljs$core$first$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$),$APP.$app$util$dom$append_child_BANG_$$($element$jscomp$68_tag$jscomp$67$$,
$c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$),$c__5548__auto___53719_child_53724_children$jscomp$200_seq__53600_53708_temp__5825__auto___53717$$=$APP.$cljs$core$next$$($G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$),$G__53691_G__53721_attrs$jscomp$55_chunk__53602_53709_seq__53565_53674_seq__53565_53689__$1_seq__53600_53718__$1_temp__5825__auto___53688$$=
null,$G__53692_G__53722_attr_name_53696_chunk__53566_53675_count__53603_53710$$=0),$G__53693_G__53720_attr_value_53697_c__5548__auto___53690_count__53567_53676_i__53604_53711_vec__53590_53695$$=0;else break;return $element$jscomp$68_tag$jscomp$67$$};
$app$util$text$content$to_dom$create_paragraph$$=function($paragraph$jscomp$11$$){return $app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$("div",new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,function(){var $or__5025__auto__$jscomp$600$$=$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$11$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$600$$)?$or__5025__auto__$jscomp$600$$:$app$util$text$content$to_dom$create_random_key$$()}(),
$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3099$itype$$,"paragraph",$APP.$cljs$cst$3100$saved_font_size$$,$APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$11$$)],null),$APP.$cljs$cst$1921$style$$,$app$util$text$content$to_dom$get_paragraph_styles$$($paragraph$jscomp$11$$)],null),$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$){var $JSCompiler_temp_const$jscomp$14346_JSCompiler_temp_const$jscomp$14354_or__5025__auto__$jscomp$inline_13562$$=
$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$);$JSCompiler_temp_const$jscomp$14346_JSCompiler_temp_const$jscomp$14354_or__5025__auto__$jscomp$inline_13562$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$14346_JSCompiler_temp_const$jscomp$14354_or__5025__auto__$jscomp$inline_13562$$)?$JSCompiler_temp_const$jscomp$14346_JSCompiler_temp_const$jscomp$14354_or__5025__auto__$jscomp$inline_13562$$:
$app$util$text$content$to_dom$create_random_key$$();var $JSCompiler_temp_const$jscomp$14353_JSCompiler_temp_const$jscomp$inline_14886$$=$APP.$cljs$cst$142$data$$,$JSCompiler_temp_const$jscomp$14352$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3099$itype$$,"span"],null);var $JSCompiler_inline_result$jscomp$14355_node$jscomp$inline_14882$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$))?
$paragraph$jscomp$11$$:$JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$;$JSCompiler_inline_result$jscomp$14355_node$jscomp$inline_14882$$=$app$util$text$content$to_dom$get_styles_from_attrs$$($JSCompiler_inline_result$jscomp$14355_node$jscomp$inline_14882$$,$APP.$app$common$types$text$text_span_attrs$$);$JSCompiler_temp_const$jscomp$14346_JSCompiler_temp_const$jscomp$14354_or__5025__auto__$jscomp$inline_13562$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$266$id$$,$JSCompiler_temp_const$jscomp$14346_JSCompiler_temp_const$jscomp$14354_or__5025__auto__$jscomp$inline_13562$$,$JSCompiler_temp_const$jscomp$14353_JSCompiler_temp_const$jscomp$inline_14886$$,$JSCompiler_temp_const$jscomp$14352$$,$APP.$cljs$cst$1921$style$$,$JSCompiler_inline_result$jscomp$14355_node$jscomp$inline_14882$$],null);$JSCompiler_temp_const$jscomp$14353_JSCompiler_temp_const$jscomp$inline_14886$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",
$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$11$$)))?$JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("br"):
($JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$),$JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$)?
$JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$.replace(RegExp("/","g"),"/​"):null,$JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$=$APP.$app$util$globals$document$$.createTextNode($JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$));return $app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$("span",
$JSCompiler_temp_const$jscomp$14346_JSCompiler_temp_const$jscomp$14354_or__5025__auto__$jscomp$inline_13562$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$JSCompiler_temp_const$jscomp$14353_JSCompiler_temp_const$jscomp$inline_14886$$,[$JSCompiler_inline_result$jscomp$inline_14888_JSCompiler_temp$jscomp$inline_14887_p1__53638_SHARP__text$jscomp$inline_14889$$],null))},$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($paragraph$jscomp$11$$)))};
$app$util$text$content$to_dom$create_root$$=function($JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$){var $root_styles$jscomp$2$$=$app$util$text$content$to_dom$get_styles_from_attrs$$($JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$,$APP.$app$common$types$text$text_valign_attrs$$),$filtered_paragraphs_paragraphs$jscomp$3$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$342$children$$,0,$APP.$cljs$cst$342$children$$],null));$filtered_paragraphs_paragraphs$jscomp$3$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$filtered_paragraphs_paragraphs$jscomp$3$$));$JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$=
$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$);$JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$)?$JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$:$app$util$text$content$to_dom$create_random_key$$();return $app$util$text$content$to_dom$create_element$cljs$0core$0IFn$0_invoke$0arity$03$$("div",
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$JSCompiler_inline_result$jscomp$1653_or__5025__auto__$jscomp$inline_8495_root$jscomp$46$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3099$itype$$,"root"],null),$APP.$cljs$cst$1921$style$$,$root_styles$jscomp$2$$],null),$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$util$text$content$to_dom$create_paragraph$$,$filtered_paragraphs_paragraphs$jscomp$3$$))};
$app$util$text$content$styles$get_style_defaults$$=function($style_defaults$$){return $APP.$cljs$core$clj__GT_js$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$115$$,$p__53461_style_value_v$jscomp$570$$){var $k$jscomp$626_style_name$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53461_style_value_v$jscomp$570$$,0,null);$p__53461_style_value_v$jscomp$570$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__53461_style_value_v$jscomp$570$$,
1,null);if($APP.$cljs$core$contains_QMARK_$$($APP.$app$util$text$content$styles$mapping$$,$k$jscomp$626_style_name$jscomp$2$$)){var $style_encode_vec__53466$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$text$content$styles$mapping$$,$k$jscomp$626_style_name$jscomp$2$$);$style_encode_vec__53466$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($style_encode_vec__53466$$,0,null);$k$jscomp$626_style_name$jscomp$2$$=$APP.$app$util$text$content$styles$get_style_name_as_css_variable$$($k$jscomp$626_style_name$jscomp$2$$);
$p__53461_style_value_v$jscomp$570$$=$APP.$app$util$text$content$styles$normalize_style_value$$($k$jscomp$626_style_name$jscomp$2$$,$style_encode_vec__53466$$.$cljs$core$IFn$_invoke$arity$1$?$style_encode_vec__53466$$.$cljs$core$IFn$_invoke$arity$1$($p__53461_style_value_v$jscomp$570$$):$style_encode_vec__53466$$($p__53461_style_value_v$jscomp$570$$))}else $k$jscomp$626_style_name$jscomp$2$$=$APP.$app$util$text$content$styles$get_style_name$$($k$jscomp$626_style_name$jscomp$2$$),$p__53461_style_value_v$jscomp$570$$=
$APP.$app$util$text$content$styles$normalize_style_value$$($k$jscomp$626_style_name$jscomp$2$$,$p__53461_style_value_v$jscomp$570$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$115$$,$k$jscomp$626_style_name$jscomp$2$$,$p__53461_style_value_v$jscomp$570$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$style_defaults$$))};
$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$=function($file_id$jscomp$302$$,$set_id$jscomp$26$$,$types$jscomp$5$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$util$storage$user$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4767$app_DOT_main_DOT_ui_DOT_workspace_DOT_tokens_SLASH_unfolded_token_types$$,$APP.$cljs$core$assoc_in$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_id$jscomp$302$$,$set_id$jscomp$26$$],null),$APP.$cljs$core$vec$$($types$jscomp$5$$)]))};
$app$main$data$workspace$tokens$library_edit$clear_tokens_types$$=function(){typeof $app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$=function($meta72934$$){this.$meta72934$=$meta72934$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4773$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_clear_tokens_types$$},$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72935$$,$meta72934__$1$$){return new $app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$($meta72934__$1$$)},
$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72934$},$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2678_file_id$jscomp$308$$,$state$jscomp$983$$){$_$jscomp$2678_file_id$jscomp$308$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$983$$);var $set_id$jscomp$32$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$983$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$2146$selected_token_set_id$$],null));$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$($_$jscomp$2678_file_id$jscomp$308$$,$set_id$jscomp$32$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$983$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$4768$unfolded_token_types$$],null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2678_file_id$jscomp$308$$,$set_id$jscomp$32$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$))});return new $app$main$data$workspace$tokens$library_edit$clear_tokens_types_72933$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$toggle_token_type$$=function($type$jscomp$560$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$=function($type$jscomp$561$$,$meta72921$$){this.type=$type$jscomp$561$$;this.$meta72921$=$meta72921$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4772$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_type$$},$app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72922$$,$meta72921__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$(this.type,
$meta72921__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72921$},$app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2677_file_id$jscomp$307$$,$new_state$jscomp$3_state$jscomp$982$$){$_$jscomp$2677_file_id$jscomp$307$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_state$jscomp$3_state$jscomp$982$$);var $set_id$jscomp$31$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_state$jscomp$3_state$jscomp$982$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$2146$selected_token_set_id$$],null)),$new_types$jscomp$2_types$jscomp$11$$=$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$($new_state$jscomp$3_state$jscomp$982$$);
$new_types$jscomp$2_types$jscomp$11$$=$APP.$cljs$core$contains_QMARK_$$($new_types$jscomp$2_types$jscomp$11$$,this.type)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($new_types$jscomp$2_types$jscomp$11$$)?$new_types$jscomp$2_types$jscomp$11$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,this.type):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($new_types$jscomp$2_types$jscomp$11$$)?$new_types$jscomp$2_types$jscomp$11$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,
this.type);$new_state$jscomp$3_state$jscomp$982$$=$APP.$cljs$core$assoc_in$$($new_state$jscomp$3_state$jscomp$982$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$4768$unfolded_token_types$$],null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2677_file_id$jscomp$307$$,$set_id$jscomp$31$$,$new_types$jscomp$2_types$jscomp$11$$));$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$($_$jscomp$2677_file_id$jscomp$307$$,
$set_id$jscomp$31$$,$new_types$jscomp$2_types$jscomp$11$$);return $new_state$jscomp$3_state$jscomp$982$$});return new $app$main$data$workspace$tokens$library_edit$toggle_token_type_72920$$($type$jscomp$560$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$close_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$=function($type$jscomp$558$$){typeof $app$main$data$workspace$tokens$library_edit$close_token_type_72914$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$close_token_type_72914$$=function($type$jscomp$559$$,$meta72915$$){this.type=$type$jscomp$559$$;this.$meta72915$=$meta72915$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$close_token_type_72914$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$close_token_type_72914$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4771$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_close_token_type$$},$app$main$data$workspace$tokens$library_edit$close_token_type_72914$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72916$$,$meta72915__$1$$){return new $app$main$data$workspace$tokens$library_edit$close_token_type_72914$$(this.type,
$meta72915__$1$$)},$app$main$data$workspace$tokens$library_edit$close_token_type_72914$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72915$},$app$main$data$workspace$tokens$library_edit$close_token_type_72914$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$close_token_type_72914$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2676_file_id$jscomp$306$$,$new_state$jscomp$2_state$jscomp$981$$){$_$jscomp$2676_file_id$jscomp$306$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_state$jscomp$2_state$jscomp$981$$);var $set_id$jscomp$30$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_state$jscomp$2_state$jscomp$981$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$2146$selected_token_set_id$$],null)),$new_types$jscomp$1_types$jscomp$10$$=$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$($new_state$jscomp$2_state$jscomp$981$$);
$new_types$jscomp$1_types$jscomp$10$$=$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($new_types$jscomp$1_types$jscomp$10$$)?$new_types$jscomp$1_types$jscomp$10$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,this.type);$new_state$jscomp$2_state$jscomp$981$$=$APP.$cljs$core$assoc_in$$($new_state$jscomp$2_state$jscomp$981$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$4768$unfolded_token_types$$],
null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2676_file_id$jscomp$306$$,$set_id$jscomp$30$$,$new_types$jscomp$1_types$jscomp$10$$));$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$($_$jscomp$2676_file_id$jscomp$306$$,$set_id$jscomp$30$$,$new_types$jscomp$1_types$jscomp$10$$);return $new_state$jscomp$2_state$jscomp$981$$});return new $app$main$data$workspace$tokens$library_edit$close_token_type_72914$$($type$jscomp$558$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$open_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$=function($type$jscomp$555$$){typeof $app$main$data$workspace$tokens$library_edit$open_token_type_72902$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$open_token_type_72902$$=function($type$jscomp$556$$,$meta72903$$){this.type=$type$jscomp$556$$;this.$meta72903$=$meta72903$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$open_token_type_72902$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$open_token_type_72902$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4770$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_open_token_type$$},$app$main$data$workspace$tokens$library_edit$open_token_type_72902$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72904$$,$meta72903__$1$$){return new $app$main$data$workspace$tokens$library_edit$open_token_type_72902$$(this.type,
$meta72903__$1$$)},$app$main$data$workspace$tokens$library_edit$open_token_type_72902$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72903$},$app$main$data$workspace$tokens$library_edit$open_token_type_72902$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$open_token_type_72902$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2675_file_id$jscomp$305$$,$new_state$jscomp$1_state$jscomp$980$$){$_$jscomp$2675_file_id$jscomp$305$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($new_state$jscomp$1_state$jscomp$980$$);var $set_id$jscomp$29$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($new_state$jscomp$1_state$jscomp$980$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$2146$selected_token_set_id$$],null)),$new_types_types$jscomp$8$$=$app$main$data$workspace$tokens$library_edit$get_unfolded_token_types_from_state$$($new_state$jscomp$1_state$jscomp$980$$);
$new_types_types$jscomp$8$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($new_types_types$jscomp$8$$)?$new_types_types$jscomp$8$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,this.type);$new_state$jscomp$1_state$jscomp$980$$=$APP.$cljs$core$assoc_in$$($new_state$jscomp$1_state$jscomp$980$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$4768$unfolded_token_types$$],
null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2675_file_id$jscomp$305$$,$set_id$jscomp$29$$,$new_types_types$jscomp$8$$));$app$main$data$workspace$tokens$library_edit$save_unfolded_token_types_in_storage$$($_$jscomp$2675_file_id$jscomp$305$$,$set_id$jscomp$29$$,$new_types_types$jscomp$8$$);return $new_state$jscomp$1_state$jscomp$980$$});return new $app$main$data$workspace$tokens$library_edit$open_token_type_72902$$($type$jscomp$555$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types$$=function(){typeof $app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$=function($meta72894$$){this.$meta72894$=$meta72894$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4769$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_restore_unfolded_token_types$$},$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72895$$,$meta72894__$1$$){return new $app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$($meta72894__$1$$)},
$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72894$},$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2674_file_id$jscomp$304$$,$state$jscomp$979$$){$_$jscomp$2674_file_id$jscomp$304$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$979$$);var $set_id$jscomp$28$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$979$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$2146$selected_token_set_id$$],null)),$stored$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4767$app_DOT_main_DOT_ui_DOT_workspace_DOT_tokens_SLASH_unfolded_token_types$$,$_$jscomp$2674_file_id$jscomp$304$$,$set_id$jscomp$28$$],null),$APP.$cljs$core$PersistentHashSet$EMPTY$$);return $APP.$cljs$core$assoc_in$$($state$jscomp$979$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$4768$unfolded_token_types$$],null),$APP.$app$main$data$workspace$tokens$library_edit$make_unfolded_token_types_state$$($_$jscomp$2674_file_id$jscomp$304$$,
$set_id$jscomp$28$$,$stored$jscomp$1$$))});return new $app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types_72893$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shortcuts$on_display_guides_keydown$$=function($event$jscomp$148$$){var $mod_QMARK_$jscomp$7_or__5025__auto__$jscomp$inline_8497$$=$APP.$app$config$check_platform_QMARK_$$()?$event$jscomp$148$$.metaKey:$event$jscomp$148$$.ctrlKey,$JSCompiler_inline_result$jscomp$1655_shift_QMARK_$jscomp$31$$=$event$jscomp$148$$.shiftKey,$code$jscomp$45$$=$event$jscomp$148$$.code;$JSCompiler_inline_result$jscomp$1655_shift_QMARK_$jscomp$31$$=$APP.$cljs$core$truth_$$($mod_QMARK_$jscomp$7_or__5025__auto__$jscomp$inline_8497$$)?
($mod_QMARK_$jscomp$7_or__5025__auto__$jscomp$inline_8497$$=$APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$1655_shift_QMARK_$jscomp$31$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("Quote",$code$jscomp$45$$))?$mod_QMARK_$jscomp$7_or__5025__auto__$jscomp$inline_8497$$:$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1655_shift_QMARK_$jscomp$31$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("Backslash",$code$jscomp$45$$):$JSCompiler_inline_result$jscomp$1655_shift_QMARK_$jscomp$31$$:
$mod_QMARK_$jscomp$7_or__5025__auto__$jscomp$inline_8497$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1655_shift_QMARK_$jscomp$31$$)?($event$jscomp$148$$.preventDefault(),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shortcuts$toggle_layout_flag$$($APP.$cljs$cst$3775$display_guides$$))):null};
$app$main$data$workspace$colors$toggle_palette$$=function($selected$jscomp$79$$){typeof $app$main$data$workspace$colors$toggle_palette_70661$$==="undefined"&&($app$main$data$workspace$colors$toggle_palette_70661$$=function($selected$jscomp$80$$,$meta70662$$){this.selected=$selected$jscomp$80$$;this.$meta70662$=$meta70662$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$toggle_palette_70661$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$toggle_palette_70661$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4195$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_toggle_palette$$},$app$main$data$workspace$colors$toggle_palette_70661$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70663$$,$meta70662__$1$$){return new $app$main$data$workspace$colors$toggle_palette_70661$$(this.selected,$meta70662__$1$$)},$app$main$data$workspace$colors$toggle_palette_70661$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70662$},$app$main$data$workspace$colors$toggle_palette_70661$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$toggle_palette_70661$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$layout$toggle_layout_flag$$($APP.$cljs$cst$3764$colorpalette$$),$APP.$app$main$broadcast$event$$($APP.$cljs$cst$4193$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpalette_selected$$,
this.selected))},$app$main$data$workspace$colors$toggle_palette_70661$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$toggle_palette_70661$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($JSCompiler_inline_result$jscomp$1654__$jscomp$2248_state$jscomp$inline_8499$$,$G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$){a:{$JSCompiler_inline_result$jscomp$1654__$jscomp$2248_state$jscomp$inline_8499$$=
$APP.$cljs$cst$2196$workspace_global$$.$cljs$core$IFn$_invoke$arity$1$($G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$);$G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$=$APP.$cljs$core$seq$$($APP.$app$main$data$workspace$layout$layout_state_persistence_mapping$$);for(var $G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$=
null,$count__67447$jscomp$inline_8502$$=0,$i__67448$jscomp$inline_8503$$=0;;)if($i__67448$jscomp$inline_8503$$<$count__67447$jscomp$inline_8502$$){var $skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$=$G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__67448$jscomp$inline_8503$$),$G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$,0,null);$skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$,1,null);$G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1654__$jscomp$2248_state$jscomp$inline_8499$$,
$G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$,$APP.$cljs$cst$3799$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$,$APP.$cljs$cst$3799$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,
$APP.$cljs$core$dissoc$$,$skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$,$G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$);$i__67448$jscomp$inline_8503$$+=1}else if($G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$=
$APP.$cljs$core$seq$$($G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$)?($G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$=$APP.$cljs$core$_chunked_first$$($G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$),
$G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$=$APP.$cljs$core$_chunked_rest$$($G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$),$G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$=$G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$,
$count__67447$jscomp$inline_8502$$=$G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$=$APP.$cljs$core$count$$($G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$)):($G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$=$APP.$cljs$core$first$$($G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$),
$G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$,0,null),$skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$,
1,null),$G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1654__$jscomp$2248_state$jscomp$inline_8499$$,$G__67533$jscomp$inline_8513_c__5548__auto__$jscomp$inline_8510_key$jscomp$inline_8505_val_67521$jscomp$inline_8507$$,$APP.$cljs$cst$3799$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$,
$APP.$cljs$cst$3799$app_DOT_main_DOT_data_DOT_workspace_DOT_layout_SLASH_does_not_exist$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,$APP.$cljs$core$dissoc$$,$skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$skey$jscomp$inline_8506_vec__67460$jscomp$inline_8504$$,$G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$),
$G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$=$APP.$cljs$core$next$$($G__67531$jscomp$inline_8511_seq__67445$jscomp$inline_8500_seq__67445__$1$jscomp$inline_8509_state$jscomp$634_temp__5825__auto__$jscomp$inline_8508$$),$G__67532$jscomp$inline_8512_chunk__67446$jscomp$inline_8501_val_67535$jscomp$inline_8515_vec__67463$jscomp$inline_8514$$=null,$count__67447$jscomp$inline_8502$$=0),$i__67448$jscomp$inline_8503$$=
0;else{$JSCompiler_inline_result$jscomp$1654__$jscomp$2248_state$jscomp$inline_8499$$=null;break a}$JSCompiler_inline_result$jscomp$1654__$jscomp$2248_state$jscomp$inline_8499$$=void 0}return $JSCompiler_inline_result$jscomp$1654__$jscomp$2248_state$jscomp$inline_8499$$});return new $app$main$data$workspace$colors$toggle_palette_70661$$($selected$jscomp$79$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$fonts$add_recent_font$$=function($font$jscomp$37$$){typeof $app$main$data$fonts$add_recent_font_56067$$==="undefined"&&($app$main$data$fonts$add_recent_font_56067$$=function($font$jscomp$38$$,$meta56068$$){this.font=$font$jscomp$38$$;this.$meta56068$=$meta56068$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$fonts$add_recent_font_56067$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_recent_font_56067$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3561$app_DOT_main_DOT_data_DOT_fonts_SLASH_add_recent_font$$},$app$main$data$fonts$add_recent_font_56067$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_56069$$,$meta56068__$1$$){return new $app$main$data$fonts$add_recent_font_56067$$(this.font,$meta56068__$1$$)},$app$main$data$fonts$add_recent_font_56067$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta56068$},$app$main$data$fonts$add_recent_font_56067$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_recent_font_56067$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1863_file_id$jscomp$79$$,$state$jscomp$301$$){$_$jscomp$1863_file_id$jscomp$79$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$301$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$301$$,$APP.$cljs$cst$2222$recent_fonts$$,$app$main$data$fonts$update_recent_font$$,$_$jscomp$1863_file_id$jscomp$79$$,
this.font)},$app$main$data$fonts$add_recent_font_56067$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$fonts$add_recent_font_56067$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$1864_recent_fonts$$,$state$jscomp$302$$){$_$jscomp$1864_recent_fonts$$=$APP.$cljs$cst$2222$recent_fonts$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$302$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2222$recent_fonts$$,$_$jscomp$1864_recent_fonts$$)});return new $app$main$data$fonts$add_recent_font_56067$$($font$jscomp$37$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$hooks$use_persisted_state$$=function($key$jscomp$348$$,$default$$jscomp$55$$){var $id$jscomp$304$$=(0,$APP.$rumext$v2$use_id$$)(),$state_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,$key$jscomp$348$$,$default$$jscomp$55$$)}),$state$jscomp$156$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$2$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$156$$),
$APP.$rumext$v2$adapt$$($key$jscomp$348$$),$APP.$rumext$v2$adapt$$($id$jscomp$304$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$key$jscomp$348$$,$state$jscomp$156$$)});return $state_STAR_$jscomp$2$$};
$app$main$ui$hooks$use_shared_state$$=function($key$jscomp$347$$){var $default$$jscomp$54$$=$cljs$cst$5702$recent$$,$id$jscomp$303$$=(0,$APP.$rumext$v2$use_id$$)(),$state_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$storage$user$$,$key$jscomp$347$$,$default$$jscomp$54$$)}),$state$jscomp$155$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$1$$),$stream$jscomp$24$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$303$$)],
function(){return $APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$(function($p1__52742_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__52742_SHARP_$$),$key$jscomp$347$$)},$APP.$beicon$v2$core$filter$$(function($p1__52741_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__52741_SHARP_$$),$id$jscomp$303$$)},
$APP.$app$main$broadcast$stream$$)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$155$$),$APP.$rumext$v2$adapt$$($key$jscomp$347$$),$APP.$rumext$v2$adapt$$($id$jscomp$303$$)],function(){$APP.$app$main$broadcast$emit_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$303$$,$key$jscomp$347$$,$state$jscomp$155$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$key$jscomp$347$$,
$state$jscomp$155$$)});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$24$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$state_STAR_$jscomp$1$$));return $state_STAR_$jscomp$1$$};
$app$main$data$workspace$clipboard$copy_selected_css_nested$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$=function($meta70805$$){this.$meta70805$=$meta70805$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4174$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_css_nested$$},$app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70806$$,$meta70805__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$($meta70805__$1$$)},$app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70805$},$app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2232_objects$jscomp$588$$,$css$jscomp$9_selected$jscomp$67_state$jscomp$617$$){$_$jscomp$2232_objects$jscomp$588$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($css$jscomp$9_selected$jscomp$67_state$jscomp$617$$);
$css$jscomp$9_selected$jscomp$67_state$jscomp$617$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2232_objects$jscomp$588$$),$APP.$app$common$files$helpers$selected_with_children$$($_$jscomp$2232_objects$jscomp$588$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($css$jscomp$9_selected$jscomp$67_state$jscomp$617$$)));$css$jscomp$9_selected$jscomp$67_state$jscomp$617$$=$APP.$app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$4$($_$jscomp$2232_objects$jscomp$588$$,
$css$jscomp$9_selected$jscomp$67_state$jscomp$617$$,$css$jscomp$9_selected$jscomp$67_state$jscomp$617$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4163$with_prelude_QMARK_$$,!1],null));return $APP.$app$util$clipboard$to_clipboard$$($css$jscomp$9_selected$jscomp$67_state$jscomp$617$$)});return new $app$main$data$workspace$clipboard$copy_selected_css_nested_70804$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$copy_selected_css$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_css_70798$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_css_70798$$=function($meta70799$$){this.$meta70799$=$meta70799$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_css_70798$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_css_70798$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4173$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_css$$},$app$main$data$workspace$clipboard$copy_selected_css_70798$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70800$$,$meta70799__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_css_70798$$($meta70799__$1$$)},$app$main$data$workspace$clipboard$copy_selected_css_70798$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70799$},$app$main$data$workspace$clipboard$copy_selected_css_70798$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_css_70798$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2231_objects$jscomp$587$$,$css$jscomp$8_selected$jscomp$66_state$jscomp$616$$){$_$jscomp$2231_objects$jscomp$587$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($css$jscomp$8_selected$jscomp$66_state$jscomp$616$$);$css$jscomp$8_selected$jscomp$66_state$jscomp$616$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($_$jscomp$2231_objects$jscomp$587$$),
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($css$jscomp$8_selected$jscomp$66_state$jscomp$616$$));$css$jscomp$8_selected$jscomp$66_state$jscomp$616$$=$APP.$app$util$code_gen$style_css$generate_style$$.$cljs$core$IFn$_invoke$arity$4$($_$jscomp$2231_objects$jscomp$587$$,$css$jscomp$8_selected$jscomp$66_state$jscomp$616$$,$css$jscomp$8_selected$jscomp$66_state$jscomp$616$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4163$with_prelude_QMARK_$$,
!1],null));return $APP.$app$util$clipboard$to_clipboard$$($css$jscomp$8_selected$jscomp$66_state$jscomp$616$$)});return new $app$main$data$workspace$clipboard$copy_selected_css_70798$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$dashboard$subscription$main_menu_power_up_STAR_$$=function($close_sub_menu_props_73902$$){$close_sub_menu_props_73902$$=$close_sub_menu_props_73902$$.closeSubMenu;var $go_to_subscription$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$router$nav$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$5225$settings_subscription$$))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_dashboard_subscription__menu-item",onClick:$go_to_subscription$jscomp$1$$,onKeyDown:function($event$jscomp$192$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$192$$))?$go_to_subscription$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$go_to_subscription$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$go_to_subscription$jscomp$1$$():null},onPointerEnter:$close_sub_menu_props_73902$$,id:"file-menu-power-up",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_dashboard_subscription__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.workspace.header.menu.option.power-up")})})};
$app$main$data$workspace$tokens$library_edit$drop_error$$=function($p__73171$$){var $map__73172__$1$$=$APP.$cljs$core$__destructure_map$$($p__73171$$),$error$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73172__$1$$,$APP.$cljs$cst$849$error$$),$to_path$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73172__$1$$,$APP.$cljs$cst$2666$to_path$$);typeof $app$main$data$workspace$tokens$library_edit$drop_error_73176$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$drop_error_73176$$=
function($p__73171$jscomp$1$$,$map__73172$jscomp$1$$,$error$jscomp$77$$,$to_path$jscomp$12$$,$meta73177$$){this.$p__73171$=$p__73171$jscomp$1$$;this.$map__73172$=$map__73172$jscomp$1$$;this.error=$error$jscomp$77$$;this.$to_path$=$to_path$jscomp$12$$;this.$meta73177$=$meta73177$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$drop_error_73176$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$library_edit$drop_error_73176$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4793$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_error$$},$app$main$data$workspace$tokens$library_edit$drop_error_73176$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73178$$,$meta73177__$1$$){return new $app$main$data$workspace$tokens$library_edit$drop_error_73176$$(this.$p__73171$,this.$map__73172$,this.error,
this.$to_path$,$meta73177__$1$$)},$app$main$data$workspace$tokens$library_edit$drop_error_73176$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73177$},$app$main$data$workspace$tokens$library_edit$drop_error_73176$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_error_73176$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6683$$=this,$content$jscomp$225$$=function(){var $G__73179$$=
$self__$jscomp$6683$$.error;switch($G__73179$$ instanceof $APP.$cljs$core$Keyword$$?$G__73179$$.$fqn$:null){case "path-exists":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.token-set-exists-on-drop",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$self__$jscomp$6683$$.$to_path$]));case "parent-to-child":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.drop-token-set-parent-to-child");default:return null}}();return $APP.$cljs$core$truth_$$($content$jscomp$225$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1642$content$$,$content$jscomp$225$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2364$timeout$$,9E3],null))):null});return new $app$main$data$workspace$tokens$library_edit$drop_error_73176$$($p__73171$$,$map__73172__$1$$,$error$jscomp$76$$,$to_path$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$=function($JSCompiler_temp$jscomp$1656_error$jscomp$74$$){if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1656_error$jscomp$74$$)){var $JSCompiler_inline_result$jscomp$1660_temp__5823__auto__$jscomp$187$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1656_error$jscomp$74$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1660_temp__5823__auto__$jscomp$187$$)){var $JSCompiler_temp_const$jscomp$1658$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1657$$=$APP.$cljs$cst$141$message$$,$G__72080$jscomp$inline_8517$$=$APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1656_error$jscomp$74$$);$JSCompiler_inline_result$jscomp$1660_temp__5823__auto__$jscomp$187$$=$JSCompiler_inline_result$jscomp$1660_temp__5823__auto__$jscomp$187$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1660_temp__5823__auto__$jscomp$187$$.$cljs$core$IFn$_invoke$arity$1$($G__72080$jscomp$inline_8517$$):
$JSCompiler_inline_result$jscomp$1660_temp__5823__auto__$jscomp$187$$($G__72080$jscomp$inline_8517$$);$JSCompiler_temp$jscomp$1656_error$jscomp$74$$=$JSCompiler_temp_const$jscomp$1658$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$1656_error$jscomp$74$$,$JSCompiler_temp_const$jscomp$1657$$,$JSCompiler_inline_result$jscomp$1660_temp__5823__auto__$jscomp$187$$)}return $JSCompiler_temp$jscomp$1656_error$jscomp$74$$}return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1656_error$jscomp$74$$,
$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.unknown-error"))};
$app$main$data$workspace$tokens$errors$resolve_error_message$$=function($G__72077_error$jscomp$73$$){if($APP.$cljs$core$truth_$$($G__72077_error$jscomp$73$$)){var $temp__5823__auto__$jscomp$186$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($G__72077_error$jscomp$73$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$186$$)?($G__72077_error$jscomp$73$$=$APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($G__72077_error$jscomp$73$$),$temp__5823__auto__$jscomp$186$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5823__auto__$jscomp$186$$.$cljs$core$IFn$_invoke$arity$1$($G__72077_error$jscomp$73$$):$temp__5823__auto__$jscomp$186$$($G__72077_error$jscomp$73$$)):$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($G__72077_error$jscomp$73$$)}return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.unknown-error")};
$app$main$data$style_dictionary$resolve_tokens_with_verbose_errors$$=function($tokens$jscomp$34$$){return $APP.$app$main$data$style_dictionary$resolve_tokens_tree$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$tokens_lib$tokens_tree$$($tokens$jscomp$34$$),function($p1__72424_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$34$$,$p1__72424_SHARP_$$.original.name)},new $APP.$app$main$data$style_dictionary$StyleDictionary$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$style_dictionary$default_config$$,
$APP.$cljs$cst$3040$log$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4697$verbosity$$,"verbose"],null))))};
$app$main$data$workspace$tokens$errors$error_ex_info$$=function($err$jscomp$39_error_key$jscomp$2$$,$error_value$jscomp$1$$,$exception$jscomp$12$$){$err$jscomp$39_error_key$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$main$data$workspace$tokens$errors$error_with_value$$($err$jscomp$39_error_key$jscomp$2$$,$error_value$jscomp$1$$),$APP.$cljs$cst$4685$error_SLASH_exception$$,$exception$jscomp$12$$);return $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$945$error_SLASH_code$$.$cljs$core$IFn$_invoke$arity$1$($err$jscomp$39_error_key$jscomp$2$$),
$err$jscomp$39_error_key$jscomp$2$$)};
$app$util$color$get_color_name$$=function($color$jscomp$41$$){var $or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($color$jscomp$41$$));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$))return $or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$;$or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$41$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$))return $or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$;$or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$41$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$)?
$or__5025__auto__$jscomp$500_or__5025__auto____$1$jscomp$54_or__5025__auto____$2$jscomp$13$$:$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$41$$)))};
$app$main$data$workspace$clipboard$copy_as_image$$=function(){typeof $app$main$data$workspace$clipboard$copy_as_image_71197$$==="undefined"&&($app$main$data$workspace$clipboard$copy_as_image_71197$$=function($meta71198$$){this.$meta71198$=$meta71198$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_as_image_71197$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_as_image_71197$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4189$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_as_image$$},$app$main$data$workspace$clipboard$copy_as_image_71197$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71199$$,$meta71198__$1$$){return new $app$main$data$workspace$clipboard$copy_as_image_71197$$($meta71198__$1$$)},$app$main$data$workspace$clipboard$copy_as_image_71197$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71198$},$app$main$data$workspace$clipboard$copy_as_image_71197$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_as_image_71197$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2244_export$_file_id$jscomp$208$$,$state$jscomp$632$$){$_$jscomp$2244_export$_file_id$jscomp$208$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$632$$);var $page_id$jscomp$197$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$632$$),$selected$jscomp$76$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$632$$));
$_$jscomp$2244_export$_file_id$jscomp$208$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1649$file_id$$,$_$jscomp$2244_export$_file_id$jscomp$208$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$197$$,$APP.$cljs$cst$2281$object_id$$,$selected$jscomp$76$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1539$png$$,$APP.$cljs$cst$1910$scale$$,2,$APP.$cljs$cst$1376$suffix$$,"",$APP.$cljs$cst$3133$enabled$$,!0,$APP.$cljs$cst$725$name$$,""],null);var $deferred$jscomp$12$$=new $APP.$$jscomp$scope$84173391$14$PromiseImpl$$,
$write_promise$$=$APP.$app$util$clipboard$to_clipboard_promise$$("image/png",$deferred$jscomp$12$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2545$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$),$APP.$app$main$data$persistence$wait_persisted$cljs$0core$0IFn$0_invoke$0arity$01$$(400)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$info$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.clipboard.copying"))),
$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($e$jscomp$330$$){console.error("clipboard error:",$e$jscomp$330$$);$APP.$promesa$protocols$_reject_BANG_$$($deferred$jscomp$12$$,$e$jscomp$330$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.clipboard.image-copy-failed")))},$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$notifications$success$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.clipboard.image-copied"))},
$APP.$beicon$v2$core$mapcat$$(function($blob$jscomp$36$$){$APP.$promesa$protocols$_resolve_BANG_$$($deferred$jscomp$12$$,$blob$jscomp$36$$);return $APP.$beicon$v2$core$from$$($write_promise$$)},$APP.$beicon$v2$core$map$$($APP.$cljs$cst$1586$body$$,$APP.$beicon$v2$core$mapcat$$(function($map__71202__$1_p__71201_uri$jscomp$97$$){$map__71202__$1_p__71201_uri$jscomp$97$$=$APP.$cljs$core$__destructure_map$$($map__71202__$1_p__71201_uri$jscomp$97$$);$map__71202__$1_p__71201_uri$jscomp$97$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71202__$1_p__71201_uri$jscomp$97$$,
$APP.$cljs$cst$1584$uri$$);return $APP.$app$util$http$send_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1583$method$$,$APP.$cljs$cst$1302$get$$,$APP.$cljs$cst$1584$uri$$,$map__71202__$1_p__71201_uri$jscomp$97$$,$APP.$cljs$cst$1592$response_type$$,$APP.$cljs$cst$1596$blob$$],null))},$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$632$$,"render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4190$wasm_export$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1584$uri$$,$APP.$app$main$data$exports$wasm$export_image_uri$$($_$jscomp$2244_export$_file_id$jscomp$208$$)],null)):$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2185$export$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1877$exports$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_$jscomp$2244_export$_file_id$jscomp$208$$],null),$APP.$cljs$cst$2321$profile_id$$,$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$632$$),
$APP.$cljs$cst$3139$cmd$$,$APP.$cljs$cst$4191$export_shapes$$,$APP.$cljs$cst$2290$wait$$,!0],null))))))))});return new $app$main$data$workspace$clipboard$copy_as_image_71197$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$clipboard$copy_selected_svg$$=function(){typeof $app$main$data$workspace$clipboard$copy_selected_svg_70795$$==="undefined"&&($app$main$data$workspace$clipboard$copy_selected_svg_70795$$=function($meta70796$$){this.$meta70796$=$meta70796$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$clipboard$copy_selected_svg_70795$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_svg_70795$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4172$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_copy_selected_svg$$},$app$main$data$workspace$clipboard$copy_selected_svg_70795$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70797$$,$meta70796__$1$$){return new $app$main$data$workspace$clipboard$copy_selected_svg_70795$$($meta70796__$1$$)},$app$main$data$workspace$clipboard$copy_selected_svg_70795$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70796$},$app$main$data$workspace$clipboard$copy_selected_svg_70795$$.prototype.$potok$v2$core$EffectEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$copy_selected_svg_70795$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$,$state$jscomp$615$$){var $objects$jscomp$586$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$615$$);$_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$586$$),
$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$586$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$615$$)));var $parent_frame_id$jscomp$2$$=$APP.$app$common$files$helpers$common_parent_frame$$($objects$jscomp$586$$,$_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$);$_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70794_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parent_frame_id$jscomp$2$$,
$APP.$app$common$uuid$zero$$)?$p1__70794_SHARP_$$:$APP.$app$common$geom$shapes$translate_to_frame$$($p1__70794_SHARP_$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$586$$,$parent_frame_id$jscomp$2$$))},$_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$);$_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$=$APP.$app$util$code_beautify$format_code$$($APP.$app$util$code_gen$markup_svg$generate_markup$$($objects$jscomp$586$$,$_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$),
"svg");return $app$util$clipboard$to_clipboard_multi$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,["image/svg+xml",$_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$,"text/plain",$_$jscomp$2230_selected$jscomp$65_shapes$jscomp$117_svg_formatted$$],null))});return new $app$main$data$workspace$clipboard$copy_selected_svg_70795$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$modifiers$set_wasm_modifiers$$=function($var_args$jscomp$1255$$){for(var $args__5755__auto__$jscomp$227$$=[],$len__5749__auto___69187$$=arguments.length,$i__5750__auto___69188$$=0;;)if($i__5750__auto___69188$$<$len__5749__auto___69187$$)$args__5755__auto__$jscomp$227$$.push(arguments[$i__5750__auto___69188$$]),$i__5750__auto___69188$$+=1;else break;return $APP.$app$main$data$workspace$modifiers$set_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<
$args__5755__auto__$jscomp$227$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$227$$.slice(1),0,null):null)};
$app$main$data$workspace$texts$v2_sync_wasm_text_layout$$=function($id$jscomp$646$$,$content$jscomp$187$$){typeof $app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$==="undefined"&&($app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$=function($id$jscomp$647$$,$content$jscomp$188$$,$meta70601$$){this.id=$id$jscomp$647$$;this.content=$content$jscomp$188$$;this.$meta70601$=$meta70601$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4105$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_v2_sync_wasm_text_layout$$},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70602$$,$meta70601__$1$$){return new $app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$(this.id,
this.content,$meta70601__$1$$)},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70601$},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$,
$state$jscomp$604$$){$_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$604$$);$_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$,this.id);return $_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$!=null&&$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$)?
($_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$=$APP.$app$main$data$workspace$wasm_text$get_wasm_text_new_size$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$,this.content)!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1676$fixed$$,$APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$))?$APP.$app$main$data$workspace$wasm_text$resize_wasm_text_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$,
this.content):null,$_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$!=null?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$set_wasm_modifiers$$($_$jscomp$2215_modifiers$jscomp$96_objects$jscomp$526_shape$jscomp$592$$)):$APP.$beicon$v2$core$empty$$()):$APP.$beicon$v2$core$empty$$()},$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=
function(){return $APP.$app$render_wasm$api$request_render$$("text-editor-v2-needslayout")});return new $app$main$data$workspace$texts$v2_sync_wasm_text_layout_70600$$($id$jscomp$646$$,$content$jscomp$187$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$resize_text_editor$$=function($id$jscomp$560$$,$p__69615$$){var $map__69616__$1$$=$APP.$cljs$core$__destructure_map$$($p__69615$$),$width$jscomp$139$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69616__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$125$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69616__$1$$,$APP.$cljs$cst$1527$height$$);typeof $app$main$data$workspace$transforms$resize_text_editor_69617$$==="undefined"&&($app$main$data$workspace$transforms$resize_text_editor_69617$$=
function($id$jscomp$561$$,$p__69615$jscomp$1$$,$map__69616$jscomp$1$$,$width$jscomp$140$$,$height$jscomp$126$$,$meta69618$$){this.id=$id$jscomp$561$$;this.$p__69615$=$p__69615$jscomp$1$$;this.$map__69616$=$map__69616$jscomp$1$$;this.width=$width$jscomp$140$$;this.height=$height$jscomp$126$$;this.$meta69618$=$meta69618$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$resize_text_editor_69617$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$resize_text_editor_69617$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3957$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_resize_text_editor$$},$app$main$data$workspace$transforms$resize_text_editor_69617$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69619$$,$meta69618__$1$$){return new $app$main$data$workspace$transforms$resize_text_editor_69617$$(this.id,this.$p__69615$,
this.$map__69616$,this.width,this.height,$meta69618__$1$$)},$app$main$data$workspace$transforms$resize_text_editor_69617$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69618$},$app$main$data$workspace$transforms$resize_text_editor_69617$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$resize_text_editor_69617$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$,
$resize_v$jscomp$1_state$jscomp$486$$){$_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($resize_v$jscomp$1_state$jscomp$486$$);$_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$,this.id);$resize_v$jscomp$1_state$jscomp$486$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(this.width/
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$)),this.height/$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$)));var $origin$jscomp$42$$=$APP.$cljs$core$first$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$));
$_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$=$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([this.id,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1816$modifiers$$,$APP.$app$common$types$modifiers$resize_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($resize_v$jscomp$1_state$jscomp$486$$,$origin$jscomp$42$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()),
$APP.$cljs$cst$1793$transform_inverse$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$,$APP.$app$common$geom$matrix$matrix$$.$cljs$core$IFn$_invoke$arity$0$()))],null)]);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$modifiers$set_wasm_modifiers$$($_$jscomp$2093_modifiers$jscomp$92_objects$jscomp$503_shape$jscomp$553$$))});return new $app$main$data$workspace$transforms$resize_text_editor_69617$$($id$jscomp$560$$,$p__69615$$,$map__69616__$1$$,
$width$jscomp$139$$,$height$jscomp$125$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_nudge$$=function($p__71937$$){var $map__71938__$1$$=$APP.$cljs$core$__destructure_map$$($p__71937$$),$big$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71938__$1$$,$APP.$cljs$cst$3944$big$$),$small$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71938__$1$$,$APP.$cljs$cst$3945$small$$);typeof $app$main$data$workspace$update_nudge_71939$$==="undefined"&&($app$main$data$workspace$update_nudge_71939$$=function($p__71937$jscomp$1$$,$map__71938$jscomp$1$$,
$params$jscomp$295$$,$big$jscomp$1$$,$small$jscomp$1$$,$meta71940$$){this.$p__71937$=$p__71937$jscomp$1$$;this.$map__71938$=$map__71938$jscomp$1$$;this.params=$params$jscomp$295$$;this.big=$big$jscomp$1$$;this.small=$small$jscomp$1$$;this.$meta71940$=$meta71940$$;this.$cljs$lang$protocol_mask$partition0$$=425984;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$update_nudge_71939$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_nudge_71939$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4540$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_nudge$$},$app$main$data$workspace$update_nudge_71939$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71941$$,$meta71940__$1$$){return new $app$main$data$workspace$update_nudge_71939$$(this.$p__71937$,this.$map__71938$,this.params,this.big,this.small,$meta71940__$1$$)},$app$main$data$workspace$update_nudge_71939$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71940$},$app$main$data$workspace$update_nudge_71939$$.prototype.$cljs$core$IDeref$_deref$arity$1$=
function(){return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(this.params)},$app$main$data$workspace$update_nudge_71939$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_nudge_71939$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2568$$,$state$jscomp$898$$){var $self__$jscomp$6267$$=this;return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$898$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1931$profile$$,$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3943$nudge$$],null),function($G__71942__$1_nudge$jscomp$1$$){$G__71942__$1_nudge$jscomp$1$$=typeof $self__$jscomp$6267$$.big==="number"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71942__$1_nudge$jscomp$1$$,$APP.$cljs$cst$3944$big$$,$self__$jscomp$6267$$.big):$G__71942__$1_nudge$jscomp$1$$;return typeof $self__$jscomp$6267$$.small==="number"?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71942__$1_nudge$jscomp$1$$,
$APP.$cljs$cst$3945$small$$,$self__$jscomp$6267$$.small):$G__71942__$1_nudge$jscomp$1$$})},$app$main$data$workspace$update_nudge_71939$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_nudge_71939$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2569_nudge$jscomp$2$$,$state$jscomp$899$$){$_$jscomp$2569_nudge$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$899$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1931$profile$$,$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3943$nudge$$],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3943$nudge$$,$_$jscomp$2569_nudge$jscomp$2$$],null)))});return new $app$main$data$workspace$update_nudge_71939$$($p__71937$$,$map__71938__$1$$,$map__71938__$1$$,$big$$,$small$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$finalize_workspace$$=function($_team_id$$,$file_id$jscomp$273$$){typeof $app$main$data$workspace$finalize_workspace_71915$$==="undefined"&&($app$main$data$workspace$finalize_workspace_71915$$=function($_team_id$jscomp$1$$,$file_id$jscomp$274$$,$meta71916$$){this.$_team_id$=$_team_id$jscomp$1$$;this.$file_id$=$file_id$jscomp$274$$;this.$meta71916$=$meta71916$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$finalize_workspace_71915$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$finalize_workspace_71915$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4405$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize_workspace$$},$app$main$data$workspace$finalize_workspace_71915$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71917$$,$meta71916__$1$$){return new $app$main$data$workspace$finalize_workspace_71915$$(this.$_team_id$,this.$file_id$,$meta71916__$1$$)},$app$main$data$workspace$finalize_workspace_71915$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71916$},$app$main$data$workspace$finalize_workspace_71915$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$finalize_workspace_71915$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2560$$,$state$jscomp$894$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$894$$,
$APP.$cljs$cst$1934$current_file_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2230$workspace_editor_state$$,$APP.$cljs$cst$2232$workspace_wasm_editor_styles$$,$APP.$cljs$cst$4535$workspace_media_objects$$,$APP.$cljs$cst$4536$workspace_persistence$$,$APP.$cljs$cst$2224$workspace_presence$$,$APP.$cljs$cst$2145$workspace_tokens$$,$APP.$cljs$cst$3616$workspace_undo$$,$APP.$cljs$cst$4537$workspace_versions$$])),$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$core$dissoc$$,
$APP.$cljs$cst$2225$read_only_QMARK_$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$2208$options_mode$$],null),$APP.$cljs$cst$3782$design$$),$APP.$cljs$cst$1933$files$$,$APP.$app$common$data$update_vals$$,function($p1__71914_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__71914_SHARP_$$,$APP.$cljs$cst$142$data$$)})},$app$main$data$workspace$finalize_workspace_71915$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$finalize_workspace_71915$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2561_project_id$jscomp$15$$,$state$jscomp$895$$){$_$jscomp$2561_project_id$jscomp$15$$=$APP.$cljs$cst$2182$current_project_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$895$$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$notifications$finalize$$(this.$file_id$),$app$main$data$project$finalize_project$$($_$jscomp$2561_project_id$jscomp$15$$),
$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4461$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_finalize_shape_layout$$),$app$main$data$workspace$colors$stop_picker$$(),$APP.$app$main$data$workspace$common$set_workspace_visited$$(),$APP.$app$main$data$modal$hide$$(),$APP.$app$main$data$notifications$hide$$())});return new $app$main$data$workspace$finalize_workspace_71915$$($_team_id$$,$file_id$jscomp$273$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$malli$util$assoc_in$cljs$0core$0IFn$0_invoke$0arity$04$$=function($_QMARK_schema$jscomp$121_schema$jscomp$79$$,$first__35101_p__35098$$,$JSCompiler_temp$jscomp$439_value$jscomp$295$$,$JSCompiler_inline_result$jscomp$440_default$$jscomp$inline_8524_options$jscomp$291$$){var $seq__35100_seq__35100__$1$$=$APP.$cljs$core$seq$$($first__35101_p__35098$$);$first__35101_p__35098$$=$APP.$cljs$core$first$$($seq__35100_seq__35100__$1$$);$seq__35100_seq__35100__$1$$=$APP.$cljs$core$next$$($seq__35100_seq__35100__$1$$);
$_QMARK_schema$jscomp$121_schema$jscomp$79$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($_QMARK_schema$jscomp$121_schema$jscomp$79$$,$JSCompiler_inline_result$jscomp$440_default$$jscomp$inline_8524_options$jscomp$291$$);$seq__35100_seq__35100__$1$$&&($JSCompiler_inline_result$jscomp$440_default$$jscomp$inline_8524_options$jscomp$291$$=$APP.$malli$core$schema$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$202$map$$,$APP.$malli$core$options$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_schema$jscomp$121_schema$jscomp$79$$)),
$JSCompiler_inline_result$jscomp$440_default$$jscomp$inline_8524_options$jscomp$291$$=$APP.$malli$util$get$cljs$0core$0IFn$0_invoke$0arity$04$$($_QMARK_schema$jscomp$121_schema$jscomp$79$$,$first__35101_p__35098$$,$JSCompiler_inline_result$jscomp$440_default$$jscomp$inline_8524_options$jscomp$291$$),$JSCompiler_temp$jscomp$439_value$jscomp$295$$=$malli$util$assoc_in$cljs$0core$0IFn$0_invoke$0arity$04$$($JSCompiler_inline_result$jscomp$440_default$$jscomp$inline_8524_options$jscomp$291$$,$seq__35100_seq__35100__$1$$,
$JSCompiler_temp$jscomp$439_value$jscomp$295$$,null));return $APP.$malli$util$assoc$cljs$0core$0IFn$0_invoke$0arity$04$$($_QMARK_schema$jscomp$121_schema$jscomp$79$$,$first__35101_p__35098$$,$JSCompiler_temp$jscomp$439_value$jscomp$295$$,null)};
$malli$error$_resolve_direct_error$$=function($JSCompiler_temp_const$jscomp$1661__$jscomp$766$$,$error$jscomp$22$$,$options$jscomp$392$$){$JSCompiler_temp_const$jscomp$1661__$jscomp$766$$=$APP.$cljs$core$PersistentVector$EMPTY_NODE$$;var $JSCompiler_inline_result$jscomp$1662_JSCompiler_temp_const$jscomp$11263$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$;var $JSCompiler_temp_const$jscomp$11262$$=$APP.$cljs$cst$297$in$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$22$$);var $JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$=
$APP.$cljs$core$__destructure_map$$($error$jscomp$22$$);var $properties$jscomp$inline_13571_schema$jscomp$inline_13567$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$,$APP.$cljs$cst$298$schema$$),$default_locale$jscomp$inline_13570_map__35408__$1$jscomp$inline_13568$$=$APP.$cljs$core$__destructure_map$$($options$jscomp$392$$);$JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($default_locale$jscomp$inline_13570_map__35408__$1$jscomp$inline_13568$$,$APP.$cljs$cst$888$locale$$);$default_locale$jscomp$inline_13570_map__35408__$1$jscomp$inline_13568$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($default_locale$jscomp$inline_13570_map__35408__$1$jscomp$inline_13568$$,$APP.$cljs$cst$889$default_locale$$,$APP.$cljs$cst$883$en$$);$properties$jscomp$inline_13571_schema$jscomp$inline_13567$$=$APP.$malli$core$properties$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$inline_13571_schema$jscomp$inline_13567$$);
$JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$=$APP.$malli$error$_maybe_localized$$($APP.$cljs$cst$890$error_SLASH_path$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$inline_13571_schema$jscomp$inline_13567$$),$JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$);$JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$)?$JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$:$APP.$malli$error$_maybe_localized$$($APP.$cljs$cst$890$error_SLASH_path$$.$cljs$core$IFn$_invoke$arity$1$($properties$jscomp$inline_13571_schema$jscomp$inline_13567$$),$default_locale$jscomp$inline_13570_map__35408__$1$jscomp$inline_13568$$);
$JSCompiler_inline_result$jscomp$1662_JSCompiler_temp_const$jscomp$11263$$=$JSCompiler_inline_result$jscomp$1662_JSCompiler_temp_const$jscomp$11263$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$11262$$,$JSCompiler_inline_result$jscomp$11265_locale$jscomp$inline_13569_map__35406__$1$jscomp$inline_13566_or__5025__auto__$jscomp$inline_13572$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$JSCompiler_temp_const$jscomp$1661__$jscomp$766$$,[$JSCompiler_inline_result$jscomp$1662_JSCompiler_temp_const$jscomp$11263$$,
$APP.$malli$error$error_message$cljs$0core$0IFn$0_invoke$0arity$02$$($error$jscomp$22$$,$options$jscomp$392$$)],null)};
$malli$error$humanize$cljs$0core$0IFn$0_invoke$0arity$02$$=function($errors$jscomp$10_p__35631$$){var $map__35633__$1$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$10_p__35631$$),$value$jscomp$314$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35633__$1$$,$APP.$cljs$cst$260$value$$);$errors$jscomp$10_p__35631$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__35633__$1$$,$APP.$cljs$cst$570$errors$$);var $map__35634__$1$$=$APP.$cljs$core$__destructure_map$$(null),$wrap$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__35634__$1$$,$APP.$cljs$cst$896$wrap$$,$APP.$cljs$cst$141$message$$),$resolve$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__35634__$1$$,$APP.$cljs$cst$898$resolve$$,$malli$error$_resolve_direct_error$$);return $APP.$cljs$core$truth_$$($errors$jscomp$10_p__35631$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$73$$,$G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$){var $message$jscomp$46_vec__35637$$=
$resolve$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$resolve$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($map__35633__$1$$,$G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$,$map__35634__$1$$):$resolve$jscomp$1$$($map__35633__$1$$,$G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$,$map__35634__$1$$),$path$jscomp$115$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$46_vec__35637$$,0,null);$message$jscomp$46_vec__35637$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$46_vec__35637$$,1,null);$G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$,$APP.$cljs$cst$141$message$$,$message$jscomp$46_vec__35637$$);$G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$=$wrap$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?
$wrap$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$):$wrap$jscomp$2$$($G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$);return $malli$error$_push_in$$($acc$jscomp$73$$,$value$jscomp$314$$,$path$jscomp$115$$,$G__35641$jscomp$inline_8537_JSCompiler_inline_result$jscomp$1663_error$jscomp$27$$)},null,$errors$jscomp$10_p__35631$$):null};
$app$common$schema$valid_QMARK_$$=function($s$jscomp$378$$,$value$jscomp$316$$){try{return $APP.$malli$core$validate$cljs$0core$0IFn$0_invoke$0arity$03$$($s$jscomp$378$$,$value$jscomp$316$$)}catch($e40203$$){return!1}};
$app$main$data$plugins$update_plugin_permissions_peek$$=function($map__66395__$1_p__66394_url$jscomp$85$$){$map__66395__$1_p__66394_url$jscomp$85$$=$APP.$cljs$core$__destructure_map$$($map__66395__$1_p__66394_url$jscomp$85$$);var $plugin_id$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66395__$1_p__66394_url$jscomp$85$$,$APP.$cljs$cst$1725$plugin_id$$);$map__66395__$1_p__66394_url$jscomp$85$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__66395__$1_p__66394_url$jscomp$85$$,
$APP.$cljs$cst$1991$url$$);$APP.$cljs$core$truth_$$($map__66395__$1_p__66394_url$jscomp$85$$)&&$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($new_manifest$jscomp$1_permissions$jscomp$12$$){$new_manifest$jscomp$1_permissions$jscomp$12$$=$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($new_manifest$jscomp$1_permissions$jscomp$12$$);return $APP.$cljs$core$truth_$$($new_manifest$jscomp$1_permissions$jscomp$12$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$plugins$save_plugin_permissions_peek$$($plugin_id$jscomp$12$$,
$new_manifest$jscomp$1_permissions$jscomp$12$$)):null},function(){return null},$APP.$app$main$data$plugins$fetch_manifest$$($map__66395__$1_p__66394_url$jscomp$85$$))};
$app$main$data$plugins$update_plugins_permissions_peek$$=function(){typeof $app$main$data$plugins$update_plugins_permissions_peek_66403$$==="undefined"&&($app$main$data$plugins$update_plugins_permissions_peek_66403$$=function($meta66404$$){this.$meta66404$=$meta66404$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$plugins$update_plugins_permissions_peek_66403$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$update_plugins_permissions_peek_66403$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$3461$app_DOT_main_DOT_data_DOT_plugins_SLASH_update_plugins_permissions_peek$$},$app$main$data$plugins$update_plugins_permissions_peek_66403$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_66405$$,$meta66404__$1$$){return new $app$main$data$plugins$update_plugins_permissions_peek_66403$$($meta66404__$1$$)},$app$main$data$plugins$update_plugins_permissions_peek_66403$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta66404$},$app$main$data$plugins$update_plugins_permissions_peek_66403$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$plugins$update_plugins_permissions_peek_66403$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$1804_now$jscomp$5$$,$state$jscomp$255$$){$_$jscomp$1804_now$jscomp$5$$=$APP.$app$common$time$now$$();var $c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$=$APP.$app$common$time$minus$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3462$days$$,1],null)),$G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$255$$,$APP.$cljs$cst$2235$plugins_permissions_peek$$),$APP.$cljs$cst$3463$updated_at$$,0);if($c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$>$G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$){$c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$=$APP.$app$plugins$register$plugins_list$$();
$c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$=$APP.$cljs$core$seq$$($c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$);$G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$=null;for(var $G__66528_count__66412_66516$$=0,$G__66526_i__66413_66517$$=0;;)if($G__66526_i__66413_66517$$<$G__66528_count__66412_66516$$){var $plugin_66518$$=$G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__66526_i__66413_66517$$);$app$main$data$plugins$update_plugin_permissions_peek$$($plugin_66518$$);$G__66526_i__66413_66517$$+=1}else if($c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$=$APP.$cljs$core$seq$$($c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$))$G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$=$c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$)?($c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$=$APP.$cljs$core$_chunked_first$$($G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$),$G__66526_i__66413_66517$$=$APP.$cljs$core$_chunked_rest$$($G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$),$G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$=$c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$,
$G__66528_count__66412_66516$$=$APP.$cljs$core$count$$($c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$),$c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$=$G__66526_i__66413_66517$$):($c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$=$APP.$cljs$core$first$$($G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$),$app$main$data$plugins$update_plugin_permissions_peek$$($c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$),
$c__5548__auto___66525_expiration_plugin_66530_plugins_seq__66410_66514_temp__5825__auto___66523$$=$APP.$cljs$core$next$$($G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$),$G__66527_chunk__66411_66515_seq__66410_66524__$1_updated_at$$=null,$G__66528_count__66412_66516$$=0),$G__66526_i__66413_66517$$=0;else break;return $APP.$cljs$core$assoc_in$$($state$jscomp$255$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2235$plugins_permissions_peek$$,
$APP.$cljs$cst$3463$updated_at$$],null),$_$jscomp$1804_now$jscomp$5$$)}return $state$jscomp$255$$});return new $app$main$data$plugins$update_plugins_permissions_peek_66403$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$types$tokens_lib$export_dtcg_multi_file$$=function($tokens_lib$jscomp$2$$){var $active_themes$jscomp$6_vec__50091$$=$APP.$app$common$types$tokens_lib$dtcg_export_themes$$($tokens_lib$jscomp$2$$),$themes$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($active_themes$jscomp$6_vec__50091$$,0,null);$active_themes$jscomp$6_vec__50091$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($active_themes$jscomp$6_vec__50091$$,1,null);var $sets$jscomp$11$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($token_set$jscomp$6_tokens$jscomp$19$$){var $name$jscomp$223$$=$APP.$app$common$types$tokens_lib$get_name$$($token_set$jscomp$6_tokens$jscomp$19$$);$token_set$jscomp$6_tokens$jscomp$19$$=$APP.$app$common$types$tokens_lib$get_tokens_$$($token_set$jscomp$6_tokens$jscomp$19$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$223$$),
".json"].join(""),$APP.$app$common$types$tokens_lib$tokens_tree$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($token_set$jscomp$6_tokens$jscomp$19$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2111$update_token_fn$$,$APP.$app$common$types$tokens_lib$token__GT_dtcg_token$$]))],null)},$APP.$app$common$types$tokens_lib$get_sets$$($tokens_lib$jscomp$2$$)));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($sets$jscomp$11$$,
"$themes.json",$themes$jscomp$6$$),"$metadata.json",new $APP.$cljs$core$PersistentArrayMap$$(null,3,["tokenSetOrder",$app$common$types$tokens_lib$get_set_names$$($tokens_lib$jscomp$2$$),"activeThemes",$active_themes$jscomp$6_vec__50091$$,"activeSets",$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($tokens_lib$jscomp$2$$)],null))};
$app$main$data$workspace$colors$add_recent_color$$=function($color$jscomp$93_color__$1$jscomp$12$$){$color$jscomp$93_color__$1$jscomp$12$$=(0,$APP.$app$common$types$color$check_color$$)($color$jscomp$93_color__$1$jscomp$12$$);typeof $app$main$data$workspace$colors$add_recent_color_71194$$==="undefined"&&($app$main$data$workspace$colors$add_recent_color_71194$$=function($color$jscomp$94$$,$meta71195$$){this.color=$color$jscomp$94$$;this.$meta71195$=$meta71195$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$add_recent_color_71194$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_recent_color_71194$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4233$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_recent_color$$},$app$main$data$workspace$colors$add_recent_color_71194$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71196$$,$meta71195__$1$$){return new $app$main$data$workspace$colors$add_recent_color_71194$$(this.color,$meta71195__$1$$)},$app$main$data$workspace$colors$add_recent_color_71194$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71195$},$app$main$data$workspace$colors$add_recent_color_71194$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_recent_color_71194$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2275_file_id$jscomp$209$$,$state$jscomp$654$$){var $self__$jscomp$5297$$=this;$_$jscomp$2275_file_id$jscomp$209$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$654$$);return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$654$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2221$recent_colors$$,$_$jscomp$2275_file_id$jscomp$209$$],null),function($colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$){$colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$=
$APP.$app$common$data$removev$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$colors$recent_color_equal_QMARK_$$,$self__$jscomp$5297$$.color),$colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$);$colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$,$self__$jscomp$5297$$.color);return $APP.$cljs$core$count$$($colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$)>
15?$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$02$$($colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$,1):$colors$jscomp$4_colors__$1$jscomp$2_colors__$2$jscomp$1$$})},$app$main$data$workspace$colors$add_recent_color_71194$$.prototype.$potok$v2$core$EffectEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_recent_color_71194$$.prototype.$potok$v2$core$EffectEvent$effect$arity$3$=function($_$jscomp$2276_recent_colors$$,$state$jscomp$655$$){$_$jscomp$2276_recent_colors$$=
$APP.$cljs$cst$2221$recent_colors$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$655$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2221$recent_colors$$,$_$jscomp$2276_recent_colors$$)});return new $app$main$data$workspace$colors$add_recent_color_71194$$($color$jscomp$93_color__$1$jscomp$12$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$apply_color_from_colorpicker$$=function($color$jscomp$91_color__$1$jscomp$11$$){$color$jscomp$91_color__$1$jscomp$11$$=(0,$APP.$app$common$types$color$check_color$$)($color$jscomp$91_color__$1$jscomp$11$$);typeof $app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$==="undefined"&&($app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$=function($color$jscomp$92$$,$meta71177$$){this.color=$color$jscomp$92$$;this.$meta71177$=$meta71177$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4228$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_colorpicker$$},$app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71178$$,$meta71177__$1$$){return new $app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$(this.color,$meta71177__$1$$)},$app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71177$},$app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2274$$,$state$jscomp$653$$){var $self__$jscomp$5293$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$653$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$29$$){if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5293$$.color)))return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$29$$,$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1617$image$$),$APP.$cljs$cst$4229$editing_stop$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1739$stops$$,$APP.$cljs$cst$1730$gradient$$]));if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5293$$.color)))return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$29$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1303$color$$),
$APP.$cljs$cst$4229$editing_stop$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1739$stops$$,$APP.$cljs$cst$1730$gradient$$]));var $gradient_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5293$$.color,$APP.$cljs$cst$1730$gradient$$),$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$287$linear$$,$gradient_type$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$29$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$4230$linear_gradient$$),$APP.$cljs$cst$4229$editing_stop$$,0),$APP.$cljs$cst$4231$current_color$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1617$image$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1734$radial$$,$gradient_type$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$29$$,$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$4232$radial_gradient$$),$APP.$cljs$cst$4229$editing_stop$$,0),$APP.$cljs$cst$4231$current_color$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1617$image$$):null})});return new $app$main$data$workspace$colors$apply_color_from_colorpicker_71176$$($color$jscomp$91_color__$1$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$start_path_from_point$$=function($position$jscomp$136$$){typeof $app$main$data$workspace$path$drawing$start_path_from_point_70070$$==="undefined"&&($app$main$data$workspace$path$drawing$start_path_from_point_70070$$=function($position$jscomp$137$$,$meta70071$$){this.position=$position$jscomp$137$$;this.$meta70071$=$meta70071$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$start_path_from_point_70070$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_path_from_point_70070$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4288$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_start_path_from_point$$},$app$main$data$workspace$path$drawing$start_path_from_point_70070$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70072$$,$meta70071__$1$$){return new $app$main$data$workspace$path$drawing$start_path_from_point_70070$$(this.position,
$meta70071__$1$$)},$app$main$data$workspace$path$drawing$start_path_from_point_70070$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70071$},$app$main$data$workspace$path$drawing$start_path_from_point_70070$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$start_path_from_point_70070$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2322_stopper$jscomp$24$$,$drag_events_state$jscomp$704$$,
$stream$jscomp$71$$){$_$jscomp$2322_stopper$jscomp$24$$=$APP.$beicon$v2$core$merge$$($APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$71$$,null),$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$drawing$end_path_event_QMARK_$$,$stream$jscomp$71$$));$drag_events_state$jscomp$704$$=$APP.$beicon$v2$core$take_until$$($_$jscomp$2322_stopper$jscomp$24$$,$APP.$beicon$v2$core$map$$(function($p1__70069_SHARP_$$){return $APP.$app$main$data$workspace$path$drawing$drag_handler$cljs$0core$0IFn$0_invoke$0arity$04$$(null,
null,$APP.$cljs$cst$1827$c1$$,$p1__70069_SHARP_$$)},$APP.$app$main$data$workspace$path$streams$position_stream$$($drag_events_state$jscomp$704$$)));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$add_node$$(this.position)),$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$beicon$v2$core$concat$$($drag_events_state$jscomp$704$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$finish_drag$$()))))});
return new $app$main$data$workspace$path$drawing$start_path_from_point_70070$$($position$jscomp$136$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$drawing$close_path_drag_start$$=function($position$jscomp$134$$){typeof $app$main$data$workspace$path$drawing$close_path_drag_start_70050$$==="undefined"&&($app$main$data$workspace$path$drawing$close_path_drag_start_70050$$=function($position$jscomp$135$$,$meta70051$$){this.position=$position$jscomp$135$$;this.$meta70051$=$meta70051$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$drawing$close_path_drag_start_70050$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$close_path_drag_start_70050$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4286$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_drawing_SLASH_close_path_drag_start$$},$app$main$data$workspace$path$drawing$close_path_drag_start_70050$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70052$$,$meta70051__$1$$){return new $app$main$data$workspace$path$drawing$close_path_drag_start_70050$$(this.position,
$meta70051__$1$$)},$app$main$data$workspace$path$drawing$close_path_drag_start_70050$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70051$},$app$main$data$workspace$path$drawing$close_path_drag_start_70050$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$drawing$close_path_drag_start_70050$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$,$drag_events_stream_state$jscomp$702$$,
$stream$jscomp$70$$){var $self__$jscomp$5450$$=this;$_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($drag_events_stream_state$jscomp$702$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$]));$_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$path$get_handlers$$($_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$),
$self__$jscomp$5450$$.position);$_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$),1)?$APP.$cljs$core$first$$($_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$):null;var $idx$jscomp$95$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$,0,null),$prefix$jscomp$52$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($_$jscomp$2320_content$jscomp$202_handlers$jscomp$5_vec__70056$$,1,null);$drag_events_stream_state$jscomp$702$$=$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$merge$$($APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$70$$,null),$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$drawing$end_path_event_QMARK_$$,$stream$jscomp$70$$)),$APP.$beicon$v2$core$map$$(function($p1__70049_SHARP_$$){return $APP.$app$main$data$workspace$path$drawing$drag_handler$cljs$0core$0IFn$0_invoke$0arity$04$$($self__$jscomp$5450$$.position,
$idx$jscomp$95$$,$prefix$jscomp$52$$,$p1__70049_SHARP_$$)},$APP.$app$main$data$workspace$path$streams$position_stream$$($drag_events_stream_state$jscomp$702$$)));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$add_node$$($self__$jscomp$5450$$.position)),$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$beicon$v2$core$concat$$($drag_events_stream_state$jscomp$702$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$drawing$finish_drag$$()),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$drawing$close_path_drag_end$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$workspace$path$drawing$close_path_drag_end$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$workspace$path$drawing$close_path_drag_end$$()))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$common$finish_path$$()))});return new $app$main$data$workspace$path$drawing$close_path_drag_start_70050$$($position$jscomp$134$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$schema$validation_errors$$=function($JSCompiler_inline_result$jscomp$1664_exp$jscomp$inline_8539_value$jscomp$319$$,$_QMARK_schema$jscomp$inline_13574_explainer$jscomp$13_schema$jscomp$203$$){$_QMARK_schema$jscomp$inline_13574_explainer$jscomp$13_schema$jscomp$203$$=$APP.$app$common$schema$schema$$($_QMARK_schema$jscomp$inline_13574_explainer$jscomp$13_schema$jscomp$203$$);$_QMARK_schema$jscomp$inline_13574_explainer$jscomp$13_schema$jscomp$203$$=$APP.$malli$core$explainer$cljs$0core$0IFn$0_invoke$0arity$02$$($_QMARK_schema$jscomp$inline_13574_explainer$jscomp$13_schema$jscomp$203$$,
null);$JSCompiler_inline_result$jscomp$1664_exp$jscomp$inline_8539_value$jscomp$319$$=$_QMARK_schema$jscomp$inline_13574_explainer$jscomp$13_schema$jscomp$203$$.$cljs$core$IFn$_invoke$arity$1$?$_QMARK_schema$jscomp$inline_13574_explainer$jscomp$13_schema$jscomp$203$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1664_exp$jscomp$inline_8539_value$jscomp$319$$):$_QMARK_schema$jscomp$inline_13574_explainer$jscomp$13_schema$jscomp$203$$($JSCompiler_inline_result$jscomp$1664_exp$jscomp$inline_8539_value$jscomp$319$$);
$JSCompiler_inline_result$jscomp$1664_exp$jscomp$inline_8539_value$jscomp$319$$=$malli$error$humanize$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1664_exp$jscomp$inline_8539_value$jscomp$319$$);return $APP.$cljs$core$not_empty$$($JSCompiler_inline_result$jscomp$1664_exp$jscomp$inline_8539_value$jscomp$319$$)};
$app$main$data$workspace$colors$update_colorpicker_color$$=function($changes$jscomp$228$$,$add_recent_QMARK_$$){typeof $app$main$data$workspace$colors$update_colorpicker_color_71270$$==="undefined"&&($app$main$data$workspace$colors$update_colorpicker_color_71270$$=function($changes$jscomp$229$$,$add_recent_QMARK_$jscomp$1$$,$meta71271$$){this.$changes$=$changes$jscomp$229$$;this.$add_recent_QMARK_$=$add_recent_QMARK_$jscomp$1$$;this.$meta71271$=$meta71271$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$update_colorpicker_color_71270$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_color_71270$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4240$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_update_colorpicker_color$$},$app$main$data$workspace$colors$update_colorpicker_color_71270$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71272$$,$meta71271__$1$$){return new $app$main$data$workspace$colors$update_colorpicker_color_71270$$(this.$changes$,this.$add_recent_QMARK_$,$meta71271__$1$$)},$app$main$data$workspace$colors$update_colorpicker_color_71270$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71271$},$app$main$data$workspace$colors$update_colorpicker_color_71270$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_color_71270$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2289$$,$state$jscomp$667$$){var $self__$jscomp$5347$$=this;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$667$$,$APP.$cljs$cst$2247$colorpicker$$,function($G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$){var $type$jscomp$493$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$);$G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$,
$APP.$cljs$cst$4231$current_color$$,$APP.$cljs$core$merge$$,$self__$jscomp$5347$$.$changes$),$APP.$cljs$cst$4231$current_color$$,$app$main$data$workspace$colors$materialize_color_components$$),$APP.$cljs$cst$4231$current_color$$,function($p1__71269_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$493$$,$APP.$cljs$cst$1617$image$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__71269_SHARP_$$,$APP.$cljs$cst$1617$image$$):$p1__71269_SHARP_$$}),$APP.$cljs$cst$4231$current_color$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1741$ref_id$$,$APP.$cljs$cst$1742$ref_file$$);var $temp__5823__auto__$jscomp$180$$=$APP.$cljs$cst$4229$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$180$$))return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1739$stops$$,$temp__5823__auto__$jscomp$180$$],null),function($data$jscomp$386$$){return $app$main$data$workspace$colors$materialize_color_components$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$data$jscomp$386$$,$self__$jscomp$5347$$.$changes$])))});$G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$,
$APP.$cljs$cst$1730$gradient$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1739$stops$$,$APP.$cljs$cst$4229$editing_stop$$]));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1617$image$$,$type$jscomp$493$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1303$color$$):$G__71276_state__$1$jscomp$38_state__$2$jscomp$3$$})},$app$main$data$workspace$colors$update_colorpicker_color_71270$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$update_colorpicker_color_71270$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$,$ignore_color_QMARK__state$jscomp$668_type$jscomp$494$$){$_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$=$app$main$data$workspace$colors$get_color_from_colorpicker_state$$($APP.$cljs$cst$2247$colorpicker$$.$cljs$core$IFn$_invoke$arity$1$($ignore_color_QMARK__state$jscomp$668_type$jscomp$494$$));
$ignore_color_QMARK__state$jscomp$668_type$jscomp$494$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$,$APP.$cljs$cst$139$type$$);$ignore_color_QMARK__state$jscomp$668_type$jscomp$494$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ignore_color_QMARK__state$jscomp$668_type$jscomp$494$$,$APP.$cljs$cst$1303$color$$)&&$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$)==
null;var $and__5023__auto__$jscomp$inline_8541$$=this.$add_recent_QMARK_$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8541$$)?!$ignore_color_QMARK__state$jscomp$668_type$jscomp$494$$:$and__5023__auto__$jscomp$inline_8541$$)?($_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$select_keys$$($_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1617$image$$,$APP.$cljs$cst$1730$gradient$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1740$opacity$$],null))),$APP.$cljs$core$truth_$$($_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$)?$APP.$cljs$core$truth_$$((0,$APP.$app$common$types$color$valid_color_QMARK_$$)($_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$))?(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$colors$add_recent_color$$($_$jscomp$2290_state__$1$jscomp$39_temp__5825__auto__$jscomp$219$$)):
null:null):null});return new $app$main$data$workspace$colors$update_colorpicker_color_71270$$($changes$jscomp$228$$,$add_recent_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$activate_colorpicker_color$$=function(){typeof $app$main$data$workspace$colors$activate_colorpicker_color_71289$$==="undefined"&&($app$main$data$workspace$colors$activate_colorpicker_color_71289$$=function($meta71290$$){this.$meta71290$=$meta71290$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$activate_colorpicker_color_71289$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$colors$activate_colorpicker_color_71289$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4250$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_activate_colorpicker_color$$},$app$main$data$workspace$colors$activate_colorpicker_color_71289$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71291$$,$meta71290__$1$$){return new $app$main$data$workspace$colors$activate_colorpicker_color_71289$$($meta71290__$1$$)},$app$main$data$workspace$colors$activate_colorpicker_color_71289$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71290$},$app$main$data$workspace$colors$activate_colorpicker_color_71289$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_color_71289$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2293$$,$state$jscomp$671$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$671$$,$APP.$cljs$cst$2247$colorpicker$$,function($state__$1$jscomp$41$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__$1$jscomp$41$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1303$color$$),$APP.$cljs$cst$4229$editing_stop$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1739$stops$$,$APP.$cljs$cst$1730$gradient$$]))})},$app$main$data$workspace$colors$activate_colorpicker_color_71289$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$activate_colorpicker_color_71289$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$colors$update_colorpicker_color$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
!1))});return new $app$main$data$workspace$colors$activate_colorpicker_color_71289$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$files$tokens$make_node_token_name_schema$$=function($active_tokens$jscomp$1$$,$tokens_tree$jscomp$2$$,$node$jscomp$341$$){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__72016_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__72016_SHARP_$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$token$schema_COLON_token_node_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__72017_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__72017_SHARP_$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$common$i18n$tr$$)("workspace.tokens.token-name-validation-error"))].join("")}])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,
function($p1__72018_SHARP_$$){return $APP.$app$common$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.token-name-duplication-validation-error",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__72018_SHARP_$$)]))}],null),function($name$jscomp$366_new_tokens$$){var $and__5023__auto__$jscomp$562_current_path$jscomp$2$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$341$$),$current_name$jscomp$1$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$341$$);$name$jscomp$366_new_tokens$$=$app$common$types$tokens_lib$update_tokens_group$$($active_tokens$jscomp$1$$,$and__5023__auto__$jscomp$562_current_path$jscomp$2$$,$current_name$jscomp$1$$,$name$jscomp$366_new_tokens$$);return($and__5023__auto__$jscomp$562_current_path$jscomp$2$$=$name$jscomp$366_new_tokens$$!=null)?$APP.$cljs$core$some$$(function($p__72021$$){var $token_name$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72021$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__72021$$,1,null);return!$APP.$app$common$types$tokens_lib$token_name_path_exists_QMARK_$$($token_name$jscomp$8$$,$tokens_tree$jscomp$2$$)},$name$jscomp$366_new_tokens$$):$and__5023__auto__$jscomp$562_current_path$jscomp$2$$}],null)],null)};
$app$common$schema$assoc_key$cljs$0core$0IFn$0_invoke$0arity$04$$=function($s$jscomp$385_s__$1$jscomp$12$$,$k$jscomp$446$$,$v$jscomp$225_v__$1$jscomp$13$$){var $opts$jscomp$220$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$s$jscomp$385_s__$1$jscomp$12$$=$APP.$app$common$schema$schema$$($s$jscomp$385_s__$1$jscomp$12$$);$v$jscomp$225_v__$1$jscomp$13$$=$APP.$app$common$schema$schema$$($v$jscomp$225_v__$1$jscomp$13$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$385_s__$1$jscomp$12$$),
$APP.$cljs$cst$202$map$$))return $APP.$malli$util$assoc$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$385_s__$1$jscomp$12$$,$k$jscomp$446$$,$v$jscomp$225_v__$1$jscomp$13$$,$opts$jscomp$220$$);var $temp__5823__auto__$jscomp$75$$=$APP.$malli$util$find_first$cljs$0core$0IFn$0_invoke$0arity$02$$($s$jscomp$385_s__$1$jscomp$12$$,function($s_SINGLEQUOTE_$$,$path$jscomp$117$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$malli$core$type$$.$cljs$core$IFn$_invoke$arity$1$($s_SINGLEQUOTE_$$),
$APP.$cljs$cst$202$map$$)?$path$jscomp$117$$:null});return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$75$$)?$malli$util$assoc_in$cljs$0core$0IFn$0_invoke$0arity$04$$($s$jscomp$385_s__$1$jscomp$12$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$75$$,$k$jscomp$446$$),$v$jscomp$225_v__$1$jscomp$13$$,$opts$jscomp$220$$):$s$jscomp$385_s__$1$jscomp$12$$};
$app$common$types$tokens_lib$walk_sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($nodes$jscomp$29$$,$map__49801__$1_p__49800$$){$map__49801__$1_p__49800$$=$APP.$cljs$core$__destructure_map$$($map__49801__$1_p__49800$$);var $skip_children_pred$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49801__$1_p__49800$$,$APP.$cljs$cst$2121$skip_children_pred$$,$APP.$cljs$core$constantly$$(!1)),$new_editing_set_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49801__$1_p__49800$$,
$APP.$cljs$cst$2122$new_editing_set_path$$);return function $app$common$types$tokens_lib$walk$$($node$jscomp$249$$,$p__49802$$){var $map__49803__$1$$=$APP.$cljs$core$__destructure_map$$($p__49802$$),$parent$jscomp$191$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49803__$1$$,$APP.$cljs$cst$1370$parent$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$depth$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49803__$1$$,$APP.$cljs$cst$839$depth$$,0);return new $APP.$cljs$core$LazySeq$$(null,
function(){if($APP.$app$common$data$ordered_map_QMARK_$$($node$jscomp$249$$)){var $root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$new_editing_set_path$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$249$$,$APP.$cljs$cst$2123$new_QMARK_$$,!0):$node$jscomp$249$$;return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49792_SHARP_$$){return $app$common$types$tokens_lib$walk$$($p1__49792_SHARP_$$,
$map__49803__$1$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$]))}var $item$jscomp$51_k$jscomp$599_unprefixed_path$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$249$$,0,null);$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$249$$,1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2123$new_QMARK_$$,
$item$jscomp$51_k$jscomp$599_unprefixed_path$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2123$new_QMARK_$$,!0,$APP.$cljs$cst$2124$group_QMARK_$$,!1,$APP.$cljs$cst$2125$parent_path$$,$parent$jscomp$191$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$13$$],null)],null);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$)?$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$ instanceof
$APP.$app$common$types$tokens_lib$TokenSet$$:$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2124$group_QMARK_$$,!1,$APP.$cljs$cst$296$path$$,$APP.$app$common$types$tokens_lib$split_set_name$$($APP.$app$common$types$tokens_lib$get_name$$($root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$)),$APP.$cljs$cst$2125$parent_path$$,
$parent$jscomp$191$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$13$$,$APP.$cljs$cst$203$set$$,$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$],null)],null);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$)?$APP.$app$common$data$ordered_map_QMARK_$$($root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$):$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$)){$item$jscomp$51_k$jscomp$599_unprefixed_path$$=$APP.$cljs$core$last$$($app$common$types$tokens_lib$split_set_str_path_prefix$$($item$jscomp$51_k$jscomp$599_unprefixed_path$$));
var $path$jscomp$175$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($parent$jscomp$191$$,$item$jscomp$51_k$jscomp$599_unprefixed_path$$);$item$jscomp$51_k$jscomp$599_unprefixed_path$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2124$group_QMARK_$$,!0,$APP.$cljs$cst$296$path$$,$path$jscomp$175$$,$APP.$cljs$cst$2125$parent_path$$,$parent$jscomp$191$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$13$$],null);if($APP.$cljs$core$truth_$$($skip_children_pred$$.$cljs$core$IFn$_invoke$arity$1$?
$skip_children_pred$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$175$$):$skip_children_pred$$($path$jscomp$175$$)))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$item$jscomp$51_k$jscomp$599_unprefixed_path$$],null);$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$175$$,$new_editing_set_path$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$,
$APP.$cljs$cst$2123$new_QMARK_$$,!0):$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$;return $APP.$cljs$core$cons$$($item$jscomp$51_k$jscomp$599_unprefixed_path$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49794_SHARP_$$){return $app$common$types$tokens_lib$walk$$($p1__49794_SHARP_$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__49803__$1$$,$APP.$cljs$cst$1370$parent$$,$path$jscomp$175$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$839$depth$$,
$depth$jscomp$13$$+1])))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$root$jscomp$34_v$jscomp$535_v_SINGLEQUOTE_$jscomp$3$$])))}return null},null,null)}($APP.$cljs$core$truth_$$($nodes$jscomp$29$$)?$nodes$jscomp$29$$:$APP.$linked$map$empty_linked_map$$,null)};
$app$common$logic$tokens$calculate_move_token_set_or_set_group$$=function($tokens_lib$jscomp$26$$,$map__72473__$1_p__72472_prev_before$$){$map__72473__$1_p__72472_prev_before$$=$APP.$cljs$core$__destructure_map$$($map__72473__$1_p__72472_prev_before$$);var $from_index$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72473__$1_p__72472_prev_before$$,$APP.$cljs$cst$4758$from_index$$),$to_index$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72473__$1_p__72472_prev_before$$,
$APP.$cljs$cst$4759$to_index$$),$position$jscomp$171$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72473__$1_p__72472_prev_before$$,$APP.$cljs$cst$1681$position$$),$collapsed_paths$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__72473__$1_p__72472_prev_before$$,$APP.$cljs$cst$4760$collapsed_paths$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),$tree$jscomp$19$$=$app$common$types$tokens_lib$walk_sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$tokens_lib$get_set_tree$$($tokens_lib$jscomp$26$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2121$skip_children_pred$$,function($p1__72471_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($collapsed_paths$$,$p1__72471_SHARP_$$)}])),$from$jscomp$22$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tree$jscomp$19$$,$from_index$jscomp$9$$),$to$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($tree$jscomp$19$$,$to_index$jscomp$15$$),$G__72476__$1_before$jscomp$5$$=function(){var $G__72474__$1$$=
$position$jscomp$171$$ instanceof $APP.$cljs$core$Keyword$$?$position$jscomp$171$$.$fqn$:null;switch($G__72474__$1$$){case "top":return $to$jscomp$24$$;case "bot":return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tree$jscomp$19$$,$to_index$jscomp$15$$+1,null);case "center":return null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__72474__$1$$)].join(""));}}();$map__72473__$1_p__72472_prev_before$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2124$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$))?
$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($element$jscomp$74$$){return $APP.$cljs$cst$839$depth$$.$cljs$core$IFn$_invoke$arity$1$($element$jscomp$74$$)<=$APP.$cljs$cst$839$depth$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$)},$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$($from_index$jscomp$9$$+1,$tree$jscomp$19$$))):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($tree$jscomp$19$$,$from_index$jscomp$9$$+1,null);var $G__72476_drop_as_direct_group_child_QMARK__identical_QMARK_$$=
function(){var $and__5023__auto__$jscomp$580_and__5023__auto____$1$jscomp$101_or__5025__auto__$jscomp$932$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1672$center$$,$position$jscomp$171$$);return $and__5023__auto__$jscomp$580_and__5023__auto____$1$jscomp$101_or__5025__auto__$jscomp$932$$?$and__5023__auto__$jscomp$580_and__5023__auto____$1$jscomp$101_or__5025__auto__$jscomp$932$$:($and__5023__auto__$jscomp$580_and__5023__auto____$1$jscomp$101_or__5025__auto__$jscomp$932$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2963$bot$$,$position$jscomp$171$$))?($and__5023__auto__$jscomp$580_and__5023__auto____$1$jscomp$101_or__5025__auto__$jscomp$932$$=$APP.$cljs$cst$2124$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$24$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$580_and__5023__auto____$1$jscomp$101_or__5025__auto__$jscomp$932$$)?$APP.$cljs$core$not$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_paths$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$24$$))):
$and__5023__auto__$jscomp$580_and__5023__auto____$1$jscomp$101_or__5025__auto__$jscomp$932$$):$and__5023__auto__$jscomp$580_and__5023__auto____$1$jscomp$101_or__5025__auto__$jscomp$932$$}(),$from_path$jscomp$10$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$),$to_parent_path$$=$APP.$cljs$core$truth_$$($G__72476_drop_as_direct_group_child_QMARK__identical_QMARK_$$)?$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$24$$):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$butlast$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$24$$))),$to_path$jscomp$10$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($to_parent_path$$,$APP.$cljs$core$last$$($from_path$jscomp$10$$));$G__72476_drop_as_direct_group_child_QMARK__identical_QMARK_$$=function(){var $and__5023__auto__$jscomp$581_or__5025__auto__$jscomp$933$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_index$jscomp$9$$,$to_index$jscomp$15$$);if(!$and__5023__auto__$jscomp$581_or__5025__auto__$jscomp$933$$&&
($and__5023__auto__$jscomp$581_or__5025__auto__$jscomp$933$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_path$jscomp$10$$,$to_path$jscomp$10$$)))switch($position$jscomp$171$$ instanceof $APP.$cljs$core$Keyword$$?$position$jscomp$171$$.$fqn$:null){case "top":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_index$jscomp$9$$,$to_index$jscomp$15$$-1);case "bot":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($from_index$jscomp$9$$,$to_index$jscomp$15$$);
default:return null}else return $and__5023__auto__$jscomp$581_or__5025__auto__$jscomp$933$$}();var $to_exists_QMARK_$$=function(){var $and__5023__auto__$jscomp$582$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2125$parent_path$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$),$to_parent_path$$);return $and__5023__auto__$jscomp$582$$?$APP.$cljs$core$truth_$$($APP.$cljs$cst$2124$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$))?$app$common$types$tokens_lib$set_group_path_exists_QMARK_$$($tokens_lib$jscomp$26$$,
$to_path$jscomp$10$$):$app$common$types$tokens_lib$set_path_exists_QMARK_$$($tokens_lib$jscomp$26$$,$to_path$jscomp$10$$):$and__5023__auto__$jscomp$582$$}(),$parent_to_child_drop_QMARK_$$=function(){var $JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2125$parent_path$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$),$to_parent_path$$);if($JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$){$JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$=
$APP.$cljs$cst$2124$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$)){$JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$22$$);var $JSCompiler_temp_const$jscomp$inline_13578$$=$APP.$cljs$core$_EQ_$$,$JSCompiler_temp_const$jscomp$inline_13579$$=
$JSCompiler_temp_const$jscomp$inline_13578$$.$cljs$core$IFn$_invoke$arity$2$,$x__5113__auto__$jscomp$inline_13581$$=$APP.$cljs$core$count$$($to_path$jscomp$10$$),$y__5114__auto__$jscomp$inline_13582$$=$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$);$JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$=$JSCompiler_temp_const$jscomp$inline_13579$$.call($JSCompiler_temp_const$jscomp$inline_13578$$,
$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($to_path$jscomp$10$$,0,$x__5113__auto__$jscomp$inline_13581$$<$y__5114__auto__$jscomp$inline_13582$$?$x__5113__auto__$jscomp$inline_13581$$:$y__5114__auto__$jscomp$inline_13582$$),$JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$)}return $JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$}return $JSCompiler_temp$jscomp$11247_and__5023__auto__$jscomp$583_and__5023__auto____$1$jscomp$102_v2$jscomp$inline_13577$$}();
if($APP.$cljs$core$truth_$$($G__72476_drop_as_direct_group_child_QMARK__identical_QMARK_$$))return null;if($APP.$cljs$core$truth_$$($to_exists_QMARK_$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("move token set error: path exists",new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$4761$path_exists$$,$APP.$cljs$cst$296$path$$,$to_path$jscomp$10$$],null));if($APP.$cljs$core$truth_$$($parent_to_child_drop_QMARK_$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("move token set error: parent-to-child",
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$4762$parent_to_child$$,$APP.$cljs$cst$2665$from_path$$,$from_path$jscomp$10$$,$APP.$cljs$cst$2666$to_path$$,$to_path$jscomp$10$$],null));$G__72476_drop_as_direct_group_child_QMARK__identical_QMARK_$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2665$from_path$$,$from_path$jscomp$10$$,$APP.$cljs$cst$2666$to_path$$,$to_path$jscomp$10$$,$APP.$cljs$cst$2667$before_path$$,null,$APP.$cljs$cst$3204$before_group_QMARK_$$,
null],null);$G__72476__$1_before$jscomp$5$$=$APP.$cljs$core$truth_$$($G__72476__$1_before$jscomp$5$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__72476_drop_as_direct_group_child_QMARK__identical_QMARK_$$,$APP.$cljs$cst$2667$before_path$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($G__72476__$1_before$jscomp$5$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3204$before_group_QMARK_$$,$APP.$cljs$cst$2124$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__72476__$1_before$jscomp$5$$)])):
$G__72476_drop_as_direct_group_child_QMARK__identical_QMARK_$$;return $APP.$cljs$core$truth_$$($map__72473__$1_p__72472_prev_before$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__72476__$1_before$jscomp$5$$,$APP.$cljs$cst$3205$prev_before_path$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($map__72473__$1_p__72472_prev_before$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3206$prev_before_group_QMARK_$$,$APP.$cljs$cst$2124$group_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__72473__$1_p__72472_prev_before$$)])):
$G__72476__$1_before$jscomp$5$$};
$app$common$types$tokens_lib$sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($tree$jscomp$6_tree__$1$$,$map__49819__$1_p__49818$$){$map__49819__$1_p__49818$$=$APP.$cljs$core$__destructure_map$$($map__49819__$1_p__49818$$);var $skip_children_pred$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__49819__$1_p__49818$$,$APP.$cljs$cst$2121$skip_children_pred$$,$APP.$cljs$core$constantly$$(!1)),$new_at_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__49819__$1_p__49818$$,$APP.$cljs$cst$2126$new_at_path$$),
$walk$jscomp$2$$=function $app$common$types$tokens_lib$walk$jscomp$1$$($p__49820$$,$parent_path$jscomp$3$$,$depth$jscomp$14$$){var $k$jscomp$600$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49820$$,0,null),$v$jscomp$536$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49820$$,1,null);return new $APP.$cljs$core$LazySeq$$(null,function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2127$is_new$$,$k$jscomp$600$$)){var $item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$=
$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,$APP.$cljs$core$empty_QMARK_$$($parent_path$jscomp$3$$)?"":$APP.$app$common$types$tokens_lib$join_set_path$$($parent_path$jscomp$3$$)]));return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2127$is_new$$,!0,
$APP.$cljs$cst$2128$is_group$$,!1,$APP.$cljs$cst$296$path$$,$APP.$app$common$types$tokens_lib$split_set_name$$($item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$.name),$APP.$cljs$cst$839$depth$$,$depth$jscomp$14$$,$APP.$cljs$cst$266$id$$,$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$.id,$APP.$cljs$cst$2129$token_set$$,$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$],null)],null)}if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($v$jscomp$536$$)?$v$jscomp$536$$ instanceof
$APP.$app$common$types$tokens_lib$TokenSet$$:$v$jscomp$536$$))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2128$is_group$$,!1,$APP.$cljs$cst$296$path$$,$APP.$app$common$types$tokens_lib$split_set_name$$($APP.$app$common$types$tokens_lib$get_name$$($v$jscomp$536$$)),$APP.$cljs$cst$839$depth$$,$depth$jscomp$14$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$types$tokens_lib$get_id$$($v$jscomp$536$$),
$APP.$cljs$cst$2129$token_set$$,$v$jscomp$536$$],null)],null);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($v$jscomp$536$$)?$APP.$app$common$data$ordered_map_QMARK_$$($v$jscomp$536$$):$v$jscomp$536$$)){$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$=$APP.$cljs$core$last$$($app$common$types$tokens_lib$split_set_str_path_prefix$$($k$jscomp$600$$));var $path$jscomp$176$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($parent_path$jscomp$3$$,$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$);
$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2128$is_group$$,!0,$APP.$cljs$cst$296$path$$,$path$jscomp$176$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$14$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$types$tokens_lib$join_set_path$$($path$jscomp$176$$)],null);if($APP.$cljs$core$truth_$$($skip_children_pred$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$skip_children_pred$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$176$$):
$skip_children_pred$jscomp$1$$($path$jscomp$176$$)))return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$],null);var $v__$1$jscomp$27$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$176$$,$new_at_path$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($v$jscomp$536$$,$APP.$cljs$cst$2127$is_new$$,!0):$v$jscomp$536$$;return $APP.$cljs$core$cons$$($item$jscomp$52_token_set$jscomp$4_unprefixed_path$jscomp$1$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49812_SHARP_$$){return $app$common$types$tokens_lib$walk$jscomp$1$$($p1__49812_SHARP_$$,$path$jscomp$176$$,$depth$jscomp$14$$+1)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v__$1$jscomp$27$$])))}return null},null,null)};$tree$jscomp$6_tree__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$new_at_path$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($tree$jscomp$6_tree__$1$$,
$APP.$cljs$cst$2127$is_new$$,!0):$tree$jscomp$6_tree__$1$$;return $APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$207$$,$item$jscomp$53$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$53$$,$APP.$cljs$cst$1801$index$$,$index$jscomp$207$$)},$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__49813_SHARP_$$){return $walk$jscomp$2$$($p1__49813_SHARP_$$,$APP.$cljs$core$PersistentVector$EMPTY$$,0)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tree$jscomp$6_tree__$1$$])))};
$app$common$types$tokens_lib$parse_single_set_dtcg_json$$=function($set_name$jscomp$25_set_name__$1$$,$decoded_json_tokens$jscomp$2_tokens$jscomp$16$$){$set_name$jscomp$25_set_name__$1$$=$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$1$($set_name$jscomp$25_set_name__$1$$);$decoded_json_tokens$jscomp$2_tokens$jscomp$16$$=$APP.$app$common$types$tokens_lib$flatten_nested_tokens_json$cljs$0core$0IFn$0_invoke$0arity$03$$($decoded_json_tokens$jscomp$2_tokens$jscomp$16$$,
"",null);if($APP.$cljs$core$empty_QMARK_$$($decoded_json_tokens$jscomp$2_tokens$jscomp$16$$))throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$02$$("the file doesn't contain any tokens",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$945$error_SLASH_code$$,$APP.$cljs$cst$2142$error_DOT_import_SLASH_invalid_json_data$$],null));return $APP.$app$common$types$tokens_lib$make_tokens_lib$$().$app$common$types$tokens_lib$ITokenSets$add_set$arity$2$(null,$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,
$set_name$jscomp$25_set_name__$1$$,$APP.$cljs$cst$2108$tokens$$,$decoded_json_tokens$jscomp$2_tokens$jscomp$16$$])))};
$app$common$logic$libraries$add_shape_to_main$$=function($changes$jscomp$126_changes_SINGLEQUOTE_$jscomp$2$$,$shape$jscomp$424$$,$index$jscomp$258$$,$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$,$component_container$jscomp$3$$,$page$jscomp$55$$,$root_instance$jscomp$1$$,$root_main$jscomp$5$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$424$$),$page$jscomp$55$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",
$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,["ADD [C ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_container$jscomp$3$$)),"] ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$424$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$424$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1161$info$$,!1);var $parent_shape$jscomp$2$$=$APP.$app$common$types$container$get_shape$$($page$jscomp$55$$,$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$424$$)),$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__66679_SHARP_$$){return $APP.$app$common$types$component$is_main_of_QMARK_$$($p1__66679_SHARP_$$,
$parent_shape$jscomp$2$$)},$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_container$jscomp$3$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($root_main$jscomp$5$$))),$all_parents$jscomp$5$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$)],
null),$APP.$app$common$files$helpers$get_parent_ids$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($component_container$jscomp$3$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$))),$updated_shapes$jscomp$4_vec__66690$$=$APP.$app$common$types$shape_tree$clone_shape$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$424$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$55$$,$APP.$cljs$cst$1636$objects$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2097$update_new_shape$$,function($new_shape$jscomp$9$$){return $APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$app$common$logic$libraries$reposition_shape$$.$cljs$core$IFn$_invoke$arity$3$($new_shape$jscomp$9$$,$root_instance$jscomp$1$$,$root_main$jscomp$5$$):$APP.$app$common$logic$libraries$reposition_shape$$($new_shape$jscomp$9$$,
$root_instance$jscomp$1$$,$root_main$jscomp$5$$)},$APP.$cljs$cst$2098$update_original_shape$$,function($original_shape$jscomp$4$$,$new_shape$jscomp$10$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($original_shape$jscomp$4$$,$APP.$cljs$cst$2055$shape_ref$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$10$$))},$APP.$cljs$cst$1612$frame_id$$,$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$)?
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$):$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$)]));$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($updated_shapes$jscomp$4_vec__66690$$,0,null);$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($updated_shapes$jscomp$4_vec__66690$$,
1,null);$updated_shapes$jscomp$4_vec__66690$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($updated_shapes$jscomp$4_vec__66690$$,2,null);$changes$jscomp$126_changes_SINGLEQUOTE_$jscomp$2$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$37$$,$G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$){var $JSCompiler_temp_const$jscomp$11267$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$;$G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2621$add_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$),$APP.$cljs$cst$1624$parent_id$$,$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$),$APP.$cljs$cst$1612$frame_id$$,
$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$),$APP.$cljs$cst$1801$index$$,$index$jscomp$258$$,$APP.$cljs$cst$2567$ignore_touched$$,!0,$APP.$cljs$cst$2622$obj$$,$G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$],null);$G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$=$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$logic$libraries$make_change$$.$cljs$core$IFn$_invoke$arity$2$($component_container$jscomp$3$$,$G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$):$APP.$app$common$logic$libraries$make_change$$($component_container$jscomp$3$$,$G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$);return $JSCompiler_temp_const$jscomp$11267$$.call($APP.$cljs$core$update$$,$changes__$1$jscomp$37$$,$APP.$cljs$cst$3157$redo_changes$$,
$APP.$cljs$core$conj$$,$G__66698$jscomp$inline_13585_JSCompiler_inline_result$jscomp$11269_shape_SINGLEQUOTE_$jscomp$7$$)},$changes$jscomp$126_changes_SINGLEQUOTE_$jscomp$2$$,$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$);$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$126_changes_SINGLEQUOTE_$jscomp$2$$,$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2635$reg_objects$$,$APP.$cljs$cst$1632$component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$),$APP.$cljs$cst$1619$shapes$$,$all_parents$jscomp$5$$],null));$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$38$$,
$shape_SINGLEQUOTE_$jscomp$8$$){var $shape_original$$=$APP.$app$common$types$container$get_shape$$($page$jscomp$55$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$8$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes__$1$jscomp$38$$,$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2623$mod_obj$$,
$APP.$cljs$cst$2051$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$55$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$8$$),$APP.$cljs$cst$2624$operations$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$1632$component_id$$,
$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$8$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$1648$component_file$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$8$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$2052$component_root$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2052$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$8$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$2055$shape_ref$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2055$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$8$$)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1631$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$8$$)],null)],null)],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2623$mod_obj$$,$APP.$cljs$cst$2051$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$55$$),
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$),$APP.$cljs$cst$2624$operations$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$1632$component_id$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$1648$component_file$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$2052$component_root$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2052$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$2055$shape_ref$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$2055$shape_ref$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$108$val$$,$APP.$cljs$cst$1631$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape_original$$)],
null)],null)],null))},$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$,$updated_shapes$jscomp$4_vec__66690$$);$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$39$$,$shape_SINGLEQUOTE_$jscomp$9$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes__$1$jscomp$39$$,$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2625$del_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_SINGLEQUOTE_$jscomp$9$$),$APP.$cljs$cst$2051$page_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$55$$),$APP.$cljs$cst$2567$ignore_touched$$,!0],null))},$changes_SINGLEQUOTE___$1$jscomp$1_changes_SINGLEQUOTE___$2$jscomp$1_component$jscomp$69$$,$changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$);
return $APP.$app$common$files$changes_builder$apply_changes_local$$($changes_SINGLEQUOTE___$3_component_parent_shape$jscomp$1_new_shapes$jscomp$7$$)};
$app$common$logic$tokens$generate_toggle_token_set_group$$=function($changes$jscomp$292$$,$tokens_lib$jscomp$25$$,$group_path$jscomp$8$$){return $APP.$app$common$logic$tokens$generate_update_active_sets$$($changes$jscomp$292$$,$tokens_lib$jscomp$25$$,function($p1__72466_SHARP_$$){return $app$common$logic$tokens$toggle_token_set_group$$($group_path$jscomp$8$$,$tokens_lib$jscomp$25$$,$p1__72466_SHARP_$$)})};
$app$common$logic$tokens$generate_delete_token_set_group$$=function($changes$jscomp$295$$,$sets$jscomp$14_tokens_lib$jscomp$29$$,$path$jscomp$246$$){$sets$jscomp$14_tokens_lib$jscomp$29$$=$app$common$types$tokens_lib$get_sets_at_path$$($sets$jscomp$14_tokens_lib$jscomp$29$$,$path$jscomp$246$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$86$$,$set$jscomp$17$$){return $APP.$app$common$files$changes_builder$set_token_set$$($changes__$1$jscomp$86$$,
$APP.$app$common$types$tokens_lib$get_id$$($set$jscomp$17$$),null)},$changes$jscomp$295$$,$sets$jscomp$14_tokens_lib$jscomp$29$$)};
$app$common$logic$libraries$update_grid_main_attrs$$=function($changes$jscomp$141$$,$new_changes$jscomp$3_shape_main$jscomp$11$$,$shape_copy$jscomp$3$$,$main_container$jscomp$3$$,$copy_container$jscomp$2$$){var $ids_map$jscomp$12$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__67030_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($main_container$jscomp$3$$,$APP.$cljs$cst$1636$objects$$),
$p1__67030_SHARP_$$)}),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($main_shape$jscomp$2$$){var $copy_shape$jscomp$1$$=$app$common$types$file$get_shape_in_copy$$($copy_container$jscomp$2$$,$main_shape$jscomp$2$$,$shape_copy$jscomp$3$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($copy_shape$jscomp$1$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_shape$jscomp$2$$)],
null)})),$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$3_shape_main$jscomp$11$$));$new_changes$jscomp$3_shape_main$jscomp$11$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$main_container$jscomp$3$$),$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_container$jscomp$3$$)),
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$3_shape_main$jscomp$11$$)],null),function($shape_main__$1$jscomp$1$$){var $new_cells$$=$APP.$cljs$cst$1701$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$shape$layout$remap_grid_cells$$($shape_copy$jscomp$3$$,$ids_map$jscomp$12$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape_main__$1$jscomp$1$$,
$APP.$cljs$cst$1701$layout_grid_cells$$,$new_cells$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2567$ignore_touched$$,!0],null));return $APP.$app$common$files$changes_builder$concat_changes$$($changes$jscomp$141$$,$new_changes$jscomp$3_shape_main$jscomp$11$$)};
$app$common$logic$libraries$update_flex_child_main_attrs$$=function($changes$jscomp$139$$,$new_changes$jscomp$2_shape_main$jscomp$9$$,$shape_copy$jscomp$1$$,$main_container$jscomp$1$$,$copy_container$jscomp$1$$,$omit_touched_QMARK_$jscomp$10$$){$new_changes$jscomp$2_shape_main$jscomp$9$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$main_container$jscomp$1$$),$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_container$jscomp$1$$)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$2_shape_main$jscomp$9$$)],null),function($G__67023__$1_shape_main__$1$$){$G__67023__$1_shape_main__$1$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1702$fix$$,null,$APP.$cljs$cst$1677$auto$$,null],null),null),$APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape_copy$jscomp$1$$))?$APP.$app$common$logic$libraries$propagate_attrs$$($G__67023__$1_shape_main__$1$$,$shape_copy$jscomp$1$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1713$layout_item_h_sizing$$,null],null),null),$omit_touched_QMARK_$jscomp$10$$):$G__67023__$1_shape_main__$1$$;
return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1702$fix$$,null,$APP.$cljs$cst$1677$auto$$,null],null),null),$APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($shape_copy$jscomp$1$$))?$APP.$app$common$logic$libraries$propagate_attrs$$($G__67023__$1_shape_main__$1$$,$shape_copy$jscomp$1$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1714$layout_item_v_sizing$$,null],null),null),$omit_touched_QMARK_$jscomp$10$$):$G__67023__$1_shape_main__$1$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2567$ignore_touched$$,!0],null)),$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($new_changes$jscomp$2_shape_main$jscomp$9$$),function($child_main$jscomp$15$$){var $child_copy$jscomp$1$$=$app$common$types$file$get_shape_in_copy$$($copy_container$jscomp$1$$,$child_main$jscomp$15$$,$shape_copy$jscomp$1$$);
return $APP.$app$common$logic$libraries$propagate_attrs$$($child_main$jscomp$15$$,$child_copy$jscomp$1$$,$APP.$app$common$types$component$swap_keep_attrs$$,$omit_touched_QMARK_$jscomp$10$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2567$ignore_touched$$,!0],null));return $APP.$app$common$files$changes_builder$concat_changes$$($changes$jscomp$139$$,$new_changes$jscomp$2_shape_main$jscomp$9$$)};
$app$common$logic$libraries$generate_sync_shape_inverse$$=function($changes$jscomp$122_changes__$1$jscomp$27$$,$file$jscomp$54$$,$libraries$jscomp$52$$,$container$jscomp$51$$,$shape_id$jscomp$72$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($shape_id$jscomp$72$$,$container$jscomp$51$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,"Sync shape inverse"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1817$shape$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$72$$)],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$1160$debug$$,!1);var $shape_inst$jscomp$6$$=
$APP.$app$common$types$container$get_shape$$($container$jscomp$51$$,$shape_id$jscomp$72$$),$library$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$52$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$)),$APP.$cljs$cst$142$data$$),$component$jscomp$67$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($library$jscomp$20$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$)),
$shape_main$jscomp$6$$=$APP.$cljs$core$truth_$$($component$jscomp$67$$)?$app$common$types$file$find_remote_shape$$($container$jscomp$51$$,$libraries$jscomp$52$$,$shape_inst$jscomp$6$$):null,$initial_root_QMARK_$jscomp$2$$=$APP.$cljs$cst$2052$component_root$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$),$root_main$jscomp$2$$=$APP.$app$common$types$file$get_component_root$$($library$jscomp$20$$,$component$jscomp$67$$);$changes$jscomp$122_changes__$1$jscomp$27$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($component$jscomp$67$$)?
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$1631$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$),$APP.$cljs$cst$2082$name_group$$):$component$jscomp$67$$)?$APP.$app$common$logic$libraries$generate_rename_component$$($changes$jscomp$122_changes__$1$jscomp$27$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$6$$),$library$jscomp$20$$):$changes$jscomp$122_changes__$1$jscomp$27$$;
return $APP.$cljs$core$truth_$$($component$jscomp$67$$)?$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$.$cljs$core$IFn$_invoke$arity$11$?$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$.$cljs$core$IFn$_invoke$arity$11$($changes$jscomp$122_changes__$1$jscomp$27$$,$container$jscomp$51$$,$shape_inst$jscomp$6$$,$component$jscomp$67$$,$library$jscomp$20$$,$file$jscomp$54$$,$libraries$jscomp$52$$,$shape_main$jscomp$6$$,$shape_inst$jscomp$6$$,$root_main$jscomp$2$$,
$initial_root_QMARK_$jscomp$2$$):$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$($changes$jscomp$122_changes__$1$jscomp$27$$,$container$jscomp$51$$,$shape_inst$jscomp$6$$,$component$jscomp$67$$,$library$jscomp$20$$,$file$jscomp$54$$,$libraries$jscomp$52$$,$shape_main$jscomp$6$$,$shape_inst$jscomp$6$$,$root_main$jscomp$2$$,$initial_root_QMARK_$jscomp$2$$):$changes$jscomp$122_changes__$1$jscomp$27$$};
$app$common$logic$variant_properties$generate_reorder_variant_poperties$$=function($changes$jscomp$89$$,$related_components$jscomp$2_variant_id$jscomp$13$$,$from_pos$jscomp$1$$,$to_space_between_pos$jscomp$1$$){var $data$jscomp$312$$=$APP.$app$common$files$changes_builder$get_library_data$$($changes$jscomp$89$$),$objects$jscomp$275$$=$APP.$app$common$files$changes_builder$get_objects$$($changes$jscomp$89$$);$related_components$jscomp$2_variant_id$jscomp$13$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$312$$,
$objects$jscomp$275$$,$related_components$jscomp$2_variant_id$jscomp$13$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes__$1$jscomp$10$$,$component$jscomp$55$$){var $main_id$jscomp$3_props$jscomp$140$$=$APP.$cljs$cst$2017$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$55$$),$props__$1$jscomp$21$$=$app$common$data$reorder$$($main_id$jscomp$3_props$jscomp$140$$,$from_pos$jscomp$1$$,$to_space_between_pos$jscomp$1$$);$main_id$jscomp$3_props$jscomp$140$$=
$APP.$cljs$cst$2070$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$55$$);var $name$jscomp$287$$=$APP.$app$common$types$variant$properties_to_name$$($props__$1$jscomp$21$$);return $APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($changes__$1$jscomp$10$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$55$$),function($p1__55920_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55920_SHARP_$$,
$APP.$cljs$cst$2017$variant_properties$$,$props__$1$jscomp$21$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3203$apply_changes_local_library_QMARK_$$,!0],null)])),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$main_id$jscomp$3_props$jscomp$140$$],null),function($p1__55921_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__55921_SHARP_$$,$APP.$cljs$cst$2018$variant_name$$,
$name$jscomp$287$$)})},$changes$jscomp$89$$,$related_components$jscomp$2_variant_id$jscomp$13$$)};
$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens$$=function($set_id$jscomp$43$$,$token_ids$jscomp$4$$){typeof $app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$=function($set_id$jscomp$44$$,$token_ids$jscomp$5$$,$meta73236$$){this.$set_id$=$set_id$jscomp$44$$;this.$token_ids$=$token_ids$jscomp$5$$;this.$meta73236$=$meta73236$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4802$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_delete_tokens$$},$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_73237$$,$meta73236__$1$$){return new $app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$(this.$set_id$,this.$token_ids$,$meta73236__$1$$)},$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73236$},$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$321_data$jscomp$426_it$jscomp$274$$,$state$jscomp$1009$$){var $self__$jscomp$6719$$=this;$changes$jscomp$321_data$jscomp$426_it$jscomp$274$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1009$$);$changes$jscomp$321_data$jscomp$426_it$jscomp$274$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$322$$,$token_id$jscomp$21$$){return $APP.$app$common$files$changes_builder$set_token$$($changes$jscomp$322$$,
$self__$jscomp$6719$$.$set_id$,$token_id$jscomp$21$$,null)},$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$321_data$jscomp$426_it$jscomp$274$$),$self__$jscomp$6719$$.$token_ids$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$321_data$jscomp$426_it$jscomp$274$$),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-token-node"],null)))});return new $app$main$data$workspace$tokens$library_edit$bulk_delete_tokens_73235$$($set_id$jscomp$43$$,$token_ids$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($set_id$jscomp$39$$,$token_ids$jscomp$2$$,$type$jscomp$564$$,$old_path$jscomp$1$$,$new_path$jscomp$1$$,$p__73225$$){var $map__73226__$1$$=$APP.$cljs$core$__destructure_map$$($p__73225$$),$undo_group$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__73226__$1$$,$APP.$cljs$cst$3162$undo_group$$);typeof $app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$===
"undefined"&&($app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$=function($set_id$jscomp$40$$,$token_ids$jscomp$3$$,$type$jscomp$565$$,$old_path$jscomp$2$$,$new_path$jscomp$2$$,$p__73225$jscomp$1$$,$map__73226$jscomp$1$$,$undo_group$jscomp$43$$,$meta73228$$){this.$set_id$=$set_id$jscomp$40$$;this.$token_ids$=$token_ids$jscomp$3$$;this.type=$type$jscomp$565$$;this.$old_path$=$old_path$jscomp$2$$;this.$new_path$=$new_path$jscomp$2$$;this.$p__73225$=$p__73225$jscomp$1$$;this.$map__73226$=
$map__73226$jscomp$1$$;this.$undo_group$=$undo_group$jscomp$43$$;this.$meta73228$=$meta73228$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4800$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_update_tokens$$},
$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73229$$,$meta73228__$1$$){return new $app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$(this.$set_id$,this.$token_ids$,this.type,this.$old_path$,this.$new_path$,this.$p__73225$,this.$map__73226$,this.$undo_group$,$meta73228__$1$$)},$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73228$},$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$318_changes__$1$jscomp$87_data$jscomp$424_it$jscomp$272$$,$state$jscomp$1007$$){var $self__$jscomp$6711$$=this,$token_set$jscomp$17$$=$APP.$cljs$core$truth_$$($self__$jscomp$6711$$.$set_id$)?
$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$1007$$,$self__$jscomp$6711$$.$set_id$):$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$1007$$);$changes$jscomp$318_changes__$1$jscomp$87_data$jscomp$424_it$jscomp$272$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1007$$);$changes$jscomp$318_changes__$1$jscomp$87_data$jscomp$424_it$jscomp$272$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$319$$,$token_id$jscomp$18$$){var $token$jscomp$105_token_SINGLEQUOTE_$jscomp$3$$=$APP.$app$common$types$tokens_lib$get_token$$($APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$1007$$),$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$17$$),$token_id$jscomp$18$$),$new_name$jscomp$32$$=$APP.$cuerdas$core$replace$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$105_token_SINGLEQUOTE_$jscomp$3$$),
$self__$jscomp$6711$$.$old_path$,$self__$jscomp$6711$$.$new_path$);$token$jscomp$105_token_SINGLEQUOTE_$jscomp$3$$=$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token$jscomp$105_token_SINGLEQUOTE_$jscomp$3$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$new_name$jscomp$32$$],null)])))]));return $APP.$app$common$files$changes_builder$set_token$$($changes$jscomp$319$$,$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$17$$),$token_id$jscomp$18$$,$token$jscomp$105_token_SINGLEQUOTE_$jscomp$3$$)},$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$318_changes__$1$jscomp$87_data$jscomp$424_it$jscomp$272$$),
$self__$jscomp$6711$$.$token_ids$);$changes$jscomp$318_changes__$1$jscomp$87_data$jscomp$424_it$jscomp$272$$=$self__$jscomp$6711$$.$undo_group$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$318_changes__$1$jscomp$87_data$jscomp$424_it$jscomp$272$$,$APP.$cljs$cst$3162$undo_group$$,$self__$jscomp$6711$$.$undo_group$):$changes$jscomp$318_changes__$1$jscomp$87_data$jscomp$424_it$jscomp$272$$;$APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($self__$jscomp$6711$$.type),
".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6711$$.$old_path$)].join(""));$APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($self__$jscomp$6711$$.type),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6711$$.$new_path$)].join(""));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$318_changes__$1$jscomp$87_data$jscomp$424_it$jscomp$272$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2347$app_DOT_main_DOT_data_DOT_event_SLASH_event$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"bulk-update-tokens",$APP.$cljs$cst$139$type$$,$self__$jscomp$6711$$.type],null)))});return new $app$main$data$workspace$tokens$library_edit$bulk_update_tokens_73227$$($set_id$jscomp$39$$,$token_ids$jscomp$2$$,$type$jscomp$564$$,$old_path$jscomp$1$$,$new_path$jscomp$1$$,$p__73225$$,$map__73226__$1$$,$undo_group$jscomp$42$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$$=function($var_args$jscomp$1395$$){for(var $args__5755__auto__$jscomp$238$$=[],$len__5749__auto___73288$$=arguments.length,$i__5750__auto___73289$$=0;;)if($i__5750__auto___73289$$<$len__5749__auto___73288$$)$args__5755__auto__$jscomp$238$$.push(arguments[$i__5750__auto___73289$$]),$i__5750__auto___73289$$+=1;else break;return $app$main$data$workspace$tokens$library_edit$bulk_update_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4],5<$args__5755__auto__$jscomp$238$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$238$$.slice(5),0,null):null)};$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$800$$,$params$jscomp$312$$){return $APP.$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$03$$(null,$id$jscomp$800$$,$params$jscomp$312$$)};
$app$main$data$workspace$tokens$library_edit$bulk_create_tokens$$=function($set_id$jscomp$35$$,$token_ids$$,$type$jscomp$562$$,$node$jscomp$349$$,$new_node_name$$){typeof $app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$=function($set_id$jscomp$36$$,$token_ids$jscomp$1$$,$type$jscomp$563$$,$node$jscomp$350$$,$new_node_name$jscomp$1$$,$meta73212$$){this.$set_id$=$set_id$jscomp$36$$;this.$token_ids$=
$token_ids$jscomp$1$$;this.type=$type$jscomp$563$$;this.node=$node$jscomp$350$$;this.$new_node_name$=$new_node_name$jscomp$1$$;this.$meta73212$=$meta73212$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4798$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_bulk_create_tokens$$},$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73213$$,$meta73212__$1$$){return new $app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$(this.$set_id$,this.$token_ids$,this.type,this.node,this.$new_node_name$,$meta73212__$1$$)},$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73212$},$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$315_data$jscomp$422_it$jscomp$270$$,$state$jscomp$1005$$){var $self__$jscomp$6703$$=this,$token_set$jscomp$15$$=$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$1005$$,
$self__$jscomp$6703$$.$set_id$);$changes$jscomp$315_data$jscomp$422_it$jscomp$270$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1005$$);$changes$jscomp$315_data$jscomp$422_it$jscomp$270$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$316$$,$token$jscomp$103_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$){$token$jscomp$103_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$=$APP.$app$common$types$tokens_lib$get_token$$($APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$1005$$),
$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$15$$),$token$jscomp$103_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$);var $new_name$jscomp$31$$=$APP.$app$common$path_names$join_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$103_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,"."])),$APP.$cljs$cst$839$depth$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6703$$.node),$self__$jscomp$6703$$.$new_node_name$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,".",$APP.$cljs$cst$2014$with_spaces_QMARK_$$,!1])),$JSCompiler_temp_const$jscomp$1519$$=$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$,$JSCompiler_temp_const$jscomp$1517$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$1516$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$JSCompiler_temp_const$jscomp$1514$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$label$jscomp$inline_8555$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($new_name$jscomp$31$$),$id$jscomp$inline_8556$$=$APP.$app$common$uuid$next$$();$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$test_helpers$ids_map$idmap$$,
$APP.$cljs$core$assoc$$,$label$jscomp$inline_8555$$,$id$jscomp$inline_8556$$);$token$jscomp$103_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$=$JSCompiler_temp_const$jscomp$1519$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp_const$jscomp$1517$$.call($APP.$cljs$core$into$$,$JSCompiler_temp_const$jscomp$1516$$,$JSCompiler_temp_const$jscomp$1514$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token$jscomp$103_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$725$name$$,$new_name$jscomp$31$$,$APP.$cljs$cst$266$id$$,$id$jscomp$inline_8556$$],null)])))]));return $APP.$app$common$files$changes_builder$set_token$$($changes$jscomp$316$$,$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$15$$),$token$jscomp$103_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$.id,$token$jscomp$103_token_SINGLEQUOTE_$jscomp$1_token_id$jscomp$17$$)},$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$changes$jscomp$315_data$jscomp$422_it$jscomp$270$$),$self__$jscomp$6703$$.$token_ids$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$315_data$jscomp$422_it$jscomp$270$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2347$app_DOT_main_DOT_data_DOT_event_SLASH_event$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"bulk-create-tokens",$APP.$cljs$cst$139$type$$,
$self__$jscomp$6703$$.type],null)))});return new $app$main$data$workspace$tokens$library_edit$bulk_create_tokens_73211$$($set_id$jscomp$35$$,$token_ids$$,$type$jscomp$562$$,$node$jscomp$349$$,$new_node_name$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$duplicate_token$$=function($token_id$jscomp$22$$){typeof $app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$=function($token_id$jscomp$23$$,$meta73239$$){this.$token_id$=$token_id$jscomp$23$$;this.$meta73239$=$meta73239$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4803$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_duplicate_token$$},$app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73240$$,$meta73239__$1$$){return new $app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$(this.$token_id$,
$meta73239__$1$$)},$app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73239$},$app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$,
$new_token_state$jscomp$1010_temp__5825__auto____$2$$){$_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$=$APP.$app$main$data$workspace$tokens$library_edit$lookup_token_set$cljs$0core$0IFn$0_invoke$0arity$01$$($new_token_state$jscomp$1010_temp__5825__auto____$2$$);if($APP.$cljs$core$truth_$$($_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$)){var $temp__5825__auto____$1$jscomp$13$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($new_token_state$jscomp$1010_temp__5825__auto____$2$$);
if($APP.$cljs$core$truth_$$($temp__5825__auto____$1$jscomp$13$$)&&($new_token_state$jscomp$1010_temp__5825__auto____$2$$=$APP.$app$common$types$tokens_lib$get_token$$($temp__5825__auto____$1$jscomp$13$$,$APP.$app$common$types$tokens_lib$get_id$$($_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$),this.$token_id$),$APP.$cljs$core$truth_$$($new_token_state$jscomp$1010_temp__5825__auto____$2$$)))return $_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$=
$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens$$($temp__5825__auto____$1$jscomp$13$$,$APP.$app$common$types$tokens_lib$get_id$$($_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$))),$_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$),
$_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($new_token_state$jscomp$1010_temp__5825__auto____$2$$),$_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1376$suffix$$,
"copy"])),$new_token_state$jscomp$1010_temp__5825__auto____$2$$=$APP.$app$common$types$tokens_lib$rename$$($APP.$app$common$types$tokens_lib$reid$$($new_token_state$jscomp$1010_temp__5825__auto____$2$$),$_$jscomp$2707_copy_name$jscomp$1_temp__5825__auto__$jscomp$256_tokens$jscomp$39_unames$jscomp$13$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$new_token_state$jscomp$1010_temp__5825__auto____$2$$))}return null});
return new $app$main$data$workspace$tokens$library_edit$duplicate_token_73238$$($token_id$jscomp$22$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$rename_token_set_group$$=function($set_group_path$jscomp$2$$,$set_group_fname$jscomp$2$$){typeof $app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$=function($set_group_path$jscomp$3$$,$set_group_fname$jscomp$3$$,$meta73082$$){this.$set_group_path$=$set_group_path$jscomp$3$$;this.$set_group_fname$=$set_group_fname$jscomp$3$$;this.$meta73082$=
$meta73082$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4785$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_rename_token_set_group$$},
$app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73083$$,$meta73082__$1$$){return new $app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$(this.$set_group_path$,this.$set_group_fname$,$meta73082__$1$$)},$app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73082$},$app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $changes$jscomp$303_changes$jscomp$inline_8558$$=$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this);var $set_group_path$jscomp$inline_8559$$=this.$set_group_path$,$set_group_fname$jscomp$inline_8560$$=this.$set_group_fname$,$undo_path$jscomp$inline_8561$$=$APP.$app$common$types$tokens_lib$replace_last_path_name$$($set_group_path$jscomp$inline_8559$$,
$set_group_fname$jscomp$inline_8560$$),$undo_fname$jscomp$inline_8562$$=$APP.$cljs$core$last$$($set_group_path$jscomp$inline_8559$$);$changes$jscomp$303_changes$jscomp$inline_8558$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$303_changes$jscomp$inline_8558$$,$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2661$rename_token_set_group$$,$APP.$cljs$cst$2662$set_group_path$$,$set_group_path$jscomp$inline_8559$$,$APP.$cljs$cst$2663$set_group_fname$$,$set_group_fname$jscomp$inline_8560$$],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2661$rename_token_set_group$$,$APP.$cljs$cst$2662$set_group_path$$,$undo_path$jscomp$inline_8561$$,$APP.$cljs$cst$2663$set_group_fname$$,
$undo_fname$jscomp$inline_8562$$],null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$303_changes$jscomp$inline_8558$$))});return new $app$main$data$workspace$tokens$library_edit$rename_token_set_group_73081$$($set_group_path$jscomp$2$$,$set_group_fname$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_component_annotation$$=function($id$jscomp$761$$,$annotation$jscomp$4$$){typeof $app$main$data$workspace$update_component_annotation_72267$$==="undefined"&&($app$main$data$workspace$update_component_annotation_72267$$=function($id$jscomp$762$$,$annotation$jscomp$5$$,$meta72268$$){this.id=$id$jscomp$762$$;this.$annotation$=$annotation$jscomp$5$$;this.$meta72268$=$meta72268$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$update_component_annotation_72267$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_component_annotation_72267$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4592$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_component_annotation$$},$app$main$data$workspace$update_component_annotation_72267$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72269$$,$meta72268__$1$$){return new $app$main$data$workspace$update_component_annotation_72267$$(this.id,
this.$annotation$,$meta72268__$1$$)},$app$main$data$workspace$update_component_annotation_72267$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72268$},$app$main$data$workspace$update_component_annotation_72267$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_component_annotation_72267$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$285_data$jscomp$403_it$jscomp$252$$,$state$jscomp$943$$){var $self__$jscomp$6450$$=
this;$changes$jscomp$285_data$jscomp$403_it$jscomp$252$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$943$$);$changes$jscomp$285_data$jscomp$403_it$jscomp$252$$=$APP.$app$common$files$changes_builder$update_component$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$285_data$jscomp$403_it$jscomp$252$$),$self__$jscomp$6450$$.id,function($component$jscomp$95$$){return $APP.$cljs$core$truth_$$($component$jscomp$95$$)?
$self__$jscomp$6450$$.$annotation$==null?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($component$jscomp$95$$,$APP.$cljs$cst$2553$annotation$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($component$jscomp$95$$,$APP.$cljs$cst$2553$annotation$$,$self__$jscomp$6450$$.$annotation$):null});return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$285_data$jscomp$403_it$jscomp$252$$)),$self__$jscomp$6450$$.$annotation$==
null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"delete-component-annotation"],null))):null)});return new $app$main$data$workspace$update_component_annotation_72267$$($id$jscomp$761$$,$annotation$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$change_pixel_grid_color$cljs$0core$0IFn$0_invoke$0arity$02$$=function($color$jscomp$110$$){typeof $app$main$data$workspace$change_pixel_grid_color_72219$$==="undefined"&&($app$main$data$workspace$change_pixel_grid_color_72219$$=function($page_id$jscomp$285$$,$color$jscomp$111$$,$meta72220$$){this.$page_id$=$page_id$jscomp$285$$;this.color=$color$jscomp$111$$;this.$meta72220$=$meta72220$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$change_pixel_grid_color_72219$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$change_pixel_grid_color_72219$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4585$app_DOT_main_DOT_data_DOT_workspace_SLASH_change_pixel_grid_color$$},$app$main$data$workspace$change_pixel_grid_color_72219$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72221$$,$meta72220__$1$$){return new $app$main$data$workspace$change_pixel_grid_color_72219$$(this.$page_id$,
this.color,$meta72220__$1$$)},$app$main$data$workspace$change_pixel_grid_color_72219$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72220$},$app$main$data$workspace$change_pixel_grid_color_72219$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$change_pixel_grid_color_72219$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$251_or__5025__auto__$jscomp$inline_8564_page_id__$1$jscomp$19$$,$changes$jscomp$284_page$jscomp$107_state$jscomp$934$$){$it$jscomp$251_or__5025__auto__$jscomp$inline_8564_page_id__$1$jscomp$19$$=
this.$page_id$;$it$jscomp$251_or__5025__auto__$jscomp$inline_8564_page_id__$1$jscomp$19$$=$APP.$cljs$core$truth_$$($it$jscomp$251_or__5025__auto__$jscomp$inline_8564_page_id__$1$jscomp$19$$)?$it$jscomp$251_or__5025__auto__$jscomp$inline_8564_page_id__$1$jscomp$19$$:$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$284_page$jscomp$107_state$jscomp$934$$);$changes$jscomp$284_page$jscomp$107_state$jscomp$934$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$284_page$jscomp$107_state$jscomp$934$$,
$it$jscomp$251_or__5025__auto__$jscomp$inline_8564_page_id__$1$jscomp$19$$);$changes$jscomp$284_page$jscomp$107_state$jscomp$934$$=$APP.$app$common$files$changes_builder$mod_page$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$284_page$jscomp$107_state$jscomp$934$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2067$pixel_grid_color$$,
$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$(this.color),$APP.$cljs$cst$2068$pixel_grid_opacity$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$(this.color)],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$284_page$jscomp$107_state$jscomp$934$$))});return new $app$main$data$workspace$change_pixel_grid_color_72219$$(null,$color$jscomp$110$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$relocate_page$$=function($id$jscomp$755$$,$index$jscomp$366$$){typeof $app$main$data$workspace$relocate_page_72007$$==="undefined"&&($app$main$data$workspace$relocate_page_72007$$=function($id$jscomp$756$$,$index$jscomp$367$$,$meta72008$$){this.id=$id$jscomp$756$$;this.index=$index$jscomp$367$$;this.$meta72008$=$meta72008$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$relocate_page_72007$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$relocate_page_72007$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4555$app_DOT_main_DOT_data_DOT_workspace_SLASH_relocate_page$$},$app$main$data$workspace$relocate_page_72007$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72009$$,$meta72008__$1$$){return new $app$main$data$workspace$relocate_page_72007$$(this.id,this.index,$meta72008__$1$$)},$app$main$data$workspace$relocate_page_72007$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta72008$},$app$main$data$workspace$relocate_page_72007$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$relocate_page_72007$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$282_it$jscomp$249_prev_index$jscomp$1$$,$page_id$jscomp$inline_8567_state$jscomp$914$$){$changes$jscomp$282_it$jscomp$249_prev_index$jscomp$1$$=$APP.$app$common$data$index_of$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$inline_8567_state$jscomp$914$$),
$APP.$cljs$cst$2236$pages$$),this.id);$page_id$jscomp$inline_8567_state$jscomp$914$$=this.id;$changes$jscomp$282_it$jscomp$249_prev_index$jscomp$1$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2634$mov_page$$,$APP.$cljs$cst$266$id$$,$page_id$jscomp$inline_8567_state$jscomp$914$$,$APP.$cljs$cst$1801$index$$,this.index],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2634$mov_page$$,$APP.$cljs$cst$266$id$$,$page_id$jscomp$inline_8567_state$jscomp$914$$,$APP.$cljs$cst$1801$index$$,$changes$jscomp$282_it$jscomp$249_prev_index$jscomp$1$$],null)));
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$282_it$jscomp$249_prev_index$jscomp$1$$))});return new $app$main$data$workspace$relocate_page_72007$$($id$jscomp$755$$,$index$jscomp$366$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$update_page_position_data$cljs$0core$0IFn$0_invoke$0arity$02$$=function(){typeof $app$main$data$workspace$update_page_position_data_71850$$==="undefined"&&($app$main$data$workspace$update_page_position_data_71850$$=function($file_id$jscomp$262$$,$page_id$jscomp$271$$,$meta71851$$){this.$file_id$=$file_id$jscomp$262$$;this.$page_id$=$page_id$jscomp$271$$;this.$meta71851$=$meta71851$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$update_page_position_data_71850$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_page_position_data_71850$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4528$app_DOT_main_DOT_data_DOT_workspace_SLASH_update_page_position_data$$},$app$main$data$workspace$update_page_position_data_71850$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71852$$,$meta71851__$1$$){return new $app$main$data$workspace$update_page_position_data_71850$$(this.$file_id$,
this.$page_id$,$meta71851__$1$$)},$app$main$data$workspace$update_page_position_data_71850$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71851$},$app$main$data$workspace$update_page_position_data_71850$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$update_page_position_data_71850$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$276_file_id__$1$jscomp$5_it$jscomp$245$$,$state$jscomp$887$$){var $self__$jscomp$6219$$=
this;$changes$jscomp$276_file_id__$1$jscomp$5_it$jscomp$245$$=function(){var $or__5025__auto__$jscomp$881$$=$self__$jscomp$6219$$.$file_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$881$$)?$or__5025__auto__$jscomp$881$$:$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$887$$)}();var $page_id__$1$jscomp$14$$=function(){var $or__5025__auto__$jscomp$882$$=$self__$jscomp$6219$$.$page_id$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$882$$)?$or__5025__auto__$jscomp$882$$:
$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$887$$)}();$changes$jscomp$276_file_id__$1$jscomp$5_it$jscomp$245$$=$APP.$cljs$core$reduce_kv$$(function($result$jscomp$319$$,$___$1$jscomp$1738$$,$shape$jscomp$755$$){return $APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$755$$)&&$APP.$cljs$cst$1899$position_data$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$755$$)==null?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$319$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2623$mod_obj$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$755$$),$APP.$cljs$cst$2051$page_id$$,$page_id__$1$jscomp$14$$,$APP.$cljs$cst$2624$operations$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$203$set$$,$APP.$cljs$cst$2610$attr$$,
$APP.$cljs$cst$1899$position_data$$,$APP.$cljs$cst$108$val$$,$APP.$app$render_wasm$api$calculate_position_data$$($shape$jscomp$755$$),$APP.$cljs$cst$2567$ignore_touched$$,!0,$APP.$cljs$cst$2568$ignore_geometry$$,!0],null)],null)],null)):$result$jscomp$319$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$887$$,$changes$jscomp$276_file_id__$1$jscomp$5_it$jscomp$245$$,$page_id__$1$jscomp$14$$));return $APP.$app$common$data$not_empty_QMARK_$$($changes$jscomp$276_file_id__$1$jscomp$5_it$jscomp$245$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$3157$redo_changes$$,$changes$jscomp$276_file_id__$1$jscomp$5_it$jscomp$245$$,$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$cst$3164$save_undo_QMARK_$$,!1,$APP.$cljs$cst$1792$origin$$,this,$APP.$cljs$cst$3166$tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1899$position_data$$,
null],null),null)],null))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$update_page_position_data_71850$$(null,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$reorder_variant_poperties$$=function($variant_id$jscomp$29$$,$from_pos$jscomp$8$$,$to_space_between_pos$jscomp$8$$){typeof $app$main$data$workspace$variants$reorder_variant_properties_71700$$==="undefined"&&($app$main$data$workspace$variants$reorder_variant_properties_71700$$=function($variant_id$jscomp$30$$,$from_pos$jscomp$9$$,$to_space_between_pos$jscomp$9$$,$meta71701$$){this.$variant_id$=$variant_id$jscomp$30$$;this.$from_pos$=$from_pos$jscomp$9$$;this.$to_space_between_pos$=
$to_space_between_pos$jscomp$9$$;this.$meta71701$=$meta71701$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$reorder_variant_properties_71700$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$reorder_variant_properties_71700$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4498$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_reorder_variant_properties$$},
$app$main$data$workspace$variants$reorder_variant_properties_71700$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71702$$,$meta71701__$1$$){return new $app$main$data$workspace$variants$reorder_variant_properties_71700$$(this.$variant_id$,this.$from_pos$,this.$to_space_between_pos$,$meta71701__$1$$)},$app$main$data$workspace$variants$reorder_variant_properties_71700$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71701$},$app$main$data$workspace$variants$reorder_variant_properties_71700$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$reorder_variant_properties_71700$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$272_it$jscomp$238_page_id$jscomp$260$$,$data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$){$changes$jscomp$272_it$jscomp$238_page_id$jscomp$260$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$);$data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$);var $objects$jscomp$656$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$,$changes$jscomp$272_it$jscomp$238_page_id$jscomp$260$$),$APP.$cljs$cst$1636$objects$$);$changes$jscomp$272_it$jscomp$238_page_id$jscomp$260$$=$app$common$logic$variant_properties$generate_reorder_variant_poperties$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,
$changes$jscomp$272_it$jscomp$238_page_id$jscomp$260$$),$data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$),$objects$jscomp$656$$),this.$variant_id$,this.$from_pos$,this.$to_space_between_pos$);$data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$272_it$jscomp$238_page_id$jscomp$260$$),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($data$jscomp$396_state$jscomp$856_undo_id$jscomp$71$$))});return new $app$main$data$workspace$variants$reorder_variant_properties_71700$$($variant_id$jscomp$29$$,$from_pos$jscomp$8$$,$to_space_between_pos$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$pages$duplicate_page$$=function($page_id$jscomp$242$$){typeof $app$main$data$workspace$pages$duplicate_page_71028$$==="undefined"&&($app$main$data$workspace$pages$duplicate_page_71028$$=function($page_id$jscomp$243$$,$meta71029$$){this.$page_id$=$page_id$jscomp$243$$;this.$meta71029$=$meta71029$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$pages$duplicate_page_71028$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$duplicate_page_71028$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4438$app_DOT_main_DOT_data_DOT_workspace_DOT_pages_SLASH_duplicate_page$$},$app$main$data$workspace$pages$duplicate_page_71028$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71030$$,$meta71029__$1$$){return new $app$main$data$workspace$pages$duplicate_page_71028$$(this.$page_id$,$meta71029__$1$$)},$app$main$data$workspace$pages$duplicate_page_71028$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71029$},$app$main$data$workspace$pages$duplicate_page_71028$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$pages$duplicate_page_71028$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$,$base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$820$$){function $add_comp$$($changes$jscomp$250$$,$component$jscomp$88_main$jscomp$2$$){var $new_component_id$jscomp$6$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$)),$new_variant_id$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$)),$main_instance_id$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$));
$component$jscomp$88_main$jscomp$2$$=$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($fdata$jscomp$16$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$));return $APP.$app$common$files$changes_builder$add_component$$($changes$jscomp$250$$,$new_component_id$jscomp$6$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$),
$APP.$cljs$core$PersistentVector$EMPTY$$,$main_instance_id$jscomp$6$$,$new_page_id$$,$APP.$cljs$cst$2553$annotation$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$),$new_variant_id$jscomp$1$$,$APP.$cljs$cst$2017$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$88_main$jscomp$2$$))}function $add_component_copy$$($objs$jscomp$17_objs__$1$jscomp$1$$,$id$jscomp$729$$,$new_shape$jscomp$20_shape$jscomp$724$$){var $children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$=
$APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($fdata$jscomp$16$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$724$$)),$parent_id$jscomp$92$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$724$$),$APP.$app$common$uuid$zero$$)?$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$724$$):
null;$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$=$APP.$app$common$types$container$make_component_instance$cljs$0core$0IFn$0_invoke$0arity$05$$($page$jscomp$98$$,$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$,$fdata$jscomp$16$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$724$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$724$$)),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2100$keep_ids_QMARK_$$,!0,$APP.$cljs$cst$2560$force_frame_id$$,$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($new_shape$jscomp$20_shape$jscomp$724$$),$APP.$cljs$cst$2561$force_parent_id$$,$parent_id$jscomp$92$$],null));$new_shape$jscomp$20_shape$jscomp$724$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$,0,null);$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$,1,null);$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape__$1$jscomp$54$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$54$$),
$shape__$1$jscomp$54$$],null)},$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$));$objs$jscomp$17_objs__$1$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objs$jscomp$17_objs__$1$jscomp$1$$,$id$jscomp$729$$,$new_shape$jscomp$20_shape$jscomp$724$$);return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$objs$jscomp$17_objs__$1$jscomp$1$$,$children$jscomp$250_component$jscomp$87_new_shapes$jscomp$8_vec__71050$$]))}
var $it__$1$jscomp$98$$=this,$new_page_id$$=$APP.$app$common$uuid$next$$(),$fdata$jscomp$16$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$820$$);$changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fdata$jscomp$16$$,$APP.$cljs$cst$1635$pages_index$$);var $page$jscomp$98$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$,
this.$page_id$);$changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$=$APP.$app$common$files$helpers$get_used_names$$($changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$);$base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$820$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$98$$);$changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$=$APP.$app$common$files$helpers$generate_unique_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$820$$,
$changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1633$suffix_fn$$,function($copy_count$jscomp$2$$){return" "+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.copy-suffix")??"")+(($copy_count$jscomp$2$$>1?[" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($copy_count$jscomp$2$$)].join(""):null)??"")}]));var $objects$jscomp$622$$=$APP.$cljs$core$update_vals$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$98$$),
function($p1__71017_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__71017_SHARP_$$,$APP.$cljs$cst$2975$use_for_thumbnail$$)}),$main_not_variant_ids$$=$APP.$cljs$core$set$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__71018_SHARP_$$){return $APP.$app$common$types$component$main_instance_QMARK_$$($APP.$cljs$core$_val$$($p1__71018_SHARP_$$))&&!$APP.$app$common$types$component$is_variant_QMARK_$$($APP.$cljs$core$_val$$($p1__71018_SHARP_$$))?$APP.$cljs$core$_key$$($p1__71018_SHARP_$$):
null},$objects$jscomp$622$$)),$ids_to_remove$$=$APP.$cljs$core$set$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71019_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$622$$,$p1__71019_SHARP_$$)},$main_not_variant_ids$$))),$variant_mains$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$is_variant_QMARK_$$,
$APP.$cljs$core$vals$$($objects$jscomp$622$$)),$variants_ids_map$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ids_map$jscomp$20$$,$shape$jscomp$725$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($ids_map$jscomp$20$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$725$$),$APP.$app$common$uuid$next$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$725$$),
$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$725$$),$APP.$app$common$uuid$next$$()]))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$variant_mains$$);$base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$820$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($JSCompiler_temp$jscomp$11272_JSCompiler_temp$jscomp$11273_JSCompiler_temp$jscomp$11274_objs$jscomp$18$$,$JSCompiler_temp_const$jscomp$11275_p__71067$$){var $id$jscomp$730$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11275_p__71067$$,0,null),$JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11275_p__71067$$,1,null);if($APP.$cljs$core$contains_QMARK_$$($main_not_variant_ids$$,$id$jscomp$730$$))$JSCompiler_temp$jscomp$11272_JSCompiler_temp$jscomp$11273_JSCompiler_temp$jscomp$11274_objs$jscomp$18$$=$add_component_copy$$($JSCompiler_temp$jscomp$11272_JSCompiler_temp$jscomp$11273_JSCompiler_temp$jscomp$11274_objs$jscomp$18$$,
$id$jscomp$730$$,$JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$);else if(!$APP.$cljs$core$contains_QMARK_$$($ids_to_remove$$,$id$jscomp$730$$))if($APP.$cljs$core$contains_QMARK_$$($variants_ids_map$$,$id$jscomp$730$$)){$JSCompiler_temp_const$jscomp$11275_p__71067$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__71062__$1$jscomp$inline_13597$$=$APP.$cljs$core$contains_QMARK_$$($JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$,$APP.$cljs$cst$1632$component_id$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$,$APP.$cljs$cst$1632$component_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$))):$JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$;$JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$=$APP.$cljs$core$contains_QMARK_$$($JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$,
$APP.$cljs$cst$2016$variant_id$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71062__$1$jscomp$inline_13597$$,$APP.$cljs$cst$2016$variant_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_ids_map$$,$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$))):$G__71062__$1$jscomp$inline_13597$$;$JSCompiler_temp$jscomp$11272_JSCompiler_temp$jscomp$11273_JSCompiler_temp$jscomp$11274_objs$jscomp$18$$=$JSCompiler_temp_const$jscomp$11275_p__71067$$.call($APP.$cljs$core$assoc$$,
$JSCompiler_temp$jscomp$11272_JSCompiler_temp$jscomp$11273_JSCompiler_temp$jscomp$11274_objs$jscomp$18$$,$id$jscomp$730$$,$JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$)}else $JSCompiler_temp$jscomp$11272_JSCompiler_temp$jscomp$11273_JSCompiler_temp$jscomp$11274_objs$jscomp$18$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$11272_JSCompiler_temp$jscomp$11273_JSCompiler_temp$jscomp$11274_objs$jscomp$18$$,$id$jscomp$730$$,$JSCompiler_inline_result$jscomp$11277_shape$jscomp$727$$);
return $JSCompiler_temp$jscomp$11272_JSCompiler_temp$jscomp$11273_JSCompiler_temp$jscomp$11274_objs$jscomp$18$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$objects$jscomp$622$$);var $objects__$2$$=$APP.$cljs$core$reduce_kv$$(function($objs$jscomp$19$$,$___$1$jscomp$1677$$,$p__71076$$){var $map__71077__$1$$=$APP.$cljs$core$__destructure_map$$($p__71076$$),$id$jscomp$731$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71077__$1$$,$APP.$cljs$cst$266$id$$),$parent_id$jscomp$93$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71077__$1$$,
$APP.$cljs$cst$1624$parent_id$$),$frame_id$jscomp$110$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__71077__$1$$,$APP.$cljs$cst$1612$frame_id$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objs$jscomp$19$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$id$jscomp$731$$,$id$jscomp$731$$),function(){var $G__71078$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__71077__$1$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$id$jscomp$731$$,$id$jscomp$731$$)),$APP.$cljs$cst$1624$parent_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$parent_id$jscomp$93$$,$parent_id$jscomp$93$$)),$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$frame_id$jscomp$110$$,$frame_id$jscomp$110$$));return $APP.$cljs$core$contains_QMARK_$$($map__71077__$1$$,$APP.$cljs$cst$1619$shapes$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__71078$$,$APP.$cljs$cst$1619$shapes$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71025_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($variants_ids_map$$,$p1__71025_SHARP_$$,$p1__71025_SHARP_$$)},$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($map__71077__$1$$))):$G__71078$$}())},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$base_name$jscomp$4_objects__$1$jscomp$25_state$jscomp$820$$),
$page__$1$jscomp$6$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$98$$,$APP.$cljs$cst$725$name$$,$changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$),$APP.$cljs$cst$266$id$$,$new_page_id$$),$APP.$cljs$cst$1636$objects$$,$objects__$2$$);$changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$=function(){var $JSCompiler_inline_result$jscomp$1673_changes$jscomp$251$$=
$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$($it__$1$jscomp$98$$),$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2631$add_page$$,$APP.$cljs$cst$266$id$$,$new_page_id$$,$APP.$cljs$cst$1629$page$$,
$page__$1$jscomp$6$$],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2633$del_page$$,$APP.$cljs$cst$266$id$$,$new_page_id$$],null)));$JSCompiler_inline_result$jscomp$1673_changes$jscomp$251$$=$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($JSCompiler_inline_result$jscomp$1673_changes$jscomp$251$$,$page__$1$jscomp$6$$),$objects__$2$$);
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($add_comp$$,$JSCompiler_inline_result$jscomp$1673_changes$jscomp$251$$,$variant_mains$$)}();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$249_it$jscomp$222_name$jscomp$345_pages$jscomp$5_unames$jscomp$12$$))});return new $app$main$data$workspace$pages$duplicate_page_71028$$($page_id$jscomp$242$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$rename_flow$$=function($flow_id$jscomp$9$$,$name$jscomp$342$$){typeof $app$main$data$workspace$interactions$rename_flow_70651$$==="undefined"&&($app$main$data$workspace$interactions$rename_flow_70651$$=function($flow_id$jscomp$10$$,$name$jscomp$343$$,$meta70652$$){this.$flow_id$=$flow_id$jscomp$10$$;this.name=$name$jscomp$343$$;this.$meta70652$=$meta70652$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$rename_flow_70651$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$rename_flow_70651$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4375$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_rename_flow$$},$app$main$data$workspace$interactions$rename_flow_70651$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70653$$,$meta70652__$1$$){return new $app$main$data$workspace$interactions$rename_flow_70651$$(this.$flow_id$,this.name,$meta70652__$1$$)},
$app$main$data$workspace$interactions$rename_flow_70651$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70652$},$app$main$data$workspace$interactions$rename_flow_70651$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$rename_flow_70651$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2416_page$jscomp$92$$,$state$jscomp$781$$){var $self__$jscomp$5764$$=this;$_$jscomp$2416_page$jscomp$92$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$781$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$interactions$update_flow$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2416_page$jscomp$92$$),$self__$jscomp$5764$$.$flow_id$,function($p1__70650_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__70650_SHARP_$$,$APP.$cljs$cst$725$name$$,$self__$jscomp$5764$$.name)}))});return new $app$main$data$workspace$interactions$rename_flow_70651$$($flow_id$jscomp$9$$,
$name$jscomp$342$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$01$$=function($flow_id$jscomp$4$$){return $APP.$app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$flow_id$jscomp$4$$)};
$app$main$data$workspace$interactions$add_flow_selected_frame$$=function(){typeof $app$main$data$workspace$interactions$add_flow_selected_frame_70634$$==="undefined"&&($app$main$data$workspace$interactions$add_flow_selected_frame_70634$$=function($meta70635$$){this.$meta70635$=$meta70635$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4372$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_flow_selected_frame$$},$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70636$$,$meta70635__$1$$){return new $app$main$data$workspace$interactions$add_flow_selected_frame_70634$$($meta70635__$1$$)},$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70635$},$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-prototype-interaction"],null)},$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_flow_selected_frame_70634$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2413_selected$jscomp$82$$,$state$jscomp$778$$){$_$jscomp$2413_selected$jscomp$82$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$778$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$interactions$add_flow$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$first$$($_$jscomp$2413_selected$jscomp$82$$)))});
return new $app$main$data$workspace$interactions$add_flow_selected_frame_70634$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$guides$update_guide_color$$=function($guide_id$jscomp$2$$,$color$jscomp$103$$){typeof $app$main$data$workspace$guides$update_guide_color_70551$$==="undefined"&&($app$main$data$workspace$guides$update_guide_color_70551$$=function($guide_id$jscomp$3$$,$color$jscomp$104$$,$meta70552$$){this.$guide_id$=$guide_id$jscomp$3$$;this.color=$color$jscomp$104$$;this.$meta70552$=$meta70552$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$main$data$workspace$guides$update_guide_color_70551$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$update_guide_color_70551$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4363$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_update_guide_color$$},$app$main$data$workspace$guides$update_guide_color_70551$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70553$$,$meta70552__$1$$){return new $app$main$data$workspace$guides$update_guide_color_70551$$(this.$guide_id$,
this.color,$meta70552__$1$$)},$app$main$data$workspace$guides$update_guide_color_70551$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70552$},$app$main$data$workspace$guides$update_guide_color_70551$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$update_guide_color_70551$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$243_it$jscomp$217_map__70557_map__70557__$1$$,$guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$){$changes$jscomp$243_it$jscomp$217_map__70557_map__70557__$1$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$);$changes$jscomp$243_it$jscomp$217_map__70557_map__70557__$1$$=$APP.$cljs$core$__destructure_map$$($changes$jscomp$243_it$jscomp$217_map__70557_map__70557__$1$$);$guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$243_it$jscomp$217_map__70557_map__70557__$1$$,$APP.$cljs$cst$2065$guides$$);
$guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$,this.$guide_id$);return $guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$!=null?($guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$=this.color!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$,$APP.$cljs$cst$1303$color$$,
this.color):$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$,$APP.$cljs$cst$1303$color$$),$changes$jscomp$243_it$jscomp$217_map__70557_map__70557__$1$$=$APP.$app$common$files$changes_builder$set_guide$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$243_it$jscomp$217_map__70557_map__70557__$1$$),this.$guide_id$,
$guide$jscomp$9_guides$jscomp$11_state$jscomp$771_updated_guide$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$243_it$jscomp$217_map__70557_map__70557__$1$$))):null});return new $app$main$data$workspace$guides$update_guide_color_70551$$($guide_id$jscomp$2$$,$color$jscomp$103$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$guides$remove_frame_guides$$=function($frame_ids$jscomp$3$$){typeof $app$main$data$workspace$guides$remove_frame_guides_70514$$==="undefined"&&($app$main$data$workspace$guides$remove_frame_guides_70514$$=function($frame_ids$jscomp$4$$,$meta70515$$){this.$frame_ids$=$frame_ids$jscomp$4$$;this.$meta70515$=$meta70515$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$guides$remove_frame_guides_70514$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_frame_guides_70514$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4362$app_DOT_main_DOT_data_DOT_workspace_DOT_guides_SLASH_remove_frame_guides$$},$app$main$data$workspace$guides$remove_frame_guides_70514$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70516$$,$meta70515__$1$$){return new $app$main$data$workspace$guides$remove_frame_guides_70514$$(this.$frame_ids$,$meta70515__$1$$)},
$app$main$data$workspace$guides$remove_frame_guides_70514$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70515$},$app$main$data$workspace$guides$remove_frame_guides_70514$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_frame_guides_70514$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2401_guides$jscomp$8_map__70521_map__70521__$1$$,$state$jscomp$768$$){$_$jscomp$2401_guides$jscomp$8_map__70521_map__70521__$1$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$768$$);$_$jscomp$2401_guides$jscomp$8_map__70521_map__70521__$1$$=$APP.$cljs$core$__destructure_map$$($_$jscomp$2401_guides$jscomp$8_map__70521_map__70521__$1$$);$_$jscomp$2401_guides$jscomp$8_map__70521_map__70521__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2401_guides$jscomp$8_map__70521_map__70521__$1$$,$APP.$cljs$cst$2065$guides$$);var $frame_ids_set$$=$APP.$cljs$core$set$$(this.$frame_ids$),
$guide_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__70509_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($frame_ids_set$$,$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70509_SHARP_$$))}),$APP.$app$common$data$xf_COLON_map_id$$),$APP.$cljs$core$vals$$($_$jscomp$2401_guides$jscomp$8_map__70521_map__70521__$1$$));
return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$768$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4360$workspace_guides$$,$APP.$cljs$cst$2212$hover$$],null),function($hover$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$disj$$,$APP.$cljs$core$truth_$$($hover$$)?$hover$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$guide_ids$$)})},$app$main$data$workspace$guides$remove_frame_guides_70514$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$guides$remove_frame_guides_70514$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$242_it$jscomp$216_map__70525_map__70525__$1$$,$guides$jscomp$9_state$jscomp$769_to_remove$$){$changes$jscomp$242_it$jscomp$216_map__70525_map__70525__$1$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($guides$jscomp$9_state$jscomp$769_to_remove$$);$changes$jscomp$242_it$jscomp$216_map__70525_map__70525__$1$$=
$APP.$cljs$core$__destructure_map$$($changes$jscomp$242_it$jscomp$216_map__70525_map__70525__$1$$);$guides$jscomp$9_state$jscomp$769_to_remove$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$242_it$jscomp$216_map__70525_map__70525__$1$$,$APP.$cljs$cst$2065$guides$$);var $frame_ids_set$jscomp$1$$=$APP.$cljs$core$set$$(this.$frame_ids$);$guides$jscomp$9_state$jscomp$769_to_remove$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70510_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($frame_ids_set$jscomp$1$$,
$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__70510_SHARP_$$))},$APP.$cljs$core$vals$$($guides$jscomp$9_state$jscomp$769_to_remove$$));$changes$jscomp$242_it$jscomp$216_map__70525_map__70525__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$134$$,$id$jscomp$718_map__70527__$1_p__70526$$){$id$jscomp$718_map__70527__$1_p__70526$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$718_map__70527__$1_p__70526$$);$id$jscomp$718_map__70527__$1_p__70526$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$718_map__70527__$1_p__70526$$,$APP.$cljs$cst$266$id$$);return $APP.$app$common$files$changes_builder$set_guide$$($acc$jscomp$134$$,$id$jscomp$718_map__70527__$1_p__70526$$,null)},$APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$242_it$jscomp$216_map__70525_map__70525__$1$$),$guides$jscomp$9_state$jscomp$769_to_remove$$);
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$242_it$jscomp$216_map__70525_map__70525__$1$$))});return new $app$main$data$workspace$guides$remove_frame_guides_70514$$($frame_ids$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$drag_selected_points$$=function($start_position$jscomp$1$$){typeof $app$main$data$workspace$path$edition$drag_selected_points_70136$$==="undefined"&&($app$main$data$workspace$path$edition$drag_selected_points_70136$$=function($start_position$jscomp$2$$,$meta70137$$){this.$start_position$=$start_position$jscomp$2$$;this.$meta70137$=$meta70137$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$drag_selected_points_70136$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$drag_selected_points_70136$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4322$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_drag_selected_points$$},$app$main$data$workspace$path$edition$drag_selected_points_70136$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70138$$,$meta70137__$1$$){return new $app$main$data$workspace$path$edition$drag_selected_points_70136$$(this.$start_position$,
$meta70137__$1$$)},$app$main$data$workspace$path$edition$drag_selected_points_70136$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70137$},$app$main$data$workspace$path$edition$drag_selected_points_70136$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$drag_selected_points_70136$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2353_stopper$jscomp$27$$,$content$jscomp$214_points$jscomp$91_state$jscomp$735$$,
$id$jscomp$697_selected_points$jscomp$5_stream$jscomp$78$$){var $self__$jscomp$5567$$=this;$_$jscomp$2353_stopper$jscomp$27$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$697_selected_points$jscomp$5_stream$jscomp$78$$,null);$id$jscomp$697_selected_points$jscomp$5_stream$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$214_points$jscomp$91_state$jscomp$735$$,$APP.$cljs$cst$1937$workspace_local$$),
$APP.$cljs$cst$2207$edition$$);$id$jscomp$697_selected_points$jscomp$5_stream$jscomp$78$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$214_points$jscomp$91_state$jscomp$735$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1940$edit_path$$),$id$jscomp$697_selected_points$jscomp$5_stream$jscomp$78$$),$APP.$cljs$cst$4308$selected_points$$,
$APP.$cljs$core$PersistentHashSet$EMPTY$$);var $start_position__$1$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$min_key$$,function($p1__70134_SHARP_$$){return $APP.$app$common$geom$point$distance$$($self__$jscomp$5567$$.$start_position$,$p1__70134_SHARP_$$)},$id$jscomp$697_selected_points$jscomp$5_stream$jscomp$78$$);$content$jscomp$214_points$jscomp$91_state$jscomp$735$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($content$jscomp$214_points$jscomp$91_state$jscomp$735$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$]));$content$jscomp$214_points$jscomp$91_state$jscomp$735$$=$APP.$app$common$types$path$get_points$$($content$jscomp$214_points$jscomp$91_state$jscomp$735$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2353_stopper$jscomp$27$$,$APP.$beicon$v2$core$map$$(function($p1__70135_SHARP_$$){return $app$main$data$workspace$path$edition$move_selected_path_point$$($start_position__$1$$,
$p1__70135_SHARP_$$)},$app$main$data$workspace$path$streams$move_points_stream$$($start_position__$1$$,$id$jscomp$697_selected_points$jscomp$5_stream$jscomp$78$$,$content$jscomp$214_points$jscomp$91_state$jscomp$735$$))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$edition$apply_content_modifiers$$()))});return new $app$main$data$workspace$path$edition$drag_selected_points_70136$$($start_position$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$split_segments$$=function($id$jscomp$706$$,$p__70207$$){var $map__70208__$1$$=$APP.$cljs$core$__destructure_map$$($p__70207$$),$from_p$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70208__$1$$,$APP.$cljs$cst$1859$from_p$$),$to_p$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70208__$1$$,$APP.$cljs$cst$1860$to_p$$),$t$jscomp$96$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70208__$1$$,$APP.$cljs$cst$1858$t$$);
typeof $app$main$data$workspace$path$edition$split_segments_70209$$==="undefined"&&($app$main$data$workspace$path$edition$split_segments_70209$$=function($id$jscomp$707$$,$p__70207$jscomp$1$$,$map__70208$jscomp$1$$,$from_p$jscomp$15$$,$to_p$jscomp$13$$,$t$jscomp$97$$,$meta70210$$){this.id=$id$jscomp$707$$;this.$p__70207$=$p__70207$jscomp$1$$;this.$map__70208$=$map__70208$jscomp$1$$;this.$from_p$=$from_p$jscomp$15$$;this.$to_p$=$to_p$jscomp$13$$;this.t=$t$jscomp$97$$;this.$meta70210$=$meta70210$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$split_segments_70209$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$split_segments_70209$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4329$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_split_segments$$},$app$main$data$workspace$path$edition$split_segments_70209$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70211$$,$meta70210__$1$$){return new $app$main$data$workspace$path$edition$split_segments_70209$$(this.id,this.$p__70207$,this.$map__70208$,this.$from_p$,this.$to_p$,this.t,$meta70210__$1$$)},$app$main$data$workspace$path$edition$split_segments_70209$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70210$},$app$main$data$workspace$path$edition$split_segments_70209$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$split_segments_70209$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($JSCompiler_inline_result$jscomp$793__$jscomp$2363_content$jscomp$216_content__$1$jscomp$inline_8580$$,$JSCompiler_temp_const$jscomp$792_state$jscomp$742$$){$JSCompiler_inline_result$jscomp$793__$jscomp$2363_content$jscomp$216_content__$1$jscomp$inline_8580$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($JSCompiler_temp_const$jscomp$792_state$jscomp$742$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$]));
$JSCompiler_temp_const$jscomp$792_state$jscomp$742$$=$APP.$cljs$core$assoc_in$$($JSCompiler_temp_const$jscomp$792_state$jscomp$742$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,this.id,$APP.$cljs$cst$4266$old_content$$],null),$JSCompiler_inline_result$jscomp$793__$jscomp$2363_content$jscomp$216_content__$1$jscomp$inline_8580$$);var $points$jscomp$inline_8578$$=$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([this.$to_p$,
this.$from_p$]),$value$jscomp$inline_8579$$=this.t;$JSCompiler_inline_result$jscomp$793__$jscomp$2363_content$jscomp$216_content__$1$jscomp$inline_8580$$=$APP.$app$common$types$path$impl$path_data$$($JSCompiler_inline_result$jscomp$793__$jscomp$2363_content$jscomp$216_content__$1$jscomp$inline_8580$$);$JSCompiler_inline_result$jscomp$793__$jscomp$2363_content$jscomp$216_content__$1$jscomp$inline_8580$$=$APP.$app$common$types$path$segment$split_segments$$($JSCompiler_inline_result$jscomp$793__$jscomp$2363_content$jscomp$216_content__$1$jscomp$inline_8580$$,
$points$jscomp$inline_8578$$,$value$jscomp$inline_8579$$);return $APP.$app$main$data$workspace$path$state$set_content$$($JSCompiler_temp_const$jscomp$792_state$jscomp$742$$,$APP.$app$common$types$path$impl$path_data$$($JSCompiler_inline_result$jscomp$793__$jscomp$2363_content$jscomp$216_content__$1$jscomp$inline_8580$$))},$app$main$data$workspace$path$edition$split_segments_70209$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$split_segments_70209$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$changes$save_path_content$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4264$preserve_move_to$$,!0],null)))});return new $app$main$data$workspace$path$edition$split_segments_70209$$($id$jscomp$706$$,$p__70207$$,$map__70208__$1$$,$from_p$jscomp$14$$,$to_p$jscomp$12$$,$t$jscomp$96$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$update_component$cljs$0core$0IFn$0_invoke$0arity$02$$=function($id$jscomp$599$$,$undo_group$jscomp$25$$){typeof $app$main$data$workspace$libraries$update_component_69895$$==="undefined"&&($app$main$data$workspace$libraries$update_component_69895$$=function($id$jscomp$600$$,$undo_group$jscomp$26$$,$meta69896$$){this.id=$id$jscomp$600$$;this.$undo_group$=$undo_group$jscomp$26$$;this.$meta69896$=$meta69896$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$update_component_69895$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_69895$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4018$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component$$},$app$main$data$workspace$libraries$update_component_69895$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69897$$,$meta69896__$1$$){return new $app$main$data$workspace$libraries$update_component_69895$$(this.id,
this.$undo_group$,$meta69896__$1$$)},$app$main$data$workspace$libraries$update_component_69895$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69896$},$app$main$data$workspace$libraries$update_component_69895$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_69895$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($file$jscomp$65_it$jscomp$200$$,$ldata$jscomp$3_state$jscomp$525$$){var $self__$jscomp$4885$$=
this;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,"UPDATE-COMPONENT of shape"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4885$$.id)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3162$undo_group$$,$self__$jscomp$4885$$.$undo_group$],null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$,!1);var $page_id$jscomp$190_shape$jscomp$561$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($ldata$jscomp$3_state$jscomp$525$$),
$changes$jscomp$222_libraries$jscomp$77$$=$APP.$app$main$data$helpers$lookup_libraries$$($ldata$jscomp$3_state$jscomp$525$$);$file$jscomp$65_it$jscomp$200$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($ldata$jscomp$3_state$jscomp$525$$);var $fdata$jscomp$13$$=$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$65_it$jscomp$200$$),$container$jscomp$71$$=$APP.$app$common$types$container$get_container$$($fdata$jscomp$13$$,$page_id$jscomp$190_shape$jscomp$561$$);
$page_id$jscomp$190_shape$jscomp$561$$=$APP.$app$common$types$container$get_shape$$($container$jscomp$71$$,$self__$jscomp$4885$$.id);if($APP.$app$common$types$component$instance_head_QMARK_$$($page_id$jscomp$190_shape$jscomp$561$$)){$changes$jscomp$222_libraries$jscomp$77$$=$app$common$logic$libraries$generate_sync_shape_inverse$$($APP.$app$common$files$changes_builder$with_container$$($APP.$app$common$files$changes_builder$set_undo_group$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$self__$jscomp$4885$$.$undo_group$),$container$jscomp$71$$),$fdata$jscomp$13$$,$changes$jscomp$222_libraries$jscomp$77$$,$container$jscomp$71$$,$self__$jscomp$4885$$.id);$ldata$jscomp$3_state$jscomp$525$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($ldata$jscomp$3_state$jscomp$525$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$190_shape$jscomp$561$$));var $xf_filter$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3593$local_change_QMARK_$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69887_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__69887_SHARP_$$,$APP.$cljs$cst$3593$local_change_QMARK_$$)})),$local_changes$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$222_libraries$jscomp$77$$,$APP.$cljs$cst$3157$redo_changes$$,function($p1__69888_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$xf_filter$$,$p1__69888_SHARP_$$)}),$APP.$cljs$cst$3161$undo_changes$$,function($p1__69889_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$xf_filter$$,$p1__69889_SHARP_$$)}),$xf_remove$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3593$local_change_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__69890_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__69890_SHARP_$$,
$APP.$cljs$cst$3593$local_change_QMARK_$$)})),$nonlocal_changes$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$222_libraries$jscomp$77$$,$APP.$cljs$cst$3157$redo_changes$$,function($p1__69891_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$xf_remove$$,$p1__69891_SHARP_$$)}),$APP.$cljs$cst$3161$undo_changes$$,function($p1__69892_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$xf_remove$$,$p1__69892_SHARP_$$)});$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,"UPDATE-COMPONENT finished"],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4019$js_SLASH_local_changes$$,$APP.$app$main$data$workspace$libraries$log_changes$$($APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($local_changes$$),$fdata$jscomp$13$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4020$js_SLASH_nonlocal_changes$$,$APP.$app$main$data$workspace$libraries$log_changes$$($APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($nonlocal_changes$$),
$fdata$jscomp$13$$)],null)],null)}),null,"app.main.data.workspace.libraries",$APP.$cljs$cst$1160$debug$$,!1);return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$seq$$($APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($local_changes$$))?$APP.$app$main$data$changes$commit_changes$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($local_changes$$,$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$65_it$jscomp$200$$))):null,$APP.$cljs$core$seq$$($APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($nonlocal_changes$$))?
$APP.$app$main$data$changes$commit_changes$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($nonlocal_changes$$,$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($ldata$jscomp$3_state$jscomp$525$$))):null)}return null});return new $app$main$data$workspace$libraries$update_component_69895$$($id$jscomp$599$$,$undo_group$jscomp$25$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$update_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$=function($shape_id$jscomp$103$$,$file_id$jscomp$160$$){typeof $app$main$data$workspace$libraries$update_component_sync_69922$$==="undefined"&&($app$main$data$workspace$libraries$update_component_sync_69922$$=function($shape_id$jscomp$104$$,$file_id$jscomp$161$$,$undo_group$jscomp$28$$,$meta69923$$){this.$shape_id$=$shape_id$jscomp$104$$;this.$file_id$=$file_id$jscomp$161$$;this.$undo_group$=$undo_group$jscomp$28$$;
this.$meta69923$=$meta69923$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$update_component_sync_69922$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_sync_69922$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4021$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_update_component_sync$$},$app$main$data$workspace$libraries$update_component_sync_69922$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69924$$,$meta69923__$1$$){return new $app$main$data$workspace$libraries$update_component_sync_69922$$(this.$shape_id$,this.$file_id$,this.$undo_group$,$meta69923__$1$$)},$app$main$data$workspace$libraries$update_component_sync_69922$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69923$},$app$main$data$workspace$libraries$update_component_sync_69922$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$update_component_sync_69922$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2145_current_file_id$jscomp$11$$,$state$jscomp$527$$){$_$jscomp$2145_current_file_id$jscomp$11$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$527$$);var $current_file_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2145_current_file_id$jscomp$11$$,this.$file_id$),$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$527$$);
$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$=$APP.$app$common$types$container$get_shape$$($component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$,this.$shape_id$);$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$=$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$);var $undo_id$jscomp$29$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$29$$),
$app$main$data$workspace$libraries$update_component$cljs$0core$0IFn$0_invoke$0arity$02$$(this.$shape_id$,this.$undo_group$),$APP.$app$main$data$workspace$libraries$update_component_thumbnail_sync$$($state$jscomp$527$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$,this.$file_id$,"frame"),$APP.$app$main$data$workspace$libraries$update_component_thumbnail_sync$$($state$jscomp$527$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$,this.$file_id$,"component"),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$?
$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$($_$jscomp$2145_current_file_id$jscomp$11$$,this.$file_id$,$APP.$cljs$cst$1643$components$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$,this.$undo_group$):$APP.$app$main$data$workspace$libraries$sync_file$$($_$jscomp$2145_current_file_id$jscomp$11$$,this.$file_id$,$APP.$cljs$cst$1643$components$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$,this.$undo_group$),$current_file_QMARK_$$?null:
$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$?$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$05$$(this.$file_id$,this.$file_id$,$APP.$cljs$cst$1643$components$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$,this.$undo_group$):$APP.$app$main$data$workspace$libraries$sync_file$$(this.$file_id$,this.$file_id$,$APP.$cljs$cst$1643$components$$,$component_id$jscomp$59_page$jscomp$75_shape$jscomp$562$$,this.$undo_group$),
$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$29$$))});return new $app$main$data$workspace$libraries$update_component_sync_69922$$($shape_id$jscomp$103$$,$file_id$jscomp$160$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$reset_components$$=function($ids$jscomp$147$$){typeof $app$main$data$workspace$libraries$reset_components_69878$$==="undefined"&&($app$main$data$workspace$libraries$reset_components_69878$$=function($ids$jscomp$148$$,$meta69879$$){this.ids=$ids$jscomp$148$$;this.$meta69879$=$meta69879$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$reset_components_69878$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$reset_components_69878$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4017$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_reset_components$$},$app$main$data$workspace$libraries$reset_components_69878$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69880$$,$meta69879__$1$$){return new $app$main$data$workspace$libraries$reset_components_69878$$(this.ids,$meta69879__$1$$)},
$app$main$data$workspace$libraries$reset_components_69878$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69879$},$app$main$data$workspace$libraries$reset_components_69878$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$reset_components_69878$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $undo_id$jscomp$28$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$28$$)),
$APP.$beicon$v2$core$map$$(function($p1__69877_SHARP_$$){return $APP.$app$main$data$workspace$libraries$reset_component$$($p1__69877_SHARP_$$)},$APP.$beicon$v2$core$from$$(this.ids)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$28$$)))});return new $app$main$data$workspace$libraries$reset_components_69878$$($ids$jscomp$147$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$detach_components$$=function($ids$jscomp$142$$){typeof $app$main$data$workspace$libraries$detach_components_69836$$==="undefined"&&($app$main$data$workspace$libraries$detach_components_69836$$=function($ids$jscomp$143$$,$meta69837$$){this.ids=$ids$jscomp$143$$;this.$meta69837$=$meta69837$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$detach_components_69836$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_components_69836$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4003$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_detach_components$$},$app$main$data$workspace$libraries$detach_components_69836$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69838$$,$meta69837__$1$$){return new $app$main$data$workspace$libraries$detach_components_69836$$(this.ids,$meta69837__$1$$)},
$app$main$data$workspace$libraries$detach_components_69836$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69837$},$app$main$data$workspace$libraries$detach_components_69836$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$detach_components_69836$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $undo_id$jscomp$26$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$26$$)),
$APP.$beicon$v2$core$map$$(function($p1__69834_SHARP_$$){return $APP.$app$main$data$workspace$libraries$detach_component$$($p1__69834_SHARP_$$)},$APP.$beicon$v2$core$from$$(this.ids)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$26$$)))});return new $app$main$data$workspace$libraries$detach_components_69836$$($ids$jscomp$142$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$duplicate_typography$$=function($file_id$jscomp$146$$,$typography_id$jscomp$6$$){typeof $app$main$data$workspace$libraries$duplicate_typography_69723$$==="undefined"&&($app$main$data$workspace$libraries$duplicate_typography_69723$$=function($file_id$jscomp$147$$,$typography_id$jscomp$7$$,$meta69724$$){this.$file_id$=$file_id$jscomp$147$$;this.$typography_id$=$typography_id$jscomp$7$$;this.$meta69724$=$meta69724$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$duplicate_typography_69723$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_typography_69723$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3987$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_typography$$},$app$main$data$workspace$libraries$duplicate_typography_69723$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69725$$,$meta69724__$1$$){return new $app$main$data$workspace$libraries$duplicate_typography_69723$$(this.$file_id$,this.$typography_id$,$meta69724__$1$$)},$app$main$data$workspace$libraries$duplicate_typography_69723$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69724$},$app$main$data$workspace$libraries$duplicate_typography_69723$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_typography_69723$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$,$state$jscomp$508$$){$changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$508$$);$changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2223$typographies$$,this.$typography_id$],null));$changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$=(0,$APP.$app$common$types$typography$check_typography$$)($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$()));
$changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$=$APP.$app$common$files$changes_builder$add_typography$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$209_data$jscomp$360_it$jscomp$189_new_typography_typography$jscomp$18$$))});
return new $app$main$data$workspace$libraries$duplicate_typography_69723$$($file_id$jscomp$146$$,$typography_id$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$delete_media$$=function($p__69681$$){var $map__69682__$1$$=$APP.$cljs$core$__destructure_map$$($p__69681$$),$id$jscomp$580$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__69682__$1$$,$APP.$cljs$cst$266$id$$);typeof $app$main$data$workspace$libraries$delete_media_69683$$==="undefined"&&($app$main$data$workspace$libraries$delete_media_69683$$=function($p__69681$jscomp$1$$,$map__69682$jscomp$1$$,$id$jscomp$581$$,$meta69684$$){this.$p__69681$=$p__69681$jscomp$1$$;
this.$map__69682$=$map__69682$jscomp$1$$;this.id=$id$jscomp$581$$;this.$meta69684$=$meta69684$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$delete_media_69683$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_media_69683$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3981$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_delete_media$$},
$app$main$data$workspace$libraries$delete_media_69683$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69685$$,$meta69684__$1$$){return new $app$main$data$workspace$libraries$delete_media_69683$$(this.$p__69681$,this.$map__69682$,this.id,$meta69684__$1$$)},$app$main$data$workspace$libraries$delete_media_69683$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69684$},$app$main$data$workspace$libraries$delete_media_69683$$.prototype.$app$main$data$event$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_media_69683$$.prototype.$app$main$data$event$Event$_data$arity$1$=function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,this.id],null)},$app$main$data$workspace$libraries$delete_media_69683$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$delete_media_69683$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$205_changes$jscomp$inline_8582_data$jscomp$356_it$jscomp$183$$,
$id$jscomp$inline_8583_state$jscomp$503$$){$changes$jscomp$205_changes$jscomp$inline_8582_data$jscomp$356_it$jscomp$183$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$inline_8583_state$jscomp$503$$);$changes$jscomp$205_changes$jscomp$inline_8582_data$jscomp$356_it$jscomp$183$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$205_changes$jscomp$inline_8582_data$jscomp$356_it$jscomp$183$$);
$id$jscomp$inline_8583_state$jscomp$503$$=this.id;var $library_data$jscomp$inline_8584_prev_object$jscomp$inline_8585$$=$APP.$cljs$cst$3195$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$205_changes$jscomp$inline_8582_data$jscomp$356_it$jscomp$183$$));$library_data$jscomp$inline_8584_prev_object$jscomp$inline_8585$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($library_data$jscomp$inline_8584_prev_object$jscomp$inline_8585$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1644$media$$,$id$jscomp$inline_8583_state$jscomp$503$$],null));$changes$jscomp$205_changes$jscomp$inline_8582_data$jscomp$356_it$jscomp$183$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$205_changes$jscomp$inline_8582_data$jscomp$356_it$jscomp$183$$,
$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2641$del_media$$,$APP.$cljs$cst$266$id$$,$id$jscomp$inline_8583_state$jscomp$503$$],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2639$add_media$$,$APP.$cljs$cst$2206$object$$,$library_data$jscomp$inline_8584_prev_object$jscomp$inline_8585$$],null)));
return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$205_changes$jscomp$inline_8582_data$jscomp$356_it$jscomp$183$$))});return new $app$main$data$workspace$libraries$delete_media_69683$$($p__69681$$,$map__69682__$1$$,$id$jscomp$580$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$duplicate_color$$=function($file_id$jscomp$139$$,$color_id$jscomp$6$$){typeof $app$main$data$workspace$libraries$duplicate_color_69667$$==="undefined"&&($app$main$data$workspace$libraries$duplicate_color_69667$$=function($file_id$jscomp$140$$,$color_id$jscomp$7$$,$meta69668$$){this.$file_id$=$file_id$jscomp$140$$;this.$color_id$=$color_id$jscomp$7$$;this.$meta69668$=$meta69668$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$libraries$duplicate_color_69667$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_color_69667$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3978$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_color$$},$app$main$data$workspace$libraries$duplicate_color_69667$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69669$$,$meta69668__$1$$){return new $app$main$data$workspace$libraries$duplicate_color_69667$$(this.$file_id$,
this.$color_id$,$meta69668__$1$$)},$app$main$data$workspace$libraries$duplicate_color_69667$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69668$},$app$main$data$workspace$libraries$duplicate_color_69667$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_color_69667$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$,
$state$jscomp$501$$){$changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$501$$);$changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$=$APP.$app$common$types$library$get_color$$($changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$,this.$color_id$);$changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$=(0,$APP.$app$common$types$color$check_library_color$$)($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$,
$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$())));$changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$=$APP.$app$common$files$changes_builder$add_color$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$202_color$jscomp$67_data$jscomp$354_it$jscomp$180_new_color$$))});
return new $app$main$data$workspace$libraries$duplicate_color_69667$$($file_id$jscomp$139$$,$color_id$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$merge_cells$$=function($layout_id$jscomp$6$$,$ids$jscomp$245$$){typeof $app$main$data$workspace$shape_layout$merge_cells_71557$$==="undefined"&&($app$main$data$workspace$shape_layout$merge_cells_71557$$=function($layout_id$jscomp$7$$,$ids$jscomp$246$$,$meta71558$$){this.$layout_id$=$layout_id$jscomp$7$$;this.ids=$ids$jscomp$246$$;this.$meta71558$=$meta71558$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$merge_cells_71557$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$merge_cells_71557$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4481$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_merge_cells$$},$app$main$data$workspace$shape_layout$merge_cells_71557$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71559$$,$meta71558__$1$$){return new $app$main$data$workspace$shape_layout$merge_cells_71557$$(this.$layout_id$,this.ids,$meta71558__$1$$)},
$app$main$data$workspace$shape_layout$merge_cells_71557$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71558$},$app$main$data$workspace$shape_layout$merge_cells_71557$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$merge_cells_71557$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6055$$=this,$undo_id$jscomp$60$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$60$$),
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6055$$.$layout_id$],null),function($shape$jscomp$746$$,$objects$jscomp$643$$){var $cells$jscomp$23_first_row$jscomp$11_map__71560$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71556_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$746$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$p1__71556_SHARP_$$],null))},$self__$jscomp$6055$$.ids);$cells$jscomp$23_first_row$jscomp$11_map__71560$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$23_first_row$jscomp$11_map__71560$$);var $last_column$jscomp$11_map__71560__$1$$=$APP.$cljs$core$__destructure_map$$($cells$jscomp$23_first_row$jscomp$11_map__71560$$);$cells$jscomp$23_first_row$jscomp$11_map__71560$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$11_map__71560__$1$$,
$APP.$cljs$cst$1720$first_row$$);var $first_column$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$11_map__71560__$1$$,$APP.$cljs$cst$1721$first_column$$),$last_row$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$11_map__71560__$1$$,$APP.$cljs$cst$1722$last_row$$);$last_column$jscomp$11_map__71560__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$11_map__71560__$1$$,$APP.$cljs$cst$1723$last_column$$);
var $target_cell$jscomp$9$$=$APP.$app$common$types$shape$layout$get_cell_by_position$$($shape$jscomp$746$$,$cells$jscomp$23_first_row$jscomp$11_map__71560$$,$first_column$jscomp$11$$);return $APP.$app$common$types$shape$layout$assign_cells$$($APP.$app$common$types$shape$layout$resize_cell_area$$($shape$jscomp$746$$,$APP.$cljs$cst$1661$row$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$9$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$9$$),$cells$jscomp$23_first_row$jscomp$11_map__71560$$,
$first_column$jscomp$11$$,$last_row$jscomp$11$$-$cells$jscomp$23_first_row$jscomp$11_map__71560$$+1,$last_column$jscomp$11_map__71560__$1$$-$first_column$jscomp$11$$+1),$objects$jscomp$643$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3199$with_objects_QMARK_$$,!0],null)),$APP.$app$main$data$workspace$grid_layout$editor$clean_selection$$($self__$jscomp$6055$$.$layout_id$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6055$$.$layout_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$60$$))});return new $app$main$data$workspace$shape_layout$merge_cells_71557$$($layout_id$jscomp$6$$,$ids$jscomp$245$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$reorder_strokes$$=function($ids$jscomp$204$$,$from_pos$jscomp$6$$,$to_space_between_pos$jscomp$6$$){typeof $app$main$data$workspace$colors$reorder_strokes_71091$$==="undefined"&&($app$main$data$workspace$colors$reorder_strokes_71091$$=function($ids$jscomp$205$$,$from_pos$jscomp$7$$,$to_space_between_pos$jscomp$7$$,$meta71092$$){this.ids=$ids$jscomp$205$$;this.$from_pos$=$from_pos$jscomp$7$$;this.$to_space_between_pos$=$to_space_between_pos$jscomp$7$$;this.$meta71092$=
$meta71092$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$reorder_strokes_71091$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_strokes_71091$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4220$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_strokes$$},$app$main$data$workspace$colors$reorder_strokes_71091$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71093$$,$meta71092__$1$$){return new $app$main$data$workspace$colors$reorder_strokes_71091$$(this.ids,this.$from_pos$,this.$to_space_between_pos$,$meta71092__$1$$)},$app$main$data$workspace$colors$reorder_strokes_71091$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71092$},$app$main$data$workspace$colors$reorder_strokes_71091$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_strokes_71091$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5276$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5276$$.ids,function($p1__71079_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__71079_SHARP_$$,$APP.$cljs$cst$1641$strokes$$,$app$common$data$reorder$$,$self__$jscomp$5276$$.$from_pos$,$self__$jscomp$5276$$.$to_space_between_pos$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2656$attrs$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$strokes$$],null)],null)))});return new $app$main$data$workspace$colors$reorder_strokes_71091$$($ids$jscomp$204$$,$from_pos$jscomp$6$$,$to_space_between_pos$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$remove_all_strokes$$=function($ids$jscomp$200$$){typeof $app$main$data$workspace$colors$remove_all_strokes_71053$$==="undefined"&&($app$main$data$workspace$colors$remove_all_strokes_71053$$=function($ids$jscomp$201$$,$meta71054$$){this.ids=$ids$jscomp$201$$;this.$meta71054$=$meta71054$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$remove_all_strokes_71053$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_all_strokes_71053$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4218$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_all_strokes$$},$app$main$data$workspace$colors$remove_all_strokes_71053$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71055$$,$meta71054__$1$$){return new $app$main$data$workspace$colors$remove_all_strokes_71053$$(this.ids,$meta71054__$1$$)},$app$main$data$workspace$colors$remove_all_strokes_71053$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71054$},$app$main$data$workspace$colors$remove_all_strokes_71053$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_all_strokes_71053$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(this.ids,function($p1__71049_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__71049_SHARP_$$,
$APP.$cljs$cst$1641$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$strokes$$],null)],null)))});return new $app$main$data$workspace$colors$remove_all_strokes_71053$$($ids$jscomp$200$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$remove_stroke$$=function($ids$jscomp$198$$,$position$jscomp$118$$){typeof $app$main$data$workspace$colors$remove_stroke_71014$$==="undefined"&&($app$main$data$workspace$colors$remove_stroke_71014$$=function($ids$jscomp$199$$,$position$jscomp$119$$,$meta71015$$){this.ids=$ids$jscomp$199$$;this.position=$position$jscomp$119$$;this.$meta71015$=$meta71015$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$remove_stroke_71014$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_stroke_71014$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4217$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_stroke$$},$app$main$data$workspace$colors$remove_stroke_71014$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71016$$,$meta71015__$1$$){return new $app$main$data$workspace$colors$remove_stroke_71014$$(this.ids,this.position,$meta71015__$1$$)},$app$main$data$workspace$colors$remove_stroke_71014$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71015$},$app$main$data$workspace$colors$remove_stroke_71014$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_stroke_71014$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){function $remove_fill_by_index$jscomp$1$$($values$jscomp$74$$,$index$jscomp$306$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filterv$$(function($p__71042$$){var $idx$jscomp$93$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71042$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__71042$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$93$$,$index$jscomp$306$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$74$$)))}var $self__$jscomp$5264$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5264$$.ids,
function($shape$jscomp$692$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$692$$,$APP.$cljs$cst$1641$strokes$$,$remove_fill_by_index$jscomp$1$$,$self__$jscomp$5264$$.position)},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$strokes$$],null)],null)))});return new $app$main$data$workspace$colors$remove_stroke_71014$$($ids$jscomp$198$$,
$position$jscomp$118$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$04$$=function($ids$jscomp$190$$,$attrs$jscomp$142$$,$index$jscomp$302$$){typeof $app$main$data$workspace$colors$change_stroke_attrs_70937$$==="undefined"&&($app$main$data$workspace$colors$change_stroke_attrs_70937$$=function($ids$jscomp$191$$,$attrs$jscomp$143$$,$index$jscomp$303$$,$options$jscomp$568$$,$meta70938$$){this.ids=$ids$jscomp$191$$;this.$attrs$=$attrs$jscomp$143$$;this.index=$index$jscomp$303$$;this.options=
$options$jscomp$568$$;this.$meta70938$=$meta70938$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$change_stroke_attrs_70937$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_stroke_attrs_70937$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4213$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_stroke_attrs$$},$app$main$data$workspace$colors$change_stroke_attrs_70937$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70939$$,$meta70938__$1$$){return new $app$main$data$workspace$colors$change_stroke_attrs_70937$$(this.ids,this.$attrs$,this.index,this.options,$meta70938__$1$$)},$app$main$data$workspace$colors$change_stroke_attrs_70937$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70938$},$app$main$data$workspace$colors$change_stroke_attrs_70937$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_stroke_attrs_70937$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5248$$=this,$changed_sub_attr$jscomp$7_options__$1$jscomp$73$$=$APP.$cljs$core$keys$$($self__$jscomp$5248$$.$attrs$);$changed_sub_attr$jscomp$7_options__$1$jscomp$73$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($self__$jscomp$5248$$.options,$APP.$cljs$cst$3574$changed_sub_attr$$,$changed_sub_attr$jscomp$7_options__$1$jscomp$73$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5248$$.ids,
function($G__70951__$1_shape$jscomp$688$$){var $attrs__$1$jscomp$22_stroke$jscomp$21$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__70951__$1_shape$jscomp$688$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$strokes$$,$self__$jscomp$5248$$.index],null)),$style_attrs$$=$APP.$app$main$data$workspace$colors$build_stroke_style_attrs$$($attrs__$1$jscomp$22_stroke$jscomp$21$$);$attrs__$1$jscomp$22_stroke$jscomp$21$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attrs__$1$jscomp$22_stroke$jscomp$21$$,
$style_attrs$$,$self__$jscomp$5248$$.$attrs$]));$G__70951__$1_shape$jscomp$688$$=$APP.$cljs$core$contains_QMARK_$$($G__70951__$1_shape$jscomp$688$$,$APP.$cljs$cst$1641$strokes$$)?$G__70951__$1_shape$jscomp$688$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70951__$1_shape$jscomp$688$$,$APP.$cljs$cst$1641$strokes$$,$APP.$cljs$core$PersistentVector$EMPTY$$);return $APP.$cljs$core$assoc_in$$($G__70951__$1_shape$jscomp$688$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1641$strokes$$,$self__$jscomp$5248$$.index],null),$attrs__$1$jscomp$22_stroke$jscomp$21$$)},$changed_sub_attr$jscomp$7_options__$1$jscomp$73$$))});return new $app$main$data$workspace$colors$change_stroke_attrs_70937$$($ids$jscomp$190$$,$attrs$jscomp$142$$,$index$jscomp$302$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$189$$,$attrs$jscomp$141$$,$index$jscomp$301$$){return $app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$189$$,$attrs$jscomp$141$$,$index$jscomp$301$$)};
$app$main$data$workspace$texts$replace_layer_names_in_shapes$$=function($ids$jscomp$156$$,$search$jscomp$3$$,$replacement$jscomp$15$$){typeof $app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$==="undefined"&&($app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$=function($ids$jscomp$157$$,$search$jscomp$4$$,$replacement$jscomp$16$$,$meta70632$$){this.ids=$ids$jscomp$157$$;this.search=$search$jscomp$4$$;this.$replacement$=$replacement$jscomp$16$$;this.$meta70632$=$meta70632$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4114$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_replace_layer_names_in_shapes$$},$app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70633$$,$meta70632__$1$$){return new $app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$(this.ids,this.search,this.$replacement$,$meta70632__$1$$)},$app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70632$},$app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5106$$=this,$undo_group$jscomp$37$$=$APP.$app$common$uuid$next$$();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5106$$.ids,function($shape$jscomp$596$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($shape$jscomp$596$$,$APP.$cljs$cst$725$name$$,$app$common$types$text$replace_all_case_insensitive$$,$self__$jscomp$5106$$.search,$self__$jscomp$5106$$.$replacement$)},
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,null],null),null),$APP.$cljs$cst$3162$undo_group$$,$undo_group$jscomp$37$$],null)))});return new $app$main$data$workspace$texts$replace_layer_names_in_shapes_70631$$($ids$jscomp$156$$,$search$jscomp$3$$,$replacement$jscomp$15$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$commit_position_data$$=function(){typeof $app$main$data$workspace$texts$commit_position_data_70511$$==="undefined"&&($app$main$data$workspace$texts$commit_position_data_70511$$=function($meta70512$$){this.$meta70512$=$meta70512$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$commit_position_data_70511$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_position_data_70511$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4097$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_position_data$$},$app$main$data$workspace$texts$commit_position_data_70511$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70513$$,$meta70512__$1$$){return new $app$main$data$workspace$texts$commit_position_data_70511$$($meta70512__$1$$)},$app$main$data$workspace$texts$commit_position_data_70511$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70512$},$app$main$data$workspace$texts$commit_position_data_70511$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_position_data_70511$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2205$$,$state$jscomp$595$$){var $ids$jscomp$151$$=$APP.$cljs$core$keys$$($APP.$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$595$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$595$$,$APP.$cljs$cst$2246$workspace_text_modifier$$,
function($p1__70508_SHARP_$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$,$p1__70508_SHARP_$$,$ids$jscomp$151$$)})},$app$main$data$workspace$texts$commit_position_data_70511$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_position_data_70511$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2206$$,$state$jscomp$596$$){var $position_data$jscomp$9$$=$APP.$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$596$$);
return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$keys$$($position_data$jscomp$9$$),function($shape$jscomp$590$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$590$$,$APP.$cljs$cst$1899$position_data$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position_data$jscomp$9$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$590$$)))},
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3165$stack_undo_QMARK_$$,!0,$APP.$cljs$cst$3688$reg_objects_QMARK_$$,!1],null))),(0,$APP.$beicon$v2$core$of$$)(function($state__$1$jscomp$26$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state__$1$jscomp$26$$,$APP.$cljs$cst$4099$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$]))}))});
return new $app$main$data$workspace$texts$commit_position_data_70511$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$commit_resize_text$$=function(){typeof $app$main$data$workspace$texts$commit_resize_text_70368$$==="undefined"&&($app$main$data$workspace$texts$commit_resize_text_70368$$=function($meta70369$$){this.$meta70369$=$meta70369$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$commit_resize_text_70368$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_resize_text_70368$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4086$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_commit_resize_text$$},$app$main$data$workspace$texts$commit_resize_text_70368$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70370$$,$meta70369__$1$$){return new $app$main$data$workspace$texts$commit_resize_text_70368$$($meta70369__$1$$)},$app$main$data$workspace$texts$commit_resize_text_70368$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70369$},$app$main$data$workspace$texts$commit_resize_text_70368$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$commit_resize_text_70368$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2195_undo_id$jscomp$33$$,$ids$jscomp$149_state$jscomp$586$$){var $props$jscomp$187$$=$APP.$cljs$cst$4087$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_props$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$149_state$jscomp$586$$),$objects$jscomp$524$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($ids$jscomp$149_state$jscomp$586$$);
$_$jscomp$2195_undo_id$jscomp$33$$=Symbol();$ids$jscomp$149_state$jscomp$586$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$629_new_height$jscomp$3_vec__70395$$){var $shape$jscomp$587$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$524$$,$id$jscomp$629_new_height$jscomp$3_vec__70395$$);$id$jscomp$629_new_height$jscomp$3_vec__70395$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$187$$,
$id$jscomp$629_new_height$jscomp$3_vec__70395$$);var $JSCompiler_temp$jscomp$11220_new_width$jscomp$3_old_dim$jscomp$inline_13602$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$629_new_height$jscomp$3_vec__70395$$,0,null);$id$jscomp$629_new_height$jscomp$3_vec__70395$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$629_new_height$jscomp$3_vec__70395$$,1,null);var $old_dim$jscomp$inline_13599$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$587$$);
($JSCompiler_temp$jscomp$11220_new_width$jscomp$3_old_dim$jscomp$inline_13602$$=$APP.$app$common$math$abs$$($old_dim$jscomp$inline_13599$$-$JSCompiler_temp$jscomp$11220_new_width$jscomp$3_old_dim$jscomp$inline_13602$$)>.1&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$587$$),$APP.$cljs$cst$2046$auto_width$$))||($JSCompiler_temp$jscomp$11220_new_width$jscomp$3_old_dim$jscomp$inline_13602$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$587$$),
$JSCompiler_temp$jscomp$11220_new_width$jscomp$3_old_dim$jscomp$inline_13602$$=$APP.$app$common$math$abs$$($JSCompiler_temp$jscomp$11220_new_width$jscomp$3_old_dim$jscomp$inline_13602$$-$id$jscomp$629_new_height$jscomp$3_vec__70395$$)>.1&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$587$$),$APP.$cljs$cst$2045$auto_height$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$587$$),
$APP.$cljs$cst$2046$auto_width$$)));return $JSCompiler_temp$jscomp$11220_new_width$jscomp$3_old_dim$jscomp$inline_13602$$}),$APP.$cljs$core$keys$$($props$jscomp$187$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2195_undo_id$jscomp$33$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$149_state$jscomp$586$$,function($grow_type$jscomp$8_p__70401$$){var $map__70402__$1_shape__$1$jscomp$45$$=
$APP.$cljs$core$__destructure_map$$($grow_type$jscomp$8_p__70401$$),$id$jscomp$630_new_width$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70402__$1_shape__$1$jscomp$45$$,$APP.$cljs$cst$266$id$$),$selrect$jscomp$69_shape_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70402__$1_shape__$1$jscomp$45$$,$APP.$cljs$cst$1610$selrect$$);$grow_type$jscomp$8_p__70401$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70402__$1_shape__$1$jscomp$45$$,$APP.$cljs$cst$1776$grow_type$$);
var $map__70403__$1_shape_height$$=$APP.$cljs$core$__destructure_map$$($selrect$jscomp$69_shape_width$$);$selrect$jscomp$69_shape_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70403__$1_shape_height$$,$APP.$cljs$cst$290$width$$);$map__70403__$1_shape_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70403__$1_shape_height$$,$APP.$cljs$cst$1527$height$$);var $new_height$jscomp$4_vec__70404$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$187$$,
$id$jscomp$630_new_width$jscomp$4$$);$id$jscomp$630_new_width$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_height$jscomp$4_vec__70404$$,0,null);$new_height$jscomp$4_vec__70404$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_height$jscomp$4_vec__70404$$,1,null);$map__70402__$1_shape__$1$jscomp$45$$=$APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$524$$,$map__70402__$1_shape__$1$jscomp$45$$)&&$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__70402__$1_shape__$1$jscomp$45$$)||
!($APP.$app$common$math$abs$$($selrect$jscomp$69_shape_width$$-$id$jscomp$630_new_width$jscomp$4$$)>.1&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$8_p__70401$$,$APP.$cljs$cst$2046$auto_width$$))?$map__70402__$1_shape__$1$jscomp$45$$:$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($map__70402__$1_shape__$1$jscomp$45$$,$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($map__70402__$1_shape__$1$jscomp$45$$,
$APP.$cljs$cst$290$width$$,$id$jscomp$630_new_width$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1812$ignore_lock_QMARK_$$,!0],null)));return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$524$$,$map__70402__$1_shape__$1$jscomp$45$$)&&$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__70402__$1_shape__$1$jscomp$45$$)||!($APP.$app$common$math$abs$$($map__70403__$1_shape_height$$-$new_height$jscomp$4_vec__70404$$)>
.1)||!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$8_p__70401$$,$APP.$cljs$cst$2045$auto_height$$)&&!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$8_p__70401$$,$APP.$cljs$cst$2046$auto_width$$)?$map__70402__$1_shape__$1$jscomp$45$$:$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($map__70402__$1_shape__$1$jscomp$45$$,$APP.$app$common$types$modifiers$change_dimensions_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($map__70402__$1_shape__$1$jscomp$45$$,
$APP.$cljs$cst$1527$height$$,$new_height$jscomp$4_vec__70404$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1812$ignore_lock_QMARK_$$,!0],null)))},new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3199$with_objects_QMARK_$$,!0,$APP.$cljs$cst$3688$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$3165$stack_undo_QMARK_$$,!0,$APP.$cljs$cst$2567$ignore_touched$$,!0],null)),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,$ids$jscomp$149_state$jscomp$586$$],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2195_undo_id$jscomp$33$$))});return new $app$main$data$workspace$texts$commit_resize_text_70368$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$finalize_editor_state$$=function($id$jscomp$610$$,$update_name_QMARK_$$){typeof $app$main$data$workspace$texts$finalize_editor_state_70223$$==="undefined"&&($app$main$data$workspace$texts$finalize_editor_state_70223$$=function($id$jscomp$611$$,$update_name_QMARK_$jscomp$1$$,$meta70224$$){this.id=$id$jscomp$611$$;this.$update_name_QMARK_$=$update_name_QMARK_$jscomp$1$$;this.$meta70224$=$meta70224$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts$finalize_editor_state_70223$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$finalize_editor_state_70223$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4072$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$},$app$main$data$workspace$texts$finalize_editor_state_70223$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70225$$,$meta70224__$1$$){return new $app$main$data$workspace$texts$finalize_editor_state_70223$$(this.id,
this.$update_name_QMARK_$,$meta70224__$1$$)},$app$main$data$workspace$texts$finalize_editor_state_70223$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70224$},$app$main$data$workspace$texts$finalize_editor_state_70223$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$finalize_editor_state_70223$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$,$state$jscomp$571$$){var $self__$jscomp$4986$$=
this;if($app$main$data$workspace$common$initialized_QMARK_$$($state$jscomp$571$$)){$_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$571$$);$_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$,$self__$jscomp$4986$$.id);var $editor_state$jscomp$2_new_shape_QMARK_$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$571$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2230$workspace_editor_state$$,$self__$jscomp$4986$$.id],null)),$content$jscomp$179$$=$editor_state$jscomp$2_new_shape_QMARK_$$.getCurrentContent(),$name$jscomp$332$$=$app$main$data$workspace$texts$gen_name$$($editor_state$jscomp$2_new_shape_QMARK_$$);$editor_state$jscomp$2_new_shape_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$3696$workspace_new_text_shapes$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$571$$),
$self__$jscomp$4986$$.id);if($content$jscomp$179$$.hasText()){if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$571$$,"render-wasm/v1")){var $content__$1$jscomp$37$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$util$text_editor$export_content$$($content$jscomp$179$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$),
$APP.$cljs$cst$342$children$$)])),$new_size$jscomp$1$$=$APP.$app$main$data$workspace$wasm_text$get_wasm_text_new_size$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$,$content__$1$jscomp$37$$);return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$texts$update_editor_state$$($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$,null)),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$37$$,
$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$))&&$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$571$$)!=null&&$_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4986$$.id],
null),function($shape__$1$jscomp$40$$){var $G__70226_G__70227$jscomp$inline_13605$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$40$$,$APP.$cljs$cst$1642$content$$,$content__$1$jscomp$37$$);var $and__5023__auto__$jscomp$inline_13607$$=$self__$jscomp$4986$$.$update_name_QMARK_$;$G__70226_G__70227$jscomp$inline_13605$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13607$$)?$name$jscomp$332$$!=null:$and__5023__auto__$jscomp$inline_13607$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70226_G__70227$jscomp$inline_13605$$,$APP.$cljs$cst$725$name$$,$name$jscomp$332$$):$G__70226_G__70227$jscomp$inline_13605$$;return $new_size$jscomp$1$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__70226_G__70227$jscomp$inline_13605$$,$APP.$app$common$types$modifiers$change_size$$($shape__$1$jscomp$40$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($new_size$jscomp$1$$),$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($new_size$jscomp$1$$))):
$G__70226_G__70227$jscomp$inline_13605$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3162$undo_group$$,$editor_state$jscomp$2_new_shape_QMARK_$$?$self__$jscomp$4986$$.id:null],null))):null)}$content__$1$jscomp$37$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$util$text_editor$export_content$$($content$jscomp$179$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$),
$APP.$cljs$cst$342$children$$)]));var $modifiers$jscomp$95$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$571$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2246$workspace_text_modifier$$,$self__$jscomp$4986$$.id],null));return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$texts$update_editor_state$$($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$,null)),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content__$1$jscomp$37$$,
$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$))&&$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$571$$)!=null&&$_$jscomp$2180_objects$jscomp$517_shape$jscomp$569$$!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4986$$.id],
null),function($shape__$1$jscomp$41$$){var $G__70233_map__70231__$1$$=$APP.$cljs$core$__destructure_map$$($modifiers$jscomp$95$$),$width$jscomp$141$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70233_map__70231__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$127$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70233_map__70231__$1$$,$APP.$cljs$cst$1527$height$$),$position_data$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__70233_map__70231__$1$$,$APP.$cljs$cst$1899$position_data$$);
$G__70233_map__70231__$1$$=function(){var $G__70234$$=function(){var $G__70235$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$41$$,$APP.$cljs$cst$1642$content$$,$content__$1$jscomp$37$$);return $APP.$cljs$core$truth_$$($position_data$jscomp$7$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70235$$,$APP.$cljs$cst$1899$position_data$$,$position_data$jscomp$7$$):$G__70235$$}();return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$493$$=$self__$jscomp$4986$$.$update_name_QMARK_$;
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$493$$)?$name$jscomp$332$$!=null:$and__5023__auto__$jscomp$493$$}())?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70234$$,$APP.$cljs$cst$725$name$$,$name$jscomp$332$$):$G__70234$$}();return $width$jscomp$141$$!=null||$height$jscomp$127$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__70233_map__70231__$1$$,$APP.$app$common$types$modifiers$change_size$$($shape__$1$jscomp$41$$,$width$jscomp$141$$,
$height$jscomp$127$$)):$G__70233_map__70231__$1$$},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3162$undo_group$$,$editor_state$jscomp$2_new_shape_QMARK_$$?$self__$jscomp$4986$$.id:null],null))):null)}return $self__$jscomp$4986$$.id!=null?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$selection$deselect_shape$$($self__$jscomp$4986$$.id),$APP.$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$self__$jscomp$4986$$.id]))):
null}return null});return new $app$main$data$workspace$texts$finalize_editor_state_70223$$($id$jscomp$610$$,$update_name_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$initialize_editor_state$$=function($p__70245$$){var $decorator$jscomp$1$$=$app$main$ui$workspace$shapes$text$editor$default_decorator$$,$map__70246__$1$$=$APP.$cljs$core$__destructure_map$$($p__70245$$),$id$jscomp$612$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70246__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$333$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70246__$1$$,$APP.$cljs$cst$725$name$$),$content$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70246__$1$$,
$APP.$cljs$cst$1642$content$$);typeof $app$main$data$workspace$texts$initialize_editor_state_70249$$==="undefined"&&($app$main$data$workspace$texts$initialize_editor_state_70249$$=function($p__70245$jscomp$1$$,$decorator$jscomp$2$$,$map__70246$jscomp$1$$,$shape$jscomp$571$$,$id$jscomp$613$$,$name$jscomp$334$$,$content$jscomp$181$$,$meta70250$$){this.$p__70245$=$p__70245$jscomp$1$$;this.$decorator$=$decorator$jscomp$2$$;this.$map__70246$=$map__70246$jscomp$1$$;this.shape=$shape$jscomp$571$$;this.id=
$id$jscomp$613$$;this.name=$name$jscomp$334$$;this.content=$content$jscomp$181$$;this.$meta70250$=$meta70250$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$initialize_editor_state_70249$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$initialize_editor_state_70249$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4073$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_initialize_editor_state$$},
$app$main$data$workspace$texts$initialize_editor_state_70249$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70251$$,$meta70250__$1$$){return new $app$main$data$workspace$texts$initialize_editor_state_70249$$(this.$p__70245$,this.$decorator$,this.$map__70246$,this.shape,this.id,this.name,this.content,$meta70250__$1$$)},$app$main$data$workspace$texts$initialize_editor_state_70249$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70250$},$app$main$data$workspace$texts$initialize_editor_state_70249$$.prototype.$potok$v2$core$UpdateEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$initialize_editor_state_70249$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2181_editor$jscomp$4$$,$state$jscomp$572$$){var $self__$jscomp$4990$$=this,$text_state$$=function(){var $G__70259$$=$self__$jscomp$4990$$.content;return $G__70259$$==null?null:$APP.$app$util$text_editor$import_content$$($G__70259$$)}(),$attrs$jscomp$112$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$572$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$2209$default_font$$],null))]));$_$jscomp$2181_editor$jscomp$4$$=function(){var $G__70261$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.createEditorState($text_state$$,$self__$jscomp$4990$$.$decorator$);return $self__$jscomp$4990$$.content==null&&$attrs$jscomp$112$$!=null?
$APP.$app$util$text_editor$update_editor_current_block_data$$($G__70261$$,$attrs$jscomp$112$$):$G__70261$$}();return $APP.$cljs$core$assoc_in$$($state$jscomp$572$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2230$workspace_editor_state$$,$self__$jscomp$4990$$.id],null),$_$jscomp$2181_editor$jscomp$4$$)},$app$main$data$workspace$texts$initialize_editor_state_70249$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$initialize_editor_state_70249$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2182_editor$jscomp$5$$,$state$jscomp$573$$,$stream$jscomp$60$$){var $self__$jscomp$4991$$=this;$_$jscomp$2182_editor$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$573$$,$APP.$cljs$cst$2230$workspace_editor_state$$),$self__$jscomp$4991$$.id);var $update_name_QMARK_$jscomp$2$$=$self__$jscomp$4991$$.content==
null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$4991$$.name,$app$main$data$workspace$texts$gen_name$$($_$jscomp$2182_editor$jscomp$5$$));return $APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$texts$finalize_editor_state$$($self__$jscomp$4991$$.id,$update_name_QMARK_$jscomp$2$$)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2372$app_DOT_main_DOT_router_SLASH_navigate$$),
$stream$jscomp$60$$),$APP.$beicon$v2$core$filter$$(function($p1__70241_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4072$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$,$p1__70241_SHARP_$$)},$stream$jscomp$60$$))))});return new $app$main$data$workspace$texts$initialize_editor_state_70249$$($p__70245$$,$decorator$jscomp$1$$,$map__70246__$1$$,$map__70246__$1$$,$id$jscomp$612$$,$name$jscomp$333$$,$content$jscomp$180$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$remove_text_modifier$$=function($id$jscomp$637$$){typeof $app$main$data$workspace$texts$remove_text_modifier_70499$$==="undefined"&&($app$main$data$workspace$texts$remove_text_modifier_70499$$=function($id$jscomp$638$$,$meta70500$$){this.id=$id$jscomp$638$$;this.$meta70500$=$meta70500$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$remove_text_modifier_70499$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$remove_text_modifier_70499$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4096$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_remove_text_modifier$$},$app$main$data$workspace$texts$remove_text_modifier_70499$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70501$$,$meta70500__$1$$){return new $app$main$data$workspace$texts$remove_text_modifier_70499$$(this.id,$meta70500__$1$$)},
$app$main$data$workspace$texts$remove_text_modifier_70499$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70500$},$app$main$data$workspace$texts$remove_text_modifier_70499$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$remove_text_modifier_70499$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2203$$,$state$jscomp$594$$){return $APP.$app$common$data$dissoc_in$$($state$jscomp$594$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2246$workspace_text_modifier$$,this.id],null))},$app$main$data$workspace$texts$remove_text_modifier_70499$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$remove_text_modifier_70499$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3165$stack_undo_QMARK_$$,!0],null)))});return new $app$main$data$workspace$texts$remove_text_modifier_70499$$($id$jscomp$637$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$remove_fill$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$179$$,$position$jscomp$115$$){typeof $app$main$data$workspace$colors$remove_fill_70831$$==="undefined"&&($app$main$data$workspace$colors$remove_fill_70831$$=function($ids$jscomp$180$$,$position$jscomp$116$$,$options$jscomp$562$$,$meta70832$$){this.ids=$ids$jscomp$180$$;this.position=$position$jscomp$116$$;this.options=$options$jscomp$562$$;this.$meta70832$=$meta70832$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$remove_fill_70831$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_fill_70831$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4209$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_remove_fill$$},$app$main$data$workspace$colors$remove_fill_70831$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70833$$,$meta70832__$1$$){return new $app$main$data$workspace$colors$remove_fill_70831$$(this.ids,
this.position,this.options,$meta70832__$1$$)},$app$main$data$workspace$colors$remove_fill_70831$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70832$},$app$main$data$workspace$colors$remove_fill_70831$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$remove_fill_70831$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2258_undo_id$jscomp$43$$,$state$jscomp$647$$){function $remove_fill_by_index$$($fills$jscomp$27$$,
$index$jscomp$297$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($i$jscomp$507$$,$o$jscomp$270$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$507$$,$index$jscomp$297$$)?$o$jscomp$270$$:null}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$)),$fills$jscomp$27$$)}
var $self__$jscomp$5232$$=this;$_$jscomp$2258_undo_id$jscomp$43$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2258_undo_id$jscomp$43$$)),$APP.$app$main$data$workspace$colors$transform_fill_STAR_$$($state$jscomp$647$$,$self__$jscomp$5232$$.ids,function($node$jscomp$327$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($node$jscomp$327$$,$APP.$cljs$cst$1639$fills$$,$APP.$app$common$types$fills$update$$,
$remove_fill_by_index$$,$self__$jscomp$5232$$.position)},$self__$jscomp$5232$$.options),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2258_undo_id$jscomp$43$$)))});return new $app$main$data$workspace$colors$remove_fill_70831$$($ids$jscomp$179$$,$position$jscomp$115$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$detach_fill$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$176$$,$position$jscomp$112$$){typeof $app$main$data$workspace$colors$detach_fill_70816$$==="undefined"&&($app$main$data$workspace$colors$detach_fill_70816$$=function($ids$jscomp$177$$,$position$jscomp$113$$,$options$jscomp$560$$,$meta70817$$){this.ids=$ids$jscomp$177$$;this.position=$position$jscomp$113$$;this.options=$options$jscomp$560$$;this.$meta70817$=$meta70817$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$detach_fill_70816$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$detach_fill_70816$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4208$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_detach_fill$$},$app$main$data$workspace$colors$detach_fill_70816$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70818$$,$meta70817__$1$$){return new $app$main$data$workspace$colors$detach_fill_70816$$(this.ids,
this.position,this.options,$meta70817__$1$$)},$app$main$data$workspace$colors$detach_fill_70816$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70817$},$app$main$data$workspace$colors$detach_fill_70816$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$detach_fill_70816$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2257_undo_id$jscomp$42$$,$state$jscomp$646$$){function $detach_fn$jscomp$1$$($fills$jscomp$26$$,
$index$jscomp$296$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($fills$jscomp$26$$,$index$jscomp$296$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1751$fill_color_ref_id$$,$APP.$cljs$cst$1645$fill_color_ref_file$$)}var $self__$jscomp$5228$$=this;$_$jscomp$2257_undo_id$jscomp$42$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2257_undo_id$jscomp$42$$)),$APP.$app$main$data$workspace$colors$transform_fill_STAR_$$($state$jscomp$646$$,
$self__$jscomp$5228$$.ids,function($node$jscomp$326$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($node$jscomp$326$$,$APP.$cljs$cst$1639$fills$$,$APP.$app$common$types$fills$update$$,$detach_fn$jscomp$1$$,$self__$jscomp$5228$$.position)},$self__$jscomp$5228$$.options),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2257_undo_id$jscomp$42$$)))});return new $app$main$data$workspace$colors$detach_fill_70816$$($ids$jscomp$176$$,
$position$jscomp$112$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$add_fill$cljs$0core$0IFn$0_invoke$0arity$03$$=function($ids$jscomp$173$$){var $color__$1$jscomp$9$$=(0,$APP.$app$common$types$color$check_color$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,"#B1B2B5",$APP.$cljs$cst$1740$opacity$$,1],null));typeof $app$main$data$workspace$colors$add_fill_70807$$==="undefined"&&($app$main$data$workspace$colors$add_fill_70807$$=function($ids$jscomp$174$$,$color$jscomp$81$$,$options$jscomp$558$$,$meta70808$$){this.ids=
$ids$jscomp$174$$;this.color=$color$jscomp$81$$;this.options=$options$jscomp$558$$;this.$meta70808$=$meta70808$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$add_fill_70807$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_fill_70807$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4207$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_fill$$},
$app$main$data$workspace$colors$add_fill_70807$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70809$$,$meta70808__$1$$){return new $app$main$data$workspace$colors$add_fill_70807$$(this.ids,this.color,this.options,$meta70808__$1$$)},$app$main$data$workspace$colors$add_fill_70807$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70808$},$app$main$data$workspace$colors$add_fill_70807$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_fill_70807$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2256_undo_id$jscomp$41$$,$state$jscomp$645$$){$_$jscomp$2256_undo_id$jscomp$41$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($_$jscomp$2256_undo_id$jscomp$41$$)),$APP.$app$main$data$workspace$colors$transform_fill$cljs$0core$0IFn$0_invoke$0arity$05$$($state$jscomp$645$$,this.ids,this.color,function($node$jscomp$325$$,$attrs$jscomp$138$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($node$jscomp$325$$,
$APP.$cljs$cst$1639$fills$$,$app$common$types$fills$prepend$$,$attrs$jscomp$138$$)},this.options),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($_$jscomp$2256_undo_id$jscomp$41$$)))});return new $app$main$data$workspace$colors$add_fill_70807$$($ids$jscomp$173$$,$color__$1$jscomp$9$$,null,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$apply_color_from_palette$$=function($color$jscomp$89_color__$1$jscomp$10$$,$stroke_QMARK_$$){$color$jscomp$89_color__$1$jscomp$10$$=(0,$APP.$app$common$types$color$check_color$$)($color$jscomp$89_color__$1$jscomp$10$$);typeof $app$main$data$workspace$colors$apply_color_from_palette_71130$$==="undefined"&&($app$main$data$workspace$colors$apply_color_from_palette_71130$$=function($color$jscomp$90$$,$stroke_QMARK_$jscomp$1$$,$meta71131$$){this.color=$color$jscomp$90$$;
this.$stroke_QMARK_$=$stroke_QMARK_$jscomp$1$$;this.$meta71131$=$meta71131$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$apply_color_from_palette_71130$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_palette_71130$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4227$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_palette$$},
$app$main$data$workspace$colors$apply_color_from_palette_71130$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71132$$,$meta71131__$1$$){return new $app$main$data$workspace$colors$apply_color_from_palette_71130$$(this.color,this.$stroke_QMARK_$,$meta71131__$1$$)},$app$main$data$workspace$colors$apply_color_from_palette_71130$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71131$},$app$main$data$workspace$colors$apply_color_from_palette_71130$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_palette_71130$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$,$G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$){$_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$);
$G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$=$APP.$app$common$files$helpers$clean_loops$$($_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$));a:{for(var $pending$jscomp$inline_13609_pending__$1$jscomp$inline_13613$$=$APP.$cljs$core$seq$$($G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$),
$G__71154$jscomp$inline_13615_result$jscomp$inline_13610$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){if($APP.$cljs$core$empty_QMARK_$$($pending$jscomp$inline_13609_pending__$1$jscomp$inline_13613$$)){$_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$=$G__71154$jscomp$inline_13615_result$jscomp$inline_13610$$;break a}$G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$=$APP.$cljs$core$first$$($pending$jscomp$inline_13609_pending__$1$jscomp$inline_13613$$);
var $G__71414$jscomp$inline_13616_group_QMARK_$jscomp$inline_13612$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$,$G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$);$pending$jscomp$inline_13609_pending__$1$jscomp$inline_13613$$=$APP.$cljs$core$truth_$$($G__71414$jscomp$inline_13616_group_QMARK_$jscomp$inline_13612$$)?$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($pending$jscomp$inline_13609_pending__$1$jscomp$inline_13613$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$,$G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$),$APP.$cljs$cst$1619$shapes$$)):$pending$jscomp$inline_13609_pending__$1$jscomp$inline_13613$$;$G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$=$APP.$cljs$core$not$$($G__71414$jscomp$inline_13616_group_QMARK_$jscomp$inline_13612$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__71154$jscomp$inline_13615_result$jscomp$inline_13610$$,$G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$):$G__71154$jscomp$inline_13615_result$jscomp$inline_13610$$;$pending$jscomp$inline_13609_pending__$1$jscomp$inline_13613$$=$G__71414$jscomp$inline_13616_group_QMARK_$jscomp$inline_13612$$=$APP.$cljs$core$rest$$($pending$jscomp$inline_13609_pending__$1$jscomp$inline_13613$$);
$G__71154$jscomp$inline_13615_result$jscomp$inline_13610$$=$G__71415$jscomp$inline_13617_cur$jscomp$inline_13611_result__$1$jscomp$inline_13614_selected$jscomp$81_state$jscomp$652$$}$_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$=void 0}return $APP.$cljs$core$truth_$$(this.$stroke_QMARK_$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$colors$change_stroke_color$cljs$0core$0IFn$0_invoke$0arity$04$$($_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$,this.color,0)):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$colors$change_fill$cljs$0core$0IFn$0_invoke$0arity$04$$($_$jscomp$2273_ids$jscomp$207_objects$jscomp$599$$,
this.color,0))});return new $app$main$data$workspace$colors$apply_color_from_palette_71130$$($color$jscomp$89_color__$1$jscomp$10$$,$stroke_QMARK_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$apply_color_from_assets$$=function($file_id$jscomp$210$$,$color$jscomp$95_color__$1$jscomp$13$$,$stroke_QMARK_$jscomp$2$$){$color$jscomp$95_color__$1$jscomp$13$$=(0,$APP.$app$common$types$color$check_library_color$$)($color$jscomp$95_color__$1$jscomp$13$$);typeof $app$main$data$workspace$colors$apply_color_from_asserts_71203$$==="undefined"&&($app$main$data$workspace$colors$apply_color_from_asserts_71203$$=function($file_id$jscomp$211$$,$color$jscomp$96$$,$stroke_QMARK_$jscomp$3$$,
$meta71204$$){this.$file_id$=$file_id$jscomp$211$$;this.color=$color$jscomp$96$$;this.$stroke_QMARK_$=$stroke_QMARK_$jscomp$3$$;this.$meta71204$=$meta71204$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$apply_color_from_asserts_71203$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_asserts_71203$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4234$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_apply_color_from_asserts$$},
$app$main$data$workspace$colors$apply_color_from_asserts_71203$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71205$$,$meta71204__$1$$){return new $app$main$data$workspace$colors$apply_color_from_asserts_71203$$(this.$file_id$,this.color,this.$stroke_QMARK_$,$meta71204__$1$$)},$app$main$data$workspace$colors$apply_color_from_asserts_71203$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71204$},$app$main$data$workspace$colors$apply_color_from_asserts_71203$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$apply_color_from_asserts_71203$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $color__$1$jscomp$14$$=$app$common$types$color$library_color__GT_color$$(this.color,this.$file_id$);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$colors$apply_color_from_palette$$($color__$1$jscomp$14$$,this.$stroke_QMARK_$),$app$main$data$workspace$colors$add_recent_color$$($color__$1$jscomp$14$$))});return new $app$main$data$workspace$colors$apply_color_from_asserts_71203$$($file_id$jscomp$210$$,
$color$jscomp$95_color__$1$jscomp$13$$,$stroke_QMARK_$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$replace_text_in_shapes$$=function($ids$jscomp$158$$,$search$jscomp$5$$,$replacement$jscomp$17$$){typeof $app$main$data$workspace$texts$replace_text_in_shapes_70640$$==="undefined"&&($app$main$data$workspace$texts$replace_text_in_shapes_70640$$=function($ids$jscomp$159$$,$search$jscomp$6$$,$replacement$jscomp$18$$,$meta70641$$){this.ids=$ids$jscomp$159$$;this.search=$search$jscomp$6$$;this.$replacement$=$replacement$jscomp$18$$;this.$meta70641$=$meta70641$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$replace_text_in_shapes_70640$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$replace_text_in_shapes_70640$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4115$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_replace_text_in_shapes$$},$app$main$data$workspace$texts$replace_text_in_shapes_70640$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70642$$,$meta70641__$1$$){return new $app$main$data$workspace$texts$replace_text_in_shapes_70640$$(this.ids,this.search,this.$replacement$,$meta70641__$1$$)},$app$main$data$workspace$texts$replace_text_in_shapes_70640$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70641$},$app$main$data$workspace$texts$replace_text_in_shapes_70640$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$replace_text_in_shapes_70640$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2220_update_event$$,$state$jscomp$608$$){var $self__$jscomp$5110$$=this,$undo_group$jscomp$38$$=$APP.$app$common$uuid$next$$();$_$jscomp$2220_update_event$$=$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($self__$jscomp$5110$$.ids,function($shape$jscomp$597$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$))&&$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$)!=
null){var $new_content$jscomp$6$$=$app$common$types$text$replace_text_in_content$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$597$$),$self__$jscomp$5110$$.search,$self__$jscomp$5110$$.$replacement$),$new_name$jscomp$24$$=$APP.$app$common$types$text$generate_shape_name$$($APP.$app$common$types$text$content__GT_text$$($new_content$jscomp$6$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$597$$,
$APP.$cljs$cst$1642$content$$,$new_content$jscomp$6$$),$APP.$cljs$cst$725$name$$,$new_name$jscomp$24$$)}return $shape$jscomp$597$$},new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1642$content$$,null,$APP.$cljs$cst$725$name$$,null],null),null),$APP.$cljs$cst$3162$undo_group$$,$undo_group$jscomp$38$$],null));return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($_$jscomp$2220_update_event$$),
$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$608$$,"render-wasm/v1")?$APP.$beicon$v2$core$map$$(function($p1__70639_SHARP_$$){return $APP.$app$main$data$workspace$wasm_text$resize_wasm_text_debounce$$.$cljs$core$IFn$_invoke$arity$2$($p1__70639_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3162$undo_group$$,$undo_group$jscomp$38$$],null))},$APP.$beicon$v2$core$from$$($self__$jscomp$5110$$.ids)):$APP.$beicon$v2$core$empty$$())});return new $app$main$data$workspace$texts$replace_text_in_shapes_70640$$($ids$jscomp$158$$,
$search$jscomp$5$$,$replacement$jscomp$17$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$selected_fit_content$$=function(){typeof $app$main$data$workspace$transforms$selected_fit_content_69611$$==="undefined"&&($app$main$data$workspace$transforms$selected_fit_content_69611$$=function($meta69612$$){this.$meta69612$=$meta69612$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$selected_fit_content_69611$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$transforms$selected_fit_content_69611$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3956$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_selected_fit_content$$},$app$main$data$workspace$transforms$selected_fit_content_69611$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69613$$,$meta69612__$1$$){return new $app$main$data$workspace$transforms$selected_fit_content_69611$$($meta69612__$1$$)},$app$main$data$workspace$transforms$selected_fit_content_69611$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69612$},$app$main$data$workspace$transforms$selected_fit_content_69611$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$selected_fit_content_69611$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2092_undo_group$jscomp$17$$,$state$jscomp$485$$){var $objects$jscomp$502$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$485$$),$modifiers$jscomp$90_selected$jscomp$52$$=
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$485$$);$_$jscomp$2092_undo_group$jscomp$17$$=$APP.$app$common$uuid$next$$();$modifiers$jscomp$90_selected$jscomp$52$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($modifiers$jscomp$91$$,$JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$){if($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$)){var $JSCompiler_temp_const$jscomp$1610_new_modif$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$,$objects__$1$jscomp$inline_8593$$=$APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($objects$jscomp$502$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$),$APP.$cljs$cst$1713$layout_item_h_sizing$$],null),$APP.$cljs$cst$1677$auto$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$),$APP.$cljs$cst$1714$layout_item_v_sizing$$],null),$APP.$cljs$cst$1677$auto$$);$JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$=$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1816$modifiers$$,$APP.$app$common$types$modifiers$reflow$$()],null)]),$objects__$1$jscomp$inline_8593$$);return $JSCompiler_temp_const$jscomp$1610_new_modif$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$modifiers$jscomp$91$$,$JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$]))}$JSCompiler_temp_const$jscomp$1610_new_modif$$=$app$common$geom$shapes$fit_frame$fit_frame_modifiers$$($objects$jscomp$502$$,
$JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$);return $JSCompiler_temp_const$jscomp$1610_new_modif$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($modifiers$jscomp$91$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1612_frame$jscomp$36$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1816$modifiers$$,$JSCompiler_temp_const$jscomp$1610_new_modif$$],null)):$modifiers$jscomp$91$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$502$$),$modifiers$jscomp$90_selected$jscomp$52$$)));return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$485$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modifiers$jscomp$90_selected$jscomp$52$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3162$undo_group$$,$_$jscomp$2092_undo_group$jscomp$17$$],null)]))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1816$modifiers$$,$modifiers$jscomp$90_selected$jscomp$52$$,$APP.$cljs$cst$3162$undo_group$$,$_$jscomp$2092_undo_group$jscomp$17$$],
null)))});return new $app$main$data$workspace$transforms$selected_fit_content_69611$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$tokens$application$get_token_properties$$=function($token$jscomp$96$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$96$$))};
$app$main$data$workspace$tokens$library_edit$drop_token_set$$=function($params$jscomp$310$$){typeof $app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$=function($params$jscomp$311$$,$meta73185$$){this.params=$params$jscomp$311$$;this.$meta73185$=$meta73185$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4795$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_token_set$$},$app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73186$$,$meta73185__$1$$){return new $app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$(this.params,
$meta73185__$1$$)},$app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73185$},$app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$268$$,$state$jscomp$1002$$){try{var $tokens_lib$jscomp$35$$=
$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$1002$$),$changes$jscomp$inline_8595$$=$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$temp__5823__auto__$jscomp$inline_8598$$=$app$common$logic$tokens$calculate_move_token_set_or_set_group$$($tokens_lib$jscomp$35$$,this.params);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_8598$$)){var $map__54260__$1$jscomp$inline_13621$$=$APP.$cljs$core$__destructure_map$$($temp__5823__auto__$jscomp$inline_8598$$),
$from_path$jscomp$inline_13622$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54260__$1$jscomp$inline_13621$$,$APP.$cljs$cst$2665$from_path$$),$to_path$jscomp$inline_13623$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54260__$1$jscomp$inline_13621$$,$APP.$cljs$cst$2666$to_path$$),$before_path$jscomp$inline_13624$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54260__$1$jscomp$inline_13621$$,$APP.$cljs$cst$2667$before_path$$),$before_group_QMARK_$jscomp$inline_13625$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54260__$1$jscomp$inline_13621$$,$APP.$cljs$cst$3204$before_group_QMARK_$$),$prev_before_path$jscomp$inline_13626$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54260__$1$jscomp$inline_13621$$,$APP.$cljs$cst$3205$prev_before_path$$),$prev_before_group_QMARK_$jscomp$inline_13627$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54260__$1$jscomp$inline_13621$$,$APP.$cljs$cst$3206$prev_before_group_QMARK_$$);var $JSCompiler_temp$jscomp$11271$$=
$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_8595$$,$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2664$move_token_set$$,$APP.$cljs$cst$2665$from_path$$,$from_path$jscomp$inline_13622$$,$APP.$cljs$cst$2666$to_path$$,$to_path$jscomp$inline_13623$$,
$APP.$cljs$cst$2667$before_path$$,$before_path$jscomp$inline_13624$$,$APP.$cljs$cst$2668$before_group$$,$before_group_QMARK_$jscomp$inline_13625$$],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2664$move_token_set$$,$APP.$cljs$cst$2665$from_path$$,$to_path$jscomp$inline_13623$$,$APP.$cljs$cst$2666$to_path$$,$from_path$jscomp$inline_13622$$,$APP.$cljs$cst$2667$before_path$$,$prev_before_path$jscomp$inline_13626$$,
$APP.$cljs$cst$2668$before_group$$,$prev_before_group_QMARK_$jscomp$inline_13627$$],null)))}else $JSCompiler_temp$jscomp$11271$$=$changes$jscomp$inline_8595$$;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($JSCompiler_temp$jscomp$11271$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())}catch($e73192$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$tokens$library_edit$drop_error$$($APP.$cljs$core$ex_data$$($e73192$$)))}});
return new $app$main$data$workspace$tokens$library_edit$drop_token_set_73184$$($params$jscomp$310$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$drop_token_set_group$$=function($drop_opts$$){typeof $app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$=function($drop_opts$jscomp$1$$,$meta73181$$){this.$drop_opts$=$drop_opts$jscomp$1$$;this.$meta73181$=$meta73181$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4794$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_drop_token_set_group$$},$app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73182$$,$meta73181__$1$$){return new $app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$(this.$drop_opts$,
$meta73181__$1$$)},$app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73181$},$app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$267$$,$state$jscomp$1001$$){try{var $changes$jscomp$inline_8600$$=
$APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$tokens_lib$jscomp$inline_8601$$=$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($state$jscomp$1001$$),$temp__5823__auto__$jscomp$inline_8603$$=$app$common$logic$tokens$calculate_move_token_set_or_set_group$$($tokens_lib$jscomp$inline_8601$$,this.$drop_opts$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_8603$$)){var $map__54269__$1$jscomp$inline_13631$$=$APP.$cljs$core$__destructure_map$$($temp__5823__auto__$jscomp$inline_8603$$),
$from_path$jscomp$inline_13632$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54269__$1$jscomp$inline_13631$$,$APP.$cljs$cst$2665$from_path$$),$to_path$jscomp$inline_13633$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54269__$1$jscomp$inline_13631$$,$APP.$cljs$cst$2666$to_path$$),$before_path$jscomp$inline_13634$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54269__$1$jscomp$inline_13631$$,$APP.$cljs$cst$2667$before_path$$),$before_group_QMARK_$jscomp$inline_13635$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54269__$1$jscomp$inline_13631$$,$APP.$cljs$cst$3204$before_group_QMARK_$$),$prev_before_path$jscomp$inline_13636$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54269__$1$jscomp$inline_13631$$,$APP.$cljs$cst$3205$prev_before_path$$),$prev_before_group_QMARK_$jscomp$inline_13637$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__54269__$1$jscomp$inline_13631$$,$APP.$cljs$cst$3206$prev_before_group_QMARK_$$);var $JSCompiler_temp$jscomp$11270$$=
$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_8600$$,$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2669$move_token_set_group$$,$APP.$cljs$cst$2665$from_path$$,$from_path$jscomp$inline_13632$$,$APP.$cljs$cst$2666$to_path$$,$to_path$jscomp$inline_13633$$,
$APP.$cljs$cst$2667$before_path$$,$before_path$jscomp$inline_13634$$,$APP.$cljs$cst$2668$before_group$$,$before_group_QMARK_$jscomp$inline_13635$$],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2669$move_token_set_group$$,$APP.$cljs$cst$2665$from_path$$,$to_path$jscomp$inline_13633$$,$APP.$cljs$cst$2666$to_path$$,$from_path$jscomp$inline_13632$$,$APP.$cljs$cst$2667$before_path$$,$prev_before_path$jscomp$inline_13636$$,
$APP.$cljs$cst$2668$before_group$$,$prev_before_group_QMARK_$jscomp$inline_13637$$],null)))}else $JSCompiler_temp$jscomp$11270$$=$changes$jscomp$inline_8600$$;var $temp__5825__auto__$jscomp$255$$=$JSCompiler_temp$jscomp$11270$$;return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$255$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($temp__5825__auto__$jscomp$255$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$()):null}catch($e73183$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$tokens$library_edit$drop_error$$($APP.$cljs$core$ex_data$$($e73183$$)))}});
return new $app$main$data$workspace$tokens$library_edit$drop_token_set_group_73180$$($drop_opts$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$delete_token_set_group$$=function($path$jscomp$251$$){typeof $app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$=function($path$jscomp$252$$,$meta73165$$){this.path=$path$jscomp$252$$;this.$meta73165$=$meta73165$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4792$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_delete_token_set_group$$},$app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73166$$,$meta73165__$1$$){return new $app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$(this.path,
$meta73165__$1$$)},$app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73165$},$app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($data$jscomp$419_it$jscomp$266$$,$changes$jscomp$310_state$jscomp$1000$$){$data$jscomp$419_it$jscomp$266$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$310_state$jscomp$1000$$);$changes$jscomp$310_state$jscomp$1000$$=$app$common$logic$tokens$generate_delete_token_set_group$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$data$jscomp$419_it$jscomp$266$$),$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$310_state$jscomp$1000$$),
this.path);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$310_state$jscomp$1000$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$delete_token_set_group_73164$$($path$jscomp$251$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$import_tokens_lib$$=function($lib$jscomp$13$$){typeof $app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$=function($lib$jscomp$14$$,$meta73153$$){this.$lib$=$lib$jscomp$14$$;this.$meta73153$=$meta73153$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4790$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_import_tokens_lib$$},$app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73154$$,$meta73153__$1$$){return new $app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$(this.$lib$,
$meta73153__$1$$)},$app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73153$},$app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$308_changes$jscomp$inline_8605_data$jscomp$417_it$jscomp$264$$,
$state$jscomp$998_tokens_lib$jscomp$inline_8606$$){$changes$jscomp$308_changes$jscomp$inline_8605_data$jscomp$417_it$jscomp$264$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$998_tokens_lib$jscomp$inline_8606$$);$changes$jscomp$308_changes$jscomp$inline_8605_data$jscomp$417_it$jscomp$264$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$308_changes$jscomp$inline_8605_data$jscomp$417_it$jscomp$264$$);
$state$jscomp$998_tokens_lib$jscomp$inline_8606$$=this.$lib$;var $library_data$jscomp$inline_8607_prev_tokens_lib$jscomp$inline_8608$$=$APP.$cljs$cst$3195$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_library_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$308_changes$jscomp$inline_8605_data$jscomp$417_it$jscomp$264$$));$library_data$jscomp$inline_8607_prev_tokens_lib$jscomp$inline_8608$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($library_data$jscomp$inline_8607_prev_tokens_lib$jscomp$inline_8608$$,
$APP.$cljs$cst$2147$tokens_lib$$);$changes$jscomp$308_changes$jscomp$inline_8605_data$jscomp$417_it$jscomp$264$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$308_changes$jscomp$inline_8605_data$jscomp$417_it$jscomp$264$$,$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2652$set_tokens_lib$$,
$APP.$cljs$cst$2147$tokens_lib$$,$state$jscomp$998_tokens_lib$jscomp$inline_8606$$],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2652$set_tokens_lib$$,$APP.$cljs$cst$2147$tokens_lib$$,$library_data$jscomp$inline_8607_prev_tokens_lib$jscomp$inline_8608$$],null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$308_changes$jscomp$inline_8605_data$jscomp$417_it$jscomp$264$$),
$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$import_tokens_lib_73152$$($lib$jscomp$13$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$library_edit$toggle_token_set_group$$=function($group_path$jscomp$9$$){typeof $app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$==="undefined"&&($app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$=function($group_path$jscomp$10$$,$meta73119$$){this.$group_path$=$group_path$jscomp$10$$;this.$meta73119$=$meta73119$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4789$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_library_edit_SLASH_toggle_token_set_group$$},$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73120$$,$meta73119__$1$$){return new $app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$(this.$group_path$,
$meta73119__$1$$)},$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73119$},$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2693_data$jscomp$416$$,$changes$jscomp$307_state$jscomp$997$$){$_$jscomp$2693_data$jscomp$416$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$307_state$jscomp$997$$);$changes$jscomp$307_state$jscomp$997$$=$app$common$logic$tokens$generate_toggle_token_set_group$$($APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$_$jscomp$2693_data$jscomp$416$$),$APP.$app$main$data$workspace$tokens$library_edit$get_tokens_lib$$($changes$jscomp$307_state$jscomp$997$$),
this.$group_path$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$307_state$jscomp$997$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$())});return new $app$main$data$workspace$tokens$library_edit$toggle_token_set_group_73118$$($group_path$jscomp$9$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69261$$=function($handler$jscomp$33$$,$ids$jscomp$111$$,$shape$jscomp$544$$,$resize$$,$normalize_proportion_lock$$,$meta69262$$){this.handler=$handler$jscomp$33$$;this.ids=$ids$jscomp$111$$;this.shape=$shape$jscomp$544$$;this.resize=$resize$$;this.$normalize_proportion_lock$=$normalize_proportion_lock$$;this.$meta69262$=$meta69262$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0};
$app$main$data$workspace$transforms$start_resize$$=function($handler$jscomp$35$$,$ids$jscomp$113$$,$shape$jscomp$546$$){return new $app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69261$$($handler$jscomp$35$$,$ids$jscomp$113$$,$shape$jscomp$546$$,function($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$,$initial$jscomp$17_initial__$1_initial__$2$$,$layout$jscomp$14_scale_text$$,$G__69242__$4_objects$jscomp$486_value$jscomp$inline_14896$$,$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$){var $G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,
0,null),$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,1,null),$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,2,null),$point_snap_resize_origin__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,
3,null);$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$=$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$?.selrect??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$,$APP.$cljs$cst$1610$selrect$$);var $change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$=$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,$APP.$cljs$cst$290$width$$),$G__69242_height$jscomp$124$$=$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,$APP.$cljs$cst$1527$height$$),$rotation$jscomp$14_rotation__$1$$=$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$?.rotation??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$,$APP.$cljs$cst$1794$rotation$$),$change_height_QMARK__shape_center$jscomp$5$$=$APP.$app$common$geom$shapes$common$shape__GT_center$$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$);$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$=$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$);
var $shape_transform_inverse$$=$APP.$cljs$cst$1793$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$);$rotation$jscomp$14_rotation__$1$$=$APP.$cljs$core$truth_$$($rotation$jscomp$14_rotation__$1$$)?$rotation$jscomp$14_rotation__$1$$:0;$initial$jscomp$17_initial__$1_initial__$2$$=$APP.$app$common$geom$matrix$transform_point_center$$($initial$jscomp$17_initial__$1_initial__$2$$,$change_height_QMARK__shape_center$jscomp$5$$,$shape_transform_inverse$$);
$initial$jscomp$17_initial__$1_initial__$2$$=$app$main$data$workspace$transforms$fix_init_point$$($initial$jscomp$17_initial__$1_initial__$2$$,$handler$jscomp$35$$,$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$);$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$=$APP.$app$common$geom$matrix$transform_point_center$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($rotation$jscomp$14_rotation__$1$$,
0)?$point_snap_resize_origin__$1$$:$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,$change_height_QMARK__shape_center$jscomp$5$$,$shape_transform_inverse$$);$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$,
$G__69242_height$jscomp$124$$);$layout$jscomp$14_scale_text$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$14_scale_text$$,$APP.$cljs$cst$3765$scale_text$$);$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$=$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$||$layout$jscomp$14_scale_text$$;$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$=
$APP.$app$common$geom$point$multiply$$($APP.$app$common$geom$point$subtract$$($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,$initial$jscomp$17_initial__$1_initial__$2$$),$app$main$data$workspace$transforms$get_handler_multiplier$$($handler$jscomp$35$$));$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$=$APP.$app$common$geom$point$divide$$($APP.$app$common$geom$point$add$$($change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$,
$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$),$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$);$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$=$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$,$APP.$cljs$cst$1515$x$$);$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$=$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$,
$APP.$cljs$cst$1516$y$$);$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$=$APP.$app$common$geom$point$pos__GT_Point$$($APP.$app$common$math$almost_zero_QMARK_$$($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$)?.001:$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,
$APP.$app$common$math$almost_zero_QMARK_$$($change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$)?.001:$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$);$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$?($JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$35$$,
$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$35$$,$APP.$cljs$cst$257$left$$)?$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,$APP.$cljs$cst$1515$x$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$35$$,$APP.$cljs$cst$1567$top$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$35$$,$APP.$cljs$cst$1568$bottom$$)?$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,
$APP.$cljs$cst$1516$y$$):Math.max($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,$APP.$cljs$cst$1515$x$$),$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,$APP.$cljs$cst$1516$y$$)),$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$,$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$)):
$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$=$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$;$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$=$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$?.selrect??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$,
$APP.$cljs$cst$1610$selrect$$);$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$=$app$main$data$workspace$transforms$get_handler_resize_origin$$($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,$handler$jscomp$35$$);$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$=
$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$?$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$multiply$$($APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$multiply$$($APP.$app$common$geom$point$subtract$$($change_height_QMARK__shape_center$jscomp$5$$,$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$),$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$),
$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$),$change_height_QMARK__shape_center$jscomp$5$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-1,-1)),$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$):null;$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$=$APP.$app$common$geom$matrix$transform_point_center$$($change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$,
$change_height_QMARK__shape_center$jscomp$5$$,$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$);$point_snap_resize_origin__$1$$=$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$!=null?$APP.$app$common$geom$point$add$$($center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$,$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$):
$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$;$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$)?$APP.$app$main$data$workspace$modifiers$next_grow_type$$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$?.$grow_type$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$,
$APP.$cljs$cst$1776$grow_type$$),$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$):null;$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$=$APP.$cljs$core$not$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$,
$APP.$cljs$cst$1515$x$$),1));$change_height_QMARK__shape_center$jscomp$5$$=$APP.$cljs$core$not$$($APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$,$APP.$cljs$cst$1516$y$$),1));$G__69242_height$jscomp$124$$=$APP.$app$common$types$modifiers$empty$$();
$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$=$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$!=null?$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($G__69242_height$jscomp$124$$,$G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$):
$G__69242_height$jscomp$124$$;$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$=$APP.$app$common$types$modifiers$resize$cljs$0core$0IFn$0_invoke$0arity$05$$($G__69242__$1_deltav$jscomp$2_displacement$jscomp$1_point$jscomp$62_point__$1$jscomp$1_scalev$jscomp$3_selrect__$1$jscomp$4_x$jscomp$inline_14892$$,$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$,$point_snap_resize_origin__$1$$,$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,
$shape_transform_inverse$$);$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$=($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($G__69242__$4_objects$jscomp$486_value$jscomp$inline_14896$$,$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$)||$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$),
$APP.$cljs$cst$1702$fix$$)&&$change_width_QMARK__handler_origin_p$jscomp$inline_14891_shapev_width$jscomp$138_y$jscomp$inline_14893$$?$APP.$app$common$types$modifiers$change_property$$($G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,$APP.$cljs$cst$1713$layout_item_h_sizing$$,$APP.$cljs$cst$1702$fix$$):$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$;$G__69242__$4_objects$jscomp$486_value$jscomp$inline_14896$$=($APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($G__69242__$4_objects$jscomp$486_value$jscomp$inline_14896$$,
$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$)||$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$),$APP.$cljs$cst$1702$fix$$)&&$change_height_QMARK__shape_center$jscomp$5$$?$APP.$app$common$types$modifiers$change_property$$($G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$,
$APP.$cljs$cst$1714$layout_item_v_sizing$$,$APP.$cljs$cst$1702$fix$$):$G__69242__$2_G__69242__$3_p__69202_selrect$jscomp$64_shape_transform$jscomp$1$$;$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$,$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$?.$grow_type$??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$,$APP.$cljs$cst$1776$grow_type$$)):$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$)?$APP.$app$common$types$modifiers$change_property$$($G__69242__$4_objects$jscomp$486_value$jscomp$inline_14896$$,$APP.$cljs$cst$1776$grow_type$$,$center_QMARK_$jscomp$3_new_grow_type_resize_origin$jscomp$2$$):$G__69242__$4_objects$jscomp$486_value$jscomp$inline_14896$$;$layout$jscomp$14_scale_text$$&&
($G__69242__$4_objects$jscomp$486_value$jscomp$inline_14896$$=$JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11278_lock_QMARK__lock_QMARK___$1_scalev__$1_v$jscomp$inline_13642$$,$APP.$cljs$cst$1515$x$$),$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$truth_$$($G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$)?
$G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$:$APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1786$structure_child$$,$APP.$cljs$core$conj$$,new $APP.$app$common$types$modifiers$StructureOperation$$($APP.$cljs$cst$1809$scale_content$$,null,$G__69242__$4_objects$jscomp$486_value$jscomp$inline_14896$$,null,null,null,null)));return $G__69242__$5_JSCompiler_temp$jscomp$14351_shape__$1$jscomp$39$$},function($alt_QMARK__p__69253$$){var $point$jscomp$63$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK__p__69253$$,
0,null),$shift_QMARK_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK__p__69253$$,1,null);$alt_QMARK__p__69253$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($alt_QMARK__p__69253$$,2,null);var $proportion_lock_QMARK_$$=$APP.$cljs$cst$1814$proportion_lock$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$546$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$63$$,$proportion_lock_QMARK_$$||$shift_QMARK_$$,
$alt_QMARK__p__69253$$],null)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$app$main$data$workspace$start_resize$$=function($param72318$$,$param72319$$,$param72320$$){return $app$main$data$workspace$transforms$start_resize$$($param72318$$,$param72319$$,$param72320$$)};
$app$main$data$workspace$transforms$start_rotate$$=function($shapes$jscomp$98$$){typeof $app$main$data$workspace$transforms$start_rotate_69329$$==="undefined"&&($app$main$data$workspace$transforms$start_rotate_69329$$=function($shapes$jscomp$99$$,$meta69330$$){this.shapes=$shapes$jscomp$99$$;this.$meta69330$=$meta69330$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$transforms$start_rotate_69329$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_rotate_69329$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3935$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_start_rotate$$},$app$main$data$workspace$transforms$start_rotate_69329$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69331$$,$meta69330__$1$$){return new $app$main$data$workspace$transforms$start_rotate_69329$$(this.shapes,$meta69330__$1$$)},$app$main$data$workspace$transforms$start_rotate_69329$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69330$},$app$main$data$workspace$transforms$start_rotate_69329$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_rotate_69329$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2072$$,$state$jscomp$469$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$469$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,
$APP.$cljs$cst$1294$transform$$],null),$APP.$cljs$cst$2874$rotate$$)},$app$main$data$workspace$transforms$start_rotate_69329$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$start_rotate_69329$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2073_stopper$jscomp$12$$,$state$jscomp$470$$,$angle_stream_group$jscomp$37_stream$jscomp$50$$){function $emit_modifiers$jscomp$1$$($angle$jscomp$36$$){return $app$main$data$workspace$modifiers$set_rotation_modifiers$cljs$0core$0IFn$0_invoke$0arity$03$$($angle$jscomp$36$$,
$self__$jscomp$4643$$.shapes,$group_center$$)}var $self__$jscomp$4643$$=this;$_$jscomp$2073_stopper$jscomp$12$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($angle_stream_group$jscomp$37_stream$jscomp$50$$,null);$angle_stream_group$jscomp$37_stream$jscomp$50$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($self__$jscomp$4643$$.shapes);var $group_center$$=$APP.$app$common$geom$rect$rect__GT_center$$($angle_stream_group$jscomp$37_stream$jscomp$50$$),$initial_angle$$=
$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$),$group_center$$);$angle_stream_group$jscomp$37_stream$jscomp$50$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$map$$(function($p__69333_shift_QMARK_$jscomp$2$$){var $angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69333_shift_QMARK_$jscomp$2$$,0,
null),$angle__$3$jscomp$inline_8616_mod_QMARK_$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69333_shift_QMARK_$jscomp$2$$,1,null);$p__69333_shift_QMARK_$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69333_shift_QMARK_$jscomp$2$$,2,null);$angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$=$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$02$$($angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$,
$group_center$$)-$initial_angle$$;$angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$=$angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$<0?360+$angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$:$angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$;$angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$,360)?0:$angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$;$angle__$3$jscomp$inline_8616_mod_QMARK_$jscomp$2$$=$APP.$cljs$core$truth_$$($angle__$3$jscomp$inline_8616_mod_QMARK_$jscomp$2$$)?$APP.$app$common$math$floor$$($angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$/
45)*45:$angle$jscomp$inline_8613_angle__$1$jscomp$inline_8614_angle__$2$jscomp$inline_8615_pos$jscomp$109$$;return $APP.$cljs$core$truth_$$($p__69333_shift_QMARK_$jscomp$2$$)?$APP.$app$common$math$floor$$($angle__$3$jscomp$inline_8616_mod_QMARK_$jscomp$2$$/15)*15:$angle__$3$jscomp$inline_8616_mod_QMARK_$jscomp$2$$},$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$streams$mouse_position_mod$$,$APP.$sub$jscomp$inline_5658$$,$APP.$app$main$streams$mouse_position$$)));
return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$470$$,"render-wasm/v1")?$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2073_stopper$jscomp$12$$,$APP.$beicon$v2$core$map$$(function($p1__69327_SHARP_$$){return $app$main$data$workspace$modifiers$set_wasm_modifiers$$($app$main$data$workspace$transforms$rotation_modifiers$$($p1__69327_SHARP_$$,$self__$jscomp$4643$$.shapes,$group_center$$))},$APP.$beicon$v2$core$sample$$(16,$angle_stream_group$jscomp$37_stream$jscomp$50$$))),
$APP.$beicon$v2$core$map$$(function($p1__69328_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($app$main$data$workspace$transforms$rotation_modifiers$$($p1__69328_SHARP_$$,$self__$jscomp$4643$$.shapes,$group_center$$))},$APP.$beicon$v2$core$last$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2073_stopper$jscomp$12$$,$angle_stream_group$jscomp$37_stream$jscomp$50$$)))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$transforms$finish_transform$$())):$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2073_stopper$jscomp$12$$,
$APP.$beicon$v2$core$map$$($emit_modifiers$jscomp$1$$,$APP.$beicon$v2$core$sample$$(16,$angle_stream_group$jscomp$37_stream$jscomp$50$$))),$APP.$beicon$v2$core$map$$($emit_modifiers$jscomp$1$$,$APP.$beicon$v2$core$last$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2073_stopper$jscomp$12$$,$angle_stream_group$jscomp$37_stream$jscomp$50$$)))),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$app$main$data$workspace$transforms$finish_transform$$()))});
return new $app$main$data$workspace$transforms$start_rotate_69329$$($shapes$jscomp$98$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$transforms$change_orientation$$=function($ids$jscomp$119$$,$orientation$jscomp$3$$){typeof $app$main$data$workspace$transforms$change_orientation_69319$$==="undefined"&&($app$main$data$workspace$transforms$change_orientation_69319$$=function($ids$jscomp$120$$,$orientation$jscomp$4$$,$meta69320$$){this.ids=$ids$jscomp$120$$;this.orientation=$orientation$jscomp$4$$;this.$meta69320$=$meta69320$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$transforms$change_orientation_69319$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$change_orientation_69319$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3934$app_DOT_main_DOT_data_DOT_workspace_DOT_transforms_SLASH_change_orientation$$},$app$main$data$workspace$transforms$change_orientation_69319$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69321$$,$meta69320__$1$$){return new $app$main$data$workspace$transforms$change_orientation_69319$$(this.ids,
this.orientation,$meta69320__$1$$)},$app$main$data$workspace$transforms$change_orientation_69319$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69320$},$app$main$data$workspace$transforms$change_orientation_69319$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$change_orientation_69319$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2070_modif_tree$jscomp$56_objects$jscomp$488$$,$state$jscomp$467$$){var $self__$jscomp$4637$$=
this;if($APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$467$$,"render-wasm/v1"))return $state$jscomp$467$$;$_$jscomp$2070_modif_tree$jscomp$56_objects$jscomp$488$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$467$$);$_$jscomp$2070_modif_tree$jscomp$56_objects$jscomp$488$$=$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$build_modif_tree$$($self__$jscomp$4637$$.ids,
$_$jscomp$2070_modif_tree$jscomp$56_objects$jscomp$488$$,function($shape$jscomp$548$$){return $app$common$types$modifiers$change_orientation_modifiers$$($shape$jscomp$548$$,$self__$jscomp$4637$$.orientation)}),$_$jscomp$2070_modif_tree$jscomp$56_objects$jscomp$488$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$467$$,$APP.$cljs$cst$1939$workspace_modifiers$$,$_$jscomp$2070_modif_tree$jscomp$56_objects$jscomp$488$$)},$app$main$data$workspace$transforms$change_orientation_69319$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$transforms$change_orientation_69319$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2071_modif_tree$jscomp$57_objects$jscomp$489$$,$state$jscomp$468$$){var $self__$jscomp$4638$$=this;return $APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$468$$,"render-wasm/v1")?($_$jscomp$2071_modif_tree$jscomp$57_objects$jscomp$489$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$468$$),
$_$jscomp$2071_modif_tree$jscomp$57_objects$jscomp$489$$=$APP.$app$common$geom$modifiers$set_objects_modifiers$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$modifiers$build_modif_tree$$($self__$jscomp$4638$$.ids,$_$jscomp$2071_modif_tree$jscomp$57_objects$jscomp$489$$,function($shape$jscomp$549$$){return $app$common$types$modifiers$change_orientation_modifiers$$($shape$jscomp$549$$,$self__$jscomp$4638$$.orientation)}),$_$jscomp$2071_modif_tree$jscomp$57_objects$jscomp$489$$),
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($_$jscomp$2071_modif_tree$jscomp$57_objects$jscomp$489$$))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});return new $app$main$data$workspace$transforms$change_orientation_69319$$($ids$jscomp$119$$,$orientation$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$bool$change_bool_type$$=function($shape_id$jscomp$80$$,$type$jscomp$460$$){typeof $app$main$data$workspace$bool$change_bool_type_67853$$==="undefined"&&($app$main$data$workspace$bool$change_bool_type_67853$$=function($shape_id$jscomp$81$$,$type$jscomp$461$$,$meta67854$$){this.$shape_id$=$shape_id$jscomp$81$$;this.type=$type$jscomp$461$$;this.$meta67854$=$meta67854$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$bool$change_bool_type_67853$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$change_bool_type_67853$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3713$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_change_bool_type$$},$app$main$data$workspace$bool$change_bool_type_67853$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67855$$,$meta67854__$1$$){return new $app$main$data$workspace$bool$change_bool_type_67853$$(this.$shape_id$,this.type,$meta67854__$1$$)},$app$main$data$workspace$bool$change_bool_type_67853$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67854$},$app$main$data$workspace$bool$change_bool_type_67853$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$change_bool_type_67853$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1975_objects$jscomp$352$$,$state$jscomp$411$$){function $change_type$$($shape$jscomp$452$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$452$$,$APP.$cljs$cst$1896$bool_type$$,$self__$jscomp$4410$$.type)}
var $self__$jscomp$4410$$=this;$_$jscomp$1975_objects$jscomp$352$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$411$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($_$jscomp$1975_objects$jscomp$352$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1975_objects$jscomp$352$$,$self__$jscomp$4410$$.$shape_id$)))?null:(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$4410$$.$shape_id$],null),$change_type$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3688$reg_objects_QMARK_$$,!0],null)))});return new $app$main$data$workspace$bool$change_bool_type_67853$$($shape_id$jscomp$80$$,$type$jscomp$460$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$bool$bool_to_group$$=function($shape_id$jscomp$78$$){typeof $app$main$data$workspace$bool$bool_to_group_67841$$==="undefined"&&($app$main$data$workspace$bool$bool_to_group_67841$$=function($shape_id$jscomp$79$$,$meta67842$$){this.$shape_id$=$shape_id$jscomp$79$$;this.$meta67842$=$meta67842$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$bool$bool_to_group_67841$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$bool$bool_to_group_67841$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3712$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_bool_to_group$$},$app$main$data$workspace$bool$bool_to_group_67841$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67843$$,$meta67842__$1$$){return new $app$main$data$workspace$bool$bool_to_group_67841$$(this.$shape_id$,$meta67842__$1$$)},$app$main$data$workspace$bool$bool_to_group_67841$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67842$},$app$main$data$workspace$bool$bool_to_group_67841$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$bool_to_group_67841$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1974_objects$jscomp$351$$,$state$jscomp$410$$){$_$jscomp$1974_objects$jscomp$351$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$410$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($_$jscomp$1974_objects$jscomp$351$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1974_objects$jscomp$351$$,this.$shape_id$)))?null:(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$shape_id$],null),$app$main$data$workspace$bool$bool__GT_group$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3199$with_objects_QMARK_$$,!0,$APP.$cljs$cst$3688$reg_objects_QMARK_$$,
!0],null)))});return new $app$main$data$workspace$bool$bool_to_group_67841$$($shape_id$jscomp$78$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$bool$group_to_bool$$=function($shape_id$jscomp$76$$,$type$jscomp$458$$){typeof $app$main$data$workspace$bool$group_to_bool_67835$$==="undefined"&&($app$main$data$workspace$bool$group_to_bool_67835$$=function($shape_id$jscomp$77$$,$type$jscomp$459$$,$meta67836$$){this.$shape_id$=$shape_id$jscomp$77$$;this.type=$type$jscomp$459$$;this.$meta67836$=$meta67836$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$bool$group_to_bool_67835$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$group_to_bool_67835$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3711$app_DOT_main_DOT_data_DOT_workspace_DOT_bool_SLASH_group_to_bool$$},$app$main$data$workspace$bool$group_to_bool_67835$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67837$$,$meta67836__$1$$){return new $app$main$data$workspace$bool$group_to_bool_67835$$(this.$shape_id$,this.type,$meta67836__$1$$)},$app$main$data$workspace$bool$group_to_bool_67835$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta67836$},$app$main$data$workspace$bool$group_to_bool_67835$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$bool$group_to_bool_67835$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1973_objects$jscomp$349$$,$state$jscomp$409_update_fn$jscomp$24$$){$_$jscomp$1973_objects$jscomp$349$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$409_update_fn$jscomp$24$$);
$state$jscomp$409_update_fn$jscomp$24$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$bool$group__GT_bool$$,this.type);return $APP.$cljs$core$truth_$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($_$jscomp$1973_objects$jscomp$349$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$1973_objects$jscomp$349$$,this.$shape_id$)))?null:(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$shape_id$],null),$state$jscomp$409_update_fn$jscomp$24$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3199$with_objects_QMARK_$$,!0,$APP.$cljs$cst$3688$reg_objects_QMARK_$$,!0],null)))});return new $app$main$data$workspace$bool$group_to_bool_67835$$($shape_id$jscomp$76$$,$type$jscomp$458$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$unapply_multiple_tokens$$=function($p__72733$$){var $map__72734__$1$$=$APP.$cljs$core$__destructure_map$$($p__72733$$),$attributes$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72734__$1$$,$APP.$cljs$cst$2009$attributes$$),$shape_ids$jscomp$100$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72734__$1$$,$APP.$cljs$cst$4722$shape_ids$$);typeof $app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$===
"undefined"&&($app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$=function($p__72733$jscomp$1$$,$map__72734$jscomp$1$$,$_props$jscomp$4$$,$attributes$jscomp$74$$,$shape_ids$jscomp$101$$,$meta72736$$){this.$p__72733$=$p__72733$jscomp$1$$;this.$map__72734$=$map__72734$jscomp$1$$;this.$_props$=$_props$jscomp$4$$;this.attributes=$attributes$jscomp$74$$;this.$shape_ids$=$shape_ids$jscomp$101$$;this.$meta72736$=$meta72736$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4734$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_unapply_multiple_tokens$$},$app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72737$$,$meta72736__$1$$){return new $app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$(this.$p__72733$,this.$map__72734$,this.$_props$,this.attributes,this.$shape_ids$,$meta72736__$1$$)},$app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72736$},$app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6567$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$6567$$.$shape_ids$,function($shape$jscomp$774$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$774$$,$APP.$cljs$cst$1881$applied_tokens$$,function($p1__72732_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__72732_SHARP_$$)?
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$,$p1__72732_SHARP_$$,$self__$jscomp$6567$$.attributes):null})}))});return new $app$main$data$workspace$tokens$application$unapply_multiple_tokens_72735$$($p__72733$$,$map__72734__$1$$,$map__72734__$1$$,$attributes$jscomp$73$$,$shape_ids$jscomp$100$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$apply_token_on_color_selected$$=function($color_operations$$,$token$jscomp$94$$){typeof $app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$=function($color_operations$jscomp$1$$,$token$jscomp$95$$,$meta72751$$){this.$color_operations$=$color_operations$jscomp$1$$;this.token=$token$jscomp$95$$;this.$meta72751$=$meta72751$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4739$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token_on_color_selected$$},$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_72752$$,$meta72751__$1$$){return new $app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$(this.$color_operations$,this.token,$meta72751__$1$$)},$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72751$},$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$6579$$=this,$undo_id$jscomp$87$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$87$$)),$APP.$beicon$v2$core$map$$(function($G__72753_G__72753__$1_cop$$){var $shape_ids$jscomp$106$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2554$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($G__72753_G__72753__$1_cop$$)],
null);$G__72753_G__72753__$1_cop$$=$APP.$cljs$cst$4225$prop$$.$cljs$core$IFn$_invoke$arity$1$($G__72753_G__72753__$1_cop$$);$G__72753_G__72753__$1_cop$$=$G__72753_G__72753__$1_cop$$ instanceof $APP.$cljs$core$Keyword$$?$G__72753_G__72753__$1_cop$$.$fqn$:null;switch($G__72753_G__72753__$1_cop$$){case "fill":return $APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2009$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1408$fill$$,null],null),null),$APP.$cljs$cst$1136$token$$,$self__$jscomp$6579$$.token,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$106$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_fill$$],null));case "stroke":return $APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2009$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1745$stroke_color$$,null],null),null),$APP.$cljs$cst$1136$token$$,$self__$jscomp$6579$$.token,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$106$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$],null));case "content":return $APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2009$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1408$fill$$,null],null),null),$APP.$cljs$cst$1136$token$$,$self__$jscomp$6579$$.token,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$106$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_fill$$],null));case "shadow":return $APP.$beicon$v2$core$empty$$();default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__72753_G__72753__$1_cop$$)].join(""));
}},$APP.$beicon$v2$core$from$$($self__$jscomp$6579$$.$color_operations$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$87$$)))});return new $app$main$data$workspace$tokens$application$apply_token_on_color_selected_72750$$($color_operations$$,$token$jscomp$94$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$application$apply_token_from_input$$=function($p__72744$$){var $map__72745__$1$$=$APP.$cljs$core$__destructure_map$$($p__72744$$),$token$jscomp$92$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72745__$1$$,$APP.$cljs$cst$1136$token$$),$attrs$jscomp$165$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72745__$1$$,$APP.$cljs$cst$2656$attrs$$),$shape_ids$jscomp$104$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72745__$1$$,$APP.$cljs$cst$4722$shape_ids$$),
$expand_with_children$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72745__$1$$,$APP.$cljs$cst$4735$expand_with_children$$);typeof $app$main$data$workspace$tokens$application$apply_token_from_input_72746$$==="undefined"&&($app$main$data$workspace$tokens$application$apply_token_from_input_72746$$=function($p__72744$jscomp$1$$,$map__72745$jscomp$1$$,$token$jscomp$93$$,$attrs$jscomp$166$$,$shape_ids$jscomp$105$$,$expand_with_children$jscomp$3$$,$meta72747$$){this.$p__72744$=
$p__72744$jscomp$1$$;this.$map__72745$=$map__72745$jscomp$1$$;this.token=$token$jscomp$93$$;this.$attrs$=$attrs$jscomp$166$$;this.$shape_ids$=$shape_ids$jscomp$105$$;this.$expand_with_children$=$expand_with_children$jscomp$3$$;this.$meta72747$=$meta72747$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$application$apply_token_from_input_72746$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_from_input_72746$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4738$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_application_SLASH_apply_token_from_input$$},$app$main$data$workspace$tokens$application$apply_token_from_input_72746$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72748$$,$meta72747__$1$$){return new $app$main$data$workspace$tokens$application$apply_token_from_input_72746$$(this.$p__72744$,this.$map__72745$,this.token,this.$attrs$,this.$shape_ids$,this.$expand_with_children$,$meta72747__$1$$)},
$app$main$data$workspace$tokens$application$apply_token_from_input_72746$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72747$},$app$main$data$workspace$tokens$application$apply_token_from_input_72746$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$application$apply_token_from_input_72746$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2668_shapes$jscomp$131_shapes__$1$jscomp$15$$,$attributes$jscomp$76_map__72749_state$jscomp$972$$){var $self__$jscomp$6575$$=
this,$objects$jscomp$686$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($attributes$jscomp$76_map__72749_state$jscomp$972$$);$_$jscomp$2668_shapes$jscomp$131_shapes__$1$jscomp$15$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$686$$)),$self__$jscomp$6575$$.$shape_ids$);$_$jscomp$2668_shapes$jscomp$131_shapes__$1$jscomp$15$$=
$APP.$cljs$core$truth_$$($self__$jscomp$6575$$.$expand_with_children$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($shape$jscomp$776$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$776$$),$APP.$cljs$cst$1613$group$$)?$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$686$$,
$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$776$$)):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$776$$],null)}),$_$jscomp$2668_shapes$jscomp$131_shapes__$1$jscomp$15$$):$_$jscomp$2668_shapes$jscomp$131_shapes__$1$jscomp$15$$;$attributes$jscomp$76_map__72749_state$jscomp$972$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6575$$.token));
var $map__72749__$1_on_update_shape__$1$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($attributes$jscomp$76_map__72749_state$jscomp$972$$);$attributes$jscomp$76_map__72749_state$jscomp$972$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72749__$1_on_update_shape__$1$jscomp$1$$,$APP.$cljs$cst$2009$attributes$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72749__$1_on_update_shape__$1$jscomp$1$$,$APP.$cljs$cst$1102$_$$);var $on_update_shape$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__72749__$1_on_update_shape__$1$jscomp$1$$,
$APP.$cljs$cst$4727$on_update_shape$$);$map__72749__$1_on_update_shape__$1$jscomp$1$$=$APP.$cljs$core$seq$$($self__$jscomp$6575$$.$attrs$)?function(){var $or__5025__auto__$jscomp$930$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$attr__GT_shape_update$$,$APP.$cljs$core$first$$($self__$jscomp$6575$$.$attrs$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$930$$)?$or__5025__auto__$jscomp$930$$:$on_update_shape$jscomp$4$$}():$on_update_shape$jscomp$4$$;
return(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$6575$$.token),$APP.$cljs$cst$1999$spacing$$)&&$self__$jscomp$6575$$.$attrs$==null?$APP.$app$main$data$workspace$tokens$application$apply_spacing_token_separated$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$self__$jscomp$6575$$.token,$APP.$cljs$cst$2610$attr$$,$self__$jscomp$6575$$.$attrs$,$APP.$cljs$cst$1619$shapes$$,
$_$jscomp$2668_shapes$jscomp$131_shapes__$1$jscomp$15$$],null)):$APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$empty_QMARK_$$($self__$jscomp$6575$$.$attrs$)?$attributes$jscomp$76_map__72749_state$jscomp$972$$:$self__$jscomp$6575$$.$attrs$,$APP.$cljs$cst$1136$token$$,$self__$jscomp$6575$$.token,$APP.$cljs$cst$4722$shape_ids$$,$self__$jscomp$6575$$.$shape_ids$,$APP.$cljs$cst$4727$on_update_shape$$,
$map__72749__$1_on_update_shape__$1$jscomp$1$$],null)))});return new $app$main$data$workspace$tokens$application$apply_token_from_input_72746$$($p__72744$$,$map__72745__$1$$,$token$jscomp$92$$,$attrs$jscomp$165$$,$shape_ids$jscomp$104$$,$expand_with_children$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$set_shape_proportion_lock$$=function($id$jscomp$757$$,$lock$jscomp$10$$){typeof $app$main$data$workspace$set_shape_proportion_lock_72059$$==="undefined"&&($app$main$data$workspace$set_shape_proportion_lock_72059$$=function($id$jscomp$758$$,$lock$jscomp$11$$,$meta72060$$){this.id=$id$jscomp$758$$;this.lock=$lock$jscomp$11$$;this.$meta72060$=$meta72060$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$set_shape_proportion_lock_72059$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_shape_proportion_lock_72059$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4558$app_DOT_main_DOT_data_DOT_workspace_SLASH_set_shape_proportion_lock$$},$app$main$data$workspace$set_shape_proportion_lock_72059$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_72061$$,$meta72060__$1$$){return new $app$main$data$workspace$set_shape_proportion_lock_72059$$(this.id,this.lock,$meta72060__$1$$)},
$app$main$data$workspace$set_shape_proportion_lock_72059$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta72060$},$app$main$data$workspace$set_shape_proportion_lock_72059$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$set_shape_proportion_lock_72059$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6341$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6341$$.id],null),function($JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$){if($APP.$cljs$core$not$$($self__$jscomp$6341$$.lock))$JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$,$APP.$cljs$cst$1814$proportion_lock$$,!1);else{$JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$,$APP.$cljs$cst$1814$proportion_lock$$,!0);var $map__48869$jscomp$inline_8619_width$jscomp$inline_8621$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$),$height$jscomp$inline_8622_map__48869__$1$jscomp$inline_8620$$=$APP.$cljs$core$__destructure_map$$($map__48869$jscomp$inline_8619_width$jscomp$inline_8621$$);
$map__48869$jscomp$inline_8619_width$jscomp$inline_8621$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_8622_map__48869__$1$jscomp$inline_8620$$,$APP.$cljs$cst$290$width$$);$height$jscomp$inline_8622_map__48869__$1$jscomp$inline_8620$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$inline_8622_map__48869__$1$jscomp$inline_8620$$,$APP.$cljs$cst$1527$height$$);$JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$,
$APP.$cljs$cst$1813$proportion$$,$map__48869$jscomp$inline_8619_width$jscomp$inline_8621$$/$height$jscomp$inline_8622_map__48869__$1$jscomp$inline_8620$$)}return $JSCompiler_temp$jscomp$1529_shape$jscomp$761_shape$jscomp$inline_8618$$}))});return new $app$main$data$workspace$set_shape_proportion_lock_72059$$($id$jscomp$757$$,$lock$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$reorder_layout_track$$=function($ids$jscomp$232$$,$type$jscomp$527$$,$from_index$jscomp$7$$,$to_index$jscomp$11$$,$move_content_QMARK_$jscomp$3$$){typeof $app$main$data$workspace$shape_layout$reorder_layout_track_71461$$==="undefined"&&($app$main$data$workspace$shape_layout$reorder_layout_track_71461$$=function($ids$jscomp$233$$,$type$jscomp$528$$,$from_index$jscomp$8$$,$to_index$jscomp$12$$,$move_content_QMARK_$jscomp$4$$,$meta71462$$){this.ids=$ids$jscomp$233$$;
this.type=$type$jscomp$528$$;this.$from_index$=$from_index$jscomp$8$$;this.$to_index$=$to_index$jscomp$12$$;this.$move_content_QMARK_$=$move_content_QMARK_$jscomp$4$$;this.$meta71462$=$meta71462$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$reorder_layout_track_71461$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$reorder_layout_track_71461$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$4474$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_reorder_layout_track$$},$app$main$data$workspace$shape_layout$reorder_layout_track_71461$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71463$$,$meta71462__$1$$){return new $app$main$data$workspace$shape_layout$reorder_layout_track_71461$$(this.ids,this.type,this.$from_index$,this.$to_index$,this.$move_content_QMARK_$,$meta71462__$1$$)},$app$main$data$workspace$shape_layout$reorder_layout_track_71461$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta71462$},$app$main$data$workspace$shape_layout$reorder_layout_track_71461$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$reorder_layout_track_71461$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$6031$$=this,$undo_id$jscomp$55$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$55$$),$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$6031$$.ids,
function($shape$jscomp$739$$){var $G__71464_G__71464__$1$$=$self__$jscomp$6031$$.type;$G__71464_G__71464__$1$$=$G__71464_G__71464__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__71464_G__71464__$1$$.$fqn$:null;switch($G__71464_G__71464__$1$$){case "row":return $app$common$types$shape$layout$reorder_grid_track$$($shape$jscomp$739$$,$self__$jscomp$6031$$.$from_index$,$self__$jscomp$6031$$.$to_index$,$self__$jscomp$6031$$.$move_content_QMARK_$,$APP.$cljs$cst$1699$layout_grid_rows$$,$APP.$cljs$cst$1661$row$$);
case "column":return $app$common$types$shape$layout$reorder_grid_track$$($shape$jscomp$739$$,$self__$jscomp$6031$$.$from_index$,$self__$jscomp$6031$$.$to_index$,$self__$jscomp$6031$$.$move_content_QMARK_$,$APP.$cljs$cst$1700$layout_grid_columns$$,$APP.$cljs$cst$216$column$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71464_G__71464__$1$$)].join(""));}}),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,$self__$jscomp$6031$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$55$$))});return new $app$main$data$workspace$shape_layout$reorder_layout_track_71461$$($ids$jscomp$232$$,$type$jscomp$527$$,$from_index$jscomp$7$$,$to_index$jscomp$11$$,$move_content_QMARK_$jscomp$3$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$finish_move_overlay_pos$$=function($index$jscomp$347$$,$frame_pos$jscomp$3$$,$offset$jscomp$180$$){typeof $app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$==="undefined"&&($app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$=function($index$jscomp$348$$,$frame_pos$jscomp$4$$,$offset$jscomp$181$$,$meta70789$$){this.index=$index$jscomp$348$$;this.$frame_pos$=$frame_pos$jscomp$4$$;this.offset=$offset$jscomp$181$$;this.$meta70789$=
$meta70789$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4391$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_finish_move_overlay_pos$$},$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70790$$,$meta70789__$1$$){return new $app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$(this.index,this.$frame_pos$,this.offset,$meta70789__$1$$)},$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70789$},$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2430$$,$state$jscomp$795$$){return $APP.$app$common$data$dissoc_in$$($APP.$app$common$data$dissoc_in$$($state$jscomp$795$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4388$move_overlay_to$$],null)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4389$move_overlay_index$$],null))},
$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$,$shape$jscomp$723_state$jscomp$796$$){$_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);
var $overlay_pos$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$,this.$frame_pos$),this.offset);$_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$723_state$jscomp$796$$);$_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$723_state$jscomp$796$$,$_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$);$shape$jscomp$723_state$jscomp$796$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$,$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$723_state$jscomp$796$$)));
$_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$=$APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$723_state$jscomp$796$$);var $new_interactions$jscomp$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$2431_interactions$jscomp$13_objects$jscomp$620_page_id$jscomp$225_pos$jscomp$114$$,this.index,function($p1__70786_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__70786_SHARP_$$,
$APP.$cljs$cst$1987$overlay_pos_type$$,$APP.$cljs$cst$1678$manual$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1986$overlay_position$$,$overlay_pos$jscomp$1$$]))});return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$723_state$jscomp$796$$)],
null),function($p1__70787_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__70787_SHARP_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2059$interactions$$,$new_interactions$jscomp$1$$],null)]))}))});return new $app$main$data$workspace$interactions$finish_move_overlay_pos_70788$$($index$jscomp$347$$,$frame_pos$jscomp$3$$,$offset$jscomp$180$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$start_move_overlay_pos$$=function($index$jscomp$345$$){typeof $app$main$data$workspace$interactions$start_move_overlay_pos_70765$$==="undefined"&&($app$main$data$workspace$interactions$start_move_overlay_pos_70765$$=function($index$jscomp$346$$,$meta70766$$){this.index=$index$jscomp$346$$;this.$meta70766$=$meta70766$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4387$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_start_move_overlay_pos$$},$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70767$$,$meta70766__$1$$){return new $app$main$data$workspace$interactions$start_move_overlay_pos_70765$$(this.index,
$meta70766__$1$$)},$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70766$},$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2427$$,$state$jscomp$792$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$792$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4388$move_overlay_to$$],null),null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4389$move_overlay_index$$],null),this.index)},$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$interactions$start_move_overlay_pos_70765$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2428_initial_pos$jscomp$3$$,$overlay_pos_state$jscomp$793$$,$stopper$jscomp$35_stream$jscomp$88$$){$_$jscomp$2428_initial_pos$jscomp$3$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);var $objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($overlay_pos_state$jscomp$793$$);
$stopper$jscomp$35_stream$jscomp$88$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stopper$jscomp$35_stream$jscomp$88$$,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$))){$objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($overlay_pos_state$jscomp$793$$);
$objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_state$jscomp$793$$,$objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$);var $shape$jscomp$722$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$,$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($overlay_pos_state$jscomp$793$$)));
$overlay_pos_state$jscomp$793$$=$APP.$cljs$cst$1986$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$722$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2059$interactions$$,this.index],null)));$objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$,
$shape$jscomp$722$$);var $frame_pos$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$619_orig_frame$jscomp$1_page_id$jscomp$224_selected$jscomp$84$$)),$offset$jscomp$177$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($_$jscomp$2428_initial_pos$jscomp$3$$,
$overlay_pos_state$jscomp$793$$),$frame_pos$$);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($p1__70764_SHARP_$$){return $app$main$data$workspace$interactions$move_overlay_pos$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$data$workspace$interactions$move_overlay_pos$$.$cljs$core$IFn$_invoke$arity$3$($p1__70764_SHARP_$$,$frame_pos$$,$offset$jscomp$177$$):$app$main$data$workspace$interactions$move_overlay_pos$$($p1__70764_SHARP_$$,$frame_pos$$,$offset$jscomp$177$$)},$APP.$beicon$v2$core$take_until$$($stopper$jscomp$35_stream$jscomp$88$$,
$APP.$app$main$streams$mouse_position$$)),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$interactions$finish_move_overlay_pos$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$data$workspace$interactions$finish_move_overlay_pos$$.$cljs$core$IFn$_invoke$arity$3$(this.index,$frame_pos$$,$offset$jscomp$177$$):$app$main$data$workspace$interactions$finish_move_overlay_pos$$(this.index,$frame_pos$$,$offset$jscomp$177$$)))}return null});return new $app$main$data$workspace$interactions$start_move_overlay_pos_70765$$($index$jscomp$345$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$remove_all_interactions_nav_to$$=function($frame_id$jscomp$108$$){typeof $app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$==="undefined"&&($app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$=function($frame_id$jscomp$109$$,$meta70718$$){this.$frame_id$=$frame_id$jscomp$109$$;this.$meta70718$=$meta70718$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4380$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_remove_all_interactions_nav_to$$},$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70719$$,$meta70718__$1$$){return new $app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$(this.$frame_id$,
$meta70718__$1$$)},$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70718$},$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2421_page_id$jscomp$223$$,$objects$jscomp$617_state$jscomp$785$$){var $self__$jscomp$5784$$=
this;$_$jscomp$2421_page_id$jscomp$223$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$617_state$jscomp$785$$);$objects$jscomp$617_state$jscomp$785$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$617_state$jscomp$785$$,$_$jscomp$2421_page_id$jscomp$223$$);return $APP.$beicon$v2$core$from$$($APP.$app$common$data$vec_without_nils$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$720$$){var $interactions$jscomp$12$$=
$APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$720$$),$new_interactions$$=$app$common$types$shape$interactions$remove_interactions$$(function($p1__70706_SHARP_$$){var $frame_id$jscomp$inline_8625$$=$self__$jscomp$5784$$.$frame_id$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__70706_SHARP_$$),$APP.$cljs$cst$1957$navigate$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__70706_SHARP_$$),
$frame_id$jscomp$inline_8625$$)},$interactions$jscomp$12$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($interactions$jscomp$12$$),$APP.$cljs$core$count$$($new_interactions$$))?$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$720$$)],null),function($shape__$1$jscomp$53$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$53$$,
$APP.$cljs$cst$2059$interactions$$,$new_interactions$$)}):null},$APP.$cljs$core$vals$$($objects$jscomp$617_state$jscomp$785$$))))});return new $app$main$data$workspace$interactions$remove_all_interactions_nav_to_70717$$($frame_id$jscomp$108$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$add_new_interaction$cljs$0core$0IFn$0_invoke$0arity$02$$=function($shape$jscomp$712$$,$destination$jscomp$11$$){typeof $app$main$data$workspace$interactions$add_new_interaction_70675$$==="undefined"&&($app$main$data$workspace$interactions$add_new_interaction_70675$$=function($shape$jscomp$713$$,$destination$jscomp$12$$,$meta70676$$){this.shape=$shape$jscomp$713$$;this.destination=$destination$jscomp$12$$;this.$meta70676$=$meta70676$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$add_new_interaction_70675$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_new_interaction_70675$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4377$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_add_new_interaction$$},$app$main$data$workspace$interactions$add_new_interaction_70675$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70677$$,$meta70676__$1$$){return new $app$main$data$workspace$interactions$add_new_interaction_70675$$(this.shape,this.destination,$meta70676__$1$$)},$app$main$data$workspace$interactions$add_new_interaction_70675$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70676$},$app$main$data$workspace$interactions$add_new_interaction_70675$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$add_new_interaction_70675$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2418_first_QMARK_$jscomp$1_objects$jscomp$616_page$jscomp$94$$,$state$jscomp$784$$){var $self__$jscomp$5772$$=this,$page_id$jscomp$220$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$784$$);$_$jscomp$2418_first_QMARK_$jscomp$1_objects$jscomp$616_page$jscomp$94$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$784$$,$page_id$jscomp$220$$);$_$jscomp$2418_first_QMARK_$jscomp$1_objects$jscomp$616_page$jscomp$94$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2418_first_QMARK_$jscomp$1_objects$jscomp$616_page$jscomp$94$$,$APP.$cljs$cst$1636$objects$$);$_$jscomp$2418_first_QMARK_$jscomp$1_objects$jscomp$616_page$jscomp$94$$=$APP.$cljs$core$not_any_QMARK_$$(function($p1__70664_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($p1__70664_SHARP_$$))},$APP.$cljs$core$vals$$($_$jscomp$2418_first_QMARK_$jscomp$1_objects$jscomp$616_page$jscomp$94$$));
return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5772$$.shape)],null),function($shape__$1$jscomp$50$$){var $new_interaction$jscomp$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$interactions$set_destination$$($APP.$app$common$types$shape$interactions$default_interaction$$,
$self__$jscomp$5772$$.destination),$APP.$cljs$cst$1990$position_relative_to$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$50$$));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape__$1$jscomp$50$$,$APP.$cljs$cst$2059$interactions$$,$APP.$app$common$types$shape$interactions$add_interaction$$,$new_interaction$jscomp$1$$)})),$APP.$cljs$core$truth_$$($self__$jscomp$5772$$.destination)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5772$$.destination],null),$APP.$app$common$logic$shapes$show_in_viewer$$)):null,function(){var $temp__5825__auto__$jscomp$225$$=$APP.$app$main$data$workspace$interactions$new_flow_event$$($state$jscomp$784$$,$page_id$jscomp$220$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$5772$$.shape));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$225$$)?(0,$APP.$beicon$v2$core$of$$)($temp__5825__auto__$jscomp$225$$):
null}(),$_$jscomp$2418_first_QMARK_$jscomp$1_objects$jscomp$616_page$jscomp$94$$?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-prototype"],null))):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-prototype-interaction"],null))))});
return new $app$main$data$workspace$interactions$add_new_interaction_70675$$($shape$jscomp$712$$,$destination$jscomp$11$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$finish_edit_interaction$$=function($index$jscomp$343$$,$initial_pos$jscomp$1$$){typeof $app$main$data$workspace$interactions$finish_edit_interaction_70755$$==="undefined"&&($app$main$data$workspace$interactions$finish_edit_interaction_70755$$=function($index$jscomp$344$$,$initial_pos$jscomp$2$$,$meta70756$$){this.index=$index$jscomp$344$$;this.$initial_pos$=$initial_pos$jscomp$2$$;this.$meta70756$=$meta70756$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$finish_edit_interaction_70755$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_edit_interaction_70755$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4386$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_finish_edit_interaction$$},$app$main$data$workspace$interactions$finish_edit_interaction_70755$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70757$$,$meta70756__$1$$){return new $app$main$data$workspace$interactions$finish_edit_interaction_70755$$(this.index,this.$initial_pos$,$meta70756__$1$$)},$app$main$data$workspace$interactions$finish_edit_interaction_70755$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70756$},$app$main$data$workspace$interactions$finish_edit_interaction_70755$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_edit_interaction_70755$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($_$jscomp$2425$$,$state$jscomp$790$$){return $APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$790$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4382$editing_interaction_index$$],null),null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4384$draw_interaction_to$$],
null),null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4385$draw_interaction_to_frame$$],null),null)},$app$main$data$workspace$interactions$finish_edit_interaction_70755$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$finish_edit_interaction_70755$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2426_position$jscomp$158$$,
$shape$jscomp$721_state$jscomp$791$$){function $change_interaction$$($G__70760__$1_interaction$jscomp$41$$){$G__70760__$1_interaction$jscomp$41$$=$APP.$cljs$core$not$$($APP.$app$common$types$shape$interactions$has_destination$$($G__70760__$1_interaction$jscomp$41$$))?$app$common$types$shape$interactions$set_action_type$$($G__70760__$1_interaction$jscomp$41$$,$APP.$cljs$cst$1957$navigate$$):$G__70760__$1_interaction$jscomp$41$$;return $app$common$types$shape$interactions$set_destination$$($G__70760__$1_interaction$jscomp$41$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$jscomp$7$$))}$_$jscomp$2426_position$jscomp$158$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);var $target_frame$jscomp$7$$=$app$main$data$workspace$interactions$get_target_frame$$($shape$jscomp$721_state$jscomp$791$$,$_$jscomp$2426_position$jscomp$158$$),$shape_id$jscomp$120_undo_id$jscomp$46$$=$APP.$cljs$core$first$$($APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$721_state$jscomp$791$$));
$shape$jscomp$721_state$jscomp$791$$=$APP.$app$main$data$helpers$lookup_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$721_state$jscomp$791$$,$shape_id$jscomp$120_undo_id$jscomp$46$$);$shape_id$jscomp$120_undo_id$jscomp$46$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($shape_id$jscomp$120_undo_id$jscomp$46$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1883$hide_in_viewer$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$jscomp$7$$))?
$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$jscomp$7$$)],null),function($p1__70753_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__70753_SHARP_$$,$APP.$cljs$cst$1883$hide_in_viewer$$)}):null,$shape$jscomp$721_state$jscomp$791$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($_$jscomp$2426_position$jscomp$158$$,
this.$initial_pos$)||this.index==null&&$target_frame$jscomp$7$$==null?null:this.index!=null&&$target_frame$jscomp$7$$==null?$APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$721_state$jscomp$791$$,this.index):this.index==null?$app$main$data$workspace$interactions$add_new_interaction$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$721_state$jscomp$791$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_frame$jscomp$7$$)):
$APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$($shape$jscomp$721_state$jscomp$791$$,this.index,$change_interaction$$,null),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($shape_id$jscomp$120_undo_id$jscomp$46$$))});return new $app$main$data$workspace$interactions$finish_edit_interaction_70755$$($index$jscomp$343$$,$initial_pos$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$interactions$start_edit_interaction$$=function($index$jscomp$341$$){typeof $app$main$data$workspace$interactions$start_edit_interaction_70722$$==="undefined"&&($app$main$data$workspace$interactions$start_edit_interaction_70722$$=function($index$jscomp$342$$,$meta70723$$){this.index=$index$jscomp$342$$;this.$meta70723$=$meta70723$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$interactions$start_edit_interaction_70722$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_edit_interaction_70722$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4381$app_DOT_main_DOT_data_DOT_workspace_DOT_interactions_SLASH_start_edit_interaction$$},$app$main$data$workspace$interactions$start_edit_interaction_70722$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70724$$,$meta70723__$1$$){return new $app$main$data$workspace$interactions$start_edit_interaction_70722$$(this.index,
$meta70723__$1$$)},$app$main$data$workspace$interactions$start_edit_interaction_70722$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70723$},$app$main$data$workspace$interactions$start_edit_interaction_70722$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_edit_interaction_70722$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2422$$,$state$jscomp$786$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$786$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$4382$editing_interaction_index$$],null),this.index)},$app$main$data$workspace$interactions$start_edit_interaction_70722$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$interactions$start_edit_interaction_70722$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2423_selected$jscomp$83$$,
$state$jscomp$787$$,$stopper$jscomp$34_stream$jscomp$87$$){var $initial_pos$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);$_$jscomp$2423_selected$jscomp$83$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$787$$);$stopper$jscomp$34_stream$jscomp$87$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stopper$jscomp$34_stream$jscomp$87$$,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($_$jscomp$2423_selected$jscomp$83$$))?
$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$map$$(function($p1__70721_SHARP_$$){return $app$main$data$workspace$interactions$move_edit_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$interactions$move_edit_interaction$$.$cljs$core$IFn$_invoke$arity$2$($initial_pos$$,$p1__70721_SHARP_$$):$app$main$data$workspace$interactions$move_edit_interaction$$($initial_pos$$,$p1__70721_SHARP_$$)},$APP.$beicon$v2$core$take_until$$($stopper$jscomp$34_stream$jscomp$87$$,$APP.$app$main$streams$mouse_position$$)),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$interactions$finish_edit_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$interactions$finish_edit_interaction$$.$cljs$core$IFn$_invoke$arity$2$(this.index,$initial_pos$$):$app$main$data$workspace$interactions$finish_edit_interaction$$(this.index,$initial_pos$$))):null});return new $app$main$data$workspace$interactions$start_edit_interaction_70722$$($index$jscomp$341$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$create_node_at_position$$=function($params$jscomp$284$$){typeof $app$main$data$workspace$path$edition$create_node_at_position_70217$$==="undefined"&&($app$main$data$workspace$path$edition$create_node_at_position_70217$$=function($params$jscomp$285$$,$meta70218$$){this.params=$params$jscomp$285$$;this.$meta70218$=$meta70218$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$create_node_at_position_70217$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$create_node_at_position_70217$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4330$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_create_node_at_position$$},$app$main$data$workspace$path$edition$create_node_at_position_70217$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70219$$,$meta70218__$1$$){return new $app$main$data$workspace$path$edition$create_node_at_position_70217$$(this.params,
$meta70218__$1$$)},$app$main$data$workspace$path$edition$create_node_at_position_70217$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70218$},$app$main$data$workspace$path$edition$create_node_at_position_70217$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$create_node_at_position_70217$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2365_id$jscomp$708$$,$state$jscomp$743$$){$_$jscomp$2365_id$jscomp$708$$=
$APP.$app$main$data$workspace$path$state$get_path_id$$($state$jscomp$743$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$_$jscomp$2365_id$jscomp$708$$],null),$APP.$app$common$types$path$convert_to_path$$),$app$main$data$workspace$path$edition$split_segments$$($_$jscomp$2365_id$jscomp$708$$,this.params))});return new $app$main$data$workspace$path$edition$create_node_at_position_70217$$($params$jscomp$284$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$start_move_handler$$=function($index$jscomp$333$$,$prefix$jscomp$60$$){typeof $app$main$data$workspace$path$edition$start_move_handler_70185$$==="undefined"&&($app$main$data$workspace$path$edition$start_move_handler_70185$$=function($index$jscomp$334$$,$prefix$jscomp$61$$,$meta70186$$){this.index=$index$jscomp$334$$;this.prefix=$prefix$jscomp$61$$;this.$meta70186$=$meta70186$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$path$edition$start_move_handler_70185$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_move_handler_70185$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4326$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_move_handler$$},$app$main$data$workspace$path$edition$start_move_handler_70185$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70187$$,
$meta70186__$1$$){return new $app$main$data$workspace$path$edition$start_move_handler_70185$$(this.index,this.prefix,$meta70186__$1$$)},$app$main$data$workspace$path$edition$start_move_handler_70185$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70186$},$app$main$data$workspace$path$edition$start_move_handler_70185$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_move_handler_70185$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$,$points$jscomp$93_state$jscomp$739$$,$stream$jscomp$80$$){var $self__$jscomp$5581$$=this,$id$jscomp$701$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$93_state$jscomp$739$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2207$edition$$);$_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$=$APP.$app$common$data$prefix_keyword$$($self__$jscomp$5581$$.prefix,
$APP.$cljs$cst$1515$x$$);var $cy$jscomp$21_op_idx$jscomp$1$$=$APP.$app$common$data$prefix_keyword$$($self__$jscomp$5581$$.prefix,$APP.$cljs$cst$1516$y$$),$modifiers$jscomp$104_op_prefix$jscomp$1_vec__70188$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$93_state$jscomp$739$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1940$edit_path$$),
$id$jscomp$701$$),$APP.$cljs$cst$1941$content_modifiers$$),$start_delta_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$104_op_prefix$jscomp$1_vec__70188$$,$self__$jscomp$5581$$.index),$_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$,0),$start_delta_y$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$104_op_prefix$jscomp$1_vec__70188$$,
$self__$jscomp$5581$$.index),$cy$jscomp$21_op_idx$jscomp$1$$,0);$_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$=$APP.$app$main$data$workspace$path$state$get_path$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($points$jscomp$93_state$jscomp$739$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$]));$points$jscomp$93_state$jscomp$739$$=$APP.$app$common$types$path$get_points$$($_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$);
var $point$jscomp$74$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$5581$$.prefix,$APP.$cljs$cst$1827$c1$$)?$self__$jscomp$5581$$.index-1:$self__$jscomp$5581$$.index)),$handler$jscomp$42$$=$app$common$types$path$get_handler$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$,
$self__$jscomp$5581$$.index),$self__$jscomp$5581$$.prefix);$modifiers$jscomp$104_op_prefix$jscomp$1_vec__70188$$=$APP.$app$common$types$path$opposite_index$$($_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$,$self__$jscomp$5581$$.index,$self__$jscomp$5581$$.prefix);$cy$jscomp$21_op_idx$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$104_op_prefix$jscomp$1_vec__70188$$,0,null);$modifiers$jscomp$104_op_prefix$jscomp$1_vec__70188$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$104_op_prefix$jscomp$1_vec__70188$$,
1,null);$_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$=$APP.$app$common$types$path$get_handler_point$$($_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$,$cy$jscomp$21_op_idx$jscomp$1$$,$modifiers$jscomp$104_op_prefix$jscomp$1_vec__70188$$);return $APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$701$$],null),$APP.$app$common$types$path$convert_to_path$$)),$APP.$beicon$v2$core$take_until$$($APP.$beicon$v2$core$merge$$($APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$80$$,null),$APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$path$streams$finish_edition_QMARK_$$,$stream$jscomp$80$$)),$APP.$beicon$v2$core$map$$(function($alt_QMARK_$jscomp$12_p__70191$$){var $map__70192__$1_shift_QMARK_$jscomp$28$$=
$APP.$cljs$core$__destructure_map$$($alt_QMARK_$jscomp$12_p__70191$$),$G__70193$jscomp$inline_8627_pos$jscomp$111_x$jscomp$1212$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70192__$1_shift_QMARK_$jscomp$28$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$445$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70192__$1_shift_QMARK_$jscomp$28$$,$APP.$cljs$cst$1516$y$$);$alt_QMARK_$jscomp$12_p__70191$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70192__$1_shift_QMARK_$jscomp$28$$,
$APP.$cljs$cst$4271$alt_QMARK_$$);$map__70192__$1_shift_QMARK_$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__70192__$1_shift_QMARK_$jscomp$28$$,$APP.$cljs$cst$4270$shift_QMARK_$$);$G__70193$jscomp$inline_8627_pos$jscomp$111_x$jscomp$1212$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($G__70193$jscomp$inline_8627_pos$jscomp$111_x$jscomp$1212$$,$y$jscomp$445$$);$G__70193$jscomp$inline_8627_pos$jscomp$111_x$jscomp$1212$$=$APP.$cljs$core$truth_$$($map__70192__$1_shift_QMARK_$jscomp$28$$)?
$APP.$app$common$types$path$helpers$position_fixed_angle$$($G__70193$jscomp$inline_8627_pos$jscomp$111_x$jscomp$1212$$,$point$jscomp$74$$):$G__70193$jscomp$inline_8627_pos$jscomp$111_x$jscomp$1212$$;return $app$main$data$workspace$path$edition$modify_handler$$($id$jscomp$701$$,$self__$jscomp$5581$$.index,$self__$jscomp$5581$$.prefix,$start_delta_x$$+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($G__70193$jscomp$inline_8627_pos$jscomp$111_x$jscomp$1212$$)-$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($handler$jscomp$42$$)),
$start_delta_y$$+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($G__70193$jscomp$inline_8627_pos$jscomp$111_x$jscomp$1212$$)-$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($handler$jscomp$42$$)),$APP.$cljs$core$not$$($alt_QMARK_$jscomp$12_p__70191$$))},$app$main$data$workspace$path$streams$move_handler_stream$$($handler$jscomp$42$$,$point$jscomp$74$$,$handler$jscomp$42$$,$_$jscomp$2358_content$jscomp$215_cx$jscomp$20_opposite$jscomp$4$$,$points$jscomp$93_state$jscomp$739$$))),$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$path$edition$apply_content_modifiers$$()))))});
return new $app$main$data$workspace$path$edition$start_move_handler_70185$$($index$jscomp$333$$,$prefix$jscomp$60$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$edition$start_move_path_point$$=function($position$jscomp$145$$,$shift_QMARK_$jscomp$24$$){typeof $app$main$data$workspace$path$edition$start_move_path_point_70122$$==="undefined"&&($app$main$data$workspace$path$edition$start_move_path_point_70122$$=function($position$jscomp$146$$,$shift_QMARK_$jscomp$25$$,$meta70123$$){this.position=$position$jscomp$146$$;this.$shift_QMARK_$=$shift_QMARK_$jscomp$25$$;this.$meta70123$=$meta70123$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$path$edition$start_move_path_point_70122$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_move_path_point_70122$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4321$app_DOT_main_DOT_data_DOT_workspace_DOT_path_DOT_edition_SLASH_start_move_path_point$$},$app$main$data$workspace$path$edition$start_move_path_point_70122$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70124$$,$meta70123__$1$$){return new $app$main$data$workspace$path$edition$start_move_path_point_70122$$(this.position,this.$shift_QMARK_$,$meta70123__$1$$)},$app$main$data$workspace$path$edition$start_move_path_point_70122$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70123$},$app$main$data$workspace$path$edition$start_move_path_point_70122$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$path$edition$start_move_path_point_70122$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($JSCompiler_temp_const$jscomp$1696__$jscomp$2352_id$jscomp$696$$,$JSCompiler_temp_const$jscomp$1697_selected_points$jscomp$4_state$jscomp$734$$){$JSCompiler_temp_const$jscomp$1696__$jscomp$2352_id$jscomp$696$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1697_selected_points$jscomp$4_state$jscomp$734$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2207$edition$$);$JSCompiler_temp_const$jscomp$1697_selected_points$jscomp$4_state$jscomp$734$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1697_selected_points$jscomp$4_state$jscomp$734$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$1940$edit_path$$),$JSCompiler_temp_const$jscomp$1696__$jscomp$2352_id$jscomp$696$$),$APP.$cljs$cst$4308$selected_points$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);
var $JSCompiler_temp_const$jscomp$1695_selected_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($JSCompiler_temp_const$jscomp$1697_selected_points$jscomp$4_state$jscomp$734$$,this.position);$JSCompiler_temp_const$jscomp$1697_selected_points$jscomp$4_state$jscomp$734$$=$APP.$app$main$data$workspace$path$streams$drag_stream$cljs$0core$0IFn$0_invoke$0arity$02$$;$JSCompiler_temp_const$jscomp$1696__$jscomp$2352_id$jscomp$696$$=$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp_const$jscomp$1696__$jscomp$2352_id$jscomp$696$$],null),$APP.$app$common$types$path$convert_to_path$$);$JSCompiler_temp_const$jscomp$1695_selected_QMARK_$$=$JSCompiler_temp_const$jscomp$1695_selected_QMARK_$$?null:$app$main$data$workspace$path$selection$select_node$$(this.position,this.$shift_QMARK_$);var $G__70133$jscomp$inline_8629_JSCompiler_inline_result$jscomp$1698$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$);
$G__70133$jscomp$inline_8629_JSCompiler_inline_result$jscomp$1698$$=$app$main$data$workspace$path$edition$drag_selected_points$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$data$workspace$path$edition$drag_selected_points$$.$cljs$core$IFn$_invoke$arity$1$($G__70133$jscomp$inline_8629_JSCompiler_inline_result$jscomp$1698$$):$app$main$data$workspace$path$edition$drag_selected_points$$($G__70133$jscomp$inline_8629_JSCompiler_inline_result$jscomp$1698$$);return $JSCompiler_temp_const$jscomp$1697_selected_points$jscomp$4_state$jscomp$734$$((0,$APP.$beicon$v2$core$of$$)($JSCompiler_temp_const$jscomp$1696__$jscomp$2352_id$jscomp$696$$,
$JSCompiler_temp_const$jscomp$1695_selected_QMARK_$$,$G__70133$jscomp$inline_8629_JSCompiler_inline_result$jscomp$1698$$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$path$selection$select_node$$(this.position,this.$shift_QMARK_$)))});return new $app$main$data$workspace$path$edition$start_move_path_point_70122$$($position$jscomp$145$$,$shift_QMARK_$jscomp$24$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$path$shortcuts$get_tooltip$$=function($shortcut$jscomp$6$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$path$shortcuts$shortcuts$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shortcut$jscomp$6$$,$APP.$cljs$cst$2957$tooltip$$],null))};
$app$main$data$workspace$colors$reorder_shadows$$=function($ids$jscomp$202$$,$from_pos$jscomp$4$$,$to_space_between_pos$jscomp$4$$){typeof $app$main$data$workspace$colors$reorder_shadow_71064$$==="undefined"&&($app$main$data$workspace$colors$reorder_shadow_71064$$=function($ids$jscomp$203$$,$from_pos$jscomp$5$$,$to_space_between_pos$jscomp$5$$,$meta71065$$){this.ids=$ids$jscomp$203$$;this.$from_pos$=$from_pos$jscomp$5$$;this.$to_space_between_pos$=$to_space_between_pos$jscomp$5$$;this.$meta71065$=
$meta71065$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$reorder_shadow_71064$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_shadow_71064$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4219$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_shadow$$},$app$main$data$workspace$colors$reorder_shadow_71064$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71066$$,$meta71065__$1$$){return new $app$main$data$workspace$colors$reorder_shadow_71064$$(this.ids,this.$from_pos$,this.$to_space_between_pos$,$meta71065__$1$$)},$app$main$data$workspace$colors$reorder_shadow_71064$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71065$},$app$main$data$workspace$colors$reorder_shadow_71064$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_shadow_71064$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function(){var $self__$jscomp$5272$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5272$$.ids,function($p1__71063_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__71063_SHARP_$$,$APP.$cljs$cst$1659$shadow$$,$app$common$data$reorder$$,$self__$jscomp$5272$$.$from_pos$,$self__$jscomp$5272$$.$to_space_between_pos$)}))});return new $app$main$data$workspace$colors$reorder_shadow_71064$$($ids$jscomp$202$$,
$from_pos$jscomp$4$$,$to_space_between_pos$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$add_shadow$$=function($ids$jscomp$194$$){var $shadow__$1$jscomp$10$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$1921$style$$,$APP.$cljs$cst$1922$drop_shadow$$,$APP.$cljs$cst$1303$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,"#000000",$APP.$cljs$cst$1740$opacity$$,.2],null),$APP.$cljs$cst$1655$offset_x$$,4,$APP.$cljs$cst$1656$offset_y$$,4,$APP.$cljs$cst$1658$blur$$,
4,$APP.$cljs$cst$1657$spread$$,0,$APP.$cljs$cst$1625$hidden$$,!1],null);typeof $app$main$data$workspace$colors$add_shadow_70972$$==="undefined"&&($app$main$data$workspace$colors$add_shadow_70972$$=function($ids$jscomp$195$$,$shadow$jscomp$1$$,$meta70973$$){this.ids=$ids$jscomp$195$$;this.shadow=$shadow$jscomp$1$$;this.$meta70973$=$meta70973$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$add_shadow_70972$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_shadow_70972$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4215$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_add_shadow$$},$app$main$data$workspace$colors$add_shadow_70972$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70974$$,$meta70973__$1$$){return new $app$main$data$workspace$colors$add_shadow_70972$$(this.ids,this.shadow,$meta70973__$1$$)},$app$main$data$workspace$colors$add_shadow_70972$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70973$},$app$main$data$workspace$colors$add_shadow_70972$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$add_shadow_70972$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5256$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($self__$jscomp$5256$$.ids,function($shape$jscomp$690$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$690$$,
$APP.$cljs$cst$1659$shadow$$,function($p1__70971_SHARP_$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$5256$$.shadow],null),$p1__70971_SHARP_$$)})}))});return new $app$main$data$workspace$colors$add_shadow_70972$$($ids$jscomp$194$$,$shadow__$1$jscomp$10$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$change_hide_fill_on_export$$=function($ids$jscomp$184$$,$hide_fill_on_export$$){typeof $app$main$data$workspace$colors$change_hide_fill_on_export_70858$$==="undefined"&&($app$main$data$workspace$colors$change_hide_fill_on_export_70858$$=function($ids$jscomp$185$$,$hide_fill_on_export$jscomp$1$$,$meta70859$$){this.ids=$ids$jscomp$185$$;this.$hide_fill_on_export$=$hide_fill_on_export$jscomp$1$$;this.$meta70859$=$meta70859$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$change_hide_fill_on_export_70858$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_hide_fill_on_export_70858$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4211$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_change_hide_fill_on_export$$},$app$main$data$workspace$colors$change_hide_fill_on_export_70858$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70860$$,$meta70859__$1$$){return new $app$main$data$workspace$colors$change_hide_fill_on_export_70858$$(this.ids,this.$hide_fill_on_export$,$meta70859__$1$$)},$app$main$data$workspace$colors$change_hide_fill_on_export_70858$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70859$},$app$main$data$workspace$colors$change_hide_fill_on_export_70858$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$change_hide_fill_on_export_70858$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2260_page_id$jscomp$199$$,$shape_ids$jscomp$15_state$jscomp$649$$){$_$jscomp$2260_page_id$jscomp$199$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_ids$jscomp$15_state$jscomp$649$$);var $objects$jscomp$598$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($shape_ids$jscomp$15_state$jscomp$649$$,$_$jscomp$2260_page_id$jscomp$199$$);$shape_ids$jscomp$15_state$jscomp$649$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$complement$$(function($p1__70854_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$598$$,$p1__70854_SHARP_$$)))}),this.ids);var $attrs$jscomp$139$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1882$hide_fill_on_export$$,this.$hide_fill_on_export$],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$15_state$jscomp$649$$,function($shape$jscomp$686$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$686$$),
$APP.$cljs$cst$1611$frame$$)?$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$686$$,$attrs$jscomp$139$$])):$shape$jscomp$686$$}))});return new $app$main$data$workspace$colors$change_hide_fill_on_export_70858$$($ids$jscomp$184$$,$hide_fill_on_export$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$colors$reorder_fills$$=function($ids$jscomp$164$$,$from_pos$jscomp$2$$,$to_space_between_pos$jscomp$2$$){typeof $app$main$data$workspace$colors$reorder_fills_70731$$==="undefined"&&($app$main$data$workspace$colors$reorder_fills_70731$$=function($ids$jscomp$165$$,$from_pos$jscomp$3$$,$to_space_between_pos$jscomp$3$$,$meta70732$$){this.ids=$ids$jscomp$165$$;this.$from_pos$=$from_pos$jscomp$3$$;this.$to_space_between_pos$=$to_space_between_pos$jscomp$3$$;this.$meta70732$=$meta70732$$;
this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$colors$reorder_fills_70731$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_fills_70731$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4204$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_reorder_fills$$},$app$main$data$workspace$colors$reorder_fills_70731$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70733$$,$meta70732__$1$$){return new $app$main$data$workspace$colors$reorder_fills_70731$$(this.ids,this.$from_pos$,this.$to_space_between_pos$,$meta70732__$1$$)},$app$main$data$workspace$colors$reorder_fills_70731$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70732$},$app$main$data$workspace$colors$reorder_fills_70731$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$colors$reorder_fills_70731$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2253_objects$jscomp$597_text_ids$jscomp$6$$,$shape_ids$jscomp$14_state$jscomp$642_vec__70739$$){function $transform_attrs$jscomp$1$$($object$jscomp$33$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$6$($object$jscomp$33$$,$APP.$cljs$cst$1639$fills$$,$APP.$app$common$types$fills$update$$,$app$common$data$reorder$$,$self__$jscomp$5212$$.$from_pos$,$self__$jscomp$5212$$.$to_space_between_pos$)}var $self__$jscomp$5212$$=this;$_$jscomp$2253_objects$jscomp$597_text_ids$jscomp$6$$=
$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($shape_ids$jscomp$14_state$jscomp$642_vec__70739$$);$shape_ids$jscomp$14_state$jscomp$642_vec__70739$$=$app$main$data$helpers$split_text_shapes$$($_$jscomp$2253_objects$jscomp$597_text_ids$jscomp$6$$,$self__$jscomp$5212$$.ids);$_$jscomp$2253_objects$jscomp$597_text_ids$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$14_state$jscomp$642_vec__70739$$,0,null);$shape_ids$jscomp$14_state$jscomp$642_vec__70739$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_ids$jscomp$14_state$jscomp$642_vec__70739$$,1,null);return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$from$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__70730_SHARP_$$){return $APP.$app$main$data$workspace$texts$update_text_with_function$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__70730_SHARP_$$,$transform_attrs$jscomp$1$$,null)},$_$jscomp$2253_objects$jscomp$597_text_ids$jscomp$6$$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$14_state$jscomp$642_vec__70739$$,
$transform_attrs$jscomp$1$$)))});return new $app$main$data$workspace$colors$reorder_fills_70731$$($ids$jscomp$164$$,$from_pos$jscomp$2$$,$to_space_between_pos$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$=function($file_id$jscomp$197$$,$group_path$jscomp$5$$){typeof $app$main$data$workspace$texts$add_typography_70592$$==="undefined"&&($app$main$data$workspace$texts$add_typography_70592$$=function($file_id$jscomp$198$$,$group_path$jscomp$6$$,$meta70593$$){this.$file_id$=$file_id$jscomp$198$$;this.$group_path$=$group_path$jscomp$6$$;this.$meta70593$=$meta70593$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$texts$add_typography_70592$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$add_typography_70592$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4103$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_add_typography$$},$app$main$data$workspace$texts$add_typography_70592$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70594$$,$meta70593__$1$$){return new $app$main$data$workspace$texts$add_typography_70592$$(this.$file_id$,
this.$group_path$,$meta70593__$1$$)},$app$main$data$workspace$texts$add_typography_70592$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70593$},$app$main$data$workspace$texts$add_typography_70592$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$add_typography_70592$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2213_selected$jscomp$61_shape$jscomp$591$$,$state$jscomp$602_typ$$){var $self__$jscomp$5085$$=
this;$_$jscomp$2213_selected$jscomp$61_shape$jscomp$591$$=$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$602_typ$$);var $objects$jscomp$525_xform$jscomp$36$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$602_typ$$);$objects$jscomp$525_xform$jscomp$36$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$525_xform$jscomp$36$$)),
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$text_shape_QMARK_$$));var $shapes$jscomp$112$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$objects$jscomp$525_xform$jscomp$36$$,$_$jscomp$2213_selected$jscomp$61_shape$jscomp$591$$);$_$jscomp$2213_selected$jscomp$61_shape$jscomp$591$$=$APP.$cljs$core$first$$($shapes$jscomp$112$$);var $values$jscomp$73$$=$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4078$editor_state$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$602_typ$$,$APP.$cljs$cst$2230$workspace_editor_state$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2213_selected$jscomp$61_shape$jscomp$591$$)),$APP.$cljs$cst$1817$shape$$,$_$jscomp$2213_selected$jscomp$61_shape$jscomp$591$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null)),$multiple_QMARK_$jscomp$1$$=
function(){var $or__5025__auto__$jscomp$834$$=1>$APP.$cljs$core$count$$($shapes$jscomp$112$$);return $or__5025__auto__$jscomp$834$$?$or__5025__auto__$jscomp$834$$:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_EQ_$$,$APP.$cljs$cst$1621$multiple$$),$APP.$cljs$core$vals$$($values$jscomp$73$$))}(),$values__$1$jscomp$2$$=$APP.$cljs$core$select_keys$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$73$$),
$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$text$text_font_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_spacing_attrs$$,$APP.$app$common$types$text$text_transform_attrs$$]))),$values__$2$$=function(){var $G__70595__$1$$=typeof $APP.$cljs$cst$1771$line_height$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$2$$)==="number"?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($values__$1$jscomp$2$$,
$APP.$cljs$cst$1771$line_height$$,function($p1__70587_SHARP_$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$math$precision$$($p1__70587_SHARP_$$,2))}):$values__$1$jscomp$2$$;return typeof $APP.$cljs$cst$1772$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$2$$)==="number"?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__70595__$1$$,$APP.$cljs$cst$1772$letter_spacing$$,function($p1__70588_SHARP_$$){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$math$precision$$($p1__70588_SHARP_$$,
2))}):$G__70595__$1$$}(),$typ_id$$=$APP.$app$common$uuid$next$$();$state$jscomp$602_typ$$=function(){var $G__70596$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($app$main$data$workspace$texts$generate_typography_name$$($APP.$cljs$core$truth_$$($multiple_QMARK_$jscomp$1$$)?$APP.$app$common$types$text$default_typography$$:$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_typography$$,
$values__$2$$]))),$APP.$cljs$cst$266$id$$,$typ_id$$);return typeof $self__$jscomp$5085$$.$group_path$==="string"?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__70596$$,$APP.$cljs$cst$725$name$$,function($p1__70589_SHARP_$$){return[$self__$jscomp$5085$$.$group_path$," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__70589_SHARP_$$)].join("")}):$G__70596$$}();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$602_typ$$,
!0),$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-asset-to-library",$APP.$cljs$cst$2556$asset_type$$,"typography"],null))),$APP.$cljs$core$not$$($multiple_QMARK_$jscomp$1$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$texts$update_attrs$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2213_selected$jscomp$61_shape$jscomp$591$$),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1762$typography_ref_id$$,$typ_id$$,$APP.$cljs$cst$1647$typography_ref_file$$,$self__$jscomp$5085$$.$file_id$],null))):null)});return new $app$main$data$workspace$texts$add_typography_70592$$($file_id$jscomp$197$$,$group_path$jscomp$5$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$texts$update_all_attrs$$=function($ids$jscomp$152$$,$attrs$jscomp$133$$){typeof $app$main$data$workspace$texts$update_all_attrs_70569$$==="undefined"&&($app$main$data$workspace$texts$update_all_attrs_70569$$=function($ids$jscomp$153$$,$attrs$jscomp$134$$,$meta70570$$){this.ids=$ids$jscomp$153$$;this.$attrs$=$attrs$jscomp$134$$;this.$meta70570$=$meta70570$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_all_attrs_70569$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_all_attrs_70569$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4101$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_all_attrs$$},$app$main$data$workspace$texts$update_all_attrs_70569$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70571$$,$meta70570__$1$$){return new $app$main$data$workspace$texts$update_all_attrs_70569$$(this.ids,this.$attrs$,$meta70570__$1$$)},$app$main$data$workspace$texts$update_all_attrs_70569$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta70570$},$app$main$data$workspace$texts$update_all_attrs_70569$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_all_attrs_70569$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$5077$$=this,$undo_id$jscomp$34$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$34$$)),$APP.$beicon$v2$core$map$$(function($p1__70567_SHARP_$$){return $APP.$app$main$data$workspace$texts$update_attrs$$($p1__70567_SHARP_$$,
$self__$jscomp$5077$$.$attrs$)},$APP.$beicon$v2$core$from$$($self__$jscomp$5077$$.ids)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$34$$)))});return new $app$main$data$workspace$texts$update_all_attrs_70569$$($ids$jscomp$152$$,$attrs$jscomp$133$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$04$$=function($changes$jscomp$108$$,$library_data$jscomp$23$$,$component_id$jscomp$40$$,$current_page$$){var $component$jscomp$62$$=$APP.$app$common$types$components_list$get_deleted_component$$($library_data$jscomp$23$$,$component_id$jscomp$40$$),$page$jscomp$53$$=function(){var $or__5025__auto__$jscomp$673_or__5025__auto____$1$jscomp$83$$=$APP.$app$common$types$file$get_component_page$$($library_data$jscomp$23$$,
$component$jscomp$62$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$673_or__5025__auto____$1$jscomp$83$$))return $or__5025__auto__$jscomp$673_or__5025__auto____$1$jscomp$83$$;$or__5025__auto__$jscomp$673_or__5025__auto____$1$jscomp$83$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__66430_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_page$$),$p1__66430_SHARP_$$)},$APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$23$$)))?
$current_page$$:null;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$673_or__5025__auto____$1$jscomp$83$$)?$or__5025__auto__$jscomp$673_or__5025__auto____$1$jscomp$83$$:$app$common$types$pages_list$get_last_page$$($library_data$jscomp$23$$)}();return $APP.$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$08$$($changes$jscomp$108$$,$library_data$jscomp$23$$,$component_id$jscomp$40$$,$page$jscomp$53$$,null,null,null,null)};
$app$common$logic$libraries$generate_restore_component$$=function($changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$,$library_data$jscomp$26$$,$component_id$jscomp$43$$,$library_id$jscomp$31$$,$current_page$jscomp$1$$,$objects$jscomp$294$$){$changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$=$app$common$logic$libraries$prepare_restore_component$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$,$library_data$jscomp$26$$,
$component_id$jscomp$43$$,$current_page$jscomp$1$$);$changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$=$APP.$cljs$core$__destructure_map$$($changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$);var $changes__$1$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$,$APP.$cljs$cst$3155$changes$$),$shape$jscomp$433$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$,
$APP.$cljs$cst$1817$shape$$),$parent_id$jscomp$43$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$433$$),$insert_before_QMARK_$$=function(){var $and__5023__auto__$jscomp$410$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$294$$,$parent_id$jscomp$43$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$410$$)?$APP.$cljs$core$not$$($APP.$app$common$types$shape$layout$reverse_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$294$$,
$parent_id$jscomp$43$$))):$and__5023__auto__$jscomp$410$$}(),$objects__$1$jscomp$7$$=function(){var $G__67107$$=function(){var $G__67108$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($objects$jscomp$294$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$433$$),$shape$jscomp$433$$);return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$411$$=$parent_id$jscomp$43$$!=null;return $and__5023__auto__$jscomp$411$$?$insert_before_QMARK_$$:$and__5023__auto__$jscomp$411$$}())?
$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($G__67108$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$43$$,$APP.$cljs$cst$1619$shapes$$],null),function($p1__67104_SHARP_$$){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$433$$)],
null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__67104_SHARP_$$]))}):$G__67108$$}();return $parent_id$jscomp$43$$!=null&&$APP.$cljs$core$not$$($insert_before_QMARK_$$)?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__67107$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$43$$,$APP.$cljs$cst$1619$shapes$$],null),$APP.$cljs$core$conj$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$433$$)):
$G__67107$$}(),$new_objects_ids$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__67105_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__67105_SHARP_$$),$APP.$cljs$cst$2621$add_obj$$)},$APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes__$1$jscomp$44$$)));$changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$=
function(){var $G__67109$$=$APP.$app$common$files$changes_builder$resize_parents$$($APP.$app$common$files$changes_builder$with_objects$$($changes__$1$jscomp$44$$,$objects__$1$jscomp$7$$),$new_objects_ids$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$7$$,$parent_id$jscomp$43$$))?$APP.$app$common$files$changes_builder$reorder_children$$($G__67109$$,$parent_id$jscomp$43$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$7$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parent_id$jscomp$43$$,$APP.$cljs$cst$1619$shapes$$],null))):$G__67109$$}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($changes$jscomp$144_changes__$2$jscomp$21_map__67106_map__67106__$1$$,$APP.$cljs$cst$1649$file_id$$,$library_id$jscomp$31$$)};
$app$main$data$workspace$libraries$restore_component$$=function($library_id$jscomp$37$$,$component_id$jscomp$52$$){typeof $app$main$data$workspace$libraries$restore_component_69783$$==="undefined"&&($app$main$data$workspace$libraries$restore_component_69783$$=function($library_id$jscomp$38$$,$component_id$jscomp$53$$,$meta69784$$){this.$library_id$=$library_id$jscomp$38$$;this.$component_id$=$component_id$jscomp$53$$;this.$meta69784$=$meta69784$$;this.$cljs$lang$protocol_mask$partition0$$=393216;
this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$restore_component_69783$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$restore_component_69783$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3995$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_restore_component$$},$app$main$data$workspace$libraries$restore_component_69783$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69785$$,$meta69784__$1$$){return new $app$main$data$workspace$libraries$restore_component_69783$$(this.$library_id$,this.$component_id$,$meta69784__$1$$)},$app$main$data$workspace$libraries$restore_component_69783$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69784$},$app$main$data$workspace$libraries$restore_component_69783$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$restore_component_69783$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($current_file_id$jscomp$9_it$jscomp$195_local_QMARK_$jscomp$4$$,$changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$){$current_file_id$jscomp$9_it$jscomp$195_local_QMARK_$jscomp$4$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$);$current_file_id$jscomp$9_it$jscomp$195_local_QMARK_$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_file_id$jscomp$9_it$jscomp$195_local_QMARK_$jscomp$4$$,this.$library_id$);
$changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$,this.$library_id$);var $comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1643$components$$,
this.$component_id$],null));$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$=$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$);$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$=$APP.$app$main$data$helpers$get_page$$($changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$,$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$);var $frames$jscomp$14_objects$jscomp$511$$=$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$);
$changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$=$app$common$logic$libraries$generate_restore_component$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$,this.$component_id$,this.$library_id$,$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$,$frames$jscomp$14_objects$jscomp$511$$);$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$=$APP.$cljs$core$first$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2051$page_id$$,
$APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$)));$frames$jscomp$14_objects$jscomp$511$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$214_ldata$jscomp$2_state$jscomp$516$$),
$current_file_id$jscomp$9_it$jscomp$195_local_QMARK_$jscomp$4$$?$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2051$page_id$$,$comp_page_comp_page_id_component$jscomp$77_page_id$jscomp$183$$,$APP.$cljs$cst$1729$ids$$,$frames$jscomp$14_objects$jscomp$511$$],null)):null)});return new $app$main$data$workspace$libraries$restore_component_69783$$($library_id$jscomp$37$$,$component_id$jscomp$52$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$restore_components$$=function($components_data$$){typeof $app$main$data$workspace$libraries$restore_components_69787$$==="undefined"&&($app$main$data$workspace$libraries$restore_components_69787$$=function($components_data$jscomp$1$$,$meta69788$$){this.$components_data$=$components_data$jscomp$1$$;this.$meta69788$=$meta69788$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$restore_components_69787$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$restore_components_69787$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3996$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_restore_components$$},$app$main$data$workspace$libraries$restore_components_69787$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69789$$,$meta69788__$1$$){return new $app$main$data$workspace$libraries$restore_components_69787$$(this.$components_data$,
$meta69788__$1$$)},$app$main$data$workspace$libraries$restore_components_69787$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69788$},$app$main$data$workspace$libraries$restore_components_69787$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$restore_components_69787$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $undo_id$jscomp$24$$=Symbol();return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$24$$)),
$APP.$beicon$v2$core$map$$(function($p1__69786_SHARP_$$){return $app$main$data$workspace$libraries$restore_component$$($APP.$cljs$core$_val$$($p1__69786_SHARP_$$),$APP.$cljs$core$_key$$($p1__69786_SHARP_$$))},$APP.$beicon$v2$core$from$$(this.$components_data$)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$24$$)))});return new $app$main$data$workspace$libraries$restore_components_69787$$($components_data$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$component_multi_swap$$=function($shapes$jscomp$110$$,$file_id$jscomp$169$$,$id_new_component$jscomp$4$$){typeof $app$main$data$workspace$libraries$component_multi_swap_69968$$==="undefined"&&($app$main$data$workspace$libraries$component_multi_swap_69968$$=function($shapes$jscomp$111$$,$file_id$jscomp$170$$,$id_new_component$jscomp$5$$,$meta69969$$){this.shapes=$shapes$jscomp$111$$;this.$file_id$=$file_id$jscomp$170$$;this.$id_new_component$=$id_new_component$jscomp$5$$;
this.$meta69969$=$meta69969$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$component_multi_swap_69968$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_multi_swap_69968$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4025$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_component_multi_swap$$},$app$main$data$workspace$libraries$component_multi_swap_69968$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_69970$$,$meta69969__$1$$){return new $app$main$data$workspace$libraries$component_multi_swap_69968$$(this.shapes,this.$file_id$,this.$id_new_component$,$meta69969__$1$$)},$app$main$data$workspace$libraries$component_multi_swap_69968$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69969$},$app$main$data$workspace$libraries$component_multi_swap_69968$$.prototype.$app$main$data$event$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_multi_swap_69968$$.prototype.$app$main$data$event$Event$_data$arity$1$=
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"component-swap"],null)},$app$main$data$workspace$libraries$component_multi_swap_69968$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$component_multi_swap_69968$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2150$$,$state$jscomp$531$$){var $self__$jscomp$4906$$=this,$undo_id$jscomp$32$$=
Symbol();$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.libraries",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,"COMPONENT-SWAP"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$208$file$$,$APP.$app$main$data$workspace$libraries$debug_pretty_file$$($self__$jscomp$4906$$.$file_id$,$state$jscomp$531$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4026$id_new_component$$,$self__$jscomp$4906$$.$id_new_component$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3699$undo_id$$,$undo_id$jscomp$32$$],null)],null)}),null,"app.main.data.workspace.libraries",
$APP.$cljs$cst$1161$info$$,!1);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$32$$)),$APP.$beicon$v2$core$map$$(function($p1__69967_SHARP_$$){return $APP.$app$main$data$workspace$libraries$component_swap$$($p1__69967_SHARP_$$,$self__$jscomp$4906$$.$file_id$,$self__$jscomp$4906$$.$id_new_component$,!1)},$APP.$beicon$v2$core$from$$($self__$jscomp$4906$$.shapes)),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$32$$)),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$specialized_panel$open_specialized_panel$$()))});return new $app$main$data$workspace$libraries$component_multi_swap_69968$$($shapes$jscomp$110$$,$file_id$jscomp$169$$,$id_new_component$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$logic$libraries$generate_duplicate_changes$$=function($var_args$jscomp$1202$$){for(var $args__5755__auto__$jscomp$216$$=[],$len__5749__auto___67714$$=arguments.length,$i__5750__auto___67715$$=0;;)if($i__5750__auto___67715$$<$len__5749__auto___67714$$)$args__5755__auto__$jscomp$216$$.push(arguments[$i__5750__auto___67715$$]),$i__5750__auto___67715$$+=1;else break;return $APP.$app$common$logic$libraries$generate_duplicate_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],8<$args__5755__auto__$jscomp$216$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$216$$.slice(8),0,null):null)};
$app$main$data$workspace$shape_layout$paste_grid_tracks$$=function($grid_id$jscomp$21$$){typeof $app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$==="undefined"&&($app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$=function($grid_id$jscomp$22$$,$meta71598$$){this.$grid_id$=$grid_id$jscomp$22$$;this.$meta71598$=$meta71598$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4488$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_paste_grid_tracks$$},$app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71599$$,$meta71598__$1$$){return new $app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$(this.$grid_id$,
$meta71598__$1$$)},$app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71598$},$app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$,$state$jscomp$846_track_indices$jscomp$1$$){$changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$846_track_indices$jscomp$1$$);var $page$jscomp$103$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$846_track_indices$jscomp$1$$),$objects$jscomp$647$$=$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$103$$),$libraries$jscomp$98$$=$APP.$app$main$data$helpers$lookup_libraries$$($state$jscomp$846_track_indices$jscomp$1$$),$library_data$jscomp$34$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($state$jscomp$846_track_indices$jscomp$1$$,
$changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$),$grid$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$647$$,this.$grid_id$),$copied_undo_id$jscomp$63$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$846_track_indices$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2248$workspace_grid_edition$$,this.$grid_id$,$APP.$cljs$cst$4485$copied_tracks$$],
null));$state$jscomp$846_track_indices$jscomp$1$$=$APP.$cljs$cst$4486$track_indices$$.$cljs$core$IFn$_invoke$arity$1$($copied_undo_id$jscomp$63$$);var $type$jscomp$535$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($copied_undo_id$jscomp$63$$);$copied_undo_id$jscomp$63$$=Symbol();if($APP.$cljs$core$seq$$($state$jscomp$846_track_indices$jscomp$1$$)&&$type$jscomp$535$$!=null){var $shapes_by_track_fn$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$535$$,$APP.$cljs$cst$1661$row$$)?
$APP.$app$common$types$shape$layout$shapes_by_row$$:$APP.$app$common$types$shape$layout$shapes_by_column$$,$all_shapes$jscomp$2$$=$APP.$cljs$core$set$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__71593_SHARP_$$){return $shapes_by_track_fn$$.$cljs$core$IFn$_invoke$arity$3$?$shapes_by_track_fn$$.$cljs$core$IFn$_invoke$arity$3$($grid$jscomp$8$$,$p1__71593_SHARP_$$,!1):$shapes_by_track_fn$$($grid$jscomp$8$$,$p1__71593_SHARP_$$,!1)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$state$jscomp$846_track_indices$jscomp$1$$])));
$changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$=$APP.$app$common$logic$libraries$generate_duplicate_changes_update_indices$$($app$common$logic$libraries$generate_duplicate_changes$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$objects$jscomp$647$$,$page$jscomp$103$$,$all_shapes$jscomp$2$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$libraries$jscomp$98$$,$library_data$jscomp$34$$,$changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$),
$objects$jscomp$647$$,$all_shapes$jscomp$2$$);var $ids_map$jscomp$22$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71596_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3584$old_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71596_SHARP_$$),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($p1__71596_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2622$obj$$,$APP.$cljs$cst$266$id$$],null))],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__71600_p1__71595_SHARP_$$){$G__71600_p1__71595_SHARP_$$=$APP.$cljs$cst$3584$old_id$$.$cljs$core$IFn$_invoke$arity$1$($G__71600_p1__71595_SHARP_$$);return $all_shapes$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$all_shapes$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__71600_p1__71595_SHARP_$$):
$all_shapes$jscomp$2$$($G__71600_p1__71595_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71594_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__71594_SHARP_$$),$APP.$cljs$cst$2621$add_obj$$)},$APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$))))),$duplicate_at_fn$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$535$$,
$APP.$cljs$cst$1661$row$$)?$app$common$types$shape$layout$duplicate_row_at$$:$app$common$types$shape$layout$duplicate_column_at$$,$tracks_prop$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$535$$,$APP.$cljs$cst$1661$row$$)?$APP.$cljs$cst$1699$layout_grid_rows$$:$APP.$cljs$cst$1700$layout_grid_columns$$,$sorted_indices$$=$APP.$cljs$core$vec$$($APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$846_track_indices$jscomp$1$$));$changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$=
$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$grid_id$],null),function($shape$jscomp$749_shape__$1$jscomp$63$$,$objects__$1$jscomp$29$$){$shape$jscomp$749_shape__$1$jscomp$63$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape$jscomp$749_shape__$1$jscomp$63$$,
$APP.$cljs$core$select_keys$$($grid$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$cst$1700$layout_grid_columns$$,$APP.$cljs$cst$1699$layout_grid_rows$$],null))]));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($s$jscomp$553$$,$actual_src_p__71603$$){var $offset$jscomp$182_target_idx$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($actual_src_p__71603$$,
0,null);$actual_src_p__71603$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($actual_src_p__71603$$,1,null);$offset$jscomp$182_target_idx$$=$APP.$cljs$core$count$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$8$$,$tracks_prop$jscomp$1$$))+$offset$jscomp$182_target_idx$$;return $duplicate_at_fn$$.$cljs$core$IFn$_invoke$arity$5$?$duplicate_at_fn$$.$cljs$core$IFn$_invoke$arity$5$($s$jscomp$553$$,$objects__$1$jscomp$29$$,$actual_src_p__71603$$,$offset$jscomp$182_target_idx$$,
$ids_map$jscomp$22$$):$duplicate_at_fn$$($s$jscomp$553$$,$objects__$1$jscomp$29$$,$actual_src_p__71603$$,$offset$jscomp$182_target_idx$$,$ids_map$jscomp$22$$)},$shape$jscomp$749_shape__$1$jscomp$63$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$sorted_indices$$))},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3199$with_objects_QMARK_$$,!0],null));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($copied_undo_id$jscomp$63$$),
$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$264_changes__$1$jscomp$81_file_id$jscomp$253_it$jscomp$230$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$grid_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($copied_undo_id$jscomp$63$$))}return null});
return new $app$main$data$workspace$shape_layout$paste_grid_tracks_71597$$($grid_id$jscomp$21$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shape_layout$duplicate_layout_track$$=function($ids$jscomp$230$$,$type$jscomp$525$$,$index$jscomp$359$$){typeof $app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$==="undefined"&&($app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$=function($ids$jscomp$231$$,$type$jscomp$526$$,$index$jscomp$360$$,$meta71457$$){this.ids=$ids$jscomp$231$$;this.type=$type$jscomp$526$$;this.index=$index$jscomp$360$$;this.$meta71457$=$meta71457$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4473$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_duplicate_layout_track$$},$app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_71458$$,$meta71457__$1$$){return new $app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$(this.ids,this.type,this.index,$meta71457__$1$$)},$app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71457$},$app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$,$library_data$jscomp$33_state$jscomp$841$$){var $self__$jscomp$6027$$=this;$changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$33_state$jscomp$841$$);var $page$jscomp$102_undo_id$jscomp$54$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$33_state$jscomp$841$$),
$objects$jscomp$637$$=$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$102_undo_id$jscomp$54$$),$libraries$jscomp$97$$=$APP.$app$main$data$helpers$lookup_libraries$$($library_data$jscomp$33_state$jscomp$841$$);$library_data$jscomp$33_state$jscomp$841$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$02$$($library_data$jscomp$33_state$jscomp$841$$,$changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$);var $shape_id$jscomp$122_shapes_by_track$$=
$APP.$cljs$core$first$$($self__$jscomp$6027$$.ids),$base_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$637$$,$shape_id$jscomp$122_shapes_by_track$$);$shape_id$jscomp$122_shapes_by_track$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$6027$$.type,$APP.$cljs$cst$216$column$$)?$APP.$app$common$types$shape$layout$shapes_by_column$$.$cljs$core$IFn$_invoke$arity$3$($base_shape$$,$self__$jscomp$6027$$.index,!1):$APP.$app$common$types$shape$layout$shapes_by_row$$.$cljs$core$IFn$_invoke$arity$3$($base_shape$$,
$self__$jscomp$6027$$.index,!1);var $selected$jscomp$94$$=$APP.$cljs$core$set$$($shape_id$jscomp$122_shapes_by_track$$);$changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$=$APP.$app$common$logic$libraries$generate_duplicate_changes_update_indices$$($app$common$logic$libraries$generate_duplicate_changes$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$objects$jscomp$637$$,$page$jscomp$102_undo_id$jscomp$54$$,$selected$jscomp$94$$,
$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0),$libraries$jscomp$97$$,$library_data$jscomp$33_state$jscomp$841$$,$changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$),$objects$jscomp$637$$,$selected$jscomp$94$$);var $ids_map$jscomp$21$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71455_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3584$old_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__71455_SHARP_$$),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($p1__71455_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2622$obj$$,$APP.$cljs$cst$266$id$$],null))],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__71459_p1__71454_SHARP_$$){$G__71459_p1__71454_SHARP_$$=$APP.$cljs$cst$3584$old_id$$.$cljs$core$IFn$_invoke$arity$1$($G__71459_p1__71454_SHARP_$$);
return $selected$jscomp$94$$.$cljs$core$IFn$_invoke$arity$1$?$selected$jscomp$94$$.$cljs$core$IFn$_invoke$arity$1$($G__71459_p1__71454_SHARP_$$):$selected$jscomp$94$$($G__71459_p1__71454_SHARP_$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71453_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__71453_SHARP_$$),$APP.$cljs$cst$2621$add_obj$$)},$APP.$cljs$cst$3157$redo_changes$$.$cljs$core$IFn$_invoke$arity$1$($changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$)))));
$changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$,$self__$jscomp$6027$$.ids,function($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,$objects__$1$jscomp$27$$){$G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,
$APP.$cljs$core$select_keys$$($base_shape$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$cst$1700$layout_grid_columns$$,$APP.$cljs$cst$1699$layout_grid_rows$$],null))]));var $G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$=$self__$jscomp$6027$$.type;$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$=$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$ instanceof
$APP.$cljs$core$Keyword$$?$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$.$fqn$:null;switch($G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$){case "row":$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$=$self__$jscomp$6027$$.index;var $value$jscomp$inline_8635_value$jscomp$inline_8642$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,
$APP.$cljs$cst$1699$layout_grid_rows$$),$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$);$G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$=$app$common$types$shape$layout$duplicate_cells$$($APP.$app$common$types$shape$layout$add_grid_row$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$remove_cell_areas_after$$($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,$APP.$cljs$cst$1661$row$$,
$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$),$value$jscomp$inline_8635_value$jscomp$inline_8642$$,$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$+1),$APP.$cljs$cst$1661$row$$,$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$,$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$+1,$ids_map$jscomp$21$$);return $APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,
$objects__$1$jscomp$27$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,$objects__$1$jscomp$27$$);case "column":return $G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$=$self__$jscomp$6027$$.index,$value$jscomp$inline_8635_value$jscomp$inline_8642$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,
$APP.$cljs$cst$1700$layout_grid_columns$$),$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$),$G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$=$app$common$types$shape$layout$duplicate_cells$$($APP.$app$common$types$shape$layout$add_grid_column$$.$cljs$core$IFn$_invoke$arity$3$($app$common$types$shape$layout$remove_cell_areas_after$$($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,
$APP.$cljs$cst$216$column$$,$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$),$value$jscomp$inline_8635_value$jscomp$inline_8642$$,$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$+1),$APP.$cljs$cst$216$column$$,$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$,$G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$+1,$ids_map$jscomp$21$$),$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$app$common$types$shape$layout$assign_cells$$.$cljs$core$IFn$_invoke$arity$2$($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,$objects__$1$jscomp$27$$):$APP.$app$common$types$shape$layout$assign_cells$$($G__48128$jscomp$inline_8636_G__48130$jscomp$inline_8643_shape$jscomp$738_shape__$1$jscomp$56$$,$objects__$1$jscomp$27$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__71460_G__71460__$1_index$jscomp$inline_8633_index$jscomp$inline_8640$$)].join(""));
}},new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3199$with_objects_QMARK_$$,!0],null));$page$jscomp$102_undo_id$jscomp$54$$=Symbol();return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($page$jscomp$102_undo_id$jscomp$54$$),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$261_changes__$1$jscomp$79_file_id$jscomp$252_it$jscomp$228$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,$self__$jscomp$6027$$.ids],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($page$jscomp$102_undo_id$jscomp$54$$))});return new $app$main$data$workspace$shape_layout$duplicate_layout_track_71456$$($ids$jscomp$230$$,$type$jscomp$525$$,$index$jscomp$359$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$logic$libraries$generate_duplicate_component$$=function($var_args$jscomp$1194$$){for(var $args__5755__auto__$jscomp$214$$=[],$len__5749__auto___67267$$=arguments.length,$i__5750__auto___67268$$=0;;)if($i__5750__auto___67268$$<$len__5749__auto___67267$$)$args__5755__auto__$jscomp$214$$.push(arguments[$i__5750__auto___67268$$]),$i__5750__auto___67268$$+=1;else break;return $APP.$app$common$logic$libraries$generate_duplicate_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
arguments[1],arguments[2],arguments[3],4<$args__5755__auto__$jscomp$214$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$214$$.slice(4),0,null):null)};
$app$main$data$workspace$media$add_shapes_and_component$$=function($JSCompiler_inline_result$jscomp$1699_changes$jscomp$inline_8645_it$jscomp$161$$,$file_data$jscomp$70_objects$jscomp$inline_8646$$,$main_instance_page$jscomp$inline_8654_page$jscomp$68$$,$changes$jscomp$181_name$jscomp$317$$,$p__67909_updated_shapes$jscomp$6_vec__67913$$){var $main_instance_id$jscomp$inline_8653_shape$jscomp$461$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67909_updated_shapes$jscomp$6_vec__67913$$,
0,null),$children$jscomp$215$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67909_updated_shapes$jscomp$6_vec__67913$$,1,null);$p__67909_updated_shapes$jscomp$6_vec__67913$$=$APP.$app$common$types$container$convert_shape_in_component$$($main_instance_id$jscomp$inline_8653_shape$jscomp$461$$,$children$jscomp$215$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$70_objects$jscomp$inline_8646$$));var $component_shape$jscomp$5_id$jscomp$inline_8649$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67909_updated_shapes$jscomp$6_vec__67913$$,
0,null);$p__67909_updated_shapes$jscomp$6_vec__67913$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__67909_updated_shapes$jscomp$6_vec__67913$$,1,null);$JSCompiler_inline_result$jscomp$1699_changes$jscomp$inline_8645_it$jscomp$161$$=$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$($JSCompiler_inline_result$jscomp$1699_changes$jscomp$inline_8645_it$jscomp$161$$),
$main_instance_page$jscomp$inline_8654_page$jscomp$68$$),$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_page$jscomp$inline_8654_page$jscomp$68$$)),$file_data$jscomp$70_objects$jscomp$inline_8646$$);$file_data$jscomp$70_objects$jscomp$inline_8646$$=$APP.$cljs$core$cons$$($main_instance_id$jscomp$inline_8653_shape$jscomp$461$$,$children$jscomp$215$$);$JSCompiler_inline_result$jscomp$1699_changes$jscomp$inline_8645_it$jscomp$161$$=$APP.$app$common$files$changes_builder$add_objects$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1699_changes$jscomp$inline_8645_it$jscomp$161$$,
$file_data$jscomp$70_objects$jscomp$inline_8646$$,null);$component_shape$jscomp$5_id$jscomp$inline_8649$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_shape$jscomp$5_id$jscomp$inline_8649$$);$main_instance_id$jscomp$inline_8653_shape$jscomp$461$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_id$jscomp$inline_8653_shape$jscomp$461$$);$main_instance_page$jscomp$inline_8654_page$jscomp$68$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($main_instance_page$jscomp$inline_8654_page$jscomp$68$$);
$changes$jscomp$181_name$jscomp$317$$=$APP.$app$common$files$changes_builder$add_component$$($JSCompiler_inline_result$jscomp$1699_changes$jscomp$inline_8645_it$jscomp$161$$,$component_shape$jscomp$5_id$jscomp$inline_8649$$,"",$changes$jscomp$181_name$jscomp$317$$,$p__67909_updated_shapes$jscomp$6_vec__67913$$,$main_instance_id$jscomp$inline_8653_shape$jscomp$461$$,$main_instance_page$jscomp$inline_8654_page$jscomp$68$$,null,null,null);return $APP.$app$main$data$changes$commit_changes$$($changes$jscomp$181_name$jscomp$317$$)};
$app$main$data$workspace$media$process_svg_component$$=function($svg_data$jscomp$21$$){typeof $app$main$data$workspace$media$process_svg_component_67922$$==="undefined"&&($app$main$data$workspace$media$process_svg_component_67922$$=function($svg_data$jscomp$22$$,$meta67923$$){this.$svg_data$=$svg_data$jscomp$22$$;this.$meta67923$=$meta67923$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$process_svg_component_67922$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_svg_component_67922$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3758$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_svg_component$$},$app$main$data$workspace$media$process_svg_component_67922$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67924$$,$meta67923__$1$$){return new $app$main$data$workspace$media$process_svg_component_67922$$(this.$svg_data$,$meta67923__$1$$)},
$app$main$data$workspace$media$process_svg_component_67922$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67923$},$app$main$data$workspace$media$process_svg_component_67922$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_svg_component_67922$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($file_id$jscomp$110_it$jscomp$163$$,$pos$jscomp$106_state$jscomp$415$$){$file_id$jscomp$110_it$jscomp$163$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$106_state$jscomp$415$$);var $page$jscomp$70_page_id$jscomp$132$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$106_state$jscomp$415$$),$fdata$jscomp$9$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$106_state$jscomp$415$$,$file_id$jscomp$110_it$jscomp$163$$);$page$jscomp$70_page_id$jscomp$132$$=$APP.$app$main$data$helpers$get_page$$($fdata$jscomp$9$$,
$page$jscomp$70_page_id$jscomp$132$$);$pos$jscomp$106_state$jscomp$415$$=$APP.$app$main$data$helpers$get_viewport_center$$($pos$jscomp$106_state$jscomp$415$$);return $APP.$beicon$v2$core$map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$media$add_shapes_and_component$$,this,$fdata$jscomp$9$$,$page$jscomp$70_page_id$jscomp$132$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.$svg_data$)])),
$app$main$data$workspace$media$create_shapes_svg$$($file_id$jscomp$110_it$jscomp$163$$,$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$70_page_id$jscomp$132$$),$pos$jscomp$106_state$jscomp$415$$,this.$svg_data$))});return new $app$main$data$workspace$media$process_svg_component_67922$$($svg_data$jscomp$21$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$process_img_component$$=function($media_obj$jscomp$1$$){typeof $app$main$data$workspace$media$process_img_component_67916$$==="undefined"&&($app$main$data$workspace$media$process_img_component_67916$$=function($media_obj$jscomp$2$$,$meta67917$$){this.$media_obj$=$media_obj$jscomp$2$$;this.$meta67917$=$meta67917$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$media$process_img_component_67916$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_img_component_67916$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3757$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_process_img_component$$},$app$main$data$workspace$media$process_img_component_67916$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67918$$,$meta67917__$1$$){return new $app$main$data$workspace$media$process_img_component_67916$$(this.$media_obj$,$meta67917__$1$$)},
$app$main$data$workspace$media$process_img_component_67916$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67917$},$app$main$data$workspace$media$process_img_component_67916$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$process_img_component_67916$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$109_it$jscomp$162$$,$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$){$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$109_it$jscomp$162$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$);var $name$jscomp$inline_8659_page$jscomp$69_page_id$jscomp$131$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$);$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$109_it$jscomp$162$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$,
$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$109_it$jscomp$162$$);$name$jscomp$inline_8659_page$jscomp$69_page_id$jscomp$131$$=$APP.$app$main$data$helpers$get_page$$($JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$109_it$jscomp$162$$,$name$jscomp$inline_8659_page$jscomp$69_page_id$jscomp$131$$);$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$=$APP.$app$main$data$helpers$get_viewport_center$$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$);
$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$109_it$jscomp$162$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$media$add_shapes_and_component$$,this,$JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$109_it$jscomp$162$$,$name$jscomp$inline_8659_page$jscomp$69_page_id$jscomp$131$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$(this.$media_obj$)]));
var $frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$=$APP.$cljs$core$__destructure_map$$(this.$media_obj$);$name$jscomp$inline_8659_page$jscomp$69_page_id$jscomp$131$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$,$APP.$cljs$cst$725$name$$);var $width$jscomp$inline_8660$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$,$APP.$cljs$cst$290$width$$),
$height$jscomp$inline_8661$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$,$APP.$cljs$cst$1527$height$$),$id$jscomp$inline_8662_img_fills$jscomp$inline_8665$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$,$APP.$cljs$cst$266$id$$),$mtype$jscomp$inline_8663$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$,
$APP.$cljs$cst$1732$mtype$$);$frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$=$APP.$app$common$types$shape$setup_shape$$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1611$frame$$,$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$),$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$),
$APP.$cljs$cst$290$width$$,$width$jscomp$inline_8660$$,$APP.$cljs$cst$1527$height$$,$height$jscomp$inline_8661$$,$APP.$cljs$cst$725$name$$,$name$jscomp$inline_8659_page$jscomp$69_page_id$jscomp$131$$,$APP.$cljs$cst$1612$frame_id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$cst$1624$parent_id$$,$APP.$app$common$uuid$zero$$],null));$id$jscomp$inline_8662_img_fills$jscomp$inline_8665$$=$APP.$app$common$types$fills$create$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1753$fill_opacity$$,1,$APP.$cljs$cst$1637$fill_image$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$id$jscomp$inline_8662_img_fills$jscomp$inline_8665$$,$APP.$cljs$cst$290$width$$,$width$jscomp$inline_8660$$,$APP.$cljs$cst$1527$height$$,$height$jscomp$inline_8661$$,$APP.$cljs$cst$1732$mtype$$,$mtype$jscomp$inline_8663$$,$APP.$cljs$cst$1733$keep_aspect_ratio$$,!0],null)],null)]));$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$=
$APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1624$parent_id$$,$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1639$fills$$,$APP.$cljs$cst$1527$height$$],[$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$),$name$jscomp$inline_8659_page$jscomp$69_page_id$jscomp$131$$,
$width$jscomp$inline_8660$$,$APP.$cljs$cst$1616$rect$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$),$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$),$id$jscomp$inline_8662_img_fills$jscomp$inline_8665$$,
$height$jscomp$inline_8661$$]));$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$=(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_shape$jscomp$inline_8664_map__67908__$1$jscomp$inline_8658$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$],
null)],null));return $APP.$beicon$v2$core$map$$($JSCompiler_temp_const$jscomp$1641_fdata$jscomp$8_file_id$jscomp$109_it$jscomp$162$$,$JSCompiler_inline_result$jscomp$1642_img_shape$jscomp$inline_8666_pos$jscomp$105_state$jscomp$414$$)});return new $app$main$data$workspace$media$process_img_component_67916$$($media_obj$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$exit_preview$$=function(){typeof $app$main$data$workspace$versions$exit_preview_73724$$==="undefined"&&($app$main$data$workspace$versions$exit_preview_73724$$=function($meta73725$$){this.$meta73725$=$meta73725$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$exit_preview_73724$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$exit_preview_73724$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $APP.$cljs$cst$5156$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_exit_preview$$},$app$main$data$workspace$versions$exit_preview_73724$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73726$$,$meta73725__$1$$){return new $app$main$data$workspace$versions$exit_preview_73724$$($meta73725__$1$$)},$app$main$data$workspace$versions$exit_preview_73724$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta73725$},$app$main$data$workspace$versions$exit_preview_73724$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$exit_preview_73724$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2827_file_id$jscomp$331$$,$page_id$jscomp$350_state$jscomp$1096$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$350_state$jscomp$1096$$,$APP.$cljs$cst$4537$workspace_versions$$),$APP.$cljs$cst$5155$backup$$))?($_$jscomp$2827_file_id$jscomp$331$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$350_state$jscomp$1096$$),$page_id$jscomp$350_state$jscomp$1096$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$350_state$jscomp$1096$$),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$exit_preview_cleanup$$(),$APP.$app$main$data$workspace$pages$initialize_page$$($_$jscomp$2827_file_id$jscomp$331$$,$page_id$jscomp$350_state$jscomp$1096$$))):null});return new $app$main$data$workspace$versions$exit_preview_73724$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$restore_version$$=function($id$jscomp$866$$){typeof $app$main$data$workspace$versions$restore_version_73741$$==="undefined"&&($app$main$data$workspace$versions$restore_version_73741$$=function($id$jscomp$867$$,$meta73742$$){this.id=$id$jscomp$867$$;this.$meta73742$=$meta73742$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$restore_version_73741$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$restore_version_73741$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5157$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_restore_version$$},$app$main$data$workspace$versions$restore_version_73741$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73743$$,$meta73742__$1$$){return new $app$main$data$workspace$versions$restore_version_73741$$(this.id,$meta73742__$1$$)},$app$main$data$workspace$versions$restore_version_73741$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73742$},$app$main$data$workspace$versions$restore_version_73741$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$restore_version_73741$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2828$$,$state$jscomp$1097$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1097$$,$APP.$cljs$cst$4537$workspace_versions$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$5155$backup$$),$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$2225$read_only_QMARK_$$,$APP.$cljs$cst$5134$preview_id$$)},$app$main$data$workspace$versions$restore_version_73741$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$restore_version_73741$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2829$$,$state$jscomp$1098$$){var $self__$jscomp$7090$$=
this,$file_id$jscomp$332$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1098$$);return $APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2545$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$,$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3768$document_history$$)),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$versions$initialize_version$$()},$APP.$beicon$v2$core$mapcat$$(function(){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5158$restore_file_snapshot$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$332$$,$APP.$cljs$cst$266$id$$,$self__$jscomp$7090$$.id],null))},$APP.$app$main$data$persistence$wait_persisted$cljs$0core$0IFn$0_invoke$0arity$01$$(null))))});return new $app$main$data$workspace$versions$restore_version_73741$$($id$jscomp$866$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$enter_restore$$=function($id$jscomp$868$$){typeof $app$main$data$workspace$versions$enter_restore_73746$$==="undefined"&&($app$main$data$workspace$versions$enter_restore_73746$$=function($id$jscomp$869$$,$meta73747$$){this.id=$id$jscomp$869$$;this.$meta73747$=$meta73747$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$enter_restore_73746$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$enter_restore_73746$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5159$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_enter_restore$$},$app$main$data$workspace$versions$enter_restore_73746$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73748$$,$meta73747__$1$$){return new $app$main$data$workspace$versions$enter_restore_73746$$(this.id,$meta73747__$1$$)},$app$main$data$workspace$versions$enter_restore_73746$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73747$},$app$main$data$workspace$versions$enter_restore_73746$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$enter_restore_73746$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7094$$=this,$output_s$$=$APP.$beicon$v2$core$subject$$();return $APP.$beicon$v2$core$merge$$($output_s$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.restore-warning"),$APP.$cljs$cst$2361$controls$$,$APP.$cljs$cst$2363$inline_actions$$,$APP.$cljs$cst$2366$cancel$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.updates.dismiss"),$APP.$cljs$cst$2365$callback$$,function(){$output_s$$.next($APP.$app$main$data$notifications$hide$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$5146$restore_dialog$$])));$output_s$$.next($app$main$data$workspace$versions$exit_preview$$());return $output_s$$.complete()}],null),$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.restore"),$APP.$cljs$cst$2365$callback$$,function(){$output_s$$.next($app$main$data$workspace$versions$restore_version$$($self__$jscomp$7094$$.id));return $output_s$$.complete()}],null),
$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$5146$restore_dialog$$]))))});return new $app$main$data$workspace$versions$enter_restore_73746$$($id$jscomp$868$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$versions$enter_preview$$=function($id$jscomp$872$$){typeof $app$main$data$workspace$versions$enter_preview_73767$$==="undefined"&&($app$main$data$workspace$versions$enter_preview_73767$$=function($id$jscomp$873$$,$meta73768$$){this.id=$id$jscomp$873$$;this.$meta73768$=$meta73768$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$versions$enter_preview_73767$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$versions$enter_preview_73767$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$5161$app_DOT_main_DOT_data_DOT_workspace_DOT_versions_SLASH_enter_preview$$},$app$main$data$workspace$versions$enter_preview_73767$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_73769$$,$meta73768__$1$$){return new $app$main$data$workspace$versions$enter_preview_73767$$(this.id,$meta73768__$1$$)},$app$main$data$workspace$versions$enter_preview_73767$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta73768$},$app$main$data$workspace$versions$enter_preview_73767$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$enter_preview_73767$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2832_file$jscomp$90$$,$state$jscomp$1100$$){$_$jscomp$2832_file$jscomp$90$$=$APP.$app$main$data$helpers$lookup_file$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$1100$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$1100$$,
$APP.$cljs$cst$4537$workspace_versions$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5155$backup$$,$_$jscomp$2832_file$jscomp$90$$),$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2225$read_only_QMARK_$$,!0,$APP.$cljs$cst$5134$preview_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([this.id]))},$app$main$data$workspace$versions$enter_preview_73767$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$versions$enter_preview_73767$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2833_features__$1$jscomp$25_team_id$jscomp$128$$,$label$jscomp$35_state$jscomp$1101$$){var $self__$jscomp$7103$$=this,$file_id$jscomp$333$$=$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($label$jscomp$35_state$jscomp$1101$$),$page_id$jscomp$351$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($label$jscomp$35_state$jscomp$1101$$);$_$jscomp$2833_features__$1$jscomp$25_team_id$jscomp$128$$=$APP.$cljs$cst$1943$current_team_id$$.$cljs$core$IFn$_invoke$arity$1$($label$jscomp$35_state$jscomp$1101$$);
$_$jscomp$2833_features__$1$jscomp$25_team_id$jscomp$128$$=$APP.$app$main$features$get_enabled_features$$($label$jscomp$35_state$jscomp$1101$$,$_$jscomp$2833_features__$1$jscomp$25_team_id$jscomp$128$$);var $snapshot$jscomp$4$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__73765_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($self__$jscomp$7103$$.id,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__73765_SHARP_$$))},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($label$jscomp$35_state$jscomp$1101$$,
$APP.$cljs$cst$4537$workspace_versions$$),$APP.$cljs$cst$142$data$$));$label$jscomp$35_state$jscomp$1101$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("system",$APP.$cljs$cst$5162$created_by$$.$cljs$core$IFn$_invoke$arity$1$($snapshot$jscomp$4$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.autosaved.version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($snapshot$jscomp$4$$),
$APP.$cljs$cst$5141$localized_date$$)])):function(){var $or__5025__auto__$jscomp$992$$=$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($snapshot$jscomp$4$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$992$$)?$or__5025__auto__$jscomp$992$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.preview.unnamed")}();var $output_s$jscomp$1$$=$APP.$beicon$v2$core$subject$$();return $APP.$beicon$v2$core$merge$$($output_s$jscomp$1$$,(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$dialog$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1642$content$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.preview-banner-title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$label$jscomp$35_state$jscomp$1101$$])),$APP.$cljs$cst$2361$controls$$,$APP.$cljs$cst$2363$inline_actions$$,$APP.$cljs$cst$2366$cancel$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.exit"),$APP.$cljs$cst$2365$callback$$,function(){$output_s$jscomp$1$$.next($APP.$app$main$data$notifications$hide$$());
$output_s$jscomp$1$$.next($app$main$data$workspace$versions$exit_preview$$());return $output_s$jscomp$1$$.complete()}],null),$APP.$cljs$cst$924$accept$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.restore"),$APP.$cljs$cst$2365$callback$$,function(){$output_s$jscomp$1$$.next($APP.$app$main$data$notifications$hide$$());$output_s$jscomp$1$$.next($app$main$data$workspace$versions$enter_restore$$($self__$jscomp$7103$$.id));
return $output_s$jscomp$1$$.complete()}],null),$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$5163$preview_dialog$$]))),$APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($err$jscomp$44$$){$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.versions",$APP.$cljs$cst$849$error$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"failed to load snapshot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$333$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$5164$snapshot_id$$,$self__$jscomp$7103$$.id],null)],null)}),$err$jscomp$44$$,"app.main.data.workspace.versions",$APP.$cljs$cst$849$error$$,
!1);return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$exit_preview$$())},$APP.$beicon$v2$core$mapcat$$(function($snapshot__$1$$){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$versions$apply_snapshot$$($snapshot__$1$$),$APP.$app$main$data$workspace$pages$initialize_page$$($file_id$jscomp$333$$,$page_id$jscomp$351$$))},$APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5165$get_file_snapshot$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$333$$,$APP.$cljs$cst$266$id$$,$self__$jscomp$7103$$.id,$APP.$cljs$cst$227$features$$,$_$jscomp$2833_features__$1$jscomp$25_team_id$jscomp$128$$],null)))))});return new $app$main$data$workspace$versions$enter_preview_73767$$($id$jscomp$872$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$common$files$shapes_helpers$prepare_create_empty_artboard$$=function($changes$jscomp$170_changes__$2$jscomp$29_vec__66277$$,$frame_id$jscomp$48$$,$parent_id$jscomp$51$$,$objects$jscomp$334$$,$target_cell_id$jscomp$2$$){var $base_parent$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$334$$,$parent_id$jscomp$51$$),$attrs$jscomp$76$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1611$frame$$,$APP.$cljs$cst$1515$x$$,0,$APP.$cljs$cst$1516$y$$,
0,$APP.$cljs$cst$290$width$$,.01,$APP.$cljs$cst$1527$height$$,.01],null),$shape$jscomp$444$$=$APP.$app$common$types$shape$setup_shape$$(function(){var $G__66280__$2_G__66280__$3_G__66280__$4$$=$frame_id$jscomp$48$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$76$$,$APP.$cljs$cst$266$id$$,$frame_id$jscomp$48$$):$attrs$jscomp$76$$;$G__66280__$2_G__66280__$3_G__66280__$4$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__66280__$2_G__66280__$3_G__66280__$4$$,
$APP.$cljs$cst$1612$frame_id$$,$frame_id$jscomp$48$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1624$parent_id$$,$parent_id$jscomp$51$$,$APP.$cljs$cst$1619$shapes$$,$APP.$cljs$core$PersistentVector$EMPTY$$]));$G__66280__$2_G__66280__$3_G__66280__$4$$=$APP.$cljs$core$with_meta$$($G__66280__$2_G__66280__$3_G__66280__$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1801$index$$,0],null));var $or__5025__auto__$jscomp$inline_8668$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$48$$,
$APP.$app$common$uuid$zero$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8668$$?$or__5025__auto__$jscomp$inline_8668$$:!0)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__66280__$2_G__66280__$3_G__66280__$4$$,$APP.$cljs$cst$1639$fills$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1883$hide_in_viewer$$,!0])):$G__66280__$2_G__66280__$3_G__66280__$4$$}());$changes$jscomp$170_changes__$2$jscomp$29_vec__66277$$=
$APP.$app$common$files$shapes_helpers$prepare_add_shape$$($changes$jscomp$170_changes__$2$jscomp$29_vec__66277$$,$shape$jscomp$444$$,$objects$jscomp$334$$);var $shape__$1$jscomp$33$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$170_changes__$2$jscomp$29_vec__66277$$,0,null),$changes__$1$jscomp$60$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$170_changes__$2$jscomp$29_vec__66277$$,1,null);$changes$jscomp$170_changes__$2$jscomp$29_vec__66277$$=
function(){return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$334$$,$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$33$$)))?$APP.$app$common$files$changes_builder$reorder_grid_children$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$(function(){return $target_cell_id$jscomp$2$$!=null?$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($changes__$1$jscomp$60$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$33$$)],null),function($parent$jscomp$226$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parent$jscomp$226$$,$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$cst$1701$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($base_parent$jscomp$1$$)),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$target_cell_id$jscomp$2$$,$APP.$cljs$cst$1619$shapes$$],null),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$48$$],null)),$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1677$auto$$)}):$changes__$1$jscomp$60$$}(),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$33$$)],null),$APP.$app$common$types$shape$layout$assign_cells$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3199$with_objects_QMARK_$$,!0],null)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$33$$)],null)):$changes__$1$jscomp$60$$}();return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape__$1$jscomp$33$$,$changes$jscomp$170_changes__$2$jscomp$29_vec__66277$$],null)};
$app$main$data$workspace$shape_layout$create_cell_board$$=function($layout_id$jscomp$10$$,$cell_ids$$){typeof $app$main$data$workspace$shape_layout$create_cell_board_71569$$==="undefined"&&($app$main$data$workspace$shape_layout$create_cell_board_71569$$=function($layout_id$jscomp$11$$,$cell_ids$jscomp$1$$,$meta71570$$){this.$layout_id$=$layout_id$jscomp$11$$;this.$cell_ids$=$cell_ids$jscomp$1$$;this.$meta71570$=$meta71570$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$shape_layout$create_cell_board_71569$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_cell_board_71569$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4483$app_DOT_main_DOT_data_DOT_workspace_DOT_shape_layout_SLASH_create_cell_board$$},$app$main$data$workspace$shape_layout$create_cell_board_71569$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71571$$,$meta71570__$1$$){return new $app$main$data$workspace$shape_layout$create_cell_board_71569$$(this.$layout_id$,
this.$cell_ids$,$meta71570__$1$$)},$app$main$data$workspace$shape_layout$create_cell_board_71569$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71570$},$app$main$data$workspace$shape_layout$create_cell_board_71569$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$shape_layout$create_cell_board_71569$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$229_undo_id$jscomp$62$$,$cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$){var $self__$jscomp$6063$$=
this,$it__$1$jscomp$105$$=this,$page_id$jscomp$252$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$),$objects$jscomp$645$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$),$frame_id$jscomp$112$$=$APP.$app$common$uuid$next$$();
$it$jscomp$229_undo_id$jscomp$62$$=Symbol();var $shape$jscomp$748$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$645$$,$self__$jscomp$6063$$.$layout_id$);$cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__71568_SHARP_$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$748$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$p1__71568_SHARP_$$],null))},$self__$jscomp$6063$$.$cell_ids$);var $selected$jscomp$95$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1619$shapes$$),$cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$);$cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$=
$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$);$cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$=$APP.$cljs$core$__destructure_map$$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$);var $first_row$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$,
$APP.$cljs$cst$1720$first_row$$),$first_column$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$,$APP.$cljs$cst$1721$first_column$$),$last_row$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$,$APP.$cljs$cst$1722$last_row$$),$last_column$jscomp$12$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$,$APP.$cljs$cst$1723$last_column$$),$target_cell$jscomp$10$$=$APP.$app$common$types$shape$layout$get_cell_by_position$$($shape$jscomp$748$$,$first_row$jscomp$12$$,$first_column$jscomp$12$$);$cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$=function(){var $G__71578_G__71579$jscomp$inline_8670$$=
$APP.$app$common$files$changes_builder$with_objects$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$($it__$1$jscomp$105$$,$page_id$jscomp$252$$),$objects$jscomp$645$$);$G__71578_G__71579$jscomp$inline_8670$$=$APP.$app$common$data$not_empty_QMARK_$$($selected$jscomp$95$$)?$APP.$app$common$files$shapes_helpers$prepare_create_artboard_from_selection$$.$cljs$core$IFn$_invoke$arity$9$($G__71578_G__71579$jscomp$inline_8670$$,$frame_id$jscomp$112$$,$self__$jscomp$6063$$.$layout_id$,
$objects$jscomp$645$$,$selected$jscomp$95$$,0,null,!0,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$10$$)):$G__71578_G__71579$jscomp$inline_8670$$;return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$seq$$($selected$jscomp$95$$))?$app$common$files$shapes_helpers$prepare_create_empty_artboard$$($G__71578_G__71579$jscomp$inline_8670$$,$frame_id$jscomp$112$$,$self__$jscomp$6063$$.$layout_id$,$objects$jscomp$645$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$10$$)):
$G__71578_G__71579$jscomp$inline_8670$$}();$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$,0,null);$cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$,
1,null);$cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$frame_id$jscomp$112$$],null),function($shape__$1$jscomp$61$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$61$$,$APP.$cljs$cst$1713$layout_item_h_sizing$$,$APP.$cljs$cst$1408$fill$$),$APP.$cljs$cst$1714$layout_item_v_sizing$$,$APP.$cljs$cst$1408$fill$$)}),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6063$$.$layout_id$],null),function($shape__$1$jscomp$62$$){var $new_row_span$jscomp$1$$=
$last_row$jscomp$12$$-$first_row$jscomp$12$$+1,$new_col_span$$=$last_column$jscomp$12$$-$first_column$jscomp$12$$+1;return $APP.$app$common$types$shape$layout$resize_cell_area$$($shape__$1$jscomp$62$$,$APP.$cljs$cst$1661$row$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$10$$),$APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($target_cell$jscomp$10$$),$first_row$jscomp$12$$,$first_column$jscomp$12$$,$new_row_span$jscomp$1$$,$new_col_span$$)});return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($it$jscomp$229_undo_id$jscomp$62$$),
$APP.$app$main$data$changes$commit_changes$$($cells$jscomp$24_changes$jscomp$263_changes__$1$jscomp$80_map__71572_map__71572__$1_state$jscomp$844_vec__71573$$),$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$6063$$.$layout_id$],null)],null)),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($it$jscomp$229_undo_id$jscomp$62$$))});
return new $app$main$data$workspace$shape_layout$create_cell_board_71569$$($layout_id$jscomp$10$$,$cell_ids$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$add_multiple_components$$=function(){typeof $app$main$data$workspace$libraries$add_multiple_components_69757$$==="undefined"&&($app$main$data$workspace$libraries$add_multiple_components_69757$$=function($meta69758$$){this.$meta69758$=$meta69758$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$add_multiple_components_69757$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$libraries$add_multiple_components_69757$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3990$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_add_multiple_components$$},$app$main$data$workspace$libraries$add_multiple_components_69757$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69759$$,$meta69758__$1$$){return new $app$main$data$workspace$libraries$add_multiple_components_69757$$($meta69758__$1$$)},$app$main$data$workspace$libraries$add_multiple_components_69757$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta69758$},$app$main$data$workspace$libraries$add_multiple_components_69757$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$add_multiple_components_69757$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2125_can_make_component$jscomp$1_selected_objects$jscomp$1$$,$added_components_selected$jscomp$57_state$jscomp$511$$){var $objects$jscomp$509$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($added_components_selected$jscomp$57_state$jscomp$511$$);
$added_components_selected$jscomp$57_state$jscomp$511$$=$APP.$app$common$files$helpers$clean_loops$$($objects$jscomp$509$$,$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($added_components_selected$jscomp$57_state$jscomp$511$$));$_$jscomp$2125_can_make_component$jscomp$1_selected_objects$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69755_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$509$$,$p1__69755_SHARP_$$)},
$added_components_selected$jscomp$57_state$jscomp$511$$);$_$jscomp$2125_can_make_component$jscomp$1_selected_objects$jscomp$1$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$true_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__69756_SHARP_$$){return $APP.$app$common$types$container$valid_shape_for_component_QMARK_$$($objects$jscomp$509$$,$p1__69756_SHARP_$$)},$_$jscomp$2125_can_make_component$jscomp$1_selected_objects$jscomp$1$$));$added_components_selected$jscomp$57_state$jscomp$511$$=
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$586$$){return $APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$libraries$add_component2$cljs$0core$0IFn$0_invoke$0arity$02$$(null,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$586$$],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1621$multiple$$,!0],null))},$added_components_selected$jscomp$57_state$jscomp$511$$);var $undo_id$jscomp$22$$=
Symbol();return $_$jscomp$2125_can_make_component$jscomp$1_selected_objects$jscomp$1$$?$APP.$beicon$v2$core$concat$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$22$$)),$APP.$beicon$v2$core$from$$($added_components_selected$jscomp$57_state$jscomp$511$$),(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$22$$))):null});return new $app$main$data$workspace$libraries$add_multiple_components_69757$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$variants$combine_selected_as_variants$$=function($options$jscomp$577$$){typeof $app$main$data$workspace$variants$combine_selected_as_variants_71768$$==="undefined"&&($app$main$data$workspace$variants$combine_selected_as_variants_71768$$=function($options$jscomp$578$$,$meta71769$$){this.options=$options$jscomp$578$$;this.$meta71769$=$meta71769$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$variants$combine_selected_as_variants_71768$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$combine_selected_as_variants_71768$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4511$app_DOT_main_DOT_data_DOT_workspace_DOT_variants_SLASH_combine_selected_as_variants$$},$app$main$data$workspace$variants$combine_selected_as_variants_71768$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_71770$$,$meta71769__$1$$){return new $app$main$data$workspace$variants$combine_selected_as_variants_71768$$(this.options,
$meta71769__$1$$)},$app$main$data$workspace$variants$combine_selected_as_variants_71768$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta71769$},$app$main$data$workspace$variants$combine_selected_as_variants_71768$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$variants$combine_selected_as_variants_71768$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2528_selected$jscomp$97$$,$state$jscomp$867$$){$_$jscomp$2528_selected$jscomp$97$$=
$APP.$app$main$data$helpers$lookup_selected$cljs$0core$0IFn$0_invoke$0arity$01$$($state$jscomp$867$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$variants$combine_as_variants$$($_$jscomp$2528_selected$jscomp$97$$,this.options))});return new $app$main$data$workspace$variants$combine_selected_as_variants_71768$$($options$jscomp$577$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$upload_fill_image$$=function($file$jscomp$60$$,$on_success$jscomp$26$$){typeof $app$main$data$workspace$media$upload_fill_image_67897$$==="undefined"&&($app$main$data$workspace$media$upload_fill_image_67897$$=function($file$jscomp$61$$,$on_success$jscomp$27$$,$meta67898$$){this.file=$file$jscomp$61$$;this.$on_success$=$on_success$jscomp$27$$;this.$meta67898$=$meta67898$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},
$app$main$data$workspace$media$upload_fill_image_67897$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$upload_fill_image_67897$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3756$app_DOT_main_DOT_data_DOT_workspace_DOT_media_SLASH_upload_fill_image$$},$app$main$data$workspace$media$upload_fill_image_67897$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_67899$$,$meta67898__$1$$){return new $app$main$data$workspace$media$upload_fill_image_67897$$(this.file,
this.$on_success$,$meta67898__$1$$)},$app$main$data$workspace$media$upload_fill_image_67897$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta67898$},$app$main$data$workspace$media$upload_fill_image_67897$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$media$upload_fill_image_67897$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$1990$$,$state$jscomp$413$$){var $self__$jscomp$4430$$=this,$file_id$jscomp$107$$=
$APP.$cljs$cst$1934$current_file_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$413$$);$APP.$app$main$data$media$notify_start_loading$$();return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$media$handle_media_error$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($image$jscomp$23$$){$self__$jscomp$4430$$.$on_success$.$cljs$core$IFn$_invoke$arity$1$?$self__$jscomp$4430$$.$on_success$.$cljs$core$IFn$_invoke$arity$1$($image$jscomp$23$$):
$self__$jscomp$4430$$.$on_success$($image$jscomp$23$$);return $APP.$app$main$data$media$notify_finished_loading$$()},$APP.$beicon$v2$core$mapcat$$(function($p1__67896_SHARP_$$){return $APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2291$upload_file_media_object$$,$p1__67896_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($content$jscomp$161$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$107$$,$APP.$cljs$cst$725$name$$,
$APP.$app$main$data$media$file_QMARK_$$($content$jscomp$161$$)?$content$jscomp$161$$.name:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image"),$APP.$cljs$cst$2585$is_local$$,!1,$APP.$cljs$cst$1642$content$$,$content$jscomp$161$$],null)},$APP.$beicon$v2$core$map$$($APP.$app$main$data$media$validate_file$$,(0,$APP.$beicon$v2$core$of$$)($self__$jscomp$4430$$.file))))))});return new $app$main$data$workspace$media$upload_fill_image_67897$$($file$jscomp$60$$,$on_success$jscomp$26$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$media$upload_media_components$$=function($params$jscomp$258_params__$1$jscomp$37$$){$params$jscomp$258_params__$1$jscomp$37$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($params$jscomp$258_params__$1$jscomp$37$$,$APP.$cljs$cst$3743$local_QMARK_$$,!1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3745$on_image$$,function($p1__67925_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$media$process_img_component$$($p1__67925_SHARP_$$))},
$APP.$cljs$cst$3746$on_svg$$,function($p1__67926_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$media$process_svg_component$$($p1__67926_SHARP_$$))}]));return $APP.$app$main$data$workspace$media$process_media_objects$$($params$jscomp$258_params__$1$jscomp$37$$)};
$app$main$data$workspace$clipboard$paste_from_event$$=function($event$jscomp$96$$,$in_viewport_QMARK_$jscomp$1$$){typeof $app$main$data$workspace$clipboard$paste_from_event_70783$$==="undefined"&&($app$main$data$workspace$clipboard$paste_from_event_70783$$=function($event$jscomp$97$$,$in_viewport_QMARK_$jscomp$2$$,$meta70784$$){this.event=$event$jscomp$97$$;this.$in_viewport_QMARK_$=$in_viewport_QMARK_$jscomp$2$$;this.$meta70784$=$meta70784$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=
0},$app$main$data$workspace$clipboard$paste_from_event_70783$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_from_event_70783$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4171$app_DOT_main_DOT_data_DOT_workspace_DOT_clipboard_SLASH_paste_from_event$$},$app$main$data$workspace$clipboard$paste_from_event_70783$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70785$$,$meta70784__$1$$){return new $app$main$data$workspace$clipboard$paste_from_event_70783$$(this.event,
this.$in_viewport_QMARK_$,$meta70784__$1$$)},$app$main$data$workspace$clipboard$paste_from_event_70783$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70784$},$app$main$data$workspace$clipboard$paste_from_event_70783$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$clipboard$paste_from_event_70783$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$,
$JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$){$JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$);$JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$,$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2207$edition$$);$JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$,$APP.$cljs$cst$139$type$$],null))):
$JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$;if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$))$JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$=$APP.$beicon$v2$core$empty$$();else{$JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$=
$APP.$app$main$data$workspace$clipboard$create_paste_from_blob$$(this.$in_viewport_QMARK_$,!1);$JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$=this.event;var $is_input_QMARK_$jscomp$inline_13647_target$jscomp$inline_13645$$=$APP.$app$util$dom$get_target$$($JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$),$content_editable_QMARK_$jscomp$inline_13646$$=$is_input_QMARK_$jscomp$inline_13647_target$jscomp$inline_13645$$.isContentEditable;
$is_input_QMARK_$jscomp$inline_13647_target$jscomp$inline_13645$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_tag_name$$($is_input_QMARK_$jscomp$inline_13647_target$jscomp$inline_13645$$),"INPUT");$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($content_editable_QMARK_$jscomp$inline_13646$$)?$content_editable_QMARK_$jscomp$inline_13646$$:$is_input_QMARK_$jscomp$inline_13647_target$jscomp$inline_13645$$)?($JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$=
$JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$.getBrowserEvent(),$JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$=$APP.$app$util$clipboard$from_data_transfer$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$.clipboardData,$APP.$app$main$data$workspace$clipboard$default_options$$)):
$JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$=$APP.$beicon$v2$core$empty$$();$JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$=$APP.$beicon$v2$core$mapcat$$($JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$,$JSCompiler_temp$jscomp$14327__$jscomp$2229_event$jscomp$inline_13644_event$jscomp$inline_14898_objects$jscomp$585$$)}return $JSCompiler_temp$jscomp$11222_JSCompiler_temp_const$jscomp$11223_edit_id$jscomp$1_is_editing_QMARK__state$jscomp$614$$});
return new $app$main$data$workspace$clipboard$paste_from_event_70783$$($event$jscomp$96$$,$in_viewport_QMARK_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$shortcuts$get_tooltip$$=function($shortcut$jscomp$3$$){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$shortcuts$shortcuts$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shortcut$jscomp$3$$,$APP.$cljs$cst$2957$tooltip$$],null))};
$cljs$spec$alpha$explain_printer$$=function($ed$jscomp$1$$){if($APP.$cljs$core$truth_$$($ed$jscomp$1$$)){var $problems$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__33783_SHARP_$$){return-$APP.$cljs$core$count$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__33783_SHARP_$$))},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__33782_SHARP_$$){return-$APP.$cljs$core$count$$($APP.$cljs$cst$297$in$$.$cljs$core$IFn$_invoke$arity$1$($p1__33782_SHARP_$$))},
$APP.$cljs$cst$981$cljs_DOT_spec_DOT_alpha_SLASH_problems$$.$cljs$core$IFn$_invoke$arity$1$($ed$jscomp$1$$)));$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([function(){var $sb__5670__auto__$jscomp$2$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__33786_34821$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__33787_34822$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=
!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$2$$){return $sb__5670__auto__$jscomp$2$$.append($x__5671__auto__$jscomp$2$$)};try{for(var $seq__33793_34825$$=$APP.$cljs$core$seq$$($problems$$),$chunk__33794_34826$$=null,$count__33795_34827$$=0,$i__33796_34828$$=0;;)if($i__33796_34828$$<$count__33795_34827$$){var $map__33843_34834$$=$chunk__33794_34826$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__33796_34828$$),$map__33843_34835__$1$$=$APP.$cljs$core$__destructure_map$$($map__33843_34834$$),
$G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$=$map__33843_34835__$1$$,$path_34837$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33843_34835__$1$$,$APP.$cljs$cst$296$path$$),$pred_34838$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33843_34835__$1$$,$APP.$cljs$cst$351$pred$$),$val_34839$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33843_34835__$1$$,$APP.$cljs$cst$108$val$$),$reason_34840$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33843_34835__$1$$,
$APP.$cljs$cst$984$reason$$),$via_34841$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33843_34835__$1$$,$APP.$cljs$cst$143$via$$),$in_34842$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33843_34835__$1$$,$APP.$cljs$cst$297$in$$);$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$val_34839$$]));$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([" - failed: "]));
$APP.$cljs$core$truth_$$($reason_34840$$)?$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$reason_34840$$])):$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$spec$alpha$abbrev$$($pred_34838$$)]));$APP.$cljs$core$empty_QMARK_$$($in_34842$$)||$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" in: ",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$in_34842$$]))].join("")]));$APP.$cljs$core$empty_QMARK_$$($path_34837$$)||$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" at: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$path_34837$$]))].join("")]));$APP.$cljs$core$empty_QMARK_$$($via_34841$$)||
$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" spec: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$last$$($via_34841$$)]))].join("")]));var $seq__33844_34847$$=$APP.$cljs$core$seq$$($G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$);$G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$=null;for(var $chunk__33882_34912_count__33846_34849_prob_34899$$=
0,$count__33883_34913_i__33847_34850$$=0;;)if($count__33883_34913_i__33847_34850$$<$chunk__33882_34912_count__33846_34849_prob_34899$$){var $vec__33860_34851$$=$G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$count__33883_34913_i__33847_34850$$),$k_34852$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33860_34851$$,0,null),$v_34853$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33860_34851$$,1,null);$APP.$cljs$core$truth_$$(function(){var $fexpr__33863$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$351$pred$$,null,$APP.$cljs$cst$143$via$$,null,$APP.$cljs$cst$108$val$$,null,$APP.$cljs$cst$984$reason$$,null,$APP.$cljs$cst$297$in$$,null],null),null);return $fexpr__33863$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33863$$.$cljs$core$IFn$_invoke$arity$1$($k_34852$$):$fexpr__33863$$($k_34852$$)}())||($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\n\t",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_34852$$]))," "])),$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v_34853$$])));$count__33883_34913_i__33847_34850$$+=1}else{var $temp__5825__auto___34861$$=$APP.$cljs$core$seq$$($seq__33844_34847$$);if($temp__5825__auto___34861$$){var $G__34867_i__33884_34914_seq__33844_34862__$1$$=$temp__5825__auto___34861$$;
if($APP.$cljs$core$chunked_seq_QMARK_$$($G__34867_i__33884_34914_seq__33844_34862__$1$$)){var $c__5548__auto___34863$$=$APP.$cljs$core$_chunked_first$$($G__34867_i__33884_34914_seq__33844_34862__$1$$),$G__34866$$=$APP.$cljs$core$_chunked_rest$$($G__34867_i__33884_34914_seq__33844_34862__$1$$);$G__34867_i__33884_34914_seq__33844_34862__$1$$=$c__5548__auto___34863$$;var $G__34868$$=$APP.$cljs$core$count$$($c__5548__auto___34863$$);$seq__33844_34847$$=$G__34866$$;$G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$=
$G__34867_i__33884_34914_seq__33844_34862__$1$$;$chunk__33882_34912_count__33846_34849_prob_34899$$=$G__34868$$}else{var $vec__33871_34870$$=$APP.$cljs$core$first$$($G__34867_i__33884_34914_seq__33844_34862__$1$$),$k_34871$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33871_34870$$,0,null),$v_34872$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33871_34870$$,1,null);$APP.$cljs$core$truth_$$(function(){var $fexpr__33875$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$351$pred$$,null,$APP.$cljs$cst$143$via$$,null,$APP.$cljs$cst$108$val$$,null,$APP.$cljs$cst$984$reason$$,null,$APP.$cljs$cst$297$in$$,null],null),null);return $fexpr__33875$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33875$$.$cljs$core$IFn$_invoke$arity$1$($k_34871$$):$fexpr__33875$$($k_34871$$)}())||($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\n\t",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_34871$$]))," "])),$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v_34872$$])));$seq__33844_34847$$=$APP.$cljs$core$next$$($G__34867_i__33884_34914_seq__33844_34862__$1$$);$G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$=null;$chunk__33882_34912_count__33846_34849_prob_34899$$=
0}$count__33883_34913_i__33847_34850$$=0}else break}$APP.$cljs$core$newline$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$i__33796_34828$$+=1}else{var $temp__5825__auto___34889$$=$APP.$cljs$core$seq$$($seq__33793_34825$$);if($temp__5825__auto___34889$$){$G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$=$temp__5825__auto___34889$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$)){var $c__5548__auto___34892$$=$APP.$cljs$core$_chunked_first$$($G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$),
$G__34893$$=$APP.$cljs$core$_chunked_rest$$($G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$);$G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$=$c__5548__auto___34892$$;var $G__34895$$=$APP.$cljs$core$count$$($c__5548__auto___34892$$);$seq__33793_34825$$=$G__34893$$;$chunk__33794_34826$$=$G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$;$count__33795_34827$$=$G__34895$$}else{var $map__33876_34897$$=$APP.$cljs$core$first$$($G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$),
$map__33876_34898__$1$$=$APP.$cljs$core$__destructure_map$$($map__33876_34897$$);$chunk__33882_34912_count__33846_34849_prob_34899$$=$map__33876_34898__$1$$;var $path_34900$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33876_34898__$1$$,$APP.$cljs$cst$296$path$$),$pred_34901$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33876_34898__$1$$,$APP.$cljs$cst$351$pred$$),$val_34902$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33876_34898__$1$$,$APP.$cljs$cst$108$val$$),
$reason_34903$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33876_34898__$1$$,$APP.$cljs$cst$984$reason$$),$via_34904$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33876_34898__$1$$,$APP.$cljs$cst$143$via$$),$in_34905$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__33876_34898__$1$$,$APP.$cljs$cst$297$in$$);$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$val_34902$$]));$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([" - failed: "]));
$APP.$cljs$core$truth_$$($reason_34903$$)?$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$reason_34903$$])):$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$spec$alpha$abbrev$$($pred_34901$$)]));$APP.$cljs$core$empty_QMARK_$$($in_34905$$)||$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" in: ",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$in_34905$$]))].join("")]));$APP.$cljs$core$empty_QMARK_$$($path_34900$$)||$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" at: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$path_34900$$]))].join("")]));$APP.$cljs$core$empty_QMARK_$$($via_34904$$)||
$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([[" spec: ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$last$$($via_34904$$)]))].join("")]));var $seq__33881_34911$$=$APP.$cljs$core$seq$$($chunk__33882_34912_count__33846_34849_prob_34899$$);$chunk__33882_34912_count__33846_34849_prob_34899$$=null;for($G__34867_i__33884_34914_seq__33844_34862__$1$$=
$count__33883_34913_i__33847_34850$$=0;;)if($G__34867_i__33884_34914_seq__33844_34862__$1$$<$count__33883_34913_i__33847_34850$$){var $vec__33898_34915$$=$chunk__33882_34912_count__33846_34849_prob_34899$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__34867_i__33884_34914_seq__33844_34862__$1$$),$k_34916$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33898_34915$$,0,null),$v_34917$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33898_34915$$,1,null);$APP.$cljs$core$truth_$$(function(){var $fexpr__33901$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$351$pred$$,null,$APP.$cljs$cst$143$via$$,null,$APP.$cljs$cst$108$val$$,null,$APP.$cljs$cst$984$reason$$,null,$APP.$cljs$cst$297$in$$,null],null),null);return $fexpr__33901$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33901$$.$cljs$core$IFn$_invoke$arity$1$($k_34916$$):$fexpr__33901$$($k_34916$$)}())||($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\n\t",
$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_34916$$]))," "])),$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v_34917$$])));$G__34867_i__33884_34914_seq__33844_34862__$1$$+=1}else{var $temp__5825__auto___34924__$1$$=$APP.$cljs$core$seq$$($seq__33881_34911$$);if($temp__5825__auto___34924__$1$$){var $G__34930_seq__33881_34926__$1$$=$temp__5825__auto___34924__$1$$;
if($APP.$cljs$core$chunked_seq_QMARK_$$($G__34930_seq__33881_34926__$1$$)){var $c__5548__auto___34928$$=$APP.$cljs$core$_chunked_first$$($G__34930_seq__33881_34926__$1$$),$G__34929$$=$APP.$cljs$core$_chunked_rest$$($G__34930_seq__33881_34926__$1$$);$G__34930_seq__33881_34926__$1$$=$c__5548__auto___34928$$;var $G__34931$$=$APP.$cljs$core$count$$($c__5548__auto___34928$$);$seq__33881_34911$$=$G__34929$$;$chunk__33882_34912_count__33846_34849_prob_34899$$=$G__34930_seq__33881_34926__$1$$;$count__33883_34913_i__33847_34850$$=
$G__34931$$}else{var $vec__33902_34933$$=$APP.$cljs$core$first$$($G__34930_seq__33881_34926__$1$$),$k_34934$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33902_34933$$,0,null),$v_34935$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__33902_34933$$,1,null);$APP.$cljs$core$truth_$$(function(){var $fexpr__33905$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$351$pred$$,null,
$APP.$cljs$cst$143$via$$,null,$APP.$cljs$cst$108$val$$,null,$APP.$cljs$cst$984$reason$$,null,$APP.$cljs$cst$297$in$$,null],null),null);return $fexpr__33905$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__33905$$.$cljs$core$IFn$_invoke$arity$1$($k_34934$$):$fexpr__33905$$($k_34934$$)}())||($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["\n\t",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$k_34934$$])),
" "])),$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v_34935$$])));$seq__33881_34911$$=$APP.$cljs$core$next$$($G__34930_seq__33881_34926__$1$$);$chunk__33882_34912_count__33846_34849_prob_34899$$=null;$count__33883_34913_i__33847_34850$$=0}$G__34867_i__33884_34914_seq__33844_34862__$1$$=0}else break}$APP.$cljs$core$newline$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$seq__33793_34825$$=$APP.$cljs$core$next$$($G__34894_chunk__33845_34848_prob_34836_seq__33793_34891__$1$$);
$chunk__33794_34826$$=null;$count__33795_34827$$=0}$i__33796_34828$$=0}else break}}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__33787_34822$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__33786_34821$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$2$$)}()]))}else $APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Success!"]))};
$cljs$spec$alpha$assert_STAR_$$=function($spec$jscomp$45$$,$x$jscomp$940$$){if(!$APP.$cljs$spec$alpha$valid_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($spec$jscomp$45$$,$x$jscomp$940$$)){var $ed$jscomp$4$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cljs$spec$alpha$explain_data_STAR_$$($spec$jscomp$45$$,$x$jscomp$940$$),$APP.$cljs$cst$1132$cljs_DOT_spec_DOT_alpha_SLASH_failure$$,
$APP.$cljs$cst$1133$assertion_failed$$)]));throw Error(["Spec assertion failed\n",function(){var $sb__5670__auto__$jscomp$4$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__34749_35460$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__34750_35461$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$4$$){return $sb__5670__auto__$jscomp$4$$.append($x__5671__auto__$jscomp$4$$)};
try{$cljs$spec$alpha$explain_printer$$.call(null,$ed$jscomp$4$$)}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__34750_35461$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__34749_35460$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$4$$)}()].join(""));}};
$app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$=function($val$jscomp$198$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($val$jscomp$198$$),"#")?$val$jscomp$198$$:["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$198$$)].join("")};
$app$main$ui$workspace$colorpicker$color_inputs$color_inputs_STAR_$$=function($props_75947_red$jscomp$4$$){function $on_key_down_property$$($property$jscomp$80$$,$max_value$jscomp$2$$){return $on_key_down_step$$($max_value$jscomp$2$$,function($p1__75942_SHARP_$$){return $apply_property_change$$($property$jscomp$80$$,$p1__75942_SHARP_$$)})}function $on_key_down_step$$($max_value$jscomp$1$$,$on_step$$){return function($e$jscomp$345$$){var $new_value$jscomp$9_up_QMARK_$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($e$jscomp$345$$),
$and__5023__auto__$jscomp$inline_13651_down_QMARK__temp__5825__auto__$jscomp$336$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($e$jscomp$345$$);$and__5023__auto__$jscomp$inline_13651_down_QMARK__temp__5825__auto__$jscomp$336$$=$APP.$cljs$core$truth_$$($new_value$jscomp$9_up_QMARK_$$)?$new_value$jscomp$9_up_QMARK_$$:$and__5023__auto__$jscomp$inline_13651_down_QMARK__temp__5825__auto__$jscomp$336$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13651_down_QMARK__temp__5825__auto__$jscomp$336$$)?
$e$jscomp$345$$.shiftKey||$e$jscomp$345$$.altKey:$and__5023__auto__$jscomp$inline_13651_down_QMARK__temp__5825__auto__$jscomp$336$$)&&($APP.$app$util$dom$prevent_default$$($e$jscomp$345$$),$and__5023__auto__$jscomp$inline_13651_down_QMARK__temp__5825__auto__$jscomp$336$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$345$$)),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13651_down_QMARK__temp__5825__auto__$jscomp$336$$))?
($new_value$jscomp$9_up_QMARK_$$=$APP.$app$common$math$clamp$$($and__5023__auto__$jscomp$inline_13651_down_QMARK__temp__5825__auto__$jscomp$336$$+($e$jscomp$345$$.shiftKey?$APP.$cljs$core$truth_$$($new_value$jscomp$9_up_QMARK_$$)?10:-10:$e$jscomp$345$$.altKey?$APP.$cljs$core$truth_$$($new_value$jscomp$9_up_QMARK_$$)?.1:-.1:null),0,$max_value$jscomp$1$$),$app$util$dom$set_value_BANG_$$($APP.$app$util$dom$get_target$$($e$jscomp$345$$),$new_value$jscomp$9_up_QMARK_$$),$on_step$$.$cljs$core$IFn$_invoke$arity$1$?
$on_step$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$9_up_QMARK_$$):$on_step$$($new_value$jscomp$9_up_QMARK_$$)):null}}function $on_change_property$$($property$jscomp$79$$,$max_value$$){return function($e$jscomp$344_val$jscomp$204$$){$e$jscomp$344_val$jscomp$204$$=$APP.$app$common$math$clamp$$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$344_val$jscomp$204$$)),0,$max_value$$);return $e$jscomp$344_val$jscomp$204$$!=null?
$apply_property_change$$($property$jscomp$79$$,$e$jscomp$344_val$jscomp$204$$):null}}function $apply_property_change$$($property$jscomp$78$$,$val$jscomp$203$$){var $g$jscomp$142_new_l_val__$1$jscomp$15$$=function(){switch($property$jscomp$78$$ instanceof $APP.$cljs$core$Keyword$$?$property$jscomp$78$$.$fqn$:null){case "s":return $val$jscomp$203$$/100;case "v":return $val$jscomp$203$$/100*255;case "hsl-s":case "hsl-l":return $val$jscomp$203$$/100;case "alpha":return $val$jscomp$203$$/100;default:return $val$jscomp$203$$}}();
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($property$jscomp$78$$,$APP.$cljs$cst$746$alpha$$)){var $G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$746$alpha$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$],null);return $on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$):
$on_change$jscomp$35$$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$)}if($APP.$cljs$core$truth_$$(function(){var $fexpr__75970$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1749$r$$,null,$APP.$cljs$cst$1750$g$$,null,$APP.$cljs$cst$1525$b$$,null],null),null);return $fexpr__75970$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__75970$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$78$$):$fexpr__75970$$($property$jscomp$78$$)}())){$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$color$jscomp$135$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$property$jscomp$78$$],[$g$jscomp$142_new_l_val__$1$jscomp$15$$])]));var $h$jscomp$169_map__75971__$1_vec__75977$$=$APP.$cljs$core$__destructure_map$$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$);$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$169_map__75971__$1_vec__75977$$,$APP.$cljs$cst$1749$r$$);$g$jscomp$142_new_l_val__$1$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$169_map__75971__$1_vec__75977$$,$APP.$cljs$cst$1750$g$$);var $b$jscomp$342_vec__75985$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$169_map__75971__$1_vec__75977$$,$APP.$cljs$cst$1525$b$$),$hex__$1$jscomp$2$$=$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$,$b$jscomp$342_vec__75985$$],null)),$v$jscomp$638_vec__75972_vec__75980$$=$app$common$types$color$hex__GT_hsv$$($hex__$1$jscomp$2$$);$h$jscomp$169_map__75971__$1_vec__75977$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$638_vec__75972_vec__75980$$,0,null);var $s$jscomp$564$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$638_vec__75972_vec__75980$$,
1,null);$v$jscomp$638_vec__75972_vec__75980$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$638_vec__75972_vec__75980$$,2,null);$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2698$hex$$,$hex__$1$jscomp$2$$,$APP.$cljs$cst$1907$h$$,$h$jscomp$169_map__75971__$1_vec__75977$$,$APP.$cljs$cst$4235$s$$,$s$jscomp$564$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$638_vec__75972_vec__75980$$,
$APP.$cljs$cst$1749$r$$,$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$342_vec__75985$$],null);return $on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$):$on_change$jscomp$35$$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$)}if($APP.$cljs$core$truth_$$(function(){var $fexpr__75976$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5531$hsl_l$$,null,$cljs$cst$5532$hsl_s$$,null],null),null);return $fexpr__75976$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__75976$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$78$$):$fexpr__75976$$($property$jscomp$78$$)}()))return $G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($property$jscomp$78$$,
$cljs$cst$5532$hsl_s$$)?$g$jscomp$142_new_l_val__$1$jscomp$15$$:$hsl_s$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($property$jscomp$78$$,$cljs$cst$5531$hsl_l$$)?$g$jscomp$142_new_l_val__$1$jscomp$15$$:$hsl_l$$,$h$jscomp$169_map__75971__$1_vec__75977$$=$app$common$types$color$hsl__GT_rgb$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$1$$,$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,
$g$jscomp$142_new_l_val__$1$jscomp$15$$],null)),$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h$jscomp$169_map__75971__$1_vec__75977$$,0,null),$g$jscomp$142_new_l_val__$1$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h$jscomp$169_map__75971__$1_vec__75977$$,1,null),$b$jscomp$342_vec__75985$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($h$jscomp$169_map__75971__$1_vec__75977$$,
2,null),$hex__$1$jscomp$2$$=$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$,$b$jscomp$342_vec__75985$$],null)),$v$jscomp$638_vec__75972_vec__75980$$=$app$common$types$color$hex__GT_hsv$$($hex__$1$jscomp$2$$),$h$jscomp$169_map__75971__$1_vec__75977$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$638_vec__75972_vec__75980$$,
0,null),$s$jscomp$564$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$638_vec__75972_vec__75980$$,1,null),$v$jscomp$638_vec__75972_vec__75980$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$638_vec__75972_vec__75980$$,2,null),$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2698$hex$$,$hex__$1$jscomp$2$$,$APP.$cljs$cst$1907$h$$,$h$jscomp$169_map__75971__$1_vec__75977$$,
$APP.$cljs$cst$4235$s$$,$s$jscomp$564$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$638_vec__75972_vec__75980$$,$APP.$cljs$cst$1749$r$$,$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$142_new_l_val__$1$jscomp$15$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$342_vec__75985$$],null),$on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$):
$on_change$jscomp$35$$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$);$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$color$jscomp$135$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$property$jscomp$78$$],[$g$jscomp$142_new_l_val__$1$jscomp$15$$])]));$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=
$APP.$cljs$core$__destructure_map$$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$);$h$jscomp$169_map__75971__$1_vec__75977$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$1907$h$$);$s$jscomp$564$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,
$APP.$cljs$cst$4235$s$$);$v$jscomp$638_vec__75972_vec__75980$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$3723$v$$);$hex__$1$jscomp$2$$=$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$169_map__75971__$1_vec__75977$$,$s$jscomp$564$$,$v$jscomp$638_vec__75972_vec__75980$$],null));$b$jscomp$342_vec__75985$$=
$APP.$app$common$types$color$hex__GT_rgb$$($hex__$1$jscomp$2$$);$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$342_vec__75985$$,0,null);$g$jscomp$142_new_l_val__$1$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$342_vec__75985$$,1,null);$b$jscomp$342_vec__75985$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$342_vec__75985$$,2,null);
$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2698$hex$$,$hex__$1$jscomp$2$$,$APP.$cljs$cst$1907$h$$,$h$jscomp$169_map__75971__$1_vec__75977$$,$APP.$cljs$cst$4235$s$$,$s$jscomp$564$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$638_vec__75972_vec__75980$$,$APP.$cljs$cst$1749$r$$,$G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$,$APP.$cljs$cst$1750$g$$,
$g$jscomp$142_new_l_val__$1$jscomp$15$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$342_vec__75985$$],null);return $on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$):$on_change$jscomp$35$$($G__75968_G__75975_G__75983_G__75988_map__75971_map__75984_map__75984__$1_new_s_r$jscomp$121$$)}function $setup_hex_color$$($G__75964_hex__$1$jscomp$1$$){var $b$jscomp$341_vec__75957$$=
$APP.$app$common$types$color$hex__GT_rgb$$($G__75964_hex__$1$jscomp$1$$),$r$jscomp$120$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$341_vec__75957$$,0,null),$g$jscomp$141$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$341_vec__75957$$,1,null);$b$jscomp$341_vec__75957$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$341_vec__75957$$,2,null);var $v$jscomp$637_vec__75960$$=$app$common$types$color$hex__GT_hsv$$($G__75964_hex__$1$jscomp$1$$),
$h$jscomp$168$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$637_vec__75960$$,0,null),$s$jscomp$563$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$637_vec__75960$$,1,null);$v$jscomp$637_vec__75960$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$637_vec__75960$$,2,null);$G__75964_hex__$1$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2698$hex$$,$G__75964_hex__$1$jscomp$1$$,$APP.$cljs$cst$1907$h$$,$h$jscomp$168$$,
$APP.$cljs$cst$4235$s$$,$s$jscomp$563$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$637_vec__75960$$,$APP.$cljs$cst$1749$r$$,$r$jscomp$120$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$141$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$341_vec__75957$$],null);return $on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$35$$.$cljs$core$IFn$_invoke$arity$1$($G__75964_hex__$1$jscomp$1$$):$on_change$jscomp$35$$($G__75964_hex__$1$jscomp$1$$)}var $on_change$jscomp$35$$=$props_75947_red$jscomp$4$$.onChange,$disable_opacity$$=
$props_75947_red$jscomp$4$$.disableOpacity,$color$jscomp$135$$=$props_75947_red$jscomp$4$$.color,$hsb_mode_mode$jscomp$47$$=$props_75947_red$jscomp$4$$.mode,$on_mode_change$$=$props_75947_red$jscomp$4$$.onModeChange,$type$jscomp$609$$=$props_75947_red$jscomp$4$$.type,$alpha$jscomp$14_map__75951__$1$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$135$$);$props_75947_red$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$1749$r$$);var $green$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$1750$g$$),$blue$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$1525$b$$),$hue$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$1907$h$$),$saturation$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$4235$s$$),$value$jscomp$787$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$3723$v$$),$hex$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$2698$hex$$);$alpha$jscomp$14_map__75951__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$746$alpha$$);$hsb_mode_mode$jscomp$47$$=$APP.$cljs$core$truth_$$($hsb_mode_mode$jscomp$47$$)?$hsb_mode_mode$jscomp$47$$:
$cljs$cst$5530$hsb$$;var $vec__75952$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_75947_red$jscomp$4$$)?$APP.$cljs$core$truth_$$($green$jscomp$4$$)?$blue$jscomp$4$$:$green$jscomp$4$$:$props_75947_red$jscomp$4$$)?$APP.$app$common$types$color$rgb__GT_hsl$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$props_75947_red$jscomp$4$$,$green$jscomp$4$$,$blue$jscomp$4$$],null)):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[0,0,0],null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75952$$,0,null);var $hsl_s$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75952$$,1,null),$hsl_l$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__75952$$,2,null),$refs$jscomp$2$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1749$r$$,$APP.$cljs$cst$3723$v$$,$APP.$cljs$cst$4235$s$$,$cljs$cst$5531$hsl_l$$,$APP.$cljs$cst$1750$g$$,$APP.$cljs$cst$2698$hex$$,$APP.$cljs$cst$1907$h$$,
$APP.$cljs$cst$1525$b$$,$APP.$cljs$cst$746$alpha$$,$cljs$cst$5532$hsl_s$$],[(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null),(0,$APP.$rumext$v2$use_ref$$)(null)]);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$135$$),
$APP.$rumext$v2$adapt$$($type$jscomp$609$$),$APP.$rumext$v2$adapt$$($hsb_mode_mode$jscomp$47$$)],function(){for(var $G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$=$APP.$cljs$core$seq$$($APP.$cljs$core$keys$$($refs$jscomp$2$$)),$G__76041_chunk__75990_node_76048_temp__5825__auto___76047__$1$$=null,$G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$=0,$i__75992$$=0;;)if($i__75992$$<$G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$){var $ref_key$jscomp$1$$=
$G__76041_chunk__75990_node_76048_temp__5825__auto___76047__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__75992$$),$property_val_76028$$=function(){var $G__76002$$=$ref_key$jscomp$1$$;switch($G__76002$$ instanceof $APP.$cljs$core$Keyword$$?$G__76002$$.$fqn$:null){case "hsl-s":return $hsl_s$$;case "hsl-l":return $hsl_l$$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$135$$,$ref_key$jscomp$1$$)}}(),$property_ref_76029$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($refs$jscomp$2$$,
$ref_key$jscomp$1$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$723$$=$property_val_76028$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$723$$)?$property_ref_76029$$:$and__5023__auto__$jscomp$723$$}())){var $node_76032_temp__5825__auto___76031$$=$APP.$rumext$v2$ref_val$$($property_ref_76029$$);if($APP.$cljs$core$truth_$$($node_76032_temp__5825__auto___76031$$)){var $new_val_76033$$=function(){var $G__76003$$=$ref_key$jscomp$1$$;switch($G__76003$$ instanceof $APP.$cljs$core$Keyword$$?
$G__76003$$.$fqn$:null){case "s":case "alpha":return $APP.$app$common$math$precision$$($property_val_76028$$*100,2);case "v":return $APP.$app$common$math$precision$$($property_val_76028$$/255*100,2);case "hsl-s":case "hsl-l":return $APP.$app$common$math$precision$$($property_val_76028$$*100,2);default:return $property_val_76028$$}}();$app$util$dom$set_value_BANG_$$($node_76032_temp__5825__auto___76031$$,$new_val_76033$$)}}$i__75992$$+=1}else if($G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$=
$APP.$cljs$core$seq$$($G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$))$G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$=$APP.$cljs$core$_chunked_first$$($G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$),$G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$=$APP.$cljs$core$_chunked_rest$$($G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$),
$G__76041_chunk__75990_node_76048_temp__5825__auto___76047__$1$$=$G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$,$G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$=$APP.$cljs$core$count$$($G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$);else{$ref_key$jscomp$1$$=$APP.$cljs$core$first$$($G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$);var $property_val_76044$$=function(){var $G__76005$$=$ref_key$jscomp$1$$;switch($G__76005$$ instanceof
$APP.$cljs$core$Keyword$$?$G__76005$$.$fqn$:null){case "hsl-s":return $hsl_s$$;case "hsl-l":return $hsl_l$$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$135$$,$ref_key$jscomp$1$$)}}(),$property_ref_76045$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($refs$jscomp$2$$,$ref_key$jscomp$1$$);$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$724$$=$property_val_76044$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$724$$)?$property_ref_76045$$:
$and__5023__auto__$jscomp$724$$}())&&($G__76041_chunk__75990_node_76048_temp__5825__auto___76047__$1$$=$APP.$rumext$v2$ref_val$$($property_ref_76045$$),$APP.$cljs$core$truth_$$($G__76041_chunk__75990_node_76048_temp__5825__auto___76047__$1$$)&&($G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$=function(){var $G__76007$$=$ref_key$jscomp$1$$;switch($G__76007$$ instanceof $APP.$cljs$core$Keyword$$?$G__76007$$.$fqn$:null){case "s":case "alpha":return $APP.$app$common$math$precision$$($property_val_76044$$*
100,2);case "v":return $APP.$app$common$math$precision$$($property_val_76044$$/255*100,2);case "hsl-s":case "hsl-l":return $APP.$app$common$math$precision$$($property_val_76044$$*100,2);default:return $property_val_76044$$}}(),$app$util$dom$set_value_BANG_$$($G__76041_chunk__75990_node_76048_temp__5825__auto___76047__$1$$,$G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$)));$G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$=$APP.$cljs$core$next$$($G__76040_seq__75989_seq__75989__$1_temp__5825__auto__$jscomp$337$$);
$G__76041_chunk__75990_node_76048_temp__5825__auto___76047__$1$$=null;$G__76042_c__5548__auto__$jscomp$40_count__75991_new_val_76049$$=0}$i__75992$$=0}else return null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__color-values "+($APP.$cljs$core$truth_$$($disable_opacity$$)?"main_ui_workspace_colorpicker_color_inputs__disable-opacity":""),children:[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$725$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$609$$,
$cljs$cst$5533$rgb$$);return $and__5023__auto__$jscomp$725$$?$on_mode_change$$:$and__5023__auto__$jscomp$725$$}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__model-switcher",children:[(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",onClick:function(){return $on_mode_change$$.$cljs$core$IFn$_invoke$arity$1$?$on_mode_change$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5530$hsb$$):$on_mode_change$$($cljs$cst$5530$hsb$$)},className:"main_ui_workspace_colorpicker_color_inputs__model-pill "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hsb_mode_mode$jscomp$47$$,$cljs$cst$5530$hsb$$)?"main_ui_workspace_colorpicker_color_inputs__model-pill-active":""),children:"HSB"}),(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",onClick:function(){return $on_mode_change$$.$cljs$core$IFn$_invoke$arity$1$?$on_mode_change$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5534$hsl$$):$on_mode_change$$($cljs$cst$5534$hsl$$)},className:"main_ui_workspace_colorpicker_color_inputs__model-pill "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hsb_mode_mode$jscomp$47$$,
$cljs$cst$5534$hsl$$)?"main_ui_workspace_colorpicker_color_inputs__model-pill-active":""),children:"HSL"})]}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__colors-row",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$609$$,$cljs$cst$5533$rgb$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$1749$r$$,
255),"aria-label":"Red",max:255,id:"red-value",property:"Red",type:"number",ref:$APP.$cljs$cst$1749$r$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),defaultValue:$props_75947_red$jscomp$4$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1749$r$$,255),icon:"character-r"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$1750$g$$,255),"aria-label":"Green",max:255,id:"green-value",property:"Green",type:"number",ref:$APP.$cljs$cst$1750$g$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),
defaultValue:$green$jscomp$4$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1750$g$$,255),icon:"character-g"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$1525$b$$,255),"aria-label":"Blue",max:255,id:"blue-value",property:"Blue",type:"number",ref:$APP.$cljs$cst$1525$b$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),defaultValue:$blue$jscomp$4$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1525$b$$,255),
icon:"character-b"})]}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hsb_mode_mode$jscomp$47$$,$cljs$cst$5534$hsl$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$1907$h$$,360),"aria-label":"Hue",max:360,id:"hue-value",property:"Hue",type:"number",ref:$APP.$cljs$cst$1907$h$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),defaultValue:$hue$jscomp$1$$,
onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1907$h$$,360),icon:"character-h"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$4235$s$$,100),"aria-label":"Saturation",max:100,id:"saturation-value",property:"Saturation",type:"number",ref:$APP.$cljs$cst$4235$s$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),defaultValue:$saturation$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$4235$s$$,100),step:1,icon:"character-s"}),
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($cljs$cst$5531$hsl_l$$,100),"aria-label":"Lightness",max:100,id:"lightness-value",property:"Lightness",type:"number",ref:$cljs$cst$5531$hsl_l$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),defaultValue:$APP.$app$common$math$precision$$($hsl_l$$*100,2),onKeyDown:$on_key_down_property$$($cljs$cst$5531$hsl_l$$,100),step:1,icon:"character-l"})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$1907$h$$,360),"aria-label":"Hue",max:360,id:"hue-value",property:"Hue",type:"number",ref:$APP.$cljs$cst$1907$h$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),defaultValue:$hue$jscomp$1$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$1907$h$$,360),icon:"character-h"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$4235$s$$,
100),"aria-label":"Saturation",max:100,id:"saturation-value",property:"Saturation",type:"number",ref:$APP.$cljs$cst$4235$s$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),defaultValue:$saturation$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$4235$s$$,100),step:1,icon:"character-s"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$3723$v$$,100),"aria-label":"Brightness (Value)",max:100,id:"brightness-value",property:"Brightness",
type:"number",ref:$APP.$cljs$cst$3723$v$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),textIcon:"B(V)",defaultValue:$value$jscomp$787$$,onKeyDown:$on_key_down_property$$($APP.$cljs$cst$3723$v$$,100),step:1})]})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_inputs__hex-alpha-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{onChange:function($e$jscomp$342_val$jscomp$201$$){$e$jscomp$342_val$jscomp$201$$=$app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$((0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$342_val$jscomp$201$$));
return $APP.$app$common$types$color$valid_hex_color_QMARK_$$($e$jscomp$342_val$jscomp$201$$)?$setup_hex_color$$($e$jscomp$342_val$jscomp$201$$):null},"aria-label":"Hexadecimal color value",className:"main_ui_workspace_colorpicker_color_inputs__hex-input",max:7,id:"hex-value",property:"Hex",onBlur:function($e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$){$e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$=(0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$);$e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$=
$APP.$app$common$types$color$color_string_QMARK_$$($e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$)?$APP.$app$common$types$color$parse$$($e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$):$APP.$app$common$types$color$valid_hex_color_QMARK_$$($app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$($e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$))?$app$main$ui$workspace$colorpicker$color_inputs$parse_hex$$($e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$):null;return $e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$!=
null?$setup_hex_color$$($e$jscomp$343_val$jscomp$202_val__$1$jscomp$14$$):null},type:"text",ref:$APP.$cljs$cst$2698$hex$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),textIcon:"HEX",defaultValue:$hex$jscomp$9$$}),$APP.$cljs$core$not$$($disable_opacity$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{min:0,onChange:$on_change_property$$($APP.$cljs$cst$746$alpha$$,100),"aria-label":"Alpha",className:"main_ui_workspace_colorpicker_color_inputs__alpha-input",max:100,
id:"alpha-value",property:"Alpha",type:"number",ref:$APP.$cljs$cst$746$alpha$$.$cljs$core$IFn$_invoke$arity$1$($refs$jscomp$2$$),defaultValue:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$14_map__75951__$1$$,$APP.$cljs$cst$1621$multiple$$)?"":$APP.$app$common$math$precision$$($alpha$jscomp$14_map__75951__$1$$*100,2),onKeyDown:$on_key_down_property$$($APP.$cljs$cst$746$alpha$$,100),step:1,icon:"character-a"}):null]})]})};
$app$main$ui$workspace$colorpicker$color_tokens$token_empty_state_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__color-token-empty-state",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("color-token.empty-state")})};
$app$main$ui$workspace$colorpicker$color_tokens$list_item_STAR_$$=function($on_click$jscomp$33_props_75956$$){var $selected$jscomp$139$$=void 0,$on_token_pill_click$$=void 0,$token$jscomp$124$$=void 0;({token:$token$jscomp$124$$,onTokenPillClick:$on_token_pill_click$$,selected:$selected$jscomp$139$$}=$on_click$jscomp$33_props_75956$$);$on_click$jscomp$33_props_75956$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$124$$),$APP.$rumext$v2$adapt$$($on_token_pill_click$$)],
function($event$jscomp$294$$){return $on_token_pill_click$$.$cljs$core$IFn$_invoke$arity$2$?$on_token_pill_click$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$294$$,$token$jscomp$124$$):$on_token_pill_click$$($event$jscomp$294$$,$token$jscomp$124$$)});var $id_tooltip$$=(0,$APP.$rumext$v2$use_id$$)(),$resolved$jscomp$3$$=$APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$124$$),$color_value$jscomp$3$$=$APP.$app$main$data$workspace$tokens$application$value__GT_color$$($resolved$jscomp$3$$),
$item_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{id:$id_tooltip$$,style:{width:"100%"},triggerRef:$item_ref$$,content:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$124$$),children:(0,$APP.$rumext$v2$jsxs$$)("button",{ref:$item_ref$$,"aria-labelledby":$id_tooltip$$,onClick:$on_click$jscomp$33_props_75956$$,className:"main_ui_workspace_colorpicker_color_tokens__color-token-item "+($APP.$cljs$core$truth_$$($selected$jscomp$139$$)?
"main_ui_workspace_colorpicker_color_tokens__color-token-selected":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color_value$jscomp$3$$,tooltipContent:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$resolved$jscomp$3$$])),size:"small"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__token-name",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$124$$)}),$APP.$cljs$core$truth_$$($selected$jscomp$139$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_colorpicker_color_tokens__token-selected-icon"}):null]})})};
$app$main$ui$workspace$colorpicker$color_tokens$grid_item_STAR_$$=function($on_click$jscomp$34_props_75969$$){var $selected$jscomp$140$$=void 0,$on_token_pill_click$jscomp$1$$=void 0,$token$jscomp$125$$=void 0;({token:$token$jscomp$125$$,onTokenPillClick:$on_token_pill_click$jscomp$1$$,selected:$selected$jscomp$140$$}=$on_click$jscomp$34_props_75969$$);$on_click$jscomp$34_props_75969$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$125$$),$APP.$rumext$v2$adapt$$($on_token_pill_click$jscomp$1$$)],
function($event$jscomp$295$$){return $on_token_pill_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_token_pill_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$295$$,$token$jscomp$125$$):$on_token_pill_click$jscomp$1$$($event$jscomp$295$$,$token$jscomp$125$$)});var $resolved$jscomp$4$$=$APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$125$$),$token_name$jscomp$16$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$125$$),$color_value$jscomp$4$$=
$APP.$app$main$data$workspace$tokens$application$value__GT_color$$($resolved$jscomp$4$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__color-token-item-grid "+($APP.$cljs$core$truth_$$($selected$jscomp$140$$)?"main_ui_workspace_colorpicker_color_tokens__color-token-selected-grid":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color_value$jscomp$4$$,tooltipContent:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name")??"")+": "}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_color_tokens__token-name",children:$token_name$jscomp$16$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$resolved$jscomp$4$$]))})]}),
onClick:$on_click$jscomp$34_props_75969$$,size:"medium"})})};
$app$main$ui$workspace$colorpicker$color_tokens$group__GT_paths$$=function($m$jscomp$223$$){var $parts$jscomp$25$$=function(){var $temp__5825__auto__$jscomp$338$$=$APP.$cljs$cst$1613$group$$.$cljs$core$IFn$_invoke$arity$1$($m$jscomp$223$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$338$$)?$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$338$$,/\//):null}();return $APP.$cljs$core$seq$$($parts$jscomp$25$$)?$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($i$jscomp$515$$){return $APP.$cljs$core$vec$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($i$jscomp$515$$,
$parts$jscomp$25$$))},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(1,$APP.$cljs$core$count$$($parts$jscomp$25$$)+1))):$APP.$cljs$core$PersistentHashSet$EMPTY$$};
$app$main$ui$workspace$colorpicker$color_tokens$set_section_STAR_$$=function($props_75994_toggle_list_style$$){var $on_token_change$$=void 0,$collapsed$jscomp$2$$=void 0,$name$jscomp$440$$=void 0,$applied_token$$=void 0,$toggle_sets_open$$=void 0,$group_or_set$$=void 0,$color_origin$$=void 0;({collapsed:$collapsed$jscomp$2$$,toggleSetsOpen:$toggle_sets_open$$,groupOrSet:$group_or_set$$,name:$name$jscomp$440$$,colorOrigin:$color_origin$$,onTokenChange:$on_token_change$$,appliedToken:$applied_token$$}=
$props_75994_toggle_list_style$$);var $list_style_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$201$list$$),$list_style$$=$APP.$cljs$core$_deref$$($list_style_STAR_$$);$props_75994_toggle_list_style$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($list_style$$)],function(){var $new_style$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$201$list$$,$list_style$$)?$APP.$cljs$cst$1664$grid$$:$APP.$cljs$cst$201$list$$;
return $APP.$cljs$core$reset_BANG_$$($list_style_STAR_$$,$new_style$$)});var $toggle_set$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($name$jscomp$440$$),$APP.$rumext$v2$adapt$$($toggle_sets_open$$)],function(){return $toggle_sets_open$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_sets_open$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$440$$):$toggle_sets_open$$($name$jscomp$440$$)}),$objects$jscomp$774$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),
$selected$jscomp$141$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$),$selected_shapes$jscomp$14$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$141$$),$APP.$rumext$v2$adapt$$($objects$jscomp$774$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$774$$)),$selected$jscomp$141$$)}),
$applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$12$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$14$$);$applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$12$$=$APP.$cljs$cst$1881$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$12$$);var $has_color_tokens_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$12$$,$APP.$cljs$cst$1408$fill$$),
$has_stroke_tokens_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$12$$,$APP.$cljs$cst$1745$stroke_color$$),$on_token_pill_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$14$$)],function($event$jscomp$296$$,$token$jscomp$126$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$296$$);return $APP.$cljs$core$seq$$($selected_shapes$jscomp$14$$)?
$on_token_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_token_change$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$296$$,$token$jscomp$126$$):$on_token_change$$($event$jscomp$296$$,$token$jscomp$126$$):null});$applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($group_or_set$$)],function(){var $JSCompiler_temp_const$jscomp$1702_path_set$$=$app$main$ui$workspace$colorpicker$color_tokens$group__GT_paths$$($group_or_set$$),
$JSCompiler_temp_const$jscomp$1701_id$jscomp$927$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$cst$2116$sets$$.$cljs$core$IFn$_invoke$arity$1$($group_or_set$$))),$JSCompiler_temp_const$jscomp$1704$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp_const$jscomp$1703$$=$APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1620$layout$$,
$APP.$cljs$cst$2108$tokens$$]));$JSCompiler_temp_const$jscomp$1702_path_set$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$1702_path_set$$)?$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5535$expand_token_sets$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5536$paths$$,$JSCompiler_temp_const$jscomp$1702_path_set$$],null)):null;$JSCompiler_temp_const$jscomp$1701_id$jscomp$927$$=$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($JSCompiler_temp_const$jscomp$1701_id$jscomp$927$$);
var $JSCompiler_inline_result$jscomp$1706_map__76004$jscomp$inline_8674_modal$jscomp$inline_8676$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$APP.$cljs$cst$1303$color$$);var $map__76004__$1$jscomp$inline_8675_title$jscomp$inline_8677$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$1706_map__76004$jscomp$inline_8674_modal$jscomp$inline_8676$$);$JSCompiler_inline_result$jscomp$1706_map__76004$jscomp$inline_8674_modal$jscomp$inline_8676$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76004__$1$jscomp$inline_8675_title$jscomp$inline_8677$$,$APP.$cljs$cst$4618$modal$$);$map__76004__$1$jscomp$inline_8675_title$jscomp$inline_8677$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76004__$1$jscomp$inline_8675_title$jscomp$inline_8677$$,$APP.$cljs$cst$939$title$$);var $window_size$jscomp$inline_8678_y$jscomp$inline_8681$$=$APP.$app$util$dom$get_window_size$$(),$left_sidebar$jscomp$inline_8679_x$jscomp$inline_8680$$=
$APP.$goog$dom$getElement$$("left-sidebar-aside");$left_sidebar$jscomp$inline_8679_x$jscomp$inline_8680$$=($APP.$app$util$dom$get_data$$($left_sidebar$jscomp$inline_8679_x$jscomp$inline_8680$$,"width")|0)-30;$window_size$jscomp$inline_8678_y$jscomp$inline_8681$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($window_size$jscomp$inline_8678_y$jscomp$inline_8681$$)/2-196;$JSCompiler_inline_result$jscomp$1706_map__76004$jscomp$inline_8674_modal$jscomp$inline_8676$$=$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1706_map__76004$jscomp$inline_8674_modal$jscomp$inline_8676$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1515$x$$,$left_sidebar$jscomp$inline_8679_x$jscomp$inline_8680$$,$APP.$cljs$cst$1516$y$$,$window_size$jscomp$inline_8678_y$jscomp$inline_8681$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$4741$fields$$,$APP.$cljs$cst$4741$fields$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1706_map__76004$jscomp$inline_8674_modal$jscomp$inline_8676$$),$APP.$cljs$cst$939$title$$,$map__76004__$1$jscomp$inline_8675_title$jscomp$inline_8677$$,
$APP.$cljs$cst$2694$action$$,"create",$cljs$cst$5537$token_type$$,$APP.$cljs$cst$1303$color$$],null));return $JSCompiler_temp_const$jscomp$1704$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_temp_const$jscomp$1703$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp_const$jscomp$1702_path_set$$,$JSCompiler_temp_const$jscomp$1701_id$jscomp$927$$,$JSCompiler_inline_result$jscomp$1706_map__76004$jscomp$inline_8674_modal$jscomp$inline_8676$$]))});var $icon_id$jscomp$5$$=
$APP.$cljs$core$truth_$$($collapsed$jscomp$2$$)?"arrow-right":"arrow-down";return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_workspace_colorpicker_color_tokens__color-token-set",children:[(0,$APP.$rumext$v2$jsxs$$)("header",{className:"main_ui_workspace_colorpicker_color_tokens__set-title-bar",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{"aria-controls":["set-panel-",$APP.$app$common$data$name$$($name$jscomp$440$$)].join(""),"aria-expanded":$APP.$cljs$core$not$$($collapsed$jscomp$2$$),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("inspect.tabs.styles.toggle-style",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$name$jscomp$440$$])),onClick:$toggle_set$$,className:"main_ui_workspace_colorpicker_color_tokens__set-title-btn",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon_id$jscomp$5$$,size:"s",className:"main_ui_workspace_colorpicker_color_tokens__set-title-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_colorpicker_color_tokens__set-title",children:$name$jscomp$440$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__set-title-actions "+($APP.$cljs$core$truth_$$($collapsed$jscomp$2$$)?"main_ui_workspace_colorpicker_color_tokens__set-title-action-hidden":""),children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$props_75994_toggle_list_style$$,variant:"action","aria-label":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$201$list$$,
$list_style$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.grid-view"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.list-view"),icon:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$201$list$$,$list_style$$)?"flex-grid":"view-as-list"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$applied_tokens$jscomp$5_create_token_on_set_first_shape$jscomp$12$$,variant:"action",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.add-token",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["color"])),icon:"add"})]})]}),$APP.$cljs$core$not$$($collapsed$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("div",{id:["set-panel-",$APP.$app$common$data$name$$($name$jscomp$440$$)].join(""),className:"main_ui_workspace_colorpicker_color_tokens__color-token-list "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($list_style$$,$APP.$cljs$cst$201$list$$)?
"main_ui_workspace_colorpicker_color_tokens__list-view":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($list_style$$,$APP.$cljs$cst$1664$grid$$)?"main_ui_workspace_colorpicker_color_tokens__grid-view":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$118$$,$token$jscomp$127$$){$out_arr__44092__auto__$jscomp$118$$.push(function(){var $selected_QMARK_$jscomp$1$$=function(){var $G__76008$$=$color_origin$$;switch($G__76008$$ instanceof
$APP.$cljs$core$Keyword$$?$G__76008$$.$fqn$:null){case "fill":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($has_color_tokens_QMARK_$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$127$$));case "stroke-color":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($has_stroke_tokens_QMARK_$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$127$$));case "color-selection":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_token$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$127$$));default:return!1}}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1664$grid$$,$list_style$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$grid_item_STAR_$$,{onTokenPillClick:$on_token_pill_click$jscomp$2$$,selected:$selected_QMARK_$jscomp$1$$,token:$token$jscomp$127$$},["token-grid-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$127$$))].join("")):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$list_item_STAR_$$,{onTokenPillClick:$on_token_pill_click$jscomp$2$$,selected:$selected_QMARK_$jscomp$1$$,token:$token$jscomp$127$$},["token-list-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$127$$))].join(""))}());return $out_arr__44092__auto__$jscomp$118$$},[],$APP.$cljs$cst$2108$tokens$$.$cljs$core$IFn$_invoke$arity$1$($group_or_set$$))}):null]})};
$app$main$ui$workspace$colorpicker$color_tokens$label_group_or_set$$=function($group$jscomp$47_p__76009$$){var $map__76010__$1_sets$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($group$jscomp$47_p__76009$$);$group$jscomp$47_p__76009$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76010__$1_sets$jscomp$15$$,$APP.$cljs$cst$1613$group$$);$map__76010__$1_sets$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76010__$1_sets$jscomp$15$$,$APP.$cljs$cst$2116$sets$$);
return $APP.$cljs$core$truth_$$($group$jscomp$47_p__76009$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$47_p__76009$$)," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$map__76010__$1_sets$jscomp$15$$))),")"].join(""):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($map__76010__$1_sets$jscomp$15$$))};
$app$main$ui$workspace$colorpicker$color_tokens$filter_combined_tokens$$=function($combined_tokens$$,$term$jscomp$6$$){var $term__$1$$=$APP.$cuerdas$core$lower$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($term$jscomp$6$$));return $APP.$cuerdas$core$blank_QMARK_$$($term__$1$$)?$combined_tokens$$:$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($map__76014__$1_p__76012$$){$map__76014__$1_p__76012$$=
$APP.$cljs$core$__destructure_map$$($map__76014__$1_p__76012$$);var $filtered$jscomp$1_tokens$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76014__$1_p__76012$$,$APP.$cljs$cst$2108$tokens$$);$filtered$jscomp$1_tokens$jscomp$40$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__76011_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__76011_SHARP_$$)),$term__$1$$)},
$filtered$jscomp$1_tokens$jscomp$40$$);return $APP.$cljs$core$seq$$($filtered$jscomp$1_tokens$jscomp$40$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__76014__$1_p__76012$$,$APP.$cljs$cst$2108$tokens$$,$filtered$jscomp$1_tokens$jscomp$40$$):null},$combined_tokens$$))};
$app$main$ui$workspace$colorpicker$color_tokens$sort_combined_tokens$$=function($combined_tokens$jscomp$1$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($entry$jscomp$70$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($entry$jscomp$70$$,$APP.$cljs$cst$2108$tokens$$,function($p1__76015_SHARP_$$){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$p1__76015_SHARP_$$)})},$combined_tokens$jscomp$1$$)};
$app$main$ui$workspace$colorpicker$color_tokens$token_section_STAR_$$=function($filter_term_props_76016$$){var $on_token_change$jscomp$1$$=void 0,$combined_tokens$jscomp$2$$=void 0,$applied_token$jscomp$1$$=void 0,$color_origin$jscomp$1$$=void 0;({combinedTokens:$combined_tokens$jscomp$2$$,colorOrigin:$color_origin$jscomp$1$$,onTokenChange:$on_token_change$jscomp$1$$,appliedToken:$applied_token$jscomp$1$$}=$filter_term_props_76016$$);var $sets$jscomp$16$$=$APP.$cljs$core$set$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$colorpicker$color_tokens$label_group_or_set$$,
$combined_tokens$jscomp$2$$)),$filter_term_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("");$filter_term_props_76016$$=$APP.$cljs$core$_deref$$($filter_term_STAR_$$);var $open_sets_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($sets$jscomp$16$$),$open_sets$$=$APP.$cljs$core$_deref$$($open_sets_STAR_$$),$toggle_sets_open$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_sets$$)],function($name$jscomp$441$$){return $APP.$cljs$core$contains_QMARK_$$($open_sets$$,
$name$jscomp$441$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($open_sets_STAR_$$,$APP.$cljs$core$disj$$,$name$jscomp$441$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($open_sets_STAR_$$,$APP.$cljs$core$conj$$,$name$jscomp$441$$)}),$on_filter_tokens$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filter_term_props_76016$$)],function($event$jscomp$297$$){$APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$$,$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$297$$)));
return $APP.$cljs$core$reset_BANG_$$($open_sets_STAR_$$,$sets$jscomp$16$$)}),$filtered_combined_sorted_tokens$$=$app$main$ui$workspace$colorpicker$color_tokens$filter_combined_tokens$$($combined_tokens$jscomp$2$$,$filter_term_props_76016$$);$filtered_combined_sorted_tokens$$=$app$main$ui$workspace$colorpicker$color_tokens$sort_combined_tokens$$($filtered_combined_sorted_tokens$$);return $APP.$cljs$core$seq$$($combined_tokens$jscomp$2$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__color-tokens-section",
children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.search-by-token"),icon:"search",maxLength:255,variant:"comfortable",className:"main_ui_workspace_colorpicker_color_tokens__search-input",defaultValue:$filter_term_props_76016$$,onChange:$on_filter_tokens$$}),$APP.$cljs$core$seq$$($filtered_combined_sorted_tokens$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_color_tokens__color-tokens-inputs",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$119$$,$JSCompiler_inline_result$jscomp$1709_combined_sets$$){var $JSCompiler_temp_const$jscomp$1707$$=$out_arr__44092__auto__$jscomp$119$$.push,$name$jscomp$inline_8683$$=$app$main$ui$workspace$colorpicker$color_tokens$label_group_or_set$$($JSCompiler_inline_result$jscomp$1709_combined_sets$$);$JSCompiler_inline_result$jscomp$1709_combined_sets$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$set_section_STAR_$$,
{collapsed:!$APP.$cljs$core$contains_QMARK_$$($open_sets$$,$name$jscomp$inline_8683$$),toggleSetsOpen:$toggle_sets_open$jscomp$1$$,colorOrigin:$color_origin$jscomp$1$$,onTokenChange:$on_token_change$jscomp$1$$,name:$name$jscomp$inline_8683$$,appliedToken:$applied_token$jscomp$1$$,groupOrSet:$JSCompiler_inline_result$jscomp$1709_combined_sets$$},["set-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$inline_8683$$)].join(""));$JSCompiler_temp_const$jscomp$1707$$.call($out_arr__44092__auto__$jscomp$119$$,
$JSCompiler_inline_result$jscomp$1709_combined_sets$$);return $out_arr__44092__auto__$jscomp$119$$},[],$filtered_combined_sorted_tokens$$)}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$token_empty_state_STAR_$$,{})]}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$token_empty_state_STAR_$$,{})};
$instaparse$auto_flatten_seq$conj_flat$$=function($JSCompiler_temp$jscomp$1710_self$jscomp$81$$,$obj$jscomp$212$$){if($JSCompiler_temp$jscomp$1710_self$jscomp$81$$!=null&&$JSCompiler_temp$jscomp$1710_self$jscomp$81$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$!=null)$JSCompiler_temp$jscomp$1710_self$jscomp$81$$=$JSCompiler_temp$jscomp$1710_self$jscomp$81$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$($JSCompiler_temp$jscomp$1710_self$jscomp$81$$,$obj$jscomp$212$$);else{var $m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$=
$instaparse$auto_flatten_seq$conj_flat$$[$APP.$goog$typeOf$$($JSCompiler_temp$jscomp$1710_self$jscomp$81$$==null?null:$JSCompiler_temp$jscomp$1710_self$jscomp$81$$)];if($m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$!=null)$JSCompiler_temp$jscomp$1710_self$jscomp$81$$=$m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$.$cljs$core$IFn$_invoke$arity$2$?$m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1710_self$jscomp$81$$,
$obj$jscomp$212$$):$m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$($JSCompiler_temp$jscomp$1710_self$jscomp$81$$,$obj$jscomp$212$$);else if($m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$=$instaparse$auto_flatten_seq$conj_flat$$._,$m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$!=null)$JSCompiler_temp$jscomp$1710_self$jscomp$81$$=$m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$.$cljs$core$IFn$_invoke$arity$2$?
$m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1710_self$jscomp$81$$,$obj$jscomp$212$$):$m__5372__auto__$jscomp$inline_8688_m__5374__auto__$jscomp$inline_8687$$($JSCompiler_temp$jscomp$1710_self$jscomp$81$$,$obj$jscomp$212$$);else throw $APP.$cljs$core$missing_protocol$$("ConjFlat.conj-flat",$JSCompiler_temp$jscomp$1710_self$jscomp$81$$);}return $JSCompiler_temp$jscomp$1710_self$jscomp$81$$};
$instaparse$auto_flatten_seq$delve$$=function($G__76160_v$jscomp$639_v__$1$jscomp$29$$,$G__76161_index$jscomp$410_index__$1$jscomp$19$$){for($G__76160_v$jscomp$639_v__$1$jscomp$29$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__76160_v$jscomp$639_v__$1$jscomp$29$$,$G__76161_index$jscomp$410_index__$1$jscomp$19$$);;)if($APP.$cljs$core$truth_$$($instaparse$auto_flatten_seq$afs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$auto_flatten_seq$afs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__76160_v$jscomp$639_v__$1$jscomp$29$$):
$instaparse$auto_flatten_seq$afs_QMARK_$$($G__76160_v$jscomp$639_v__$1$jscomp$29$$)))$G__76160_v$jscomp$639_v__$1$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__76160_v$jscomp$639_v__$1$jscomp$29$$,0),$G__76161_index$jscomp$410_index__$1$jscomp$19$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__76161_index$jscomp$410_index__$1$jscomp$19$$,0);else return $G__76161_index$jscomp$410_index__$1$jscomp$19$$};
$instaparse$auto_flatten_seq$flat_seq$cljs$0core$0IFn$0_invoke$0arity$02$$=function($v$jscomp$642$$,$index$jscomp$412$$){return new $APP.$cljs$core$LazySeq$$(null,function(){var $JSCompiler_temp_const$jscomp$1715$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$642$$,$index$jscomp$412$$);a:{var $G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$=$v$jscomp$642$$;for(var $G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$=$index$jscomp$412$$;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$),
1)){$G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$=$APP.$cljs$core$peek$$($G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$)<($instaparse$auto_flatten_seq$true_count$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$auto_flatten_seq$true_count$$.$cljs$core$IFn$_invoke$arity$1$($G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$):$instaparse$auto_flatten_seq$true_count$$($G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$))-
1?$instaparse$auto_flatten_seq$delve$$($G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$peek$$($G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$)+1],null)):null;break a}var $JSCompiler_temp_const$jscomp$inline_13655$$=$APP.$cljs$core$peek$$($G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$);var $G__76070$jscomp$inline_13657_JSCompiler_inline_result$jscomp$inline_13656$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$,$APP.$cljs$core$pop$$($G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$));$G__76070$jscomp$inline_13657_JSCompiler_inline_result$jscomp$inline_13656$$=$instaparse$auto_flatten_seq$true_count$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$auto_flatten_seq$true_count$$.$cljs$core$IFn$_invoke$arity$1$($G__76070$jscomp$inline_13657_JSCompiler_inline_result$jscomp$inline_13656$$):
$instaparse$auto_flatten_seq$true_count$$($G__76070$jscomp$inline_13657_JSCompiler_inline_result$jscomp$inline_13656$$);if($JSCompiler_temp_const$jscomp$inline_13655$$<$G__76070$jscomp$inline_13657_JSCompiler_inline_result$jscomp$inline_13656$$-1){$G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$=$instaparse$auto_flatten_seq$delve$$($G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$),
$APP.$cljs$core$peek$$($G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$)+1));break a}$G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$=$APP.$cljs$core$pop$$($G__76167$jscomp$inline_13659_index$jscomp$inline_13654$$)}$G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$=void 0}return $APP.$cljs$core$cons$$($JSCompiler_temp_const$jscomp$1715$$,$APP.$cljs$core$truth_$$($G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$)?
$instaparse$auto_flatten_seq$flat_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($v$jscomp$642$$,$G__76166$jscomp$inline_13658_temp__5825__auto__$jscomp$inline_8692_v$jscomp$inline_13653$$):null)},null,null)};
$instaparse$auto_flatten_seq$AutoFlattenSeq$$=function($v$jscomp$643$$,$premix_hashcode$$,$hashcode$$,$cnt$jscomp$47$$,$dirty$$){this.v=$v$jscomp$643$$;this.$premix_hashcode$=$premix_hashcode$$;this.$hashcode$=$hashcode$$;this.$cnt$=$cnt$jscomp$47$$;this.$dirty$=$dirty$$;this.$cached_seq$=null;this.$cljs$lang$protocol_mask$partition0$$=31850958;this.$cljs$lang$protocol_mask$partition1$$=0};
$instaparse$auto_flatten_seq$hash_cat$$=function($v1$jscomp$38$$,$v2$jscomp$30$$){var $JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$=$APP.$cljs$core$count$$($v2$jscomp$30$$);a:if($JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$===0)$JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$=1;else{$JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$|=
0;for(var $G__76155$jscomp$inline_8705_G__76158$jscomp$inline_8707_y$jscomp$inline_8701$$=1,$G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$=31;;){var $t$jscomp$inline_8703$$=$APP.$cljs$core$even_QMARK_$$($JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$);$JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$=$APP.$cljs$core$quot$$($JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$,
2);if($t$jscomp$inline_8703$$)$G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$=(0,$APP.$cljs$core$imul$$)($G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$,$G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$);else{if($JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$===0){$JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$=
(0,$APP.$cljs$core$imul$$)($G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$,$G__76155$jscomp$inline_8705_G__76158$jscomp$inline_8707_y$jscomp$inline_8701$$);break a}$G__76155$jscomp$inline_8705_G__76158$jscomp$inline_8707_y$jscomp$inline_8701$$=(0,$APP.$cljs$core$imul$$)($G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$,$G__76155$jscomp$inline_8705_G__76158$jscomp$inline_8707_y$jscomp$inline_8701$$);$G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$=
(0,$APP.$cljs$core$imul$$)($G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$,$G__76156$jscomp$inline_8706_G__76159$jscomp$inline_8708_z$jscomp$inline_8702$$)}}$JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$=void 0}$JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$|=0;return(0,$APP.$cljs$core$imul$$)($JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$,
$v1$jscomp$38$$.$premix_hashcode$)+($v2$jscomp$30$$.$premix_hashcode$-$JSCompiler_inline_result$jscomp$1711_c$jscomp$305_e$jscomp$346_n$jscomp$inline_8700_n__$1$jscomp$inline_8704$$)};
$instaparse$auto_flatten_seq$auto_flatten_seq$$=function($v$jscomp$645_v__$1$jscomp$30$$){$v$jscomp$645_v__$1$jscomp$30$$=$APP.$cljs$core$vec$$($v$jscomp$645_v__$1$jscomp$30$$);a:{var $G__76220$jscomp$inline_13664_JSCompiler_inline_result$jscomp$11283_unmixed_hash$jscomp$inline_13662$$=1;for(var $G__76221$jscomp$inline_13665_coll__$1$jscomp$inline_13663$$=$APP.$cljs$core$seq$$($v$jscomp$645_v__$1$jscomp$30$$);;)if($G__76221$jscomp$inline_13665_coll__$1$jscomp$inline_13663$$!=null)$G__76220$jscomp$inline_13664_JSCompiler_inline_result$jscomp$11283_unmixed_hash$jscomp$inline_13662$$=
(0,$APP.$cljs$core$imul$$)(31,$G__76220$jscomp$inline_13664_JSCompiler_inline_result$jscomp$11283_unmixed_hash$jscomp$inline_13662$$)+$APP.$cljs$core$hash$$($APP.$cljs$core$first$$($G__76221$jscomp$inline_13665_coll__$1$jscomp$inline_13663$$))|0,$G__76221$jscomp$inline_13665_coll__$1$jscomp$inline_13663$$=$APP.$cljs$core$next$$($G__76221$jscomp$inline_13665_coll__$1$jscomp$inline_13663$$);else break a;$G__76220$jscomp$inline_13664_JSCompiler_inline_result$jscomp$11283_unmixed_hash$jscomp$inline_13662$$=
void 0}return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($v$jscomp$645_v__$1$jscomp$30$$,$G__76220$jscomp$inline_13664_JSCompiler_inline_result$jscomp$11283_unmixed_hash$jscomp$inline_13662$$,$APP.$cljs$core$hash$$($v$jscomp$645_v__$1$jscomp$30$$),$APP.$cljs$core$count$$($v$jscomp$645_v__$1$jscomp$30$$),!1)};$instaparse$auto_flatten_seq$afs_QMARK_$$=function($s$jscomp$565$$){return $s$jscomp$565$$ instanceof $instaparse$auto_flatten_seq$AutoFlattenSeq$$};
$instaparse$auto_flatten_seq$true_count$$=function($v$jscomp$646$$){return $instaparse$auto_flatten_seq$afs_QMARK_$$($v$jscomp$646$$)?$APP.$cljs$core$count$$($v$jscomp$646$$.v):$APP.$cljs$core$count$$($v$jscomp$646$$)};
$instaparse$auto_flatten_seq$FlattenOnDemandVector$$=function($v$jscomp$649$$,$hashcode$jscomp$2$$,$cnt$jscomp$49$$,$flat$$){this.v=$v$jscomp$649$$;this.$hashcode$=$hashcode$jscomp$2$$;this.$cnt$=$cnt$jscomp$49$$;this.flat=$flat$$;this.$cljs$lang$protocol_mask$partition0$$=167142175;this.$cljs$lang$protocol_mask$partition1$$=2048};
$JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$=function($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$){$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.flat))&&($APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.flat,function(){var $JSCompiler_inline_result$jscomp$1721_v$jscomp$inline_8710$$=
$APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.v);$JSCompiler_inline_result$jscomp$1721_v$jscomp$inline_8710$$=$APP.$cljs$core$persistent_BANG_$$($instaparse$auto_flatten_seq$flat_vec_helper$$($APP.$cljs$core$_as_transient$$($APP.$cljs$core$PersistentVector$EMPTY$$),$JSCompiler_inline_result$jscomp$1721_v$jscomp$inline_8710$$));return $APP.$cljs$core$with_meta$$($JSCompiler_inline_result$jscomp$1721_v$jscomp$inline_8710$$,$APP.$cljs$core$meta$$($APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.v)))}),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.v,function(){return null}));return $APP.$cljs$core$_deref$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$self$$.flat)};
$instaparse$auto_flatten_seq$convert_afs_to_vec$$=function($afs$jscomp$1$$){return $APP.$cljs$core$truth_$$($afs$jscomp$1$$.$dirty$)?$APP.$cljs$core$truth_$$($afs$jscomp$1$$.$cached_seq$)?$APP.$cljs$core$vec$$($APP.$cljs$core$seq$$($afs$jscomp$1$$)):new $instaparse$auto_flatten_seq$FlattenOnDemandVector$$($APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($afs$jscomp$1$$.v),$afs$jscomp$1$$.$hashcode$,$afs$jscomp$1$$.$cnt$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null)):$afs$jscomp$1$$.v};
$instaparse$print$paren_for_tags$$=function($JSCompiler_inline_result$jscomp$1722_tag_set$$,$G__76075$jscomp$inline_8715_and__5023__auto__$jscomp$inline_8714_hidden_QMARK_$jscomp$3$$,$parser$jscomp$16$$){($G__76075$jscomp$inline_8715_and__5023__auto__$jscomp$inline_8714_hidden_QMARK_$jscomp$3$$=$APP.$cljs$core$not$$($G__76075$jscomp$inline_8715_and__5023__auto__$jscomp$inline_8714_hidden_QMARK_$jscomp$3$$))?($G__76075$jscomp$inline_8715_and__5023__auto__$jscomp$inline_8714_hidden_QMARK_$jscomp$3$$=
$parser$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$?$parser$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$78$tag$$):$parser$jscomp$16$$($APP.$cljs$cst$78$tag$$),$JSCompiler_inline_result$jscomp$1722_tag_set$$=$JSCompiler_inline_result$jscomp$1722_tag_set$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1722_tag_set$$.$cljs$core$IFn$_invoke$arity$1$($G__76075$jscomp$inline_8715_and__5023__auto__$jscomp$inline_8714_hidden_QMARK_$jscomp$3$$):$JSCompiler_inline_result$jscomp$1722_tag_set$$($G__76075$jscomp$inline_8715_and__5023__auto__$jscomp$inline_8714_hidden_QMARK_$jscomp$3$$)):
$JSCompiler_inline_result$jscomp$1722_tag_set$$=$G__76075$jscomp$inline_8715_and__5023__auto__$jscomp$inline_8714_hidden_QMARK_$jscomp$3$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1722_tag_set$$)?["(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$?$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$16$$,!1):$instaparse$print$combinators__GT_str$$($parser$jscomp$16$$,
!1)),")"].join(""):$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$?$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$16$$,!1):$instaparse$print$combinators__GT_str$$($parser$jscomp$16$$,!1)};$instaparse$print$regexp_replace$$=function($s$jscomp$567$$){switch($s$jscomp$567$$){case "\n":return"\\n";case "\b":return"\\b";case "\f":return"\\f";case "\r":return"\\r";case "\t":return"\\t";default:return $s$jscomp$567$$}};
$instaparse$print$regexp__GT_str$$=function($r$jscomp$122$$){return $APP.$clojure$string$replace$$(['#"',$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($r$jscomp$122$$.source,1),'"'].join(""),/[\s]/,$instaparse$print$regexp_replace$$)};$instaparse$print$number__GT_hex_padded$$=function($n$jscomp$291$$){return $n$jscomp$291$$<=4095?["0000",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($n$jscomp$291$$.toString(16))].join("").substr(-4):$n$jscomp$291$$.toString(16)};
$instaparse$print$char_range__GT_str$$=function($lo$jscomp$5_p__76079$$){var $hi$jscomp$7_map__76080__$1$$=$APP.$cljs$core$__destructure_map$$($lo$jscomp$5_p__76079$$);$lo$jscomp$5_p__76079$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hi$jscomp$7_map__76080__$1$$,$cljs$cst$5548$lo$$);$hi$jscomp$7_map__76080__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hi$jscomp$7_map__76080__$1$$,$cljs$cst$5549$hi$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($lo$jscomp$5_p__76079$$,
$hi$jscomp$7_map__76080__$1$$)?["%x",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$number__GT_hex_padded$$($lo$jscomp$5_p__76079$$))].join(""):["%x",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$number__GT_hex_padded$$($lo$jscomp$5_p__76079$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$number__GT_hex_padded$$($hi$jscomp$7_map__76080__$1$$))].join("")};
$instaparse$print$combinators__GT_str$$=function($var_args$jscomp$1427$$){switch(arguments.length){case 1:return $instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],!1);case 2:return $instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$=function($_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$,$hidden_QMARK_$jscomp$4$$){var $map__76084__$1$$=$APP.$cljs$core$__destructure_map$$($_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$);$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76084__$1$$,$APP.$cljs$cst$646$parser$$);var $_STAR_print_fn_STAR__orig_val__76087_76116__STAR_print_fn_STAR__orig_val__76091_76120_parser1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76084__$1$$,$cljs$cst$5550$parser1$$),$parser2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76084__$1$$,$cljs$cst$5551$parser2$$),$parsers$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76084__$1$$,
$cljs$cst$5552$parsers$$),$G__76085__$1_tag$jscomp$89$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76084__$1$$,$APP.$cljs$cst$78$tag$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$727$$=$APP.$cljs$core$not$$($hidden_QMARK_$jscomp$4$$);return $and__5023__auto__$jscomp$727$$?$APP.$cljs$cst$2356$hide$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$):$and__5023__auto__$jscomp$727$$}()))return["\x3c",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($map__76084__$1$$,
!0)),"\x3e"].join("");$G__76085__$1_tag$jscomp$89$$=$G__76085__$1_tag$jscomp$89$$ instanceof $APP.$cljs$core$Keyword$$?$G__76085__$1_tag$jscomp$89$$.$fqn$:null;switch($G__76085__$1_tag$jscomp$89$$){case "epsilon":return"ε";case "opt":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$)),"?"].join("");
case "plus":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$)),"+"].join("");case "star":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$)),
"*"].join("");case "rep":return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$),$APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$))?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$)),"{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$)),
",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$)),"}"].join(""):[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$)),"{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$)),
"}"].join("");case "alt":return $APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(" | ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($instaparse$print$paren_for_tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5547$ord$$,null],null),null),$hidden_QMARK_$jscomp$4$$),$parsers$jscomp$6$$));case "ord":return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_tags$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$717$alt$$,null],null),null),$hidden_QMARK_$jscomp$4$$,$_STAR_print_fn_STAR__orig_val__76087_76116__STAR_print_fn_STAR__orig_val__76091_76120_parser1$$))," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_tags$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$717$alt$$,null],null),null),$hidden_QMARK_$jscomp$4$$,$parser2$$))].join("");case "cat":return $APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($instaparse$print$paren_for_tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5547$ord$$,null,$APP.$cljs$cst$717$alt$$,null],null),null),$hidden_QMARK_$jscomp$4$$),$parsers$jscomp$6$$));case "string":var $sb__5670__auto__$jscomp$8$$=new $APP.$goog$string$StringBuffer$$;$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$=
$APP.$cljs$core$_STAR_print_newline_STAR_$$;$_STAR_print_fn_STAR__orig_val__76087_76116__STAR_print_fn_STAR__orig_val__76091_76120_parser1$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$8$$){return $sb__5670__auto__$jscomp$8$$.append($x__5671__auto__$jscomp$8$$)};try{$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$)]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=
$_STAR_print_fn_STAR__orig_val__76087_76116__STAR_print_fn_STAR__orig_val__76091_76120_parser1$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$8$$);case "string-ci":$sb__5670__auto__$jscomp$8$$=new $APP.$goog$string$StringBuffer$$;$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$=
$APP.$cljs$core$_STAR_print_newline_STAR_$$;$_STAR_print_fn_STAR__orig_val__76087_76116__STAR_print_fn_STAR__orig_val__76091_76120_parser1$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$9$$){return $sb__5670__auto__$jscomp$8$$.append($x__5671__auto__$jscomp$9$$)};try{$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$)]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=
$_STAR_print_fn_STAR__orig_val__76087_76116__STAR_print_fn_STAR__orig_val__76091_76120_parser1$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$8$$);case "char":return $instaparse$print$char_range__GT_str$$($map__76084__$1$$);case "regexp":return $instaparse$print$regexp__GT_str$$($cljs$cst$5553$regexp$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$));
case "nt":return $APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$221$keyword$$.$cljs$core$IFn$_invoke$arity$1$($map__76084__$1$$)),1);case "look":return["\x26",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$))].join("");case "neg":return["!",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$paren_for_compound$$($hidden_QMARK_$jscomp$4$$,$_STAR_print_newline_STAR__orig_val__76086_76115__STAR_print_newline_STAR__orig_val__76090_76119_p__76083_parser$jscomp$17$$))].join("");default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76085__$1_tag$jscomp$89$$)].join(""));}};
$instaparse$print$rule__GT_str$$=function($JSCompiler_temp$jscomp$1723_non_terminal$jscomp$1$$,$parser$jscomp$18$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5554$reduction_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$18$$)),$APP.$cljs$cst$561$raw$$))$JSCompiler_temp$jscomp$1723_non_terminal$jscomp$1$$=["\x3c",$APP.$cljs$core$name$$($JSCompiler_temp$jscomp$1723_non_terminal$jscomp$1$$),"\x3e \x3d ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$18$$,
!1))].join("");else{var $temp__5823__auto__$jscomp$inline_8718$$=$APP.$cljs$core$namespace$$($JSCompiler_temp$jscomp$1723_non_terminal$jscomp$1$$);$JSCompiler_temp$jscomp$1723_non_terminal$jscomp$1$$=[$APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_8718$$)?[$temp__5823__auto__$jscomp$inline_8718$$,"/",$APP.$cljs$core$name$$($JSCompiler_temp$jscomp$1723_non_terminal$jscomp$1$$)].join(""):$APP.$cljs$core$name$$($JSCompiler_temp$jscomp$1723_non_terminal$jscomp$1$$)," \x3d ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$18$$,
!1))].join("")}return $JSCompiler_temp$jscomp$1723_non_terminal$jscomp$1$$};
$instaparse$print$Parser__GT_str$$=function($map__76096__$1_p__76095$$){$map__76096__$1_p__76095$$=$APP.$cljs$core$__destructure_map$$($map__76096__$1_p__76095$$);var $grammar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76096__$1_p__76095$$,$cljs$cst$5556$grammar$$),$start$jscomp$233$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__76096__$1_p__76095$$,$cljs$cst$5557$start_production$$);return $APP.$clojure$string$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$cons$$($instaparse$print$rule__GT_str$$($start$jscomp$233$$,
$grammar$$.$cljs$core$IFn$_invoke$arity$1$?$grammar$$.$cljs$core$IFn$_invoke$arity$1$($start$jscomp$233$$):$grammar$$($start$jscomp$233$$)),function(){return function $instaparse$print$Parser__GT_str_$_iter__76097$$($s__76098$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$=$s__76098$$;;)if($s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$=$APP.$cljs$core$seq$$($s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$)){var $JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$=
$APP.$cljs$core$_chunked_first$$($s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$),$size__5502__auto__$jscomp$39$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$),$b__76100_non_terminal$jscomp$2$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$39$$);a:{for(var $i__76099$jscomp$inline_8720$$=0;;)if($i__76099$jscomp$inline_8720$$<$size__5502__auto__$jscomp$39$$){var $b$jscomp$inline_13669_vec__76102$jscomp$inline_8721$$=
$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$,$i__76099$jscomp$inline_8720$$),$non_terminal$jscomp$inline_8722_x$jscomp$inline_13670$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13669_vec__76102$jscomp$inline_8721$$,0,null),$parser$jscomp$inline_8723$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13669_vec__76102$jscomp$inline_8721$$,1,null);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($non_terminal$jscomp$inline_8722_x$jscomp$inline_13670$$,
$start$jscomp$233$$)&&($b$jscomp$inline_13669_vec__76102$jscomp$inline_8721$$=$b__76100_non_terminal$jscomp$2$$,$non_terminal$jscomp$inline_8722_x$jscomp$inline_13670$$=$instaparse$print$rule__GT_str$$($non_terminal$jscomp$inline_8722_x$jscomp$inline_13670$$,$parser$jscomp$inline_8723$$),$b$jscomp$inline_13669_vec__76102$jscomp$inline_8721$$.add($non_terminal$jscomp$inline_8722_x$jscomp$inline_13670$$));$i__76099$jscomp$inline_8720$$+=1}else{$JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$=
!0;break a}$JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$=void 0}return $JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76100_non_terminal$jscomp$2$$),$instaparse$print$Parser__GT_str_$_iter__76097$$($APP.$cljs$core$_chunked_rest$$($s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76100_non_terminal$jscomp$2$$),
null)}$JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$=$APP.$cljs$core$first$$($s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$);$b__76100_non_terminal$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$,0,null);$JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$,
1,null);if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($b__76100_non_terminal$jscomp$2$$,$start$jscomp$233$$))return $APP.$cljs$core$cons$$($instaparse$print$rule__GT_str$$($b__76100_non_terminal$jscomp$2$$,$JSCompiler_inline_result$jscomp$1725_c__5501__auto__$jscomp$39_parser$jscomp$19_vec__76105$$),$instaparse$print$Parser__GT_str_$_iter__76097$$($APP.$cljs$core$rest$$($s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$)));$s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$=
$APP.$cljs$core$rest$$($s__76098__$1_s__76098__$2_temp__5825__auto__$jscomp$340$$)}else return null},null,null)}($grammar$$)}()))};
$instaparse$failure$print_reason$$=function($r$jscomp$123$$){$APP.$cljs$core$truth_$$($cljs$cst$5558$NOT$$.$cljs$core$IFn$_invoke$arity$1$($r$jscomp$123$$))?($APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["NOT "])),$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5558$NOT$$.$cljs$core$IFn$_invoke$arity$1$($r$jscomp$123$$)]))):$APP.$cljs$core$truth_$$($cljs$cst$5559$char_range$$.$cljs$core$IFn$_invoke$arity$1$($r$jscomp$123$$))?
$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$print$char_range__GT_str$$($r$jscomp$123$$)])):$r$jscomp$123$$ instanceof RegExp?$APP.$cljs$core$print$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$print$regexp__GT_str$$($r$jscomp$123$$)])):$APP.$cljs$core$pr$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$r$jscomp$123$$]))};
$instaparse$failure$pprint_failure$$=function($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$){$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$=$APP.$cljs$core$__destructure_map$$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$);var $G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$,$APP.$cljs$cst$209$line$$),$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$,
$APP.$cljs$cst$216$column$$),$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$,$APP.$cljs$cst$1593$text$$);$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$,
$APP.$cljs$cst$984$reason$$);$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([["Parse error at line ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$),", column ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$),
":"].join("")]));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$]));$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$)?$APP.$cljs$core$integer_QMARK_$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$):
$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$)?($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=$APP.$clojure$string$replace$$($G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$,/[^\s]/," "),$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$<=
1?"^":[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$,0,$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$-1),"^"].join("")):$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=
null;$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$]));$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5560$expecting$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1278$full$$,$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$)));$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5560$expecting$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$complement$$($APP.$cljs$cst$1278$full$$),
$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$)));$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=$APP.$cljs$core$count$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$)+$APP.$cljs$core$count$$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$);
$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$!==0&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$)?$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Expected:"])):$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Expected one of:"])));
$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$APP.$cljs$core$seq$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$);$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=
null;for(var $G__76196_i__76154_76187_i__76165$$=$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$=0;;)if($G__76196_i__76154_76187_i__76165$$<$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$){var $r_76188$$=$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__76196_i__76154_76187_i__76165$$);$instaparse$failure$print_reason$$($r_76188$$);
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([" (followed by end-of-string)"]));$G__76196_i__76154_76187_i__76165$$+=1}else if($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$APP.$cljs$core$seq$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$))$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=
$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$)?($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=
$APP.$cljs$core$_chunked_first$$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$),$G__76196_i__76154_76187_i__76165$$=$APP.$cljs$core$_chunked_rest$$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$),$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=
$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$,$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$=$APP.$cljs$core$count$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$),$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=
$G__76196_i__76154_76187_i__76165$$):($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$APP.$cljs$core$first$$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$),$instaparse$failure$print_reason$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$),
$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([" (followed by end-of-string)"])),$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$APP.$cljs$core$next$$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$),
$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=null,$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$=0),$G__76196_i__76154_76187_i__76165$$=0;else break;$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$);
$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=null;for($G__76196_i__76154_76187_i__76165$$=$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$=0;;)if($G__76196_i__76154_76187_i__76165$$<$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$)$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=
$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__76196_i__76154_76187_i__76165$$),$instaparse$failure$print_reason$$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$),$APP.$cljs$core$println$$(),$G__76196_i__76154_76187_i__76165$$+=1;else if($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$=
$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$))$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$)?
($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$=$APP.$cljs$core$_chunked_first$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$),$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$=$APP.$cljs$core$_chunked_rest$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$),
$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$,$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$),
$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$=$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$,$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$=$G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$):($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$=
$APP.$cljs$core$first$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$),$instaparse$failure$print_reason$$($G__76197_G__76211_chunk__76152_76185_line$jscomp$28_marker_text$jscomp$inline_13674_r$jscomp$124_seq__76151_76194__$1_total$jscomp$22$$),$APP.$cljs$core$println$$(),$c__5548__auto__$jscomp$41_map__76149__$1_p__76148_partial_reasons_reason$jscomp$26_seq__76162_temp__5825__auto__$jscomp$341$$=
$APP.$cljs$core$next$$($G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$),$G__76210_JSCompiler_inline_result$jscomp$11288_c__5548__auto___76195_chunk__76163_column$jscomp$38_full_reasons_r_76200_seq__76151_76184_seq__76162__$1_temp__5825__auto___76193$$=null,$G__76198_G__76209_count__76153_76186_count__76164_text$jscomp$83$$=0),$G__76196_i__76154_76187_i__76165$$=0;else break};
$instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($message$jscomp$117$$){throw $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$message$jscomp$117$$);};$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($message$jscomp$118$$){throw $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$message$jscomp$118$$);};
$instaparse$util$regexp_flags$$=function($re$jscomp$23$$){var $G__76219__$1_G__76219__$2$$=$APP.$cljs$core$truth_$$($re$jscomp$23$$.ignoreCase)?"i":"";$G__76219__$1_G__76219__$2$$=$APP.$cljs$core$truth_$$($re$jscomp$23$$.multiline)?[$G__76219__$1_G__76219__$2$$,"m"].join(""):$G__76219__$1_G__76219__$2$$;return $APP.$cljs$core$truth_$$($re$jscomp$23$$.unicode)?[$G__76219__$1_G__76219__$2$$,"u"].join(""):$G__76219__$1_G__76219__$2$$};
$instaparse$reduction$singleton_QMARK_$$=function($s$jscomp$568$$){return $APP.$cljs$core$seq$$($s$jscomp$568$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$next$$($s$jscomp$568$$))};
$instaparse$reduction$apply_reduction$$=function($f$jscomp$859$$,$content$jscomp$243_result$jscomp$351$$){var $G__76235$$=$cljs$cst$5554$reduction_type$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$859$$);switch($G__76235$$ instanceof $APP.$cljs$core$Keyword$$?$G__76235$$.$fqn$:null){case "raw":return $instaparse$auto_flatten_seq$EMPTY$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$content$jscomp$243_result$jscomp$351$$);case "hiccup":return $instaparse$auto_flatten_seq$convert_afs_to_vec$$($instaparse$auto_flatten_seq$auto_flatten_seq$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$859$$)],null)).$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$content$jscomp$243_result$jscomp$351$$));case "enlive":return $content$jscomp$243_result$jscomp$351$$=$instaparse$auto_flatten_seq$EMPTY$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$content$jscomp$243_result$jscomp$351$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($f$jscomp$859$$),$APP.$cljs$cst$1642$content$$,$APP.$cljs$core$count$$($content$jscomp$243_result$jscomp$351$$)===0?null:$content$jscomp$243_result$jscomp$351$$],null);default:return $f$jscomp$859$$.$cljs$core$IFn$_invoke$arity$1$?$f$jscomp$859$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$243_result$jscomp$351$$):$f$jscomp$859$$($content$jscomp$243_result$jscomp$351$$)}};
$instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$=function($reduction_type$$,$grammar$jscomp$2$$){var $temp__5823__auto__$jscomp$215$$=$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$($reduction_type$$):$instaparse$reduction$reduction_types$$($reduction_type$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$215$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
function(){return function $instaparse$reduction$iter__76239$$($s__76240$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__76240__$2_temp__5825__auto__$jscomp$342$$=$APP.$cljs$core$seq$$($s__76240$$);if($s__76240__$2_temp__5825__auto__$jscomp$342$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__76240__$2_temp__5825__auto__$jscomp$342$$)){var $JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$=$APP.$cljs$core$_chunked_first$$($s__76240__$2_temp__5825__auto__$jscomp$342$$),
$size__5502__auto__$jscomp$40$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$),$b__76242_k$jscomp$676$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$40$$);a:{for(var $i__76241$jscomp$inline_8725$$=0;;)if($i__76241$jscomp$inline_8725$$<$size__5502__auto__$jscomp$40$$){var $b$jscomp$inline_13676_vec__76243$jscomp$inline_8726$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$,
$i__76241$jscomp$inline_8725$$),$k$jscomp$inline_8727_x$jscomp$inline_13677$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13676_vec__76243$jscomp$inline_8726$$,0,null),$v$jscomp$inline_8728$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13676_vec__76243$jscomp$inline_8726$$,1,null);$b$jscomp$inline_13676_vec__76243$jscomp$inline_8726$$=$b__76242_k$jscomp$676$$;$k$jscomp$inline_8727_x$jscomp$inline_13677$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$inline_8728$$))?
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8727_x$jscomp$inline_13677$$,$v$jscomp$inline_8728$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8727_x$jscomp$inline_13677$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($v$jscomp$inline_8728$$,$APP.$cljs$cst$5555$red$$,$temp__5823__auto__$jscomp$215$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$215$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_8727_x$jscomp$inline_13677$$):
$temp__5823__auto__$jscomp$215$$($k$jscomp$inline_8727_x$jscomp$inline_13677$$))],null);$b$jscomp$inline_13676_vec__76243$jscomp$inline_8726$$.add($k$jscomp$inline_8727_x$jscomp$inline_13677$$);$i__76241$jscomp$inline_8725$$+=1}else{$JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$=!0;break a}$JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$=void 0}return $JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$?
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76242_k$jscomp$676$$),$instaparse$reduction$iter__76239$$($APP.$cljs$core$_chunked_rest$$($s__76240__$2_temp__5825__auto__$jscomp$342$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76242_k$jscomp$676$$),null)}$JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$=$APP.$cljs$core$first$$($s__76240__$2_temp__5825__auto__$jscomp$342$$);$b__76242_k$jscomp$676$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$,
0,null);$JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$,1,null);return $APP.$cljs$core$cons$$($APP.$cljs$core$truth_$$($APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$))?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__76242_k$jscomp$676$$,$JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__76242_k$jscomp$676$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1727_c__5501__auto__$jscomp$40_v$jscomp$652_vec__76246$$,$APP.$cljs$cst$5555$red$$,$temp__5823__auto__$jscomp$215$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5823__auto__$jscomp$215$$.$cljs$core$IFn$_invoke$arity$1$($b__76242_k$jscomp$676$$):$temp__5823__auto__$jscomp$215$$($b__76242_k$jscomp$676$$))],null),$instaparse$reduction$iter__76239$$($APP.$cljs$core$rest$$($s__76240__$2_temp__5825__auto__$jscomp$342$$)))}return null}},null,null)}($grammar$jscomp$2$$)}()):$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid output format ",$reduction_type$$,
". Use :enlive or :hiccup."]))};$instaparse$combinators_source$opt$$=function($parser$jscomp$22$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$22$$,$instaparse$combinators_source$Epsilon$$)?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$22$$],null)};
$instaparse$combinators_source$plus$$=function($parser$jscomp$23$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$23$$,$instaparse$combinators_source$Epsilon$$)?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$23$$],null)};
$instaparse$combinators_source$star$$=function($parser$jscomp$24$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$24$$,$instaparse$combinators_source$Epsilon$$)?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5565$star$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$24$$],null)};
$instaparse$combinators_source$rep$$=function($m$jscomp$224$$,$n$jscomp$294$$,$parser$jscomp$25$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$25$$,$instaparse$combinators_source$Epsilon$$)?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5566$rep$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$25$$,$APP.$cljs$cst$338$min$$,$m$jscomp$224$$,$APP.$cljs$cst$339$max$$,$n$jscomp$294$$],null)};
$instaparse$combinators_source$string$$=function($s$jscomp$569$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$569$$,"")?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,$s$jscomp$569$$],null)};
$instaparse$combinators_source$string_ci$$=function($s$jscomp$570$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$570$$,"")?$instaparse$combinators_source$Epsilon$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5567$string_ci$$,$APP.$cljs$cst$198$string$$,$s$jscomp$570$$],null)};
$instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$=function($lo$jscomp$6$$,$hi$jscomp$8$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5568$char$$,$cljs$cst$5548$lo$$,$lo$jscomp$6$$,$cljs$cst$5549$hi$$,$hi$jscomp$8$$],null)};
$instaparse$combinators_source$regexp$$=function($JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$,"")?$JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$=$instaparse$combinators_source$Epsilon$$:($JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$=
$APP.$cljs$core$re_pattern$$($JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$),$JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$=$APP.$cljs$core$regexp_QMARK_$$($JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$)?new RegExp(["^",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$.source)].join(""),
$instaparse$util$regexp_flags$$($JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$)):$JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$,$JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5553$regexp$$,$cljs$cst$5553$regexp$$,$JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$],
null));return $JSCompiler_inline_result$jscomp$1731_JSCompiler_temp$jscomp$1729_r$jscomp$126_r$jscomp$inline_8733$$};$instaparse$combinators_source$nt$$=function($s$jscomp$571$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$s$jscomp$571$$],null)};
$instaparse$combinators_source$look$$=function($parser$jscomp$26$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5570$look$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$26$$],null)};$instaparse$combinators_source$neg$$=function($parser$jscomp$27$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5571$neg$$,$APP.$cljs$cst$646$parser$$,$parser$jscomp$27$$],null)};
$instaparse$combinators_source$hide$$=function($parser$jscomp$28$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$28$$,$APP.$cljs$cst$2356$hide$$,!0)};$instaparse$combinators_source$hide_tag$$=function($parser$jscomp$29$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$29$$,$APP.$cljs$cst$5555$red$$,$instaparse$reduction$raw_non_terminal_reduction$$)};
$instaparse$combinators_source$unhide_all_content$$=function($grammar$jscomp$3$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $instaparse$combinators_source$unhide_all_content_$_iter__76274$$($s__76275$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__76275__$2_temp__5825__auto__$jscomp$343$$=$APP.$cljs$core$seq$$($s__76275$$);if($s__76275__$2_temp__5825__auto__$jscomp$343$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__76275__$2_temp__5825__auto__$jscomp$343$$)){var $JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$=
$APP.$cljs$core$_chunked_first$$($s__76275__$2_temp__5825__auto__$jscomp$343$$),$size__5502__auto__$jscomp$41$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$),$b__76277_k$jscomp$678$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$41$$);a:{for(var $i__76276$jscomp$inline_8735$$=0;;)if($i__76276$jscomp$inline_8735$$<$size__5502__auto__$jscomp$41$$){var $b$jscomp$inline_13679_vec__76278$jscomp$inline_8736$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$,
$i__76276$jscomp$inline_8735$$),$k$jscomp$inline_8737_x$jscomp$inline_13680$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13679_vec__76278$jscomp$inline_8736$$,0,null),$v$jscomp$inline_8738$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13679_vec__76278$jscomp$inline_8736$$,1,null);$b$jscomp$inline_13679_vec__76278$jscomp$inline_8736$$=$b__76277_k$jscomp$678$$;$k$jscomp$inline_8737_x$jscomp$inline_13680$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8737_x$jscomp$inline_13680$$,$instaparse$combinators_source$unhide_content$$($v$jscomp$inline_8738$$)],null);$b$jscomp$inline_13679_vec__76278$jscomp$inline_8736$$.add($k$jscomp$inline_8737_x$jscomp$inline_13680$$);$i__76276$jscomp$inline_8735$$+=1}else{$JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$=!0;break a}$JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$=
void 0}return $JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76277_k$jscomp$678$$),$instaparse$combinators_source$unhide_all_content_$_iter__76274$$($APP.$cljs$core$_chunked_rest$$($s__76275__$2_temp__5825__auto__$jscomp$343$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76277_k$jscomp$678$$),null)}$JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$=
$APP.$cljs$core$first$$($s__76275__$2_temp__5825__auto__$jscomp$343$$);$b__76277_k$jscomp$678$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$,0,null);$JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__76277_k$jscomp$678$$,$instaparse$combinators_source$unhide_content$$($JSCompiler_inline_result$jscomp$1732_c__5501__auto__$jscomp$41_v$jscomp$654_vec__76281$$)],null),$instaparse$combinators_source$unhide_all_content_$_iter__76274$$($APP.$cljs$core$rest$$($s__76275__$2_temp__5825__auto__$jscomp$343$$)))}return null}},null,null)}($grammar$jscomp$3$$)}())};
$instaparse$combinators_source$unhide_tags$$=function($reduction_type$jscomp$1$$,$grammar$jscomp$4$$){var $temp__5823__auto__$jscomp$216$$=$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$($reduction_type$jscomp$1$$):$instaparse$reduction$reduction_types$$($reduction_type$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$216$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
function(){return function $instaparse$combinators_source$unhide_tags_$_iter__76284$$($s__76285$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__76285__$2_temp__5825__auto__$jscomp$344$$=$APP.$cljs$core$seq$$($s__76285$$);if($s__76285__$2_temp__5825__auto__$jscomp$344$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__76285__$2_temp__5825__auto__$jscomp$344$$)){var $JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$=$APP.$cljs$core$_chunked_first$$($s__76285__$2_temp__5825__auto__$jscomp$344$$),
$size__5502__auto__$jscomp$42$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$),$b__76287_k$jscomp$680$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$42$$);a:{for(var $i__76286$jscomp$inline_8740$$=0;;)if($i__76286$jscomp$inline_8740$$<$size__5502__auto__$jscomp$42$$){var $b$jscomp$inline_13682_vec__76288$jscomp$inline_8741$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$,
$i__76286$jscomp$inline_8740$$),$k$jscomp$inline_8742_x$jscomp$inline_13683$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13682_vec__76288$jscomp$inline_8741$$,0,null),$v$jscomp$inline_8743$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13682_vec__76288$jscomp$inline_8741$$,1,null);$b$jscomp$inline_13682_vec__76288$jscomp$inline_8741$$=$b__76287_k$jscomp$680$$;$k$jscomp$inline_8742_x$jscomp$inline_13683$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8742_x$jscomp$inline_13683$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($v$jscomp$inline_8743$$,$APP.$cljs$cst$5555$red$$,$temp__5823__auto__$jscomp$216$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$216$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_8742_x$jscomp$inline_13683$$):$temp__5823__auto__$jscomp$216$$($k$jscomp$inline_8742_x$jscomp$inline_13683$$))],null);$b$jscomp$inline_13682_vec__76288$jscomp$inline_8741$$.add($k$jscomp$inline_8742_x$jscomp$inline_13683$$);
$i__76286$jscomp$inline_8740$$+=1}else{$JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$=!0;break a}$JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$=void 0}return $JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76287_k$jscomp$680$$),$instaparse$combinators_source$unhide_tags_$_iter__76284$$($APP.$cljs$core$_chunked_rest$$($s__76285__$2_temp__5825__auto__$jscomp$344$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76287_k$jscomp$680$$),null)}$JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$=$APP.$cljs$core$first$$($s__76285__$2_temp__5825__auto__$jscomp$344$$);$b__76287_k$jscomp$680$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$,0,null);$JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__76287_k$jscomp$680$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1733_c__5501__auto__$jscomp$42_v$jscomp$656_vec__76291$$,$APP.$cljs$cst$5555$red$$,$temp__5823__auto__$jscomp$216$$.$cljs$core$IFn$_invoke$arity$1$?
$temp__5823__auto__$jscomp$216$$.$cljs$core$IFn$_invoke$arity$1$($b__76287_k$jscomp$680$$):$temp__5823__auto__$jscomp$216$$($b__76287_k$jscomp$680$$))],null),$instaparse$combinators_source$unhide_tags_$_iter__76284$$($APP.$cljs$core$rest$$($s__76285__$2_temp__5825__auto__$jscomp$344$$)))}return null}},null,null)}($grammar$jscomp$4$$)}()):$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid output format ",
$reduction_type$jscomp$1$$,". Use :enlive or :hiccup."]))};
$instaparse$combinators_source$unhide_all$$=function($reduction_type$jscomp$2$$,$grammar$jscomp$5$$){var $temp__5823__auto__$jscomp$217$$=$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$reduction$reduction_types$$.$cljs$core$IFn$_invoke$arity$1$($reduction_type$jscomp$2$$):$instaparse$reduction$reduction_types$$($reduction_type$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$217$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
function(){return function $instaparse$combinators_source$unhide_all_$_iter__76294$$($s__76295$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__76295__$2_temp__5825__auto__$jscomp$345$$=$APP.$cljs$core$seq$$($s__76295$$);if($s__76295__$2_temp__5825__auto__$jscomp$345$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__76295__$2_temp__5825__auto__$jscomp$345$$)){var $JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$=$APP.$cljs$core$_chunked_first$$($s__76295__$2_temp__5825__auto__$jscomp$345$$),
$size__5502__auto__$jscomp$43$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$),$b__76297_k$jscomp$682$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$43$$);a:{for(var $i__76296$jscomp$inline_8745$$=0;;)if($i__76296$jscomp$inline_8745$$<$size__5502__auto__$jscomp$43$$){var $b$jscomp$inline_13685_vec__76298$jscomp$inline_8746$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$,
$i__76296$jscomp$inline_8745$$),$k$jscomp$inline_8747_x$jscomp$inline_13686$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13685_vec__76298$jscomp$inline_8746$$,0,null),$v$jscomp$inline_8748$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13685_vec__76298$jscomp$inline_8746$$,1,null);$b$jscomp$inline_13685_vec__76298$jscomp$inline_8746$$=$b__76297_k$jscomp$682$$;$k$jscomp$inline_8747_x$jscomp$inline_13686$$=new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8747_x$jscomp$inline_13686$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($instaparse$combinators_source$unhide_content$$($v$jscomp$inline_8748$$),$APP.$cljs$cst$5555$red$$,$temp__5823__auto__$jscomp$217$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$217$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_8747_x$jscomp$inline_13686$$):$temp__5823__auto__$jscomp$217$$($k$jscomp$inline_8747_x$jscomp$inline_13686$$))],
null);$b$jscomp$inline_13685_vec__76298$jscomp$inline_8746$$.add($k$jscomp$inline_8747_x$jscomp$inline_13686$$);$i__76296$jscomp$inline_8745$$+=1}else{$JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$=!0;break a}$JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$=void 0}return $JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76297_k$jscomp$682$$),
$instaparse$combinators_source$unhide_all_$_iter__76294$$($APP.$cljs$core$_chunked_rest$$($s__76295__$2_temp__5825__auto__$jscomp$345$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76297_k$jscomp$682$$),null)}$JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$=$APP.$cljs$core$first$$($s__76295__$2_temp__5825__auto__$jscomp$345$$);$b__76297_k$jscomp$682$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$,
0,null);$JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__76297_k$jscomp$682$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($instaparse$combinators_source$unhide_content$$($JSCompiler_inline_result$jscomp$1734_c__5501__auto__$jscomp$43_v$jscomp$658_vec__76301$$),
$APP.$cljs$cst$5555$red$$,$temp__5823__auto__$jscomp$217$$.$cljs$core$IFn$_invoke$arity$1$?$temp__5823__auto__$jscomp$217$$.$cljs$core$IFn$_invoke$arity$1$($b__76297_k$jscomp$682$$):$temp__5823__auto__$jscomp$217$$($b__76297_k$jscomp$682$$))],null),$instaparse$combinators_source$unhide_all_$_iter__76294$$($APP.$cljs$core$rest$$($s__76295__$2_temp__5825__auto__$jscomp$345$$)))}return null}},null,null)}($grammar$jscomp$5$$)}()):$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid output format ",
$reduction_type$jscomp$2$$,". Use :enlive or :hiccup."]))};
$instaparse$combinators_source$auto_whitespace$$=function($grammar$jscomp$6$$,$final_grammar_start$jscomp$234$$,$grammar_ws_grammar_ws__$1$$,$modified_grammar_start_ws$$){var $ws_parser$jscomp$1$$=$instaparse$combinators_source$hide$$($instaparse$combinators_source$opt$$($instaparse$combinators_source$nt$$($modified_grammar_start_ws$$)));$grammar_ws_grammar_ws__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($grammar_ws_grammar_ws__$1$$,$modified_grammar_start_ws$$,$instaparse$combinators_source$hide_tag$$($grammar_ws_grammar_ws__$1$$.$cljs$core$IFn$_invoke$arity$1$?
$grammar_ws_grammar_ws__$1$$.$cljs$core$IFn$_invoke$arity$1$($modified_grammar_start_ws$$):$grammar_ws_grammar_ws__$1$$($modified_grammar_start_ws$$)));$modified_grammar_start_ws$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $instaparse$combinators_source$auto_whitespace_$_iter__76310$$($s__76311$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__76311__$2_temp__5825__auto__$jscomp$346$$=$APP.$cljs$core$seq$$($s__76311$$);
if($s__76311__$2_temp__5825__auto__$jscomp$346$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__76311__$2_temp__5825__auto__$jscomp$346$$)){var $JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$=$APP.$cljs$core$_chunked_first$$($s__76311__$2_temp__5825__auto__$jscomp$346$$),$size__5502__auto__$jscomp$44$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$),$b__76313_nt$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$44$$);
a:{for(var $i__76312$jscomp$inline_8750$$=0;;)if($i__76312$jscomp$inline_8750$$<$size__5502__auto__$jscomp$44$$){var $b$jscomp$inline_13688_vec__76314$jscomp$inline_8751$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$,$i__76312$jscomp$inline_8750$$),$nt$jscomp$inline_8752_x$jscomp$inline_13689$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13688_vec__76314$jscomp$inline_8751$$,0,null),$parser$jscomp$inline_8753$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13688_vec__76314$jscomp$inline_8751$$,1,null);$b$jscomp$inline_13688_vec__76314$jscomp$inline_8751$$=$b__76313_nt$$;$nt$jscomp$inline_8752_x$jscomp$inline_13689$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$nt$jscomp$inline_8752_x$jscomp$inline_13689$$,$instaparse$combinators_source$auto_whitespace_parser$$($parser$jscomp$inline_8753$$,$ws_parser$jscomp$1$$)],null);$b$jscomp$inline_13688_vec__76314$jscomp$inline_8751$$.add($nt$jscomp$inline_8752_x$jscomp$inline_13689$$);
$i__76312$jscomp$inline_8750$$+=1}else{$JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$=!0;break a}$JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$=void 0}return $JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76313_nt$$),$instaparse$combinators_source$auto_whitespace_$_iter__76310$$($APP.$cljs$core$_chunked_rest$$($s__76311__$2_temp__5825__auto__$jscomp$346$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__76313_nt$$),null)}$JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$=$APP.$cljs$core$first$$($s__76311__$2_temp__5825__auto__$jscomp$346$$);$b__76313_nt$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$,0,null);$JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$,1,null);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__76313_nt$$,$instaparse$combinators_source$auto_whitespace_parser$$($JSCompiler_inline_result$jscomp$1735_c__5501__auto__$jscomp$44_parser$jscomp$33_vec__76317$$,$ws_parser$jscomp$1$$)],null),$instaparse$combinators_source$auto_whitespace_$_iter__76310$$($APP.$cljs$core$rest$$($s__76311__$2_temp__5825__auto__$jscomp$346$$)))}return null}},
null,null)}($grammar$jscomp$6$$)}());$final_grammar_start$jscomp$234$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($modified_grammar_start_ws$$,$final_grammar_start$jscomp$234$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($modified_grammar_start_ws$$.$cljs$core$IFn$_invoke$arity$1$?
$modified_grammar_start_ws$$.$cljs$core$IFn$_invoke$arity$1$($final_grammar_start$jscomp$234$$):$modified_grammar_start_ws$$($final_grammar_start$jscomp$234$$),$APP.$cljs$cst$5555$red$$),$ws_parser$jscomp$1$$])),$APP.$cljs$cst$5555$red$$,$APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($modified_grammar_start_ws$$.$cljs$core$IFn$_invoke$arity$1$?$modified_grammar_start_ws$$.$cljs$core$IFn$_invoke$arity$1$($final_grammar_start$jscomp$234$$):$modified_grammar_start_ws$$($final_grammar_start$jscomp$234$$))));
return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$final_grammar_start$jscomp$234$$,$grammar_ws_grammar_ws__$1$$]))};
$goog$i18n$uChar$fromCharCode$$=function($code$jscomp$61$$){if($code$jscomp$61$$==null||!($code$jscomp$61$$>=0&&$code$jscomp$61$$<=1114111))return null;if($code$jscomp$61$$>=65536&&$code$jscomp$61$$<=1114111){const $trailCodePoint$$=($code$jscomp$61$$&1023)+56320;return String.fromCharCode(($code$jscomp$61$$>>10)+55232)+String.fromCharCode($trailCodePoint$$)}return String.fromCharCode($code$jscomp$61$$)};
$goog$i18n$uChar$getCodePointAround$$=function($lead$jscomp$1_string$jscomp$21_trail$$,$index$jscomp$414$$){const $charCode$jscomp$1$$=$lead$jscomp$1_string$jscomp$21_trail$$.charCodeAt($index$jscomp$414$$);if($charCode$jscomp$1$$>=55296&&$charCode$jscomp$1$$<=56319&&$index$jscomp$414$$+1<$lead$jscomp$1_string$jscomp$21_trail$$.length){if($lead$jscomp$1_string$jscomp$21_trail$$=$lead$jscomp$1_string$jscomp$21_trail$$.charCodeAt($index$jscomp$414$$+1),$lead$jscomp$1_string$jscomp$21_trail$$>=56320&&
$lead$jscomp$1_string$jscomp$21_trail$$<=57343)return $charCode$jscomp$1$$>=55296&&$charCode$jscomp$1$$<=56319&&$lead$jscomp$1_string$jscomp$21_trail$$>=56320&&$lead$jscomp$1_string$jscomp$21_trail$$<=57343?($charCode$jscomp$1$$<<10)-56623104+($lead$jscomp$1_string$jscomp$21_trail$$-56320+65536):null}else if($charCode$jscomp$1$$>=56320&&$charCode$jscomp$1$$<=57343&&$index$jscomp$414$$>0&&($lead$jscomp$1_string$jscomp$21_trail$$=$lead$jscomp$1_string$jscomp$21_trail$$.charCodeAt($index$jscomp$414$$-
1),$lead$jscomp$1_string$jscomp$21_trail$$>=55296&&$lead$jscomp$1_string$jscomp$21_trail$$<=56319))return-($lead$jscomp$1_string$jscomp$21_trail$$>=55296&&$lead$jscomp$1_string$jscomp$21_trail$$<=56319&&$charCode$jscomp$1$$>=56320&&$charCode$jscomp$1$$<=57343?($lead$jscomp$1_string$jscomp$21_trail$$<<10)-56623104+($charCode$jscomp$1$$-56320+65536):0);return $charCode$jscomp$1$$};
$instaparse$gll$_parse$$=function($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$){var $G__77126_G__77126__$1$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$35$$);$G__77126_G__77126__$1$$=$G__77126_G__77126__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__77126_G__77126__$1$$.$fqn$:null;switch($G__77126_G__77126__$1$$){case "nt":return $instaparse$gll$non_terminal_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$non_terminal_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,
$index$jscomp$415$$,$tramp$$):$instaparse$gll$non_terminal_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "alt":return $instaparse$gll$alt_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$alt_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$alt_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "cat":return $instaparse$gll$cat_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$cat_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,
$index$jscomp$415$$,$tramp$$):$instaparse$gll$cat_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "string":return $instaparse$gll$string_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$string_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$string_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "string-ci":return $instaparse$gll$string_case_insensitive_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$string_case_insensitive_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,
$index$jscomp$415$$,$tramp$$):$instaparse$gll$string_case_insensitive_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "char":return $instaparse$gll$char_range_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$char_range_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$char_range_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "epsilon":return $instaparse$gll$epsilon_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$epsilon_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$epsilon_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "opt":return $instaparse$gll$opt_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$opt_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$opt_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "plus":return $instaparse$gll$plus_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$plus_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$plus_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "rep":return $instaparse$gll$rep_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$rep_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$rep_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "star":return $instaparse$gll$star_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$star_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$star_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "regexp":return $instaparse$gll$regexp_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$regexp_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$regexp_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "look":return $instaparse$gll$lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$lookahead_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);case "neg":return $instaparse$gll$negative_lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$negative_lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$negative_lookahead_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,
$tramp$$);case "ord":return $instaparse$gll$ordered_alt_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$ordered_alt_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$):$instaparse$gll$ordered_alt_parse$$($parser$jscomp$35$$,$index$jscomp$415$$,$tramp$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77126_G__77126__$1$$)].join(""));}};
$instaparse$gll$_full_parse$$=function($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$){var $G__77132_G__77132__$1$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$36$$);$G__77132_G__77132__$1$$=$G__77132_G__77132__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__77132_G__77132__$1$$.$fqn$:null;switch($G__77132_G__77132__$1$$){case "nt":return $instaparse$gll$non_terminal_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$non_terminal_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,
$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$non_terminal_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "alt":return $instaparse$gll$alt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$alt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$alt_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "cat":return $instaparse$gll$cat_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$cat_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$cat_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "string":return $instaparse$gll$string_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$string_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$string_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,
$tramp$jscomp$1$$);case "string-ci":return $instaparse$gll$string_case_insensitive_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$string_case_insensitive_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$string_case_insensitive_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "char":return $instaparse$gll$char_range_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$char_range_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,
$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$char_range_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "epsilon":return $instaparse$gll$epsilon_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$epsilon_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$epsilon_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "opt":return $instaparse$gll$opt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$opt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$opt_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "plus":return $instaparse$gll$plus_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$plus_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$plus_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);
case "rep":return $instaparse$gll$rep_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$rep_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$rep_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "star":return $instaparse$gll$star_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$star_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):
$instaparse$gll$star_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "regexp":return $instaparse$gll$regexp_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$regexp_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$regexp_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "look":return $instaparse$gll$lookahead_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$lookahead_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,
$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$lookahead_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "neg":return $instaparse$gll$negative_lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$?$instaparse$gll$negative_lookahead_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$negative_lookahead_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);case "ord":return $instaparse$gll$ordered_alt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$?
$instaparse$gll$ordered_alt_full_parse$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$):$instaparse$gll$ordered_alt_full_parse$$($parser$jscomp$36$$,$index$jscomp$416$$,$tramp$jscomp$1$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77132_G__77132__$1$$)].join(""));}};
$instaparse$gll$Failure$$=function($index$jscomp$417$$,$reason$jscomp$27$$,$__meta$jscomp$35$$,$__extmap$jscomp$35$$,$__hash$jscomp$94$$){this.index=$index$jscomp$417$$;this.reason=$reason$jscomp$27$$;this.$__meta$=$__meta$jscomp$35$$;this.$__extmap$=$__extmap$jscomp$35$$;this.$__hash$=$__hash$jscomp$94$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=139264};
$instaparse$gll$Tramp$$=function($grammar$jscomp$8$$,$text$jscomp$87$$,$segment$jscomp$47$$,$fail_index$$,$node_builder$$,$stack$jscomp$34$$,$next_stack$jscomp$2$$,$generation$$,$negative_listeners$$,$msg_cache$$,$nodes$jscomp$37$$,$success$jscomp$7$$,$failure$jscomp$1$$,$trace_QMARK_$$,$__meta$jscomp$36$$,$__extmap$jscomp$36$$,$__hash$jscomp$95$$){this.$grammar$=$grammar$jscomp$8$$;this.text=$text$jscomp$87$$;this.segment=$segment$jscomp$47$$;this.$fail_index$=$fail_index$$;this.$node_builder$=$node_builder$$;
this.stack=$stack$jscomp$34$$;this.$next_stack$=$next_stack$jscomp$2$$;this.$generation$=$generation$$;this.$negative_listeners$=$negative_listeners$$;this.$msg_cache$=$msg_cache$$;this.$nodes$=$nodes$jscomp$37$$;this.$success$=$success$jscomp$7$$;this.$failure$=$failure$jscomp$1$$;this.$trace_QMARK_$=$trace_QMARK_$$;this.$__meta$=$__meta$jscomp$36$$;this.$__extmap$=$__extmap$jscomp$36$$;this.$__hash$=$__hash$jscomp$95$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264};
$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$=function($grammar$jscomp$13$$,$text$jscomp$92$$,$segment$jscomp$50$$,$fail_index$jscomp$3$$,$node_builder$jscomp$3$$){return new $instaparse$gll$Tramp$$($grammar$jscomp$13$$,$text$jscomp$92$$,$segment$jscomp$50$$,$fail_index$jscomp$3$$,$node_builder$jscomp$3$$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(0),
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$sorted_map_by$$($APP.$cljs$core$_GT_$$)),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $instaparse$gll$Failure$$(0,$APP.$cljs$core$PersistentVector$EMPTY$$,
null,null,null)),!1,null,null,null)};$instaparse$gll$make_success$$=function($result$jscomp$352$$,$index$jscomp$419$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$828$result$$,$result$jscomp$352$$,$APP.$cljs$cst$1801$index$$,$index$jscomp$419$$],null)};
$instaparse$gll$total_success_QMARK_$$=function($tramp$jscomp$2$$,$s$jscomp$572$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$2$$)),$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($s$jscomp$572$$))};
$instaparse$gll$Node$$=function($listeners$jscomp$1$$,$full_listeners$$,$results$jscomp$2$$,$full_results$$,$__meta$jscomp$37$$,$__extmap$jscomp$37$$,$__hash$jscomp$96$$){this.$listeners$=$listeners$jscomp$1$$;this.$full_listeners$=$full_listeners$$;this.results=$results$jscomp$2$$;this.$full_results$=$full_results$$;this.$__meta$=$__meta$jscomp$37$$;this.$__extmap$=$__extmap$jscomp$37$$;this.$__hash$=$__hash$jscomp$96$$;this.$cljs$lang$protocol_mask$partition0$$=2230716170;this.$cljs$lang$protocol_mask$partition1$$=
139264};$instaparse$gll$push_stack$$=function($tramp$jscomp$3$$,$item$jscomp$125$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$3735$stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$3$$),$APP.$cljs$core$conj$$,$item$jscomp$125$$)};
$instaparse$gll$push_message$$=function($tramp$jscomp$4$$,$listener$jscomp$103$$,$result$jscomp$353$$){function $f$jscomp$860$$(){return $listener$jscomp$103$$.$cljs$core$IFn$_invoke$arity$1$?$listener$jscomp$103$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$353$$):$listener$jscomp$103$$($result$jscomp$353$$)}var $cache$jscomp$106$$=$cljs$cst$5578$msg_cache$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$4$$),$i$jscomp$520_k$jscomp$684$$=$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($result$jscomp$353$$);
$i$jscomp$520_k$jscomp$684$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$listener$jscomp$103$$,$i$jscomp$520_k$jscomp$684$$],null);var $c$jscomp$306$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($cache$jscomp$106$$),$i$jscomp$520_k$jscomp$684$$,0);$c$jscomp$306$$>$APP.$cljs$core$deref$$($cljs$cst$5576$generation$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$4$$))?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($cljs$cst$5575$next_stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$4$$),
$APP.$cljs$core$conj$$,$f$jscomp$860$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$3735$stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$4$$),$APP.$cljs$core$conj$$,$f$jscomp$860$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cache$jscomp$106$$,$APP.$cljs$core$assoc$$,$i$jscomp$520_k$jscomp$684$$,$c$jscomp$306$$+1)};
$instaparse$gll$listener_exists_QMARK_$$=function($fexpr__77196$jscomp$inline_8755_nodes$jscomp$39_tramp$jscomp$5$$,$node_key_temp__5825__auto__$jscomp$347$$){$fexpr__77196$jscomp$inline_8755_nodes$jscomp$39_tramp$jscomp$5$$=$cljs$cst$5579$nodes$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__77196$jscomp$inline_8755_nodes$jscomp$39_tramp$jscomp$5$$);$fexpr__77196$jscomp$inline_8755_nodes$jscomp$39_tramp$jscomp$5$$=$APP.$cljs$core$_deref$$($fexpr__77196$jscomp$inline_8755_nodes$jscomp$39_tramp$jscomp$5$$);
$node_key_temp__5825__auto__$jscomp$347$$=$fexpr__77196$jscomp$inline_8755_nodes$jscomp$39_tramp$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__77196$jscomp$inline_8755_nodes$jscomp$39_tramp$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($node_key_temp__5825__auto__$jscomp$347$$):$fexpr__77196$jscomp$inline_8755_nodes$jscomp$39_tramp$jscomp$5$$($node_key_temp__5825__auto__$jscomp$347$$);return $APP.$cljs$core$truth_$$($node_key_temp__5825__auto__$jscomp$347$$)?$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5592$listeners$$.$cljs$core$IFn$_invoke$arity$1$($node_key_temp__5825__auto__$jscomp$347$$)))>
0:null};
$instaparse$gll$full_listener_exists_QMARK_$$=function($fexpr__77197$jscomp$inline_8757_nodes$jscomp$40_tramp$jscomp$6$$,$node_key$jscomp$1_temp__5825__auto__$jscomp$348$$){$fexpr__77197$jscomp$inline_8757_nodes$jscomp$40_tramp$jscomp$6$$=$cljs$cst$5579$nodes$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__77197$jscomp$inline_8757_nodes$jscomp$40_tramp$jscomp$6$$);$fexpr__77197$jscomp$inline_8757_nodes$jscomp$40_tramp$jscomp$6$$=$APP.$cljs$core$_deref$$($fexpr__77197$jscomp$inline_8757_nodes$jscomp$40_tramp$jscomp$6$$);$node_key$jscomp$1_temp__5825__auto__$jscomp$348$$=
$fexpr__77197$jscomp$inline_8757_nodes$jscomp$40_tramp$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__77197$jscomp$inline_8757_nodes$jscomp$40_tramp$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$1_temp__5825__auto__$jscomp$348$$):$fexpr__77197$jscomp$inline_8757_nodes$jscomp$40_tramp$jscomp$6$$($node_key$jscomp$1_temp__5825__auto__$jscomp$348$$);return $APP.$cljs$core$truth_$$($node_key$jscomp$1_temp__5825__auto__$jscomp$348$$)?$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5593$full_listeners$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$1_temp__5825__auto__$jscomp$348$$)))>
0||$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5592$listeners$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$1_temp__5825__auto__$jscomp$348$$)))>0:null};
$instaparse$gll$result_exists_QMARK_$$=function($fexpr__77198$jscomp$inline_8759_nodes$jscomp$41_tramp$jscomp$7$$,$node_key$jscomp$2_temp__5825__auto__$jscomp$349$$){$fexpr__77198$jscomp$inline_8759_nodes$jscomp$41_tramp$jscomp$7$$=$cljs$cst$5579$nodes$$.$cljs$core$IFn$_invoke$arity$1$($fexpr__77198$jscomp$inline_8759_nodes$jscomp$41_tramp$jscomp$7$$);$fexpr__77198$jscomp$inline_8759_nodes$jscomp$41_tramp$jscomp$7$$=$APP.$cljs$core$_deref$$($fexpr__77198$jscomp$inline_8759_nodes$jscomp$41_tramp$jscomp$7$$);
$node_key$jscomp$2_temp__5825__auto__$jscomp$349$$=$fexpr__77198$jscomp$inline_8759_nodes$jscomp$41_tramp$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__77198$jscomp$inline_8759_nodes$jscomp$41_tramp$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$2_temp__5825__auto__$jscomp$349$$):$fexpr__77198$jscomp$inline_8759_nodes$jscomp$41_tramp$jscomp$7$$($node_key$jscomp$2_temp__5825__auto__$jscomp$349$$);return $APP.$cljs$core$truth_$$($node_key$jscomp$2_temp__5825__auto__$jscomp$349$$)?
$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5595$full_results$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$2_temp__5825__auto__$jscomp$349$$)))>0||$APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5594$results$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$2_temp__5825__auto__$jscomp$349$$)))>0:null};
$instaparse$gll$node_get$$=function($nodes$jscomp$43_tramp$jscomp$9$$,$node_key$jscomp$4$$){$nodes$jscomp$43_tramp$jscomp$9$$=$cljs$cst$5579$nodes$$.$cljs$core$IFn$_invoke$arity$1$($nodes$jscomp$43_tramp$jscomp$9$$);var $fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$=$APP.$cljs$core$_deref$$($nodes$jscomp$43_tramp$jscomp$9$$);$fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$=$fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$.$cljs$core$IFn$_invoke$arity$1$?
$fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$.$cljs$core$IFn$_invoke$arity$1$($node_key$jscomp$4$$):$fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$($node_key$jscomp$4$$);$APP.$cljs$core$truth_$$($fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$)||($fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$=new $instaparse$gll$Node$$($APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),null,null,null),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($nodes$jscomp$43_tramp$jscomp$9$$,$APP.$cljs$core$assoc$$,$node_key$jscomp$4$$,$fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$));
return $fexpr__77200$jscomp$inline_8761_node$jscomp$394_temp__5823__auto__$jscomp$218$$};
$instaparse$gll$safe_with_meta$$=function($obj$jscomp$215$$,$metamap$jscomp$2$$){return($obj$jscomp$215$$!=null?$obj$jscomp$215$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$215$$.$cljs$core$IWithMeta$$||($obj$jscomp$215$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$215$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$215$$))?$APP.$cljs$core$with_meta$$($obj$jscomp$215$$,
$metamap$jscomp$2$$):$obj$jscomp$215$$};
$instaparse$gll$push_result$$=function($tramp$jscomp$10$$,$node_key$jscomp$5$$,$G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$){var $c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$=$instaparse$gll$node_get$$($tramp$jscomp$10$$,$node_key$jscomp$5$$),$parser$jscomp$37$$=$node_key$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$(1):$node_key$jscomp$5$$(1),$result__$1$jscomp$41$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2356$hide$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$37$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$,$APP.$cljs$cst$828$result$$,null):$G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$,$result__$2$jscomp$9$$=function(){var $temp__5823__auto__$jscomp$219$$=$APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$37$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$219$$)?$instaparse$gll$make_success$$($instaparse$gll$safe_with_meta$$($instaparse$reduction$apply_reduction$$($temp__5823__auto__$jscomp$219$$,
$APP.$cljs$cst$828$result$$.$cljs$core$IFn$_invoke$arity$1$($result__$1$jscomp$41$$)),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5600$instaparse_DOT_gll_SLASH_start_index$$,$node_key$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$(0):$node_key$jscomp$5$$(0),$cljs$cst$5601$instaparse_DOT_gll_SLASH_end_index$$,$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($result__$1$jscomp$41$$)],null)),$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($result__$1$jscomp$41$$)):
$result__$1$jscomp$41$$}(),$results$jscomp$4$$=($G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$=$instaparse$gll$total_success_QMARK_$$($tramp$jscomp$10$$,$result__$2$jscomp$9$$))?$cljs$cst$5595$full_results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$):$cljs$cst$5594$results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$);if($APP.$cljs$core$not$$(function(){var $fexpr__77202$$=
$APP.$cljs$core$_deref$$($results$jscomp$4$$);return $fexpr__77202$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__77202$$.$cljs$core$IFn$_invoke$arity$1$($result__$2$jscomp$9$$):$fexpr__77202$$($result__$2$jscomp$9$$)}())){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($results$jscomp$4$$,$APP.$cljs$core$conj$$,$result__$2$jscomp$9$$);for(var $G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5592$listeners$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$))),
$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$=null,$G__77395_count__77205_77381_i__77210$$=0,$G__77393_i__77206_77382$$=0;;)if($G__77393_i__77206_77382$$<$G__77395_count__77205_77381_i__77210$$){var $listener_77385$$=$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77393_i__77206_77382$$);$instaparse$gll$push_message$$($tramp$jscomp$10$$,$listener_77385$$,$result__$2$jscomp$9$$);$G__77393_i__77206_77382$$+=
1}else if($G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$APP.$cljs$core$seq$$($G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$))$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$=$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$)?
($G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$APP.$cljs$core$_chunked_first$$($G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$),$G__77393_i__77206_77382$$=$APP.$cljs$core$_chunked_rest$$($G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$),$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$=$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$,
$G__77395_count__77205_77381_i__77210$$=$APP.$cljs$core$count$$($G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$),$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$G__77393_i__77206_77382$$):($G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$APP.$cljs$core$first$$($G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$),
$instaparse$gll$push_message$$($tramp$jscomp$10$$,$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$,$result__$2$jscomp$9$$),$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$APP.$cljs$core$next$$($G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$),$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$=null,$G__77395_count__77205_77381_i__77210$$=
0),$G__77393_i__77206_77382$$=0;else break;if($G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$)for($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$=$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5593$full_listeners$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$))),$G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$=null,$G__77395_count__77205_77381_i__77210$$=
$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$=0;;)if($G__77395_count__77205_77381_i__77210$$<$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$)$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77395_count__77205_77381_i__77210$$),$instaparse$gll$push_message$$($tramp$jscomp$10$$,
$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$,$result__$2$jscomp$9$$),$G__77395_count__77205_77381_i__77210$$+=1;else if($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$))$G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$=$c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$)?($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$=$APP.$cljs$core$_chunked_first$$($G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$),$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$=$APP.$cljs$core$_chunked_rest$$($G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$),$G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$=
$c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$,$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$),$c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$=$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$,$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$=
$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$):($G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$=$APP.$cljs$core$first$$($G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$),$instaparse$gll$push_message$$($tramp$jscomp$10$$,$G__77411_c__5548__auto___77392_listener$jscomp$104_listener_77400_seq__77203_77379_temp__5825__auto___77390$$,$result__$2$jscomp$9$$),
$c__5548__auto__$jscomp$42_node$jscomp$395_seq__77207_temp__5825__auto__$jscomp$351$$=$APP.$cljs$core$next$$($G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$),$G__77410_chunk__77208_result$jscomp$354_seq__77207__$1_total_QMARK_$$=null,$G__77394_G__77409_chunk__77204_77380_count__77209_seq__77203_77391__$1$$=0),$G__77395_count__77205_77381_i__77210$$=0;else return null;else return null}else return null};
$instaparse$gll$push_listener$$=function($tramp$jscomp$11$$,$node_key$jscomp$6$$,$listener$jscomp$105$$){var $listener_already_exists_QMARK_$$=$instaparse$gll$listener_exists_QMARK_$$($tramp$jscomp$11$$,$node_key$jscomp$6$$),$c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$=$instaparse$gll$node_get$$($tramp$jscomp$11$$,$node_key$jscomp$6$$),$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=
$cljs$cst$5592$listeners$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$,$APP.$cljs$core$conj$$,$listener$jscomp$105$$);$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=
$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5594$results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$)));for(var $G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$=null,$G__77435_G__77460_count__77213_77423_i__77218_77450$$=0,$G__77433_i__77214_77424_result_77451$$=0;;)if($G__77433_i__77214_77424_result_77451$$<$G__77435_G__77460_count__77213_77423_i__77218_77450$$){var $result_77425$$=
$G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77433_i__77214_77424_result_77451$$);$instaparse$gll$push_message$$($tramp$jscomp$11$$,$listener$jscomp$105$$,$result_77425$$);$G__77433_i__77214_77424_result_77451$$+=1}else if($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=$APP.$cljs$core$seq$$($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$))$G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$=
$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$)?($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=$APP.$cljs$core$_chunked_first$$($G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$),
$G__77433_i__77214_77424_result_77451$$=$APP.$cljs$core$_chunked_rest$$($G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$),$G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$=$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$,$G__77435_G__77460_count__77213_77423_i__77218_77450$$=$APP.$cljs$core$count$$($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$),
$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=$G__77433_i__77214_77424_result_77451$$):($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=$APP.$cljs$core$first$$($G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$),$instaparse$gll$push_message$$($tramp$jscomp$11$$,$listener$jscomp$105$$,
$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$),$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=$APP.$cljs$core$next$$($G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$),$G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$=null,$G__77435_G__77460_count__77213_77423_i__77218_77450$$=
0),$G__77433_i__77214_77424_result_77451$$=0;else break;$c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$=$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5595$full_results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$)));$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=
null;for($G__77435_G__77460_count__77213_77423_i__77218_77450$$=$G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$=0;;)if($G__77435_G__77460_count__77213_77423_i__77218_77450$$<$G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$)$G__77433_i__77214_77424_result_77451$$=$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$.$cljs$core$IIndexed$_nth$arity$2$(null,
$G__77435_G__77460_count__77213_77423_i__77218_77450$$),$instaparse$gll$push_message$$($tramp$jscomp$11$$,$listener$jscomp$105$$,$G__77433_i__77214_77424_result_77451$$),$G__77435_G__77460_count__77213_77423_i__77218_77450$$+=1;else if($c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$=$APP.$cljs$core$seq$$($c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$))$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=
$c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$)?($c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$=$APP.$cljs$core$_chunked_first$$($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$),
$G__77435_G__77460_count__77213_77423_i__77218_77450$$=$APP.$cljs$core$_chunked_rest$$($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$),$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=$c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$,$G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$=
$APP.$cljs$core$count$$($c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$),$c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$=$G__77435_G__77460_count__77213_77423_i__77218_77450$$):($c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$=$APP.$cljs$core$first$$($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$),
$instaparse$gll$push_message$$($tramp$jscomp$11$$,$listener$jscomp$105$$,$c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$),$c__5548__auto___77459_node$jscomp$396_result_77464_seq__77215_77447_temp__5825__auto___77457$$=$APP.$cljs$core$next$$($G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$),$G__77461_c__5548__auto___77432_chunk__77216_77448_listeners$jscomp$3_result_77437_seq__77211_77421_seq__77215_77458__$1_temp__5825__auto___77430$$=
null,$G__77434_G__77462_chunk__77212_77422_count__77217_77449_seq__77211_77431__$1$$=0),$G__77435_G__77460_count__77213_77423_i__77218_77450$$=0;else break;return $APP.$cljs$core$not$$($listener_already_exists_QMARK_$$)?$instaparse$gll$push_stack$$($tramp$jscomp$11$$,function(){return $instaparse$gll$_parse$$($node_key$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$(1):$node_key$jscomp$6$$(1),$node_key$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$(0):
$node_key$jscomp$6$$(0),$tramp$jscomp$11$$)}):null};
$instaparse$gll$push_full_listener$$=function($tramp$jscomp$12$$,$node_key$jscomp$7$$,$listener$jscomp$106$$){var $full_listener_already_exists_QMARK_$$=$instaparse$gll$full_listener_exists_QMARK_$$($tramp$jscomp$12$$,$node_key$jscomp$7$$),$c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$=$instaparse$gll$node_get$$($tramp$jscomp$12$$,$node_key$jscomp$7$$),$G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$=$cljs$cst$5593$full_listeners$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$,$APP.$cljs$core$conj$$,$listener$jscomp$106$$);$c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$=$APP.$cljs$core$seq$$($APP.$cljs$core$deref$$($cljs$cst$5595$full_results$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$)));$G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$=
null;for(var $G__77483_count__77221_77471$$=0,$G__77481_i__77222_77472$$=0;;)if($G__77481_i__77222_77472$$<$G__77483_count__77221_77471$$){var $result_77473$$=$G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77481_i__77222_77472$$);$instaparse$gll$push_message$$($tramp$jscomp$12$$,$listener$jscomp$106$$,$result_77473$$);$G__77481_i__77222_77472$$+=1}else if($c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$=
$APP.$cljs$core$seq$$($c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$))$G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$=$c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$)?($c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$=$APP.$cljs$core$_chunked_first$$($G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$),
$G__77481_i__77222_77472$$=$APP.$cljs$core$_chunked_rest$$($G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$),$G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$=$c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$,$G__77483_count__77221_77471$$=$APP.$cljs$core$count$$($c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$),$c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$=
$G__77481_i__77222_77472$$):($c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$=$APP.$cljs$core$first$$($G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$),$instaparse$gll$push_message$$($tramp$jscomp$12$$,$listener$jscomp$106$$,$c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$),$c__5548__auto___77480_node$jscomp$397_result_77485_seq__77219_77469_temp__5825__auto___77478$$=$APP.$cljs$core$next$$($G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$),
$G__77482_chunk__77220_77470_listeners$jscomp$4_seq__77219_77479__$1$$=null,$G__77483_count__77221_77471$$=0),$G__77481_i__77222_77472$$=0;else break;return $APP.$cljs$core$not$$($full_listener_already_exists_QMARK_$$)?$instaparse$gll$push_stack$$($tramp$jscomp$12$$,function(){return $instaparse$gll$_full_parse$$($node_key$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$(1):$node_key$jscomp$7$$(1),$node_key$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?
$node_key$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$(0):$node_key$jscomp$7$$(0),$tramp$jscomp$12$$)}):null};
$instaparse$gll$push_negative_listener$$=function($tramp$jscomp$13$$,$creator$$,$negative_listener$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($cljs$cst$5577$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$13$$),$instaparse$gll$merge_negative_listeners$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$creator$$.$cljs$core$IFn$_invoke$arity$1$?$creator$$.$cljs$core$IFn$_invoke$arity$1$(0):$creator$$(0),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$negative_listener$$],null)]))};
$instaparse$gll$fail$$=function($tramp$jscomp$14$$,$node_key$jscomp$8$$,$index$jscomp$420$$,$reason$jscomp$29$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$847$failure$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$),function($failure$jscomp$3$$){var $G__77223_current_index$jscomp$6$$=$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($failure$jscomp$3$$);$G__77223_current_index$jscomp$6$$=$APP.$cljs$core$compare$$($index$jscomp$420$$,$G__77223_current_index$jscomp$6$$);
switch($G__77223_current_index$jscomp$6$$){case 1:return new $instaparse$gll$Failure$$($index$jscomp$420$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$reason$jscomp$29$$],null),null,null,null);case 0:return new $instaparse$gll$Failure$$($index$jscomp$420$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$984$reason$$.$cljs$core$IFn$_invoke$arity$1$($failure$jscomp$3$$),$reason$jscomp$29$$),null,null,null);case -1:return $failure$jscomp$3$$;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77223_current_index$jscomp$6$$)].join(""));}});return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$420$$,$cljs$cst$5573$fail_index$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$))?$instaparse$gll$push_result$$($tramp$jscomp$14$$,$node_key$jscomp$8$$,$instaparse$gll$make_success$$(function(){var $G__77224$$=$cljs$cst$5574$node_builder$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$);
var $G__77226_G__77229$jscomp$inline_8763$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$);$G__77226_G__77229$jscomp$inline_8763$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($G__77226_G__77229$jscomp$inline_8763$$,$index$jscomp$420$$):$APP.$cljs$core$subs$$($G__77226_G__77229$jscomp$inline_8763$$,$index$jscomp$420$$);var $G__77228$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$));
return $instaparse$gll$build_node_with_meta$$.$cljs$core$IFn$_invoke$arity$5$?$instaparse$gll$build_node_with_meta$$.$cljs$core$IFn$_invoke$arity$5$($G__77224$$,$cljs$cst$5602$instaparse_SLASH_failure$$,$G__77226_G__77229$jscomp$inline_8763$$,$index$jscomp$420$$,$G__77228$$):$instaparse$gll$build_node_with_meta$$($G__77224$$,$cljs$cst$5602$instaparse_SLASH_failure$$,$G__77226_G__77229$jscomp$inline_8763$$,$index$jscomp$420$$,$G__77228$$)}(),$APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$14$$)))):
null};$instaparse$gll$step$$=function($stack$jscomp$36$$){var $top$jscomp$10$$=$APP.$cljs$core$peek$$($APP.$cljs$core$_deref$$($stack$jscomp$36$$));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($stack$jscomp$36$$,$APP.$cljs$core$pop$$);$top$jscomp$10$$.$cljs$core$IFn$_invoke$arity$0$?$top$jscomp$10$$.$cljs$core$IFn$_invoke$arity$0$():$top$jscomp$10$$()};
$instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$=function($tramp$jscomp$16$$,$found_result_QMARK__next_stack$jscomp$4$$){for(;;){var $index$jscomp$421_stack$jscomp$37$$=$APP.$cljs$cst$3735$stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$deref$$($APP.$cljs$cst$2355$success$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$))))return $APP.$cljs$core$cons$$($APP.$cljs$cst$828$result$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$deref$$($APP.$cljs$cst$2355$success$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$))),
new $APP.$cljs$core$LazySeq$$(null,function($tramp$jscomp$17$$){return function(){$APP.$cljs$core$reset_BANG_$$($APP.$cljs$cst$2355$success$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$17$$),null);return $instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$($tramp$jscomp$17$$,!0)}}($tramp$jscomp$16$$,$found_result_QMARK__next_stack$jscomp$4$$,$index$jscomp$421_stack$jscomp$37$$),null,null));if($APP.$cljs$core$count$$($APP.$cljs$core$_deref$$($index$jscomp$421_stack$jscomp$37$$))>0)$instaparse$gll$step$$($index$jscomp$421_stack$jscomp$37$$);
else if($APP.$cljs$core$count$$($APP.$cljs$core$deref$$($cljs$cst$5577$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$)))>0){var $listeners$jscomp$5_vec__77233$$=$APP.$cljs$core$first$$($APP.$cljs$core$deref$$($cljs$cst$5577$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$)));$index$jscomp$421_stack$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($listeners$jscomp$5_vec__77233$$,0,null);$listeners$jscomp$5_vec__77233$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($listeners$jscomp$5_vec__77233$$,
1,null);var $listener$jscomp$107$$=$APP.$cljs$core$peek$$($listeners$jscomp$5_vec__77233$$);$listener$jscomp$107$$.$cljs$core$IFn$_invoke$arity$0$?$listener$jscomp$107$$.$cljs$core$IFn$_invoke$arity$0$():$listener$jscomp$107$$();$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($listeners$jscomp$5_vec__77233$$),1)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($cljs$cst$5577$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$),$APP.$cljs$core$dissoc$$,
$index$jscomp$421_stack$jscomp$37$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($cljs$cst$5577$negative_listeners$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$),$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$421_stack$jscomp$37$$],null),$APP.$cljs$core$pop$$)}else if($APP.$cljs$core$truth_$$($found_result_QMARK__next_stack$jscomp$4$$))$found_result_QMARK__next_stack$jscomp$4$$=$cljs$cst$5575$next_stack$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$),
$APP.$cljs$core$reset_BANG_$$($index$jscomp$421_stack$jscomp$37$$,$APP.$cljs$core$_deref$$($found_result_QMARK__next_stack$jscomp$4$$)),$APP.$cljs$core$reset_BANG_$$($found_result_QMARK__next_stack$jscomp$4$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5576$generation$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$16$$),$APP.$cljs$core$inc$$),$found_result_QMARK__next_stack$jscomp$4$$=null;else return null}};
$instaparse$gll$NodeListener$$=function($node_key$jscomp$9$$,$tramp$jscomp$18$$){return function($result$jscomp$355$$){return $instaparse$gll$push_result$$($tramp$jscomp$18$$,$node_key$jscomp$9$$,$result$jscomp$355$$)}};
$instaparse$gll$LookListener$$=function($node_key$jscomp$10$$,$tramp$jscomp$19$$){return function(){return $instaparse$gll$push_result$$($tramp$jscomp$19$$,$node_key$jscomp$10$$,$instaparse$gll$make_success$$(null,$node_key$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$node_key$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$(0):$node_key$jscomp$10$$(0)))}};
$instaparse$gll$TopListener$$=function($tramp$jscomp$26$$){return function($result$jscomp$363$$){return $APP.$cljs$core$reset_BANG_$$($APP.$cljs$cst$2355$success$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$26$$),$result$jscomp$363$$)}};
$instaparse$gll$string_parse$$=function($this$$jscomp$770$$,$index$jscomp$422$$,$tramp$jscomp$27$$){var $string$jscomp$22$$=$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$770$$),$head$jscomp$24_text$jscomp$93$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$27$$);var $end$jscomp$96_x__5113__auto__$jscomp$inline_8767$$=$APP.$cljs$core$count$$($head$jscomp$24_text$jscomp$93$$);var $y__5114__auto__$jscomp$inline_8768$$=$index$jscomp$422$$+$APP.$cljs$core$count$$($string$jscomp$22$$);
$end$jscomp$96_x__5113__auto__$jscomp$inline_8767$$=$end$jscomp$96_x__5113__auto__$jscomp$inline_8767$$<$y__5114__auto__$jscomp$inline_8768$$?$end$jscomp$96_x__5113__auto__$jscomp$inline_8767$$:$y__5114__auto__$jscomp$inline_8768$$;$head$jscomp$24_text$jscomp$93$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$24_text$jscomp$93$$,$index$jscomp$422$$,$end$jscomp$96_x__5113__auto__$jscomp$inline_8767$$):$APP.$cljs$core$subs$$($head$jscomp$24_text$jscomp$93$$,
$index$jscomp$422$$,$end$jscomp$96_x__5113__auto__$jscomp$inline_8767$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($string$jscomp$22$$,$head$jscomp$24_text$jscomp$93$$)?$instaparse$gll$push_result$$($tramp$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$422$$,$this$$jscomp$770$$],null),$instaparse$gll$make_success$$($string$jscomp$22$$,$end$jscomp$96_x__5113__auto__$jscomp$inline_8767$$)):$instaparse$gll$fail$$($tramp$jscomp$27$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$422$$,$this$$jscomp$770$$],null),$index$jscomp$422$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$cljs$cst$5560$expecting$$,$string$jscomp$22$$],null))};
$instaparse$gll$string_full_parse$$=function($this$$jscomp$771$$,$index$jscomp$423$$,$tramp$jscomp$28$$){var $string$jscomp$23$$=$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$771$$),$text$jscomp$94$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$28$$);var $end$jscomp$97_x__5113__auto__$jscomp$inline_8770$$=$APP.$cljs$core$count$$($text$jscomp$94$$);var $head$jscomp$25_y__5114__auto__$jscomp$inline_8771$$=$index$jscomp$423$$+$APP.$cljs$core$count$$($string$jscomp$23$$);
$end$jscomp$97_x__5113__auto__$jscomp$inline_8770$$=$end$jscomp$97_x__5113__auto__$jscomp$inline_8770$$<$head$jscomp$25_y__5114__auto__$jscomp$inline_8771$$?$end$jscomp$97_x__5113__auto__$jscomp$inline_8770$$:$head$jscomp$25_y__5114__auto__$jscomp$inline_8771$$;$head$jscomp$25_y__5114__auto__$jscomp$inline_8771$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($text$jscomp$94$$,$index$jscomp$423$$,$end$jscomp$97_x__5113__auto__$jscomp$inline_8770$$):
$APP.$cljs$core$subs$$($text$jscomp$94$$,$index$jscomp$423$$,$end$jscomp$97_x__5113__auto__$jscomp$inline_8770$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$97_x__5113__auto__$jscomp$inline_8770$$,$APP.$cljs$core$count$$($text$jscomp$94$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($string$jscomp$23$$,$head$jscomp$25_y__5114__auto__$jscomp$inline_8771$$)?$instaparse$gll$push_result$$($tramp$jscomp$28$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$423$$,$this$$jscomp$771$$],null),$instaparse$gll$make_success$$($string$jscomp$23$$,$end$jscomp$97_x__5113__auto__$jscomp$inline_8770$$)):$instaparse$gll$fail$$($tramp$jscomp$28$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$423$$,$this$$jscomp$771$$],null),$index$jscomp$423$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$cljs$cst$5560$expecting$$,$string$jscomp$23$$,
$APP.$cljs$cst$1278$full$$,!0],null))};
$instaparse$gll$string_case_insensitive_parse$$=function($this$$jscomp$772$$,$index$jscomp$424$$,$tramp$jscomp$29$$){var $string$jscomp$24$$=$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$772$$),$head$jscomp$26_text$jscomp$95$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$29$$);var $end$jscomp$98_x__5113__auto__$jscomp$inline_8773$$=$APP.$cljs$core$count$$($head$jscomp$26_text$jscomp$95$$);var $y__5114__auto__$jscomp$inline_8774$$=$index$jscomp$424$$+
$APP.$cljs$core$count$$($string$jscomp$24$$);$end$jscomp$98_x__5113__auto__$jscomp$inline_8773$$=$end$jscomp$98_x__5113__auto__$jscomp$inline_8773$$<$y__5114__auto__$jscomp$inline_8774$$?$end$jscomp$98_x__5113__auto__$jscomp$inline_8773$$:$y__5114__auto__$jscomp$inline_8774$$;$head$jscomp$26_text$jscomp$95$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($head$jscomp$26_text$jscomp$95$$,$index$jscomp$424$$,$end$jscomp$98_x__5113__auto__$jscomp$inline_8773$$):
$APP.$cljs$core$subs$$($head$jscomp$26_text$jscomp$95$$,$index$jscomp$424$$,$end$jscomp$98_x__5113__auto__$jscomp$inline_8773$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($string$jscomp$24$$.toUpperCase(),$head$jscomp$26_text$jscomp$95$$.toUpperCase())?$instaparse$gll$push_result$$($tramp$jscomp$29$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$424$$,$this$$jscomp$772$$],null),$instaparse$gll$make_success$$($string$jscomp$24$$,
$end$jscomp$98_x__5113__auto__$jscomp$inline_8773$$)):$instaparse$gll$fail$$($tramp$jscomp$29$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$424$$,$this$$jscomp$772$$],null),$index$jscomp$424$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$cljs$cst$5560$expecting$$,$string$jscomp$24$$],null))};
$instaparse$gll$string_case_insensitive_full_parse$$=function($this$$jscomp$773$$,$index$jscomp$425$$,$tramp$jscomp$30$$){var $string$jscomp$25$$=$APP.$cljs$cst$198$string$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$773$$),$text$jscomp$96$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$30$$);var $end$jscomp$99_x__5113__auto__$jscomp$inline_8776$$=$APP.$cljs$core$count$$($text$jscomp$96$$);var $head$jscomp$27_y__5114__auto__$jscomp$inline_8777$$=$index$jscomp$425$$+$APP.$cljs$core$count$$($string$jscomp$25$$);
$end$jscomp$99_x__5113__auto__$jscomp$inline_8776$$=$end$jscomp$99_x__5113__auto__$jscomp$inline_8776$$<$head$jscomp$27_y__5114__auto__$jscomp$inline_8777$$?$end$jscomp$99_x__5113__auto__$jscomp$inline_8776$$:$head$jscomp$27_y__5114__auto__$jscomp$inline_8777$$;$head$jscomp$27_y__5114__auto__$jscomp$inline_8777$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($text$jscomp$96$$,$index$jscomp$425$$,$end$jscomp$99_x__5113__auto__$jscomp$inline_8776$$):
$APP.$cljs$core$subs$$($text$jscomp$96$$,$index$jscomp$425$$,$end$jscomp$99_x__5113__auto__$jscomp$inline_8776$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$99_x__5113__auto__$jscomp$inline_8776$$,$APP.$cljs$core$count$$($text$jscomp$96$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($string$jscomp$25$$.toUpperCase(),$head$jscomp$27_y__5114__auto__$jscomp$inline_8777$$.toUpperCase())?$instaparse$gll$push_result$$($tramp$jscomp$30$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$425$$,$this$$jscomp$773$$],null),$instaparse$gll$make_success$$($string$jscomp$25$$,$end$jscomp$99_x__5113__auto__$jscomp$inline_8776$$)):$instaparse$gll$fail$$($tramp$jscomp$30$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$425$$,$this$$jscomp$773$$],null),$index$jscomp$425$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,
$cljs$cst$5560$expecting$$,$string$jscomp$25$$,$APP.$cljs$cst$1278$full$$,!0],null))};
$instaparse$gll$char_range_parse$$=function($this$$jscomp$774$$,$index$jscomp$428$$,$tramp$jscomp$31$$){var $lo$jscomp$7$$=$cljs$cst$5548$lo$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$774$$),$hi$jscomp$9$$=$cljs$cst$5549$hi$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$774$$),$code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$31$$);if($index$jscomp$428$$>=$APP.$cljs$core$count$$($code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$))return $instaparse$gll$fail$$($tramp$jscomp$31$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$774$$],null),$index$jscomp$428$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5568$char$$,$cljs$cst$5560$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5559$char_range$$,!0,$cljs$cst$5548$lo$$,$lo$jscomp$7$$,$cljs$cst$5549$hi$$,$hi$jscomp$9$$],null)],null));if($hi$jscomp$9$$<=65535)return $code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$=
$code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$.charCodeAt($index$jscomp$428$$),$lo$jscomp$7$$<=$code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$&&$code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$<=$hi$jscomp$9$$?$instaparse$gll$push_result$$($tramp$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$774$$],null),$instaparse$gll$make_success$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$char$0$$($code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$)),
$index$jscomp$428$$+1)):$instaparse$gll$fail$$($tramp$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$774$$],null),$index$jscomp$428$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5568$char$$,$cljs$cst$5560$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5559$char_range$$,!0,$cljs$cst$5548$lo$$,$lo$jscomp$7$$,$cljs$cst$5549$hi$$,$hi$jscomp$9$$],
null)],null));$code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$=$goog$i18n$uChar$getCodePointAround$$($code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$,$index$jscomp$428$$|0);var $char_string$$=$goog$i18n$uChar$fromCharCode$$($code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$);return $lo$jscomp$7$$<=$code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$&&$code$jscomp$62_code_point$jscomp$2_text$jscomp$99$$<=$hi$jscomp$9$$?$instaparse$gll$push_result$$($tramp$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$774$$],null),$instaparse$gll$make_success$$($char_string$$,$index$jscomp$428$$+$APP.$cljs$core$count$$($char_string$$))):$instaparse$gll$fail$$($tramp$jscomp$31$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$428$$,$this$$jscomp$774$$],null),$index$jscomp$428$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5568$char$$,
$cljs$cst$5560$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5559$char_range$$,!0,$cljs$cst$5548$lo$$,$lo$jscomp$7$$,$cljs$cst$5549$hi$$,$hi$jscomp$9$$],null)],null))};
$instaparse$gll$char_range_full_parse$$=function($this$$jscomp$775$$,$index$jscomp$429$$,$tramp$jscomp$32$$){var $lo$jscomp$8$$=$cljs$cst$5548$lo$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$775$$),$hi$jscomp$10$$=$cljs$cst$5549$hi$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$775$$),$code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$32$$),$end$jscomp$100$$=$APP.$cljs$core$count$$($code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$);
if($index$jscomp$429$$>=$APP.$cljs$core$count$$($code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$))return $instaparse$gll$fail$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$429$$,$this$$jscomp$775$$],null),$index$jscomp$429$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5568$char$$,$cljs$cst$5560$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5559$char_range$$,
!0,$cljs$cst$5548$lo$$,$lo$jscomp$8$$,$cljs$cst$5549$hi$$,$hi$jscomp$10$$],null)],null));if($hi$jscomp$10$$<=65535)return $code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$=$code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$.charCodeAt($index$jscomp$429$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$429$$+1,$end$jscomp$100$$)&&$lo$jscomp$8$$<=$code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$&&$code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$<=$hi$jscomp$10$$?
$instaparse$gll$push_result$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$429$$,$this$$jscomp$775$$],null),$instaparse$gll$make_success$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$char$0$$($code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$)),$end$jscomp$100$$)):$instaparse$gll$fail$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$429$$,$this$$jscomp$775$$],null),$index$jscomp$429$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5568$char$$,$cljs$cst$5560$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5559$char_range$$,!0,$cljs$cst$5548$lo$$,$lo$jscomp$8$$,$cljs$cst$5549$hi$$,$hi$jscomp$10$$],null)],null));$code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$=$goog$i18n$uChar$getCodePointAround$$($code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$,
$index$jscomp$429$$|0);var $char_string$jscomp$1$$=$goog$i18n$uChar$fromCharCode$$($code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$429$$+$APP.$cljs$core$count$$($char_string$jscomp$1$$),$end$jscomp$100$$)&&$lo$jscomp$8$$<=$code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$&&$code$jscomp$63_code_point$jscomp$3_text$jscomp$100$$<=$hi$jscomp$10$$?$instaparse$gll$push_result$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$429$$,$this$$jscomp$775$$],null),$instaparse$gll$make_success$$($char_string$jscomp$1$$,$end$jscomp$100$$)):$instaparse$gll$fail$$($tramp$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$429$$,$this$$jscomp$775$$],null),$index$jscomp$429$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5568$char$$,$cljs$cst$5560$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5559$char_range$$,!0,$cljs$cst$5548$lo$$,$lo$jscomp$8$$,$cljs$cst$5549$hi$$,$hi$jscomp$10$$],null),$APP.$cljs$cst$1278$full$$,!0],null))};
$instaparse$gll$re_match_at_front$$=function($m$jscomp$227_regexp$jscomp$3$$,$text$jscomp$101$$){$m$jscomp$227_regexp$jscomp$3$$=(new RegExp($m$jscomp$227_regexp$jscomp$3$$.source,["g",$instaparse$util$regexp_flags$$($m$jscomp$227_regexp$jscomp$3$$)].join(""))).exec($text$jscomp$101$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($m$jscomp$227_regexp$jscomp$3$$)?$m$jscomp$227_regexp$jscomp$3$$.index===0:$m$jscomp$227_regexp$jscomp$3$$)?$APP.$cljs$core$first$$($m$jscomp$227_regexp$jscomp$3$$):
null};
$instaparse$gll$regexp_parse$$=function($this$$jscomp$776$$,$index$jscomp$430$$,$tramp$jscomp$33$$){var $regexp$jscomp$4$$=$cljs$cst$5553$regexp$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$776$$),$match$jscomp$56_substring_text$jscomp$102$$=$APP.$cljs$cst$1867$segment$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$33$$);$match$jscomp$56_substring_text$jscomp$102$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($match$jscomp$56_substring_text$jscomp$102$$,$index$jscomp$430$$):
$APP.$cljs$core$subs$$($match$jscomp$56_substring_text$jscomp$102$$,$index$jscomp$430$$);$match$jscomp$56_substring_text$jscomp$102$$=$instaparse$gll$re_match_at_front$$($regexp$jscomp$4$$,$match$jscomp$56_substring_text$jscomp$102$$);return $APP.$cljs$core$truth_$$($match$jscomp$56_substring_text$jscomp$102$$)?$instaparse$gll$push_result$$($tramp$jscomp$33$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$430$$,$this$$jscomp$776$$],null),
$instaparse$gll$make_success$$($match$jscomp$56_substring_text$jscomp$102$$,$index$jscomp$430$$+$APP.$cljs$core$count$$($match$jscomp$56_substring_text$jscomp$102$$))):$instaparse$gll$fail$$($tramp$jscomp$33$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$430$$,$this$$jscomp$776$$],null),$index$jscomp$430$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5553$regexp$$,$cljs$cst$5560$expecting$$,$regexp$jscomp$4$$],
null))};
$instaparse$gll$regexp_full_parse$$=function($this$$jscomp$777$$,$index$jscomp$431$$,$tramp$jscomp$34$$){var $regexp$jscomp$5$$=$cljs$cst$5553$regexp$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$777$$),$text$jscomp$103$$=$APP.$cljs$cst$1867$segment$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$34$$),$match$jscomp$57_substring$jscomp$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($text$jscomp$103$$,$index$jscomp$431$$):$APP.$cljs$core$subs$$($text$jscomp$103$$,
$index$jscomp$431$$);$match$jscomp$57_substring$jscomp$1$$=$instaparse$gll$re_match_at_front$$($regexp$jscomp$5$$,$match$jscomp$57_substring$jscomp$1$$);var $desired_length$$=$APP.$cljs$core$count$$($text$jscomp$103$$)-$index$jscomp$431$$;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($match$jscomp$57_substring$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($match$jscomp$57_substring$jscomp$1$$),$desired_length$$):$match$jscomp$57_substring$jscomp$1$$)?
$instaparse$gll$push_result$$($tramp$jscomp$34$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$431$$,$this$$jscomp$777$$],null),$instaparse$gll$make_success$$($match$jscomp$57_substring$jscomp$1$$,$APP.$cljs$core$count$$($text$jscomp$103$$))):$instaparse$gll$fail$$($tramp$jscomp$34$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$431$$,$this$$jscomp$777$$],null),$index$jscomp$431$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5553$regexp$$,$cljs$cst$5560$expecting$$,$regexp$jscomp$5$$,$APP.$cljs$cst$1278$full$$,!0],null))};
$instaparse$gll$cat_parse$$=function($this$$jscomp$778$$,$index$jscomp$432$$,$tramp$jscomp$35$$){var $parsers$jscomp$10$$=$cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$778$$);return $instaparse$gll$push_listener$$($tramp$jscomp$35$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$432$$,$APP.$cljs$core$first$$($parsers$jscomp$10$$)],null),$instaparse$gll$CatListener$$($instaparse$auto_flatten_seq$EMPTY$$,$APP.$cljs$core$next$$($parsers$jscomp$10$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$432$$,$this$$jscomp$778$$],null),$tramp$jscomp$35$$))};
$instaparse$gll$cat_full_parse$$=function($this$$jscomp$779$$,$index$jscomp$433$$,$tramp$jscomp$36$$){var $parsers$jscomp$11$$=$cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$779$$);return $instaparse$gll$push_listener$$($tramp$jscomp$36$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$433$$,$APP.$cljs$core$first$$($parsers$jscomp$11$$)],null),$instaparse$gll$CatFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,
$APP.$cljs$core$next$$($parsers$jscomp$11$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$433$$,$this$$jscomp$779$$],null),$tramp$jscomp$36$$))};
$instaparse$gll$plus_parse$$=function($this$$jscomp$780$$,$index$jscomp$434$$,$tramp$jscomp$37$$){var $parser$jscomp$42$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$780$$);return $instaparse$gll$push_listener$$($tramp$jscomp$37$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$434$$,$parser$jscomp$42$$],null),$instaparse$gll$PlusListener$$($instaparse$auto_flatten_seq$EMPTY$$,$parser$jscomp$42$$,$index$jscomp$434$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$434$$,$this$$jscomp$780$$],null),$tramp$jscomp$37$$))};
$instaparse$gll$plus_full_parse$$=function($this$$jscomp$781$$,$index$jscomp$435$$,$tramp$jscomp$38$$){var $parser$jscomp$43$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$781$$);return $instaparse$gll$push_listener$$($tramp$jscomp$38$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$435$$,$parser$jscomp$43$$],null),$instaparse$gll$PlusFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,$parser$jscomp$43$$,$index$jscomp$435$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$435$$,$this$$jscomp$781$$],null),$tramp$jscomp$38$$))};
$instaparse$gll$rep_parse$$=function($this$$jscomp$782$$,$index$jscomp$436$$,$tramp$jscomp$39$$){var $parser$jscomp$44$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$782$$),$m$jscomp$228$$=$APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$782$$),$n$jscomp$297$$=$APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$782$$);return $m$jscomp$228$$===0?($instaparse$gll$push_result$$($tramp$jscomp$39$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$this$$jscomp$782$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$436$$)),$n$jscomp$297$$>=1?$instaparse$gll$push_listener$$($tramp$jscomp$39$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$parser$jscomp$44$$],null),$instaparse$gll$RepListener$$($instaparse$auto_flatten_seq$EMPTY$$,0,$parser$jscomp$44$$,1,$n$jscomp$297$$,$index$jscomp$436$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$this$$jscomp$782$$],null),$tramp$jscomp$39$$)):null):$instaparse$gll$push_listener$$($tramp$jscomp$39$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$parser$jscomp$44$$],null),$instaparse$gll$RepListener$$($instaparse$auto_flatten_seq$EMPTY$$,0,$parser$jscomp$44$$,$m$jscomp$228$$,$n$jscomp$297$$,$index$jscomp$436$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$436$$,$this$$jscomp$782$$],null),$tramp$jscomp$39$$))};
$instaparse$gll$rep_full_parse$$=function($this$$jscomp$783$$,$index$jscomp$437$$,$tramp$jscomp$40$$){var $parser$jscomp$45$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$783$$),$m$jscomp$229$$=$APP.$cljs$cst$338$min$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$783$$),$n$jscomp$298$$=$APP.$cljs$cst$339$max$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$783$$);return $m$jscomp$229$$===0?($instaparse$gll$push_result$$($tramp$jscomp$40$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$437$$,$this$$jscomp$783$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$437$$)),$n$jscomp$298$$>=1?$instaparse$gll$push_listener$$($tramp$jscomp$40$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$437$$,$parser$jscomp$45$$],null),$instaparse$gll$RepFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,0,$parser$jscomp$45$$,1,$n$jscomp$298$$,$index$jscomp$437$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$437$$,$this$$jscomp$783$$],null),$tramp$jscomp$40$$)):null):$instaparse$gll$push_listener$$($tramp$jscomp$40$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$437$$,$parser$jscomp$45$$],null),$instaparse$gll$RepFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,0,$parser$jscomp$45$$,$m$jscomp$229$$,$n$jscomp$298$$,$index$jscomp$437$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$437$$,$this$$jscomp$783$$],null),$tramp$jscomp$40$$))};
$instaparse$gll$star_parse$$=function($this$$jscomp$784$$,$index$jscomp$438$$,$tramp$jscomp$41$$){var $parser$jscomp$46$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$784$$);$instaparse$gll$push_listener$$($tramp$jscomp$41$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$438$$,$parser$jscomp$46$$],null),$instaparse$gll$PlusListener$$($instaparse$auto_flatten_seq$EMPTY$$,$parser$jscomp$46$$,$index$jscomp$438$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$438$$,$this$$jscomp$784$$],null),$tramp$jscomp$41$$));return $instaparse$gll$push_result$$($tramp$jscomp$41$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$438$$,$this$$jscomp$784$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$438$$))};
$instaparse$gll$star_full_parse$$=function($this$$jscomp$785$$,$index$jscomp$439$$,$tramp$jscomp$42$$){var $parser$jscomp$47$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$785$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$439$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$42$$)))?$instaparse$gll$push_result$$($tramp$jscomp$42$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$439$$,$this$$jscomp$785$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$439$$)):$instaparse$gll$push_listener$$($tramp$jscomp$42$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$439$$,$parser$jscomp$47$$],null),$instaparse$gll$PlusFullListener$$($instaparse$auto_flatten_seq$EMPTY$$,$parser$jscomp$47$$,$index$jscomp$439$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$439$$,$this$$jscomp$785$$],null),$tramp$jscomp$42$$))};
$instaparse$gll$alt_parse$$=function($this$$jscomp$786$$,$index$jscomp$440$$,$tramp$jscomp$43$$){var $c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$=$cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$786$$);$c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$);for(var $G__77592_chunk__77255_seq__77254__$1$$=
null,$G__77591_count__77256$$=0,$i__77257$$=0;;)if($i__77257$$<$G__77591_count__77256$$){var $G__77593_parser$jscomp$48$$=$G__77592_chunk__77255_seq__77254__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__77257$$);$instaparse$gll$push_listener$$($tramp$jscomp$43$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$440$$,$G__77593_parser$jscomp$48$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$440$$,$this$$jscomp$786$$],null),$tramp$jscomp$43$$));$i__77257$$+=1}else if($c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$))$G__77592_chunk__77255_seq__77254__$1$$=$c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77592_chunk__77255_seq__77254__$1$$)?($c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$=
$APP.$cljs$core$_chunked_first$$($G__77592_chunk__77255_seq__77254__$1$$),$G__77591_count__77256$$=$APP.$cljs$core$_chunked_rest$$($G__77592_chunk__77255_seq__77254__$1$$),$G__77592_chunk__77255_seq__77254__$1$$=$c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$,$G__77593_parser$jscomp$48$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$),$c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$=
$G__77591_count__77256$$,$G__77591_count__77256$$=$G__77593_parser$jscomp$48$$):($G__77593_parser$jscomp$48$$=$APP.$cljs$core$first$$($G__77592_chunk__77255_seq__77254__$1$$),$instaparse$gll$push_listener$$($tramp$jscomp$43$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$440$$,$G__77593_parser$jscomp$48$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$440$$,$this$$jscomp$786$$],null),$tramp$jscomp$43$$)),$c__5548__auto__$jscomp$43_parsers$jscomp$12_seq__77254_temp__5825__auto__$jscomp$352$$=$APP.$cljs$core$next$$($G__77592_chunk__77255_seq__77254__$1$$),$G__77592_chunk__77255_seq__77254__$1$$=null,$G__77591_count__77256$$=0),$i__77257$$=0;else return null};
$instaparse$gll$alt_full_parse$$=function($this$$jscomp$787$$,$index$jscomp$441$$,$tramp$jscomp$44$$){var $c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$=$cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$787$$);$c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$);for(var $G__77608_chunk__77259_seq__77258__$1$$=
null,$G__77607_count__77260$$=0,$i__77261$$=0;;)if($i__77261$$<$G__77607_count__77260$$){var $G__77609_parser$jscomp$49$$=$G__77608_chunk__77259_seq__77258__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__77261$$);$instaparse$gll$push_full_listener$$($tramp$jscomp$44$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$441$$,$G__77609_parser$jscomp$49$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$441$$,$this$$jscomp$787$$],null),$tramp$jscomp$44$$));$i__77261$$+=1}else if($c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$))$G__77608_chunk__77259_seq__77258__$1$$=$c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77608_chunk__77259_seq__77258__$1$$)?($c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$=
$APP.$cljs$core$_chunked_first$$($G__77608_chunk__77259_seq__77258__$1$$),$G__77607_count__77260$$=$APP.$cljs$core$_chunked_rest$$($G__77608_chunk__77259_seq__77258__$1$$),$G__77608_chunk__77259_seq__77258__$1$$=$c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$,$G__77609_parser$jscomp$49$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$),$c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$=
$G__77607_count__77260$$,$G__77607_count__77260$$=$G__77609_parser$jscomp$49$$):($G__77609_parser$jscomp$49$$=$APP.$cljs$core$first$$($G__77608_chunk__77259_seq__77258__$1$$),$instaparse$gll$push_full_listener$$($tramp$jscomp$44$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$441$$,$G__77609_parser$jscomp$49$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$441$$,$this$$jscomp$787$$],null),$tramp$jscomp$44$$)),$c__5548__auto__$jscomp$44_parsers$jscomp$13_seq__77258_temp__5825__auto__$jscomp$353$$=$APP.$cljs$core$next$$($G__77608_chunk__77259_seq__77258__$1$$),$G__77608_chunk__77259_seq__77258__$1$$=null,$G__77607_count__77260$$=0),$i__77261$$=0;else return null};
$instaparse$gll$ordered_alt_parse$$=function($this$$jscomp$788$$,$index$jscomp$442$$,$tramp$jscomp$45$$){var $node_key_parser1_parser1$jscomp$3$$=$cljs$cst$5550$parser1$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$788$$),$parser2$jscomp$2$$=$cljs$cst$5551$parser2$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$788$$);$node_key_parser1_parser1$jscomp$3$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$442$$,$node_key_parser1_parser1$jscomp$3$$],
null);var $node_key_parser2$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$442$$,$parser2$jscomp$2$$],null),$listener$jscomp$108$$=$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$442$$,$this$$jscomp$788$$],null),$tramp$jscomp$45$$);$instaparse$gll$push_listener$$($tramp$jscomp$45$$,$node_key_parser1_parser1$jscomp$3$$,$listener$jscomp$108$$);return $instaparse$gll$push_negative_listener$$($tramp$jscomp$45$$,
$node_key_parser1_parser1$jscomp$3$$,function(){return $instaparse$gll$push_listener$$($tramp$jscomp$45$$,$node_key_parser2$$,$listener$jscomp$108$$)})};
$instaparse$gll$ordered_alt_full_parse$$=function($this$$jscomp$789$$,$index$jscomp$443$$,$tramp$jscomp$46$$){var $node_key_parser1$jscomp$1_parser1$jscomp$4$$=$cljs$cst$5550$parser1$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$789$$),$parser2$jscomp$3$$=$cljs$cst$5551$parser2$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$789$$);$node_key_parser1$jscomp$1_parser1$jscomp$4$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$443$$,$node_key_parser1$jscomp$1_parser1$jscomp$4$$],
null);var $node_key_parser2$jscomp$1$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$443$$,$parser2$jscomp$3$$],null),$listener$jscomp$109$$=$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$443$$,$this$$jscomp$789$$],null),$tramp$jscomp$46$$);$instaparse$gll$push_full_listener$$($tramp$jscomp$46$$,$node_key_parser1$jscomp$1_parser1$jscomp$4$$,$listener$jscomp$109$$);
return $instaparse$gll$push_negative_listener$$($tramp$jscomp$46$$,$node_key_parser1$jscomp$1_parser1$jscomp$4$$,function(){return $instaparse$gll$push_full_listener$$($tramp$jscomp$46$$,$node_key_parser2$jscomp$1$$,$listener$jscomp$109$$)})};
$instaparse$gll$opt_parse$$=function($this$$jscomp$790$$,$index$jscomp$444$$,$tramp$jscomp$47$$){var $parser$jscomp$50$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$790$$);$instaparse$gll$push_listener$$($tramp$jscomp$47$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$444$$,$parser$jscomp$50$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$444$$,$this$$jscomp$790$$],null),$tramp$jscomp$47$$));return $instaparse$gll$push_result$$($tramp$jscomp$47$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$444$$,$this$$jscomp$790$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$444$$))};
$instaparse$gll$opt_full_parse$$=function($this$$jscomp$791$$,$index$jscomp$445$$,$tramp$jscomp$48$$){var $parser$jscomp$51$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$791$$);$instaparse$gll$push_full_listener$$($tramp$jscomp$48$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$445$$,$parser$jscomp$51$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$445$$,$this$$jscomp$791$$],null),$tramp$jscomp$48$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$445$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$48$$)))?$instaparse$gll$push_result$$($tramp$jscomp$48$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$445$$,$this$$jscomp$791$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$445$$)):
$instaparse$gll$fail$$($tramp$jscomp$48$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$445$$,$this$$jscomp$791$$],null),$index$jscomp$445$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$450$optional$$,$cljs$cst$5560$expecting$$,$cljs$cst$5603$end_of_string$$],null))};
$instaparse$gll$non_terminal_parse$$=function($this$$jscomp$792$$,$index$jscomp$446$$,$tramp$jscomp$49$$){var $grammar$jscomp$inline_8779_parser$jscomp$52$$=$cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$49$$);var $p$jscomp$inline_8780$$=$APP.$cljs$cst$221$keyword$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$792$$);$grammar$jscomp$inline_8779_parser$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($grammar$jscomp$inline_8779_parser$jscomp$52$$,$p$jscomp$inline_8780$$,
$p$jscomp$inline_8780$$);return $instaparse$gll$push_listener$$($tramp$jscomp$49$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$446$$,$grammar$jscomp$inline_8779_parser$jscomp$52$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$446$$,$this$$jscomp$792$$],null),$tramp$jscomp$49$$))};
$instaparse$gll$non_terminal_full_parse$$=function($this$$jscomp$793$$,$index$jscomp$447$$,$tramp$jscomp$50$$){var $grammar$jscomp$inline_8782_parser$jscomp$53$$=$cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$50$$);var $p$jscomp$inline_8783$$=$APP.$cljs$cst$221$keyword$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$793$$);$grammar$jscomp$inline_8782_parser$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($grammar$jscomp$inline_8782_parser$jscomp$53$$,$p$jscomp$inline_8783$$,
$p$jscomp$inline_8783$$);return $instaparse$gll$push_full_listener$$($tramp$jscomp$50$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$447$$,$grammar$jscomp$inline_8782_parser$jscomp$53$$],null),$instaparse$gll$NodeListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$447$$,$this$$jscomp$793$$],null),$tramp$jscomp$50$$))};
$instaparse$gll$lookahead_parse$$=function($this$$jscomp$794$$,$index$jscomp$448$$,$tramp$jscomp$51$$){var $parser$jscomp$54$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$794$$);return $instaparse$gll$push_listener$$($tramp$jscomp$51$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$448$$,$parser$jscomp$54$$],null),$instaparse$gll$LookListener$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$448$$,$this$$jscomp$794$$],null),$tramp$jscomp$51$$))};
$instaparse$gll$lookahead_full_parse$$=function($this$$jscomp$795$$,$index$jscomp$449$$,$tramp$jscomp$52$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$449$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$52$$)))?$instaparse$gll$lookahead_parse$$($this$$jscomp$795$$,$index$jscomp$449$$,$tramp$jscomp$52$$):$instaparse$gll$fail$$($tramp$jscomp$52$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$449$$,$this$$jscomp$795$$],null),$index$jscomp$449$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5604$lookahead$$,$cljs$cst$5560$expecting$$,$cljs$cst$5603$end_of_string$$],null))};
$instaparse$gll$negative_lookahead_parse$$=function($this$$jscomp$796$$,$index$jscomp$450$$,$tramp$jscomp$53$$){var $parser$jscomp$55$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($this$$jscomp$796$$),$node_key$jscomp$17$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$450$$,$parser$jscomp$55$$],null);if($APP.$cljs$core$truth_$$($instaparse$gll$result_exists_QMARK_$$($tramp$jscomp$53$$,$node_key$jscomp$17$$)))return $instaparse$gll$fail$$($tramp$jscomp$53$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$450$$,$this$$jscomp$796$$],null),$index$jscomp$450$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5605$negative_lookahead$$],null));$instaparse$gll$push_listener$$($tramp$jscomp$53$$,$node_key$jscomp$17$$,function(){var $fail_send$$=new $APP.$cljs$core$Delay$$(function(){return $instaparse$gll$fail$$($tramp$jscomp$53$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$450$$,$this$$jscomp$796$$],null),$index$jscomp$450$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5605$negative_lookahead$$,$cljs$cst$5560$expecting$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5558$NOT$$,$instaparse$print$combinators__GT_str$cljs$0core$0IFn$0_invoke$0arity$02$$($parser$jscomp$55$$,!1)],null)],null))});return function(){return $APP.$cljs$core$force$$($fail_send$$)}}());
return $instaparse$gll$push_negative_listener$$($tramp$jscomp$53$$,$node_key$jscomp$17$$,function(){return $APP.$cljs$core$not$$($instaparse$gll$result_exists_QMARK_$$($tramp$jscomp$53$$,$node_key$jscomp$17$$))?$instaparse$gll$push_result$$($tramp$jscomp$53$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$450$$,$this$$jscomp$796$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$450$$)):null})};
$instaparse$gll$epsilon_parse$$=function($this$$jscomp$797$$,$index$jscomp$451$$,$tramp$jscomp$54$$){return $instaparse$gll$push_result$$($tramp$jscomp$54$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$451$$,$this$$jscomp$797$$],null),$instaparse$gll$make_success$$(null,$index$jscomp$451$$))};
$instaparse$gll$epsilon_full_parse$$=function($this$$jscomp$798$$,$index$jscomp$452$$,$tramp$jscomp$55$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$452$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$55$$)))?$instaparse$gll$push_result$$($tramp$jscomp$55$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$452$$,$this$$jscomp$798$$],null),$instaparse$gll$make_success$$(null,
$index$jscomp$452$$)):$instaparse$gll$fail$$($tramp$jscomp$55$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$452$$,$this$$jscomp$798$$],null),$index$jscomp$452$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5606$Epsilon$$,$cljs$cst$5560$expecting$$,$cljs$cst$5603$end_of_string$$],null))};
$instaparse$gll$start_parser$$=function($tramp$jscomp$56$$,$parser$jscomp$56$$,$partial_QMARK_$$){$APP.$cljs$core$truth_$$($partial_QMARK_$$)?$instaparse$gll$push_listener$$($tramp$jscomp$56$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,$parser$jscomp$56$$],null),$instaparse$gll$TopListener$$($tramp$jscomp$56$$)):$instaparse$gll$push_full_listener$$($tramp$jscomp$56$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[0,$parser$jscomp$56$$],null),$instaparse$gll$TopListener$$($tramp$jscomp$56$$))};
$instaparse$gll$parse$$=function($JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$,$JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$,$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$,$index$jscomp$inline_13691_lc$jscomp$inline_8787_partial_QMARK_$jscomp$2$$){$JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$=$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$($JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$,
$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$,$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$,-1,null);$instaparse$gll$start_parser$$($JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$,$instaparse$combinators_source$nt$$($JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$),
$index$jscomp$inline_13691_lc$jscomp$inline_8787_partial_QMARK_$jscomp$2$$);$JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$=$instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$,null);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$))$JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$=
$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$);else{$JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$=$APP.$cljs$core$deref$$($APP.$cljs$cst$847$failure$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$));a:{$index$jscomp$inline_13691_lc$jscomp$inline_8787_partial_QMARK_$jscomp$2$$=
$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$);for(var $G__76179$jscomp$inline_13704_G__76181$jscomp$inline_13706_col$jscomp$inline_13694_n$jscomp$inline_13699_n__$1$jscomp$inline_13702$$=$JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$=1,$G__76173$jscomp$inline_13696_G__76176$jscomp$inline_13697_counter$jscomp$inline_13695$$=0;;){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$inline_13691_lc$jscomp$inline_8787_partial_QMARK_$jscomp$2$$,
$G__76173$jscomp$inline_13696_G__76176$jscomp$inline_13697_counter$jscomp$inline_13695$$)){$index$jscomp$inline_13691_lc$jscomp$inline_8787_partial_QMARK_$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$209$line$$,$JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$,$APP.$cljs$cst$216$column$$,$G__76179$jscomp$inline_13704_G__76181$jscomp$inline_13706_col$jscomp$inline_13694_n$jscomp$inline_13699_n__$1$jscomp$inline_13702$$],null);
break a}$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$,$G__76173$jscomp$inline_13696_G__76176$jscomp$inline_13697_counter$jscomp$inline_13695$$))?($G__76173$jscomp$inline_13696_G__76176$jscomp$inline_13697_counter$jscomp$inline_13695$$+=1,$JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$+=
1,$G__76179$jscomp$inline_13704_G__76181$jscomp$inline_13706_col$jscomp$inline_13694_n$jscomp$inline_13699_n__$1$jscomp$inline_13702$$=1):($G__76173$jscomp$inline_13696_G__76176$jscomp$inline_13697_counter$jscomp$inline_13695$$+=1,$G__76179$jscomp$inline_13704_G__76181$jscomp$inline_13706_col$jscomp$inline_13694_n$jscomp$inline_13699_n__$1$jscomp$inline_13702$$+=1)}$index$jscomp$inline_13691_lc$jscomp$inline_8787_partial_QMARK_$jscomp$2$$=void 0}$JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$=
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$;a:{$G__76179$jscomp$inline_13704_G__76181$jscomp$inline_13706_col$jscomp$inline_13694_n$jscomp$inline_13699_n__$1$jscomp$inline_13702$$=$APP.$cljs$cst$209$line$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$inline_13691_lc$jscomp$inline_8787_partial_QMARK_$jscomp$2$$);for($G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$=$APP.$cljs$core$seq$$($APP.$clojure$string$replace$$($G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$,
"\r\n","\n"));;){if($APP.$cljs$core$empty_QMARK_$$($G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$)){$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$="";break a}if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__76179$jscomp$inline_13704_G__76181$jscomp$inline_13706_col$jscomp$inline_13694_n$jscomp$inline_13699_n__$1$jscomp$inline_13702$$,
1)){$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$APP.$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$complement$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,["\n",null],null),null)),$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$));
break a}$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$first$$($G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$))?($G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$=$APP.$cljs$core$next$$($G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$),
--$G__76179$jscomp$inline_13704_G__76181$jscomp$inline_13706_col$jscomp$inline_13694_n$jscomp$inline_13699_n__$1$jscomp$inline_13702$$):$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$=$APP.$cljs$core$next$$($G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$)}$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$=
void 0}$JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$=$JSCompiler_temp_const$jscomp$11285_grammar$jscomp$15_line$jscomp$inline_13693_tramp$jscomp$58$$.call($APP.$cljs$core$merge$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$,$index$jscomp$inline_13691_lc$jscomp$inline_8787_partial_QMARK_$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1593$text$$,$G__76178$jscomp$inline_13703_G__76180$jscomp$inline_13705_JSCompiler_inline_result$jscomp$11287_chars$jscomp$inline_13701_text$jscomp$105$$],null)]))}return $JSCompiler_temp$jscomp$1726_failure$jscomp$inline_8785_start$jscomp$236_temp__5823__auto__$jscomp$221$$};
$instaparse$gll$build_node_with_meta$$=function($node_builder$jscomp$4$$,$tag$jscomp$92$$,$content$jscomp$244$$,$start$jscomp$237$$,$end$jscomp$101$$){return $APP.$cljs$core$with_meta$$($node_builder$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$node_builder$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$92$$,$content$jscomp$244$$):$node_builder$jscomp$4$$($tag$jscomp$92$$,$content$jscomp$244$$),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5600$instaparse_DOT_gll_SLASH_start_index$$,
$start$jscomp$237$$,$cljs$cst$5601$instaparse_DOT_gll_SLASH_end_index$$,$end$jscomp$101$$],null))};
$instaparse$cfg$string_PLUS_$$=function($s$jscomp$573$$,$ci_by_default_QMARK_$$){var $G__77268$$=$instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!0,$G__77268$$))return $instaparse$combinators_source$string_ci$$($s$jscomp$573$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$G__77268$$))return $instaparse$combinators_source$string$$($s$jscomp$573$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$205$default$$,
$G__77268$$))return $APP.$cljs$core$truth_$$($ci_by_default_QMARK_$$)?$instaparse$combinators_source$string_ci$$($s$jscomp$573$$):$instaparse$combinators_source$string$$($s$jscomp$573$$);throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77268$$)].join(""));};
$instaparse$cfg$make_cfg$$=function($allow_namespaced_nts_QMARK_$$){return $instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5561$hiccup$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5571$neg$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5547$ord$$,$cljs$cst$5608$rule_separator$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5570$look$$,$cljs$cst$5609$rule$$,$cljs$cst$5569$nt$$,$cljs$cst$5610$hide_nt$$,$cljs$cst$5611$inside_comment$$,$cljs$cst$5565$star$$,$APP.$cljs$cst$198$string$$,
$APP.$cljs$cst$5612$rules$$,$APP.$cljs$cst$2356$hide$$,$cljs$cst$5613$paren$$,$cljs$cst$5614$alt_or_ord$$,$cljs$cst$5553$regexp$$,$cljs$cst$5615$factor$$,$APP.$cljs$cst$3485$comment$$,$cljs$cst$5564$plus$$,$cljs$cst$5563$epsilon$$,$cljs$cst$5607$opt_whitespace$$,$cljs$cst$5616$rules_or_parser$$,$APP.$cljs$cst$993$opt$$],[$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("!")),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5615$factor$$)])),$instaparse$combinators_source$plus$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5615$factor$$),
$instaparse$combinators_source$nt$$($cljs$cst$5570$look$$),$instaparse$combinators_source$nt$$($cljs$cst$5571$neg$$)])),$instaparse$cfg$opt_whitespace$$]))),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$594$cat$$),$instaparse$combinators_source$plus$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$cfg$opt_whitespace$$,
$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("/")),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($APP.$cljs$cst$594$cat$$)])))])),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(":"),$instaparse$combinators_source$string$$(":\x3d"),$instaparse$combinators_source$string$$("::\x3d"),$instaparse$combinators_source$string$$("\x3d")])),
$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$594$cat$$),$instaparse$combinators_source$star$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("|")),$instaparse$cfg$opt_whitespace$$,
$instaparse$combinators_source$nt$$($APP.$cljs$cst$594$cat$$)])))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x26")),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5615$factor$$)])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5569$nt$$),
$instaparse$combinators_source$nt$$($cljs$cst$5610$hide_nt$$)])),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$nt$$($cljs$cst$5608$rule_separator$$)),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5614$alt_or_ord$$),$instaparse$combinators_source$hide$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5607$opt_whitespace$$),
$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5607$opt_whitespace$$),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(";"),$instaparse$combinators_source$string$$(".")])),$instaparse$combinators_source$nt$$($cljs$cst$5607$opt_whitespace$$)]))])))])),
$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$neg$$($instaparse$combinators_source$nt$$($cljs$cst$5563$epsilon$$)),$instaparse$combinators_source$regexp$$($APP.$cljs$core$truth_$$($allow_namespaced_nts_QMARK_$$)?$instaparse$cfg$non_terminal_namespace_allowed$$:$instaparse$cfg$non_terminal$$)])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x3c")),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5569$nt$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x3e"))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$($instaparse$cfg$inside_comment$$),$instaparse$combinators_source$star$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$3485$comment$$),
$instaparse$combinators_source$regexp$$($instaparse$cfg$inside_comment$$)])))])),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("{")),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5614$alt_or_ord$$),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("}"))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5615$factor$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("*"))]))])),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$($instaparse$cfg$single_quoted_string$$),
$instaparse$combinators_source$regexp$$($instaparse$cfg$double_quoted_string$$)])),$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$plus$$($instaparse$combinators_source$nt$$($cljs$cst$5609$rule$$))]))),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x3c")),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5614$alt_or_ord$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("\x3e"))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("(")),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5614$alt_or_ord$$),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$(")"))])),$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$717$alt$$),$instaparse$combinators_source$nt$$($cljs$cst$5547$ord$$)]))),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$($instaparse$cfg$single_quoted_regexp$$),
$instaparse$combinators_source$regexp$$($instaparse$cfg$double_quoted_regexp$$)])),$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5569$nt$$),$instaparse$combinators_source$nt$$($APP.$cljs$cst$198$string$$),$instaparse$combinators_source$nt$$($cljs$cst$5553$regexp$$),$instaparse$combinators_source$nt$$($APP.$cljs$cst$993$opt$$),
$instaparse$combinators_source$nt$$($cljs$cst$5565$star$$),$instaparse$combinators_source$nt$$($cljs$cst$5564$plus$$),$instaparse$combinators_source$nt$$($cljs$cst$5613$paren$$),$instaparse$combinators_source$nt$$($APP.$cljs$cst$2356$hide$$),$instaparse$combinators_source$nt$$($cljs$cst$5563$epsilon$$)]))),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$("(*"),$instaparse$combinators_source$nt$$($cljs$cst$5611$inside_comment$$),
$instaparse$combinators_source$string$$("*)")])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5615$factor$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("+"))])),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$("Epsilon"),
$instaparse$combinators_source$string$$("epsilon"),$instaparse$combinators_source$string$$("EPSILON"),$instaparse$combinators_source$string$$("eps"),$instaparse$combinators_source$string$$("ε")])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$($instaparse$cfg$ws$$),$instaparse$combinators_source$star$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$3485$comment$$),
$instaparse$combinators_source$regexp$$($instaparse$cfg$ws$$)])))])),$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($APP.$cljs$cst$5612$rules$$),$instaparse$combinators_source$nt$$($cljs$cst$5614$alt_or_ord$$)]))),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("[")),
$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$nt$$($cljs$cst$5614$alt_or_ord$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("]"))])),$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$nt$$($cljs$cst$5615$factor$$),$instaparse$cfg$opt_whitespace$$,$instaparse$combinators_source$hide$$($instaparse$combinators_source$string$$("?"))]))]))]))};
$instaparse$cfg$escape$$=function($s$jscomp$574$$){for(var $G__77503_G__77505_G__77509_G__77511_sq$$=$APP.$cljs$core$seq$$($s$jscomp$574$$),$G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $c$jscomp$307_temp__5823__auto__$jscomp$224$$=$APP.$cljs$core$first$$($G__77503_G__77505_G__77509_G__77511_sq$$);if($APP.$cljs$core$truth_$$($c$jscomp$307_temp__5823__auto__$jscomp$224$$))switch($c$jscomp$307_temp__5823__auto__$jscomp$224$$){case "\\":var $c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$=
$APP.$cljs$core$second$$($G__77503_G__77505_G__77509_G__77511_sq$$);if($APP.$cljs$core$truth_$$($c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$)){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$,"'")?($G__77503_G__77505_G__77509_G__77511_sq$$=$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$G__77503_G__77505_G__77509_G__77511_sq$$),$G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$,
$c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$)):($G__77503_G__77505_G__77509_G__77511_sq$$=$APP.$cljs$core$drop$cljs$0core$0IFn$0_invoke$0arity$02$$(2,$G__77503_G__77505_G__77509_G__77511_sq$$),$G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$,$c$jscomp$307_temp__5823__auto__$jscomp$224$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c2$jscomp$26_temp__5823__auto____$1$jscomp$15$$])));
continue}else return $instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Encountered backslash character at end of string: ",$s$jscomp$574$$]));break;case '"':$G__77503_G__77505_G__77509_G__77511_sq$$=$APP.$cljs$core$next$$($G__77503_G__77505_G__77509_G__77511_sq$$);$G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$,
"\\",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(['"']));continue;default:$G__77503_G__77505_G__77509_G__77511_sq$$=$APP.$cljs$core$next$$($G__77503_G__77505_G__77509_G__77511_sq$$);$G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$,$c$jscomp$307_temp__5823__auto__$jscomp$224$$);continue}else return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$G__77504_G__77506_G__77510_G__77512_v$jscomp$660$$);break}};
$instaparse$cfg$process_string$$=function($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$){$G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$,1,$APP.$cljs$core$count$$($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$)-1);
$G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$=$instaparse$cfg$escape$$($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$);$G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$),'"'].join("");
$G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$=new $APP.$cljs$tools$reader$reader_types$PushbackReader$$(new $APP.$cljs$tools$reader$reader_types$StringReader$$($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$,$APP.$cljs$core$count$$($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$)));return $read_string_STAR__77513$$.$cljs$core$IFn$_invoke$arity$4$?
$read_string_STAR__77513$$.$cljs$core$IFn$_invoke$arity$4$($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$,null,null,null):$read_string_STAR__77513$$($G__77312$jscomp$inline_8802_remove_escaped_single_quotes_s$jscomp$576_s$jscomp$inline_8801_stripped$$,null,null,null)};
$instaparse$cfg$process_regexp$$=function($remove_escaped_single_quotes$jscomp$1_s$jscomp$577_stripped$jscomp$1$$){$remove_escaped_single_quotes$jscomp$1_s$jscomp$577_stripped$jscomp$1$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($remove_escaped_single_quotes$jscomp$1_s$jscomp$577_stripped$jscomp$1$$,2,$APP.$cljs$core$count$$($remove_escaped_single_quotes$jscomp$1_s$jscomp$577_stripped$jscomp$1$$)-1);$remove_escaped_single_quotes$jscomp$1_s$jscomp$577_stripped$jscomp$1$$=$instaparse$cfg$escape$$($remove_escaped_single_quotes$jscomp$1_s$jscomp$577_stripped$jscomp$1$$);
return $APP.$cljs$core$re_pattern$$($remove_escaped_single_quotes$jscomp$1_s$jscomp$577_stripped$jscomp$1$$)};
$instaparse$cfg$check_grammar$$=function($grammar_map$$){for(var $valid_nts_77525$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($grammar_map$$)),$c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$=$APP.$cljs$core$seq$$($APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($instaparse$cfg$seq_nt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($grammar_map$$)])))),
$G__77540_chunk__77350_77527_seq__77349_77536__$1$$=null,$G__77541_count__77351_77528$$=0,$G__77539_i__77352_77529$$=0;;)if($G__77539_i__77352_77529$$<$G__77541_count__77351_77528$$){var $nt_77530$$=$G__77540_chunk__77350_77527_seq__77349_77536__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77539_i__77352_77529$$);$APP.$cljs$core$truth_$$($valid_nts_77525$$.$cljs$core$IFn$_invoke$arity$1$?$valid_nts_77525$$.$cljs$core$IFn$_invoke$arity$1$($nt_77530$$):$valid_nts_77525$$($nt_77530$$))||$instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($nt_77530$$),
1)," occurs on the right-hand side of your grammar, but not on the left"]));$G__77539_i__77352_77529$$+=1}else if($c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$=$APP.$cljs$core$seq$$($c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$))$G__77540_chunk__77350_77527_seq__77349_77536__$1$$=$c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77540_chunk__77350_77527_seq__77349_77536__$1$$)?
($c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$=$APP.$cljs$core$_chunked_first$$($G__77540_chunk__77350_77527_seq__77349_77536__$1$$),$G__77539_i__77352_77529$$=$APP.$cljs$core$_chunked_rest$$($G__77540_chunk__77350_77527_seq__77349_77536__$1$$),$G__77540_chunk__77350_77527_seq__77349_77536__$1$$=$c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$,$G__77541_count__77351_77528$$=$APP.$cljs$core$count$$($c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$),
$c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$=$G__77539_i__77352_77529$$):($c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$=$APP.$cljs$core$first$$($G__77540_chunk__77350_77527_seq__77349_77536__$1$$),$APP.$cljs$core$truth_$$($valid_nts_77525$$.$cljs$core$IFn$_invoke$arity$1$?$valid_nts_77525$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$):$valid_nts_77525$$($c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$))||
$instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$),1)," occurs on the right-hand side of your grammar, but not on the left"])),$c__5548__auto___77537_nt_77545_seq__77349_77526_temp__5825__auto___77535$$=$APP.$cljs$core$next$$($G__77540_chunk__77350_77527_seq__77349_77536__$1$$),
$G__77540_chunk__77350_77527_seq__77349_77536__$1$$=null,$G__77541_count__77351_77528$$=0),$G__77539_i__77352_77529$$=0;else break;return $grammar_map$$};
$instaparse$cfg$build_parser$cljs$0core$0IFn$0_invoke$0arity$03$$=function($productions_spec$jscomp$47$$,$output_format$jscomp$1$$,$allow_namespaced_nts_QMARK_$jscomp$1_start_production$$){var $rules$$=$instaparse$gll$parse$$($APP.$cljs$core$truth_$$($allow_namespaced_nts_QMARK_$jscomp$1_start_production$$)?$instaparse$cfg$cfg_allow_namespaced_nts$$:$instaparse$cfg$cfg$$,$APP.$cljs$cst$5612$rules$$,$productions_spec$jscomp$47$$,!1);if($rules$$ instanceof $instaparse$gll$Failure$$)return $instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Error parsing grammar specification:\n",
function(){var $sb__5670__auto__$jscomp$10$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__77365_77551$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__77366_77552$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$11$$){return $sb__5670__auto__$jscomp$10$$.append($x__5671__auto__$jscomp$11$$)};try{$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$rules$$]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=
$_STAR_print_fn_STAR__orig_val__77366_77552$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__77365_77551$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$10$$)}()]));$productions_spec$jscomp$47$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$cfg$build_rule$$,$rules$$);$allow_namespaced_nts_QMARK_$jscomp$1_start_production$$=$APP.$cljs$core$first$$($APP.$cljs$core$first$$($productions_spec$jscomp$47$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5556$grammar$$,$instaparse$cfg$check_grammar$$($instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$($output_format$jscomp$1$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$productions_spec$jscomp$47$$))),$cljs$cst$5557$start_production$$,$allow_namespaced_nts_QMARK_$jscomp$1_start_production$$,$cljs$cst$5622$output_format$$,$output_format$jscomp$1$$],null)};
$instaparse$cfg$build_parser_from_combinators$$=function($grammar_map$jscomp$1$$,$output_format$jscomp$2$$,$start_production$jscomp$1$$){return $start_production$jscomp$1$$==null?$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["When you build a parser from a map of parser combinators, you must provide a start production using the :start keyword argument."])):new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5556$grammar$$,$instaparse$cfg$check_grammar$$($instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$($output_format$jscomp$2$$,$grammar_map$jscomp$1$$)),$cljs$cst$5557$start_production$$,$start_production$jscomp$1$$,$cljs$cst$5622$output_format$$,$output_format$jscomp$2$$],null)};
$instaparse$transform$merge_meta$$=function($obj$jscomp$217$$,$metamap$jscomp$4$$){return($obj$jscomp$217$$!=null?$obj$jscomp$217$$.$cljs$lang$protocol_mask$partition0$$&262144||$APP.$cljs$core$PROTOCOL_SENTINEL$$===$obj$jscomp$217$$.$cljs$core$IWithMeta$$||($obj$jscomp$217$$.$cljs$lang$protocol_mask$partition0$$?0:$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$217$$)):$APP.$cljs$core$native_satisfies_QMARK_$$($APP.$cljs$core$IWithMeta$$,$obj$jscomp$217$$))?$APP.$cljs$core$with_meta$$($obj$jscomp$217$$,
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$metamap$jscomp$4$$,$APP.$cljs$core$meta$$($obj$jscomp$217$$)]))):$obj$jscomp$217$$};
$instaparse$abnf$project$$=function($m$jscomp$230$$,$ks$jscomp$63$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,function(){return function $instaparse$abnf$project_$_iter__77975$$($s__77976$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$=$s__77976$$;;)if($s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$=$APP.$cljs$core$seq$$($s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$)){var $JSCompiler_inline_result$jscomp$1745_c__5501__auto__$jscomp$46$$=
$APP.$cljs$core$_chunked_first$$($s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$),$size__5502__auto__$jscomp$46$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1745_c__5501__auto__$jscomp$46$$),$b__77978_k$jscomp$685$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$46$$);a:{for(var $i__77977$jscomp$inline_8813$$=0;;)if($i__77977$jscomp$inline_8813$$<$size__5502__auto__$jscomp$46$$){var $k$jscomp$inline_8814_x$jscomp$inline_13720$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1745_c__5501__auto__$jscomp$46$$,
$i__77977$jscomp$inline_8813$$);if($APP.$cljs$core$contains_QMARK_$$($m$jscomp$230$$,$k$jscomp$inline_8814_x$jscomp$inline_13720$$)){var $b$jscomp$inline_13719$$=$b__77978_k$jscomp$685$$;$k$jscomp$inline_8814_x$jscomp$inline_13720$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$inline_8814_x$jscomp$inline_13720$$,$m$jscomp$230$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$230$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$inline_8814_x$jscomp$inline_13720$$):
$m$jscomp$230$$($k$jscomp$inline_8814_x$jscomp$inline_13720$$)],null);$b$jscomp$inline_13719$$.add($k$jscomp$inline_8814_x$jscomp$inline_13720$$)}$i__77977$jscomp$inline_8813$$+=1}else{$JSCompiler_inline_result$jscomp$1745_c__5501__auto__$jscomp$46$$=!0;break a}$JSCompiler_inline_result$jscomp$1745_c__5501__auto__$jscomp$46$$=void 0}return $JSCompiler_inline_result$jscomp$1745_c__5501__auto__$jscomp$46$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__77978_k$jscomp$685$$),$instaparse$abnf$project_$_iter__77975$$($APP.$cljs$core$_chunked_rest$$($s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__77978_k$jscomp$685$$),null)}$b__77978_k$jscomp$685$$=$APP.$cljs$core$first$$($s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$);if($APP.$cljs$core$contains_QMARK_$$($m$jscomp$230$$,$b__77978_k$jscomp$685$$))return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$b__77978_k$jscomp$685$$,$m$jscomp$230$$.$cljs$core$IFn$_invoke$arity$1$?$m$jscomp$230$$.$cljs$core$IFn$_invoke$arity$1$($b__77978_k$jscomp$685$$):
$m$jscomp$230$$($b__77978_k$jscomp$685$$)],null),$instaparse$abnf$project_$_iter__77975$$($APP.$cljs$core$rest$$($s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$)));$s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$=$APP.$cljs$core$rest$$($s__77976__$1_s__77976__$2_temp__5825__auto__$jscomp$355$$)}else return null},null,null)}($ks$jscomp$63$$)}())};
$instaparse$abnf$merge_core$$=function($grammar_map$jscomp$2$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$abnf$project$$($instaparse$abnf$abnf_core$$,$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($instaparse$cfg$seq_nt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($grammar_map$jscomp$2$$)])))),
$grammar_map$jscomp$2$$]))};
$instaparse$abnf$alt_preserving_hide_tag$$=function($p1$jscomp$83$$,$p2$jscomp$64$$){var $hide_tag_p1_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($p1$jscomp$83$$),$instaparse$reduction$raw_non_terminal_reduction$$),$hide_tag_p2_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($p2$jscomp$64$$),$instaparse$reduction$raw_non_terminal_reduction$$);return $hide_tag_p1_QMARK_$$&&
$hide_tag_p2_QMARK_$$?$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$83$$,$APP.$cljs$cst$5555$red$$),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$64$$,$APP.$cljs$cst$5555$red$$)]))):$hide_tag_p1_QMARK_$$?$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$83$$,
$APP.$cljs$cst$5555$red$$),$p2$jscomp$64$$]))):$hide_tag_p2_QMARK_$$?$instaparse$combinators_source$hide_tag$$($instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1$jscomp$83$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p2$jscomp$64$$,$APP.$cljs$cst$5555$red$$)]))):$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1$jscomp$83$$,
$p2$jscomp$64$$]))};
$instaparse$abnf$build_parser$$=function($grammar_map$jscomp$3_spec$jscomp$50$$,$output_format$jscomp$3$$){var $rule_tree$$=$instaparse$gll$parse$$($instaparse$abnf$abnf_parser$$,$cljs$cst$5658$rulelist$$,$grammar_map$jscomp$3_spec$jscomp$50$$,!1);if($rule_tree$$ instanceof $instaparse$gll$Failure$$)return $instaparse$util$throw_runtime_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Error parsing grammar specification:\n",function(){var $sb__5670__auto__$jscomp$13$$=
new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__78005_78093$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__78006_78094$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$14$$){return $sb__5670__auto__$jscomp$13$$.append($x__5671__auto__$jscomp$14$$)};try{$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$rule_tree$$]))}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=
$_STAR_print_fn_STAR__orig_val__78006_78094$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__78005_78093$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$13$$)}()]));var $rules$jscomp$3_start_production$jscomp$2$$=$instaparse$transform$transform$$($instaparse$abnf$abnf_transformer$$,$rule_tree$$);$grammar_map$jscomp$3_spec$jscomp$50$$=$instaparse$abnf$merge_core$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$merge_with$$,
$instaparse$abnf$alt_preserving_hide_tag$$,$rules$jscomp$3_start_production$jscomp$2$$));$rules$jscomp$3_start_production$jscomp$2$$=$APP.$cljs$core$first$$($APP.$cljs$core$first$$($APP.$cljs$core$first$$($rules$jscomp$3_start_production$jscomp$2$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5556$grammar$$,$instaparse$cfg$check_grammar$$($instaparse$reduction$apply_standard_reductions$cljs$0core$0IFn$0_invoke$0arity$02$$($output_format$jscomp$3$$,$grammar_map$jscomp$3_spec$jscomp$50$$)),
$cljs$cst$5557$start_production$$,$rules$jscomp$3_start_production$jscomp$2$$,$cljs$cst$5622$output_format$$,$output_format$jscomp$3$$],null)};
$instaparse$viz$span$$=function($s$jscomp$578_tree$jscomp$22$$){var $e$jscomp$347_m$jscomp$231$$=$APP.$cljs$core$meta$$($s$jscomp$578_tree$jscomp$22$$);$s$jscomp$578_tree$jscomp$22$$=$cljs$cst$5600$instaparse_DOT_gll_SLASH_start_index$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$347_m$jscomp$231$$);$e$jscomp$347_m$jscomp$231$$=$cljs$cst$5601$instaparse_DOT_gll_SLASH_end_index$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$347_m$jscomp$231$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($s$jscomp$578_tree$jscomp$22$$)?
$e$jscomp$347_m$jscomp$231$$:$s$jscomp$578_tree$jscomp$22$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$s$jscomp$578_tree$jscomp$22$$,$e$jscomp$347_m$jscomp$231$$],null):null};
$instaparse$repeat$empty_result_QMARK_$$=function($result$jscomp$366$$){return $APP.$cljs$core$vector_QMARK_$$($result$jscomp$366$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($result$jscomp$366$$),1)||$APP.$cljs$core$map_QMARK_$$($result$jscomp$366$$)&&$APP.$cljs$core$contains_QMARK_$$($result$jscomp$366$$,$APP.$cljs$cst$78$tag$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($result$jscomp$366$$,$APP.$cljs$cst$1642$content$$))||
$APP.$cljs$core$empty_QMARK_$$($result$jscomp$366$$)};
$instaparse$repeat$parse_from_index$$=function($grammar$jscomp$20_tramp$jscomp$61$$,$initial_parser$$,$text$jscomp$111$$,$segment$jscomp$51$$,$index$jscomp$454$$){$grammar$jscomp$20_tramp$jscomp$61$$=$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$20_tramp$jscomp$61$$,$text$jscomp$111$$,$segment$jscomp$51$$,-1,null);$instaparse$gll$push_listener$$($grammar$jscomp$20_tramp$jscomp$61$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$index$jscomp$454$$,$initial_parser$$],null),$instaparse$gll$TopListener$$($grammar$jscomp$20_tramp$jscomp$61$$));return $instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$($grammar$jscomp$20_tramp$jscomp$61$$,null)};
$instaparse$repeat$select_parse$$=function($grammar$jscomp$21$$,$initial_parser$jscomp$1$$,$text$jscomp$112$$,$segment$jscomp$52$$,$index$jscomp$455$$,$parses_parses__$1$$){var $length$jscomp$55$$=$APP.$cljs$core$count$$($text$jscomp$112$$);for($parses_parses__$1$$=$APP.$cljs$core$seq$$($parses_parses__$1$$);;)if($parses_parses__$1$$){var $parse$jscomp$7$$=$APP.$cljs$core$first$$($parses_parses__$1$$),$end$jscomp$104_end__$1_vec__77291$$=$instaparse$viz$span$$($parse$jscomp$7$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$104_end__$1_vec__77291$$,
0,null);$end$jscomp$104_end__$1_vec__77291$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$104_end__$1_vec__77291$$,1,null);$end$jscomp$104_end__$1_vec__77291$$=$APP.$cljs$core$truth_$$($end$jscomp$104_end__$1_vec__77291$$)?$end$jscomp$104_end__$1_vec__77291$$:$index$jscomp$455$$+$APP.$cljs$core$count$$($parse$jscomp$7$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$104_end__$1_vec__77291$$,$length$jscomp$55$$))return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parse$jscomp$7$$,$end$jscomp$104_end__$1_vec__77291$$,null],null);var $temp__5823__auto__$jscomp$226$$=$APP.$cljs$core$seq$$($instaparse$repeat$parse_from_index$$($grammar$jscomp$21$$,$initial_parser$jscomp$1$$,$text$jscomp$112$$,$segment$jscomp$52$$,$end$jscomp$104_end__$1_vec__77291$$));if($temp__5823__auto__$jscomp$226$$)return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$parse$jscomp$7$$,$end$jscomp$104_end__$1_vec__77291$$,
$temp__5823__auto__$jscomp$226$$],null);$parses_parses__$1$$=$APP.$cljs$core$next$$($parses_parses__$1$$)}else return null};
$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$=function($grammar$jscomp$27$$,$initial_parser$jscomp$7$$,$text$jscomp$118$$,$segment$jscomp$58$$,$G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$){var $length$jscomp$58$$=$APP.$cljs$core$count$$($text$jscomp$118$$),$G__77604_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$=$instaparse$repeat$parse_from_index$$($grammar$jscomp$27$$,$initial_parser$jscomp$7$$,$text$jscomp$118$$,
$segment$jscomp$58$$,$G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$);$G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$=$APP.$cljs$core$fix$$($G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$);var $G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$=$instaparse$repeat$select_parse$$($grammar$jscomp$27$$,$initial_parser$jscomp$7$$,$text$jscomp$118$$,$segment$jscomp$58$$,$G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$,
$G__77604_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$,2,null);$G__77604_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$=$G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$;
for($G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$=$instaparse$auto_flatten_seq$EMPTY$$;;){var $vec__77397$$=$G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$,$parse__$1$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__77397$$,0,null);$G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__77397$$,1,null);var $follow_ups__$1$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__77397$$,
2,null);if($vec__77397$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__77604_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$,$G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$))return $instaparse$repeat$failure_signal$$;if($follow_ups__$1$jscomp$2$$==null)return $instaparse$gll$safe_with_meta$$($instaparse$auto_flatten_seq$conj_flat$$($G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$,$parse__$1$jscomp$2$$),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5663$optimize$$,$cljs$cst$5664$memory$$,$cljs$cst$5600$instaparse_DOT_gll_SLASH_start_index$$,0,$cljs$cst$5601$instaparse_DOT_gll_SLASH_end_index$$,$length$jscomp$58$$],null));$G__77604_first_result$jscomp$2_index__$2$jscomp$6_index__$3$jscomp$4$$=$APP.$cljs$core$fix$$($G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$);$G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$=$instaparse$auto_flatten_seq$conj_flat$$($G__77605_index$jscomp$458_index__$1$jscomp$22_parses__$1$jscomp$3_parses__$2$jscomp$2$$,
$parse__$1$jscomp$2$$);$G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$=$instaparse$repeat$select_parse$$($grammar$jscomp$27$$,$initial_parser$jscomp$7$$,$text$jscomp$118$$,$segment$jscomp$58$$,$G__77372_G__77372__$1_G__77606_end__$1$jscomp$3$$,$follow_ups__$1$jscomp$2$$)}};
$instaparse$repeat$repeat_parse$cljs$0core$0IFn$0_invoke$0arity$05$$=function($JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$length$jscomp$inline_13727_length$jscomp$inline_13750_output_format$jscomp$5$$,$G__77571$jscomp$inline_13741_index__$2$jscomp$inline_13732_index__$3$jscomp$inline_13735_root_tag$jscomp$4$$,$text$jscomp$120$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($length$jscomp$inline_13727_length$jscomp$inline_13750_output_format$jscomp$5$$,
$cljs$cst$5561$hiccup$$))a:{$length$jscomp$inline_13727_length$jscomp$inline_13750_output_format$jscomp$5$$=$APP.$cljs$core$count$$($text$jscomp$120$$);var $G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$=$instaparse$repeat$parse_from_index$$($JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,
$text$jscomp$120$$,$text$jscomp$120$$,0),$G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$=$APP.$cljs$core$fix$$(0),$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$=
$instaparse$auto_flatten_seq$auto_flatten_seq$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__77571$jscomp$inline_13741_index__$2$jscomp$inline_13732_index__$3$jscomp$inline_13735_root_tag$jscomp$4$$],null));$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$=$instaparse$repeat$select_parse$$($JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$,
$initial_parser$jscomp$9$$,$text$jscomp$120$$,$text$jscomp$120$$,$G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$,$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$);
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$,
1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$,2,null);$G__77571$jscomp$inline_13741_index__$2$jscomp$inline_13732_index__$3$jscomp$inline_13735_root_tag$jscomp$4$$=$G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$;
$G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$=$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$;for($G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$=
$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$;;){var $parse__$1$jscomp$inline_13760_vec__77319$jscomp$inline_13737$$=$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$,
$follow_ups__$1$jscomp$inline_13762_parse__$1$jscomp$inline_13738$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parse__$1$jscomp$inline_13760_vec__77319$jscomp$inline_13737$$,0,null);$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parse__$1$jscomp$inline_13760_vec__77319$jscomp$inline_13737$$,
1,null);$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($parse__$1$jscomp$inline_13760_vec__77319$jscomp$inline_13737$$,2,null);if($parse__$1$jscomp$inline_13760_vec__77319$jscomp$inline_13737$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__77571$jscomp$inline_13741_index__$2$jscomp$inline_13732_index__$3$jscomp$inline_13735_root_tag$jscomp$4$$,
$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$)){$JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$=$instaparse$repeat$failure_signal$$;break a}if($G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$==
null){$JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$=$instaparse$gll$safe_with_meta$$($instaparse$auto_flatten_seq$convert_afs_to_vec$$($instaparse$auto_flatten_seq$conj_flat$$($G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$,$follow_ups__$1$jscomp$inline_13762_parse__$1$jscomp$inline_13738$$)),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5663$optimize$$,$cljs$cst$5664$memory$$,$cljs$cst$5600$instaparse_DOT_gll_SLASH_start_index$$,0,$cljs$cst$5601$instaparse_DOT_gll_SLASH_end_index$$,$length$jscomp$inline_13727_length$jscomp$inline_13750_output_format$jscomp$5$$],null));break a}$G__77571$jscomp$inline_13741_index__$2$jscomp$inline_13732_index__$3$jscomp$inline_13735_root_tag$jscomp$4$$=$APP.$cljs$core$fix$$($G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$);
$G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$=$instaparse$auto_flatten_seq$conj_flat$$($G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$,
$follow_ups__$1$jscomp$inline_13762_parse__$1$jscomp$inline_13738$$);$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$=$instaparse$repeat$select_parse$$($JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$text$jscomp$120$$,$text$jscomp$120$$,$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$,
$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$)}$JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$=void 0}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($length$jscomp$inline_13727_length$jscomp$inline_13750_output_format$jscomp$5$$,$cljs$cst$5562$enlive$$))a:{$length$jscomp$inline_13727_length$jscomp$inline_13750_output_format$jscomp$5$$=
$APP.$cljs$core$count$$($text$jscomp$120$$);$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$=$instaparse$repeat$parse_from_index$$($JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$text$jscomp$120$$,$text$jscomp$120$$,0);$G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$=
$APP.$cljs$core$fix$$(0);$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$=$instaparse$repeat$select_parse$$($JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$text$jscomp$120$$,$text$jscomp$120$$,$G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$,
$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$,
2,null);for($G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$=$instaparse$auto_flatten_seq$EMPTY$$;;){var $vec__77357$jscomp$inline_13759$$=$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$;
$parse__$1$jscomp$inline_13760_vec__77319$jscomp$inline_13737$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__77357$jscomp$inline_13759$$,0,null);$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__77357$jscomp$inline_13759$$,1,null);$follow_ups__$1$jscomp$inline_13762_parse__$1$jscomp$inline_13738$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__77357$jscomp$inline_13759$$,2,null);if($vec__77357$jscomp$inline_13759$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$,$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$)){$JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$=
$instaparse$repeat$failure_signal$$;break a}if($follow_ups__$1$jscomp$inline_13762_parse__$1$jscomp$inline_13738$$==null){$JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$=$instaparse$gll$safe_with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$G__77571$jscomp$inline_13741_index__$2$jscomp$inline_13732_index__$3$jscomp$inline_13735_root_tag$jscomp$4$$,$APP.$cljs$cst$1642$content$$,$APP.$cljs$core$seq$$($instaparse$auto_flatten_seq$conj_flat$$($G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$,
$parse__$1$jscomp$inline_13760_vec__77319$jscomp$inline_13737$$))],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5663$optimize$$,$cljs$cst$5664$memory$$,$cljs$cst$5600$instaparse_DOT_gll_SLASH_start_index$$,0,$cljs$cst$5601$instaparse_DOT_gll_SLASH_end_index$$,$length$jscomp$inline_13727_length$jscomp$inline_13750_output_format$jscomp$5$$],null));break a}$G__77572$jscomp$inline_13742_G__77582$jscomp$inline_13763_index__$1$jscomp$inline_13729_index__$1$jscomp$inline_13752_index__$2$jscomp$inline_13754_index__$3$jscomp$inline_13757_parses__$1$jscomp$inline_13733_parses__$2$jscomp$inline_13736$$=
$APP.$cljs$core$fix$$($G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$);$G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$=$instaparse$auto_flatten_seq$conj_flat$$($G__77308__$1$jscomp$inline_13734_G__77573$jscomp$inline_13743_G__77583$jscomp$inline_13764_end__$1$jscomp$inline_13739_first_result$jscomp$inline_13751_parses$jscomp$inline_13730_parses__$1$jscomp$inline_13755_parses__$2$jscomp$inline_13758$$,
$parse__$1$jscomp$inline_13760_vec__77319$jscomp$inline_13737$$);$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$=$instaparse$repeat$select_parse$$($JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$,$initial_parser$jscomp$9$$,$text$jscomp$120$$,$text$jscomp$120$$,$G__77308$jscomp$inline_13731_G__77345$jscomp$inline_13753_G__77345__$1$jscomp$inline_13756_G__77584$jscomp$inline_13765_end__$1$jscomp$inline_13761_first_result$jscomp$inline_13728_follow_ups__$1$jscomp$inline_13740$$,
$follow_ups__$1$jscomp$inline_13762_parse__$1$jscomp$inline_13738$$)}$JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$=void 0}else $JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$=null;return $JSCompiler_temp$jscomp$11293_JSCompiler_temp$jscomp$11294_grammar$jscomp$29$$};
$instaparse$repeat$repeat_parse_with_header$$=function($grammar$jscomp$30_repeat_result$$,$JSCompiler_inline_result$jscomp$1747_end$jscomp$108_header_parser$$,$repeating_parser$$,$output_format$jscomp$6$$,$root_tag$jscomp$5$$,$text$jscomp$121$$){var $length$jscomp$59_span_meta$$=$APP.$cljs$core$count$$($text$jscomp$121$$),$header_result_header_results$$=$instaparse$repeat$parse_from_index$$($grammar$jscomp$30_repeat_result$$,$JSCompiler_inline_result$jscomp$1747_end$jscomp$108_header_parser$$,$text$jscomp$121$$,
$text$jscomp$121$$,0),$or__5025__auto__$jscomp$inline_8816$$=$APP.$cljs$core$empty_QMARK_$$($header_result_header_results$$);$JSCompiler_inline_result$jscomp$1747_end$jscomp$108_header_parser$$=$or__5025__auto__$jscomp$inline_8816$$?$or__5025__auto__$jscomp$inline_8816$$:$APP.$cljs$cst$2356$hide$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1747_end$jscomp$108_header_parser$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1747_end$jscomp$108_header_parser$$))return $instaparse$repeat$failure_signal$$;
$header_result_header_results$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$max_key$$,$instaparse$repeat$get_end$$,$header_result_header_results$$);$JSCompiler_inline_result$jscomp$1747_end$jscomp$108_header_parser$$=$instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$1$($header_result_header_results$$);$grammar$jscomp$30_repeat_result$$=$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$30_repeat_result$$,$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$$),
$text$jscomp$121$$,$text$jscomp$121$$,$JSCompiler_inline_result$jscomp$1747_end$jscomp$108_header_parser$$);$length$jscomp$59_span_meta$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5663$optimize$$,$cljs$cst$5664$memory$$,$cljs$cst$5600$instaparse_DOT_gll_SLASH_start_index$$,0,$cljs$cst$5601$instaparse_DOT_gll_SLASH_end_index$$,$length$jscomp$59_span_meta$$],null);if($grammar$jscomp$30_repeat_result$$ instanceof $instaparse$gll$Failure$$||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$$),
$cljs$cst$5565$star$$)&&$instaparse$repeat$empty_result_QMARK_$$($grammar$jscomp$30_repeat_result$$))return $instaparse$repeat$failure_signal$$;switch($output_format$jscomp$6$$ instanceof $APP.$cljs$core$Keyword$$?$output_format$jscomp$6$$.$fqn$:null){case "enlive":return $instaparse$gll$safe_with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$root_tag$jscomp$5$$,$APP.$cljs$cst$1642$content$$,$instaparse$auto_flatten_seq$conj_flat$$($instaparse$auto_flatten_seq$EMPTY$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,
$header_result_header_results$$),$grammar$jscomp$30_repeat_result$$)],null),$length$jscomp$59_span_meta$$);case "hiccup":return $instaparse$gll$safe_with_meta$$($instaparse$auto_flatten_seq$convert_afs_to_vec$$($instaparse$auto_flatten_seq$conj_flat$$($instaparse$auto_flatten_seq$auto_flatten_seq$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$root_tag$jscomp$5$$],null)).$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$header_result_header_results$$),
$grammar$jscomp$30_repeat_result$$)),$length$jscomp$59_span_meta$$);default:return $instaparse$gll$safe_with_meta$$($instaparse$auto_flatten_seq$conj_flat$$($instaparse$auto_flatten_seq$EMPTY$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$(null,$header_result_header_results$$),$grammar$jscomp$30_repeat_result$$),$length$jscomp$59_span_meta$$)}};
$instaparse$repeat$try_repeating_parse_strategy_with_header$$=function($grammar$jscomp$31$$,$text$jscomp$122$$,$start_production$jscomp$3$$,$start_rule$$,$output_format$jscomp$7$$){var $header_parser$jscomp$1_parsers$jscomp$14$$=$cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$$),$repeating_parser$jscomp$1$$=$APP.$cljs$core$last$$($header_parser$jscomp$1_parsers$jscomp$14$$),$G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$;
if($G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$$),$APP.$cljs$cst$594$cat$$)){$G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$jscomp$1$$);
var $fexpr__77507$jscomp$inline_13770$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5565$star$$,null,$cljs$cst$5564$plus$$,null],null),null);$G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$=$fexpr__77507$jscomp$inline_13770$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__77507$jscomp$inline_13770$$.$cljs$core$IFn$_invoke$arity$1$($G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$):
$fexpr__77507$jscomp$inline_13770$$($G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$);$G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$=$APP.$cljs$core$truth_$$($G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$)?
$APP.$cljs$core$not$$($APP.$cljs$cst$2356$hide$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$jscomp$1$$))&&$APP.$cljs$core$not$$($APP.$cljs$cst$2356$hide$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($repeating_parser$jscomp$1$$))):$G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$}if($APP.$cljs$core$not$$($G__77508$jscomp$inline_13769_JSCompiler_inline_result$jscomp$11295_and__5023__auto__$jscomp$inline_13767_and__5023__auto____$1$jscomp$inline_13768$$))return $instaparse$repeat$failure_signal$$;
$header_parser$jscomp$1_parsers$jscomp$14$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$cat$$,$APP.$cljs$core$butlast$$($header_parser$jscomp$1_parsers$jscomp$14$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$$),$instaparse$reduction$raw_non_terminal_reduction$$)?$instaparse$repeat$repeat_parse_with_header$$($grammar$jscomp$31$$,$header_parser$jscomp$1_parsers$jscomp$14$$,
$repeating_parser$jscomp$1$$,null,$start_production$jscomp$3$$,$text$jscomp$122$$):$instaparse$repeat$repeat_parse_with_header$$($grammar$jscomp$31$$,$header_parser$jscomp$1_parsers$jscomp$14$$,$repeating_parser$jscomp$1$$,$output_format$jscomp$7$$,$start_production$jscomp$3$$,$text$jscomp$122$$)};
$instaparse$repeat$try_repeating_parse_strategy$$=function($output_format$jscomp$8_parser$jscomp$62$$,$result$jscomp$367_text$jscomp$123$$,$initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$){var $grammar$jscomp$32$$=$cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($output_format$jscomp$8_parser$jscomp$62$$);$output_format$jscomp$8_parser$jscomp$62$$=$cljs$cst$5622$output_format$$.$cljs$core$IFn$_invoke$arity$1$($output_format$jscomp$8_parser$jscomp$62$$);
var $start_rule$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grammar$jscomp$32$$,$initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2356$hide$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),!0)?$instaparse$repeat$failure_signal$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),
$instaparse$reduction$raw_non_terminal_reduction$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$cljs$cst$5565$star$$)?($initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$32$$,$initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$,
$result$jscomp$367_text$jscomp$123$$,$result$jscomp$367_text$jscomp$123$$,0)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$cljs$cst$5564$plus$$)?($initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$result$jscomp$367_text$jscomp$123$$=$instaparse$repeat$repeat_parse_no_tag$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$32$$,
$initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$,$result$jscomp$367_text$jscomp$123$$,$result$jscomp$367_text$jscomp$123$$,0),$instaparse$repeat$empty_result_QMARK_$$($result$jscomp$367_text$jscomp$123$$)?$instaparse$repeat$failure_signal$$:$result$jscomp$367_text$jscomp$123$$):$instaparse$repeat$try_repeating_parse_strategy_with_header$$($grammar$jscomp$32$$,$result$jscomp$367_text$jscomp$123$$,$initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$,
$start_rule$jscomp$1$$,$output_format$jscomp$8_parser$jscomp$62$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$cljs$cst$5565$star$$)?$instaparse$repeat$repeat_parse$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$32$$,$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$output_format$jscomp$8_parser$jscomp$62$$,$initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$,
$result$jscomp$367_text$jscomp$123$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$cljs$cst$5564$plus$$)?($result$jscomp$367_text$jscomp$123$$=$instaparse$repeat$repeat_parse$cljs$0core$0IFn$0_invoke$0arity$05$$($grammar$jscomp$32$$,$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($start_rule$jscomp$1$$),$output_format$jscomp$8_parser$jscomp$62$$,$initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$,
$result$jscomp$367_text$jscomp$123$$),$instaparse$repeat$empty_result_QMARK_$$($result$jscomp$367_text$jscomp$123$$)?$instaparse$repeat$failure_signal$$:$result$jscomp$367_text$jscomp$123$$):$instaparse$repeat$try_repeating_parse_strategy_with_header$$($grammar$jscomp$32$$,$result$jscomp$367_text$jscomp$123$$,$initial_parser$jscomp$inline_8822_initial_parser$jscomp$inline_8826_start_production$jscomp$4$$,$start_rule$jscomp$1$$,$output_format$jscomp$8_parser$jscomp$62$$)};
$instaparse$core$unhide_parser$$=function($parser$jscomp$63$$,$unhide$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$unhide$$))return $parser$jscomp$63$$;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$content$$,$unhide$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$63$$,$cljs$cst$5556$grammar$$,$instaparse$combinators_source$unhide_all_content$$($cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$)));
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3166$tags$$,$unhide$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$63$$,$cljs$cst$5556$grammar$$,$instaparse$combinators_source$unhide_tags$$($cljs$cst$5622$output_format$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$),$cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$)));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2132$all$$,$unhide$$))return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$63$$,
$cljs$cst$5556$grammar$$,$instaparse$combinators_source$unhide_all$$($cljs$cst$5622$output_format$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$),$cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$63$$)));throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($unhide$$)].join(""));};
$instaparse$core$Parser$$=function($grammar$jscomp$33$$,$start_production$jscomp$7$$,$output_format$jscomp$9$$,$__meta$jscomp$39$$,$__extmap$jscomp$39$$,$__hash$jscomp$98$$){this.$grammar$=$grammar$jscomp$33$$;this.$start_production$=$start_production$jscomp$7$$;this.$output_format$=$output_format$jscomp$9$$;this.$__meta$=$__meta$jscomp$39$$;this.$__extmap$=$__extmap$jscomp$39$$;this.$__hash$=$__hash$jscomp$98$$;this.$cljs$lang$protocol_mask$partition0$$=2230716171;this.$cljs$lang$protocol_mask$partition1$$=
139264};
$instaparse$core$map__GT_Parser$$=function($G__78382$$){var $G__78395$jscomp$inline_8829_extmap__5365__auto__$jscomp$39$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__78382$$,$cljs$cst$5556$grammar$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5557$start_production$$,$cljs$cst$5622$output_format$$]));$G__78395$jscomp$inline_8829_extmap__5365__auto__$jscomp$39$$=$APP.$cljs$core$record_QMARK_$$($G__78382$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$G__78395$jscomp$inline_8829_extmap__5365__auto__$jscomp$39$$):
$G__78395$jscomp$inline_8829_extmap__5365__auto__$jscomp$39$$;return new $instaparse$core$Parser$$($cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($G__78382$$),$cljs$cst$5557$start_production$$.$cljs$core$IFn$_invoke$arity$1$($G__78382$$),$cljs$cst$5622$output_format$$.$cljs$core$IFn$_invoke$arity$1$($G__78382$$),null,$APP.$cljs$core$not_empty$$($G__78395$jscomp$inline_8829_extmap__5365__auto__$jscomp$39$$),null)};
$instaparse$core$parser$$=function($var_args$jscomp$1457$$){for(var $args__5755__auto__$jscomp$254$$=[],$len__5749__auto___78457$$=arguments.length,$i__5750__auto___78458$$=0;;)if($i__5750__auto___78458$$<$len__5749__auto___78457$$)$args__5755__auto__$jscomp$254$$.push(arguments[$i__5750__auto___78458$$]),$i__5750__auto___78458$$+=1;else break;return $instaparse$core$parser$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],1<$args__5755__auto__$jscomp$254$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$254$$.slice(1),
0,null):null)};
$instaparse$core$parser$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($grammar_specification$$,$built_parser_p__78399$$){var $options$jscomp$605$$=$APP.$cljs$core$__destructure_map$$($built_parser_p__78399$$),$input_format$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$605$$,$cljs$cst$5674$input_format$$,$cljs$cst$5670$ebnf$$),$output_format$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$605$$,$cljs$cst$5622$output_format$$,$cljs$cst$5561$hiccup$$),
$start$jscomp$246$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$605$$,$APP.$cljs$cst$1297$start$$,null);$built_parser_p__78399$$=typeof $grammar_specification$$==="string"?function(){a:{var $_STAR_case_insensitive_literals_STAR__orig_val__78402$jscomp$inline_8833$$=$instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$;$instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$=$cljs$cst$5567$string_ci$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$605$$,$APP.$cljs$cst$205$default$$);
try{var $G__78404__$1$jscomp$inline_8834$$=$input_format$$ instanceof $APP.$cljs$core$Keyword$$?$input_format$$.$fqn$:null;switch($G__78404__$1$jscomp$inline_8834$$){case "abnf":var $parser$jscomp$78$$=$instaparse$abnf$build_parser$$($grammar_specification$$,$output_format$jscomp$11$$);break a;case "ebnf":$parser$jscomp$78$$=$instaparse$cfg$build_parser$cljs$0core$0IFn$0_invoke$0arity$03$$($grammar_specification$$,$output_format$jscomp$11$$,$cljs$cst$5675$allow_namespaced_nts$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$605$$,
!1));break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78404__$1$jscomp$inline_8834$$)].join(""));}}finally{$instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$=$_STAR_case_insensitive_literals_STAR__orig_val__78402$jscomp$inline_8833$$}$parser$jscomp$78$$=void 0}return $APP.$cljs$core$truth_$$($start$jscomp$246$$)?$instaparse$core$map__GT_Parser$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$78$$,$cljs$cst$5557$start_production$$,
$start$jscomp$246$$)):$instaparse$core$map__GT_Parser$$($parser$jscomp$78$$)}():$APP.$cljs$core$map_QMARK_$$($grammar_specification$$)?function(){var $parser$jscomp$79$$=$instaparse$cfg$build_parser_from_combinators$$($grammar_specification$$,$output_format$jscomp$11$$,$start$jscomp$246$$);return $instaparse$core$map__GT_Parser$$($parser$jscomp$79$$)}():$APP.$cljs$core$vector_QMARK_$$($grammar_specification$$)?function(){var $parser$jscomp$80_start__$1$jscomp$14$$=$APP.$cljs$core$truth_$$($start$jscomp$246$$)?
$start$jscomp$246$$:$grammar_specification$$.$cljs$core$IFn$_invoke$arity$1$?$grammar_specification$$.$cljs$core$IFn$_invoke$arity$1$(0):$grammar_specification$$(0);$parser$jscomp$80_start__$1$jscomp$14$$=$instaparse$cfg$build_parser_from_combinators$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$hash_map$$,$grammar_specification$$),$output_format$jscomp$11$$,$parser$jscomp$80_start__$1$jscomp$14$$);return $instaparse$core$map__GT_Parser$$($parser$jscomp$80_start__$1$jscomp$14$$)}():
$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Expected string, map, or vector as grammar specification, got ",$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$grammar_specification$$]))]));var $auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$605$$,
$cljs$cst$5676$auto_whitespace$$);$auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$=$auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$core$standard_whitespace_parsers$$,$auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$):$auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$;if($APP.$cljs$core$truth_$$($auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$)){var $map__78406__$1_ws_start$$=
$APP.$cljs$core$__destructure_map$$($auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$);$auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78406__$1_ws_start$$,$cljs$cst$5556$grammar$$);$map__78406__$1_ws_start$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78406__$1_ws_start$$,$cljs$cst$5557$start_production$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($built_parser_p__78399$$,$cljs$cst$5556$grammar$$,
$instaparse$combinators_source$auto_whitespace$$($built_parser_p__78399$$.$grammar$,$built_parser_p__78399$$.$start_production$,$auto_whitespace_temp__5823__auto__$jscomp$227_ws_grammar$$,$map__78406__$1_ws_start$$))}return $built_parser_p__78399$$};$instaparse$core$failure_QMARK_$$=function($result$jscomp$369$$){return $result$jscomp$369$$ instanceof $instaparse$gll$failure_type$$||$APP.$cljs$core$meta$$($result$jscomp$369$$)instanceof $instaparse$gll$failure_type$$};
$app$util$simple_math$expr_eval$$=function($expr$jscomp$5_text$jscomp$141$$,$index$jscomp$462_init_value$jscomp$1_init_value__$1$$){$APP.$cljs$core$truth_$$(!1)&&$APP.$cljs$core$truth_$$($APP.$cljs$core$deref$$(new $APP.$cljs$core$Var$$(function(){return!1},$cljs$cst$5679$cljs_DOT_spec_DOT_alpha_SLASH__STAR_runtime_asserts_STAR_$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1483$private$$,$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,
$APP.$cljs$cst$216$column$$,$cljs$cst$5680$dynamic$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1484$arglists$$,$APP.$cljs$cst$1485$doc$$,$APP.$cljs$cst$171$test$$],[!0,$cljs$cst$5681$cljs_DOT_spec_DOT_alpha$$,$cljs$cst$5682$_STAR_runtime_asserts_STAR_$$,"cljs/spec/alpha.cljs",20,1,!0,1480,1482,$APP.$cljs$core$List$EMPTY$$,null,$APP.$cljs$core$truth_$$(!1)?(!1).$cljs$lang$test$:null]))))&&$cljs$spec$alpha$assert_STAR_$$($APP.$cljs$core$string_QMARK_$$,$expr$jscomp$5_text$jscomp$141$$);
var $expecting_result$jscomp$371$$=$app$util$simple_math$parser$$.$cljs$core$IFn$_invoke$arity$1$?$app$util$simple_math$parser$$.$cljs$core$IFn$_invoke$arity$1$($expr$jscomp$5_text$jscomp$141$$):$app$util$simple_math$parser$$($expr$jscomp$5_text$jscomp$141$$);$index$jscomp$462_init_value$jscomp$1_init_value__$1$$=$APP.$cljs$core$truth_$$($index$jscomp$462_init_value$jscomp$1_init_value__$1$$)?$index$jscomp$462_init_value$jscomp$1_init_value__$1$$:0;$APP.$cljs$core$truth_$$(!1)&&$APP.$cljs$core$truth_$$($APP.$cljs$core$deref$$(new $APP.$cljs$core$Var$$(function(){return!1},
$cljs$cst$5679$cljs_DOT_spec_DOT_alpha_SLASH__STAR_runtime_asserts_STAR_$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1483$private$$,$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,$APP.$cljs$cst$216$column$$,$cljs$cst$5680$dynamic$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1484$arglists$$,$APP.$cljs$cst$1485$doc$$,$APP.$cljs$cst$171$test$$],[!0,$cljs$cst$5681$cljs_DOT_spec_DOT_alpha$$,$cljs$cst$5682$_STAR_runtime_asserts_STAR_$$,
"cljs/spec/alpha.cljs",20,1,!0,1480,1482,$APP.$cljs$core$List$EMPTY$$,null,$APP.$cljs$core$truth_$$(!1)?(!1).$cljs$lang$test$:null]))))&&$cljs$spec$alpha$assert_STAR_$$($APP.$cljs$core$number_QMARK_$$,$index$jscomp$462_init_value$jscomp$1_init_value__$1$$);if($instaparse$core$failure_QMARK_$$($expecting_result$jscomp$371$$))return $expr$jscomp$5_text$jscomp$141$$=$APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($expecting_result$jscomp$371$$),$index$jscomp$462_init_value$jscomp$1_init_value__$1$$=
$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($expecting_result$jscomp$371$$),$expecting_result$jscomp$371$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5560$expecting$$,$APP.$cljs$cst$984$reason$$.$cljs$core$IFn$_invoke$arity$1$($expecting_result$jscomp$371$$))),console.debug(["Invalid value '",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr$jscomp$5_text$jscomp$141$$),
"' at index ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$462_init_value$jscomp$1_init_value__$1$$),". Expected one of ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expecting_result$jscomp$371$$),"."].join("")),null;try{var $value$jscomp$790$$=$app$util$simple_math$interpret$$($expecting_result$jscomp$371$$,$index$jscomp$462_init_value$jscomp$1_init_value__$1$$);return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1117$$=Number.isFinite($value$jscomp$790$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1117$$)?$or__5025__auto__$jscomp$1117$$:$value$jscomp$790$$==null}())?$value$jscomp$790$$:null}catch($e78463$$){return console.debug(["Expression evaluation error: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_message$$($e78463$$))].join(""),["Expression: '",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($expr$jscomp$5_text$jscomp$141$$),"'"].join("")),null}};
$app$main$ui$components$reorder_handler$reorder_handler_STAR_$$=function($props_77120$$){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{ref:$props_77120$$.ref,className:"main_ui_components_reorder_handler__reorder",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"reorder",className:"main_ui_components_reorder_handler__reorder-icon","aria-hidden":!0})}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_components_reorder_handler__reorder-separator-top"}),
(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_components_reorder_handler__reorder-separator-bottom"})]})};
$app$main$ui$workspace$tokens$management$forms$controls$utils$token__GT_dropdown_option$$=function($token$jscomp$129$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$129$$,$APP.$cljs$cst$266$id$$)),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1136$token$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$129$$,
$APP.$cljs$cst$260$value$$),$APP.$cljs$cst$4686$resolved_value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$129$$,$APP.$cljs$cst$4686$resolved_value$$),$APP.$cljs$cst$725$name$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$129$$,$APP.$cljs$cst$725$name$$)],null)};
$app$main$ui$workspace$tokens$management$forms$controls$utils$generate_dropdown_options$$=function($non_empty_groups_tokens$jscomp$41$$,$no_sets$$){$non_empty_groups_tokens$jscomp$41$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($items$jscomp$59_p__77122$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$59_p__77122$$,0,null);$items$jscomp$59_p__77122$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$59_p__77122$$,1,null);return $APP.$cljs$core$seq$$($items$jscomp$59_p__77122$$)},
$non_empty_groups_tokens$jscomp$41$$);return $APP.$cljs$core$empty_QMARK_$$($non_empty_groups_tokens$jscomp$41$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$489$empty$$,$APP.$cljs$cst$2296$label$$,$APP.$cljs$core$truth_$$($no_sets$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.no-applicable-tokens"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.no-matches")],
null)],null):$APP.$cljs$core$not_empty$$($APP.$cljs$core$vec$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$concat$$,$APP.$cljs$core$interpose$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1477$separator$$,!0,$APP.$cljs$cst$266$id$$,"separator",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1477$separator$$],null)],null),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($items$jscomp$60_p__77127$$){var $type$jscomp$612$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$60_p__77127$$,0,null);$items$jscomp$60_p__77127$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($items$jscomp$60_p__77127$$,1,null);return $APP.$cljs$core$seq_QMARK_$$($items$jscomp$60_p__77127$$)?$APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1613$group$$,!0,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1613$group$$,$APP.$cljs$cst$266$id$$,"group-"+($APP.$cljs$core$name$$($type$jscomp$612$$)??
""),$APP.$cljs$cst$725$name$$,$APP.$cljs$core$name$$($type$jscomp$612$$)],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$forms$controls$utils$token__GT_dropdown_option$$,$items$jscomp$60_p__77127$$)):null},$non_empty_groups_tokens$jscomp$41$$)))))};
$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_token_groups_by_name$$=function($tokens$jscomp$42$$,$filter_text$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($filtered$jscomp$2_p__77138_tokens__$1$$){var $group$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filtered$jscomp$2_p__77138_tokens__$1$$,0,null);$filtered$jscomp$2_p__77138_tokens__$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filtered$jscomp$2_p__77138_tokens__$1$$,1,null);$filtered$jscomp$2_p__77138_tokens__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77133_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__77133_SHARP_$$),$filter_text$$)},$filtered$jscomp$2_p__77138_tokens__$1$$);return $APP.$cljs$core$seq$$($filtered$jscomp$2_p__77138_tokens__$1$$)?new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$group$jscomp$48$$,$filtered$jscomp$2_p__77138_tokens__$1$$],null):null}),$tokens$jscomp$42$$)};
$app$main$ui$workspace$tokens$management$forms$controls$utils$sort_groups_and_tokens$$=function($groups__GT_tokens$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$156$$,$p__77143_tokens$jscomp$43$$){var $group$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77143_tokens$jscomp$43$$,0,null);$p__77143_tokens$jscomp$43$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77143_tokens$jscomp$43$$,1,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$156$$,
$group$jscomp$49$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$p__77143_tokens$jscomp$43$$))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$groups__GT_tokens$$)};
$app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$=function($tokens$jscomp$44$$,$filter_term$jscomp$1$$){return new $APP.$cljs$core$Delay$$(function(){var $no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$=$APP.$cljs$core$delay_QMARK_$$($tokens$jscomp$44$$)?$APP.$cljs$core$_deref$$($tokens$jscomp$44$$):$tokens$jscomp$44$$;$no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$=$app$main$ui$workspace$tokens$management$forms$controls$utils$sort_groups_and_tokens$$($no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$);
var $options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($filter_term$jscomp$1$$,"{");$APP.$cljs$core$truth_$$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$)?($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($filter_term$jscomp$1$$,
$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$+1),$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$=$APP.$cljs$core$seq$$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$)&&$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$.length>0&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("}",
$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$,$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$.length-1))?$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$,0,$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$.length-
1):$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$):$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$=null;$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$=$APP.$cljs$core$seq$$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$)?$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_token_groups_by_name$$($no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$,
$options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$):$no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$;$no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$=$APP.$cljs$core$empty_QMARK_$$($no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$);return $app$main$ui$workspace$tokens$management$forms$controls$utils$generate_dropdown_options$$($options$jscomp$606_partial$jscomp$1_partial$jscomp$inline_8838_temp__5825__auto__$jscomp$inline_8837$$,
$no_sets_QMARK__sorted_tokens$jscomp$1_tokens__$1$jscomp$1$$)})};
$app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$=function($raw_tokens$$,$input_type$jscomp$1$$){return new $APP.$cljs$core$Delay$$(function(){var $raw_tokens__$1$$=$APP.$cljs$core$_deref$$($raw_tokens$$);a:switch($input_type$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$input_type$jscomp$1$$.$fqn$:null){case "color-selection":var $key_order$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$token$tokens_by_input$$,$APP.$cljs$cst$1408$fill$$),
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$token$tokens_by_input$$,$APP.$cljs$cst$1745$stroke_color$$));break a;default:$key_order$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$token$tokens_by_input$$,$input_type$jscomp$1$$)}return $APP.$cljs$core$not_empty$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$157$$,$k$jscomp$692$$){return $APP.$cljs$core$contains_QMARK_$$($raw_tokens__$1$$,$k$jscomp$692$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$157$$,$k$jscomp$692$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($raw_tokens__$1$$,$k$jscomp$692$$)):$acc$jscomp$157$$},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$key_order$$))})};
$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$=function($options$jscomp$607$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77153_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__77153_SHARP_$$),$APP.$cljs$cst$1136$token$$)},$options$jscomp$607$$)};
$app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$=function($error$jscomp$143$$,$token_name$jscomp$17_translated_string$$){$token_name$jscomp$17_translated_string$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.tokens.name-collision",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_name$jscomp$17_translated_string$$]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($error$jscomp$143$$,$token_name$jscomp$17_translated_string$$)};
$app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$=function($JSCompiler_temp_const$jscomp$1748_props_78534$$){var $children$jscomp$295$$=$JSCompiler_temp_const$jscomp$1748_props_78534$$.children,$JSCompiler_temp$jscomp$1749_select_on_focus$jscomp$1$$=$JSCompiler_temp_const$jscomp$1748_props_78534$$.selectOnFocus,$JSCompiler_inline_result$jscomp$1751_color$jscomp$136_opacity$jscomp$inline_8841$$=$JSCompiler_temp_const$jscomp$1748_props_78534$$.color,$on_focus$jscomp$7$$=
$JSCompiler_temp_const$jscomp$1748_props_78534$$.onFocus,$on_blur$jscomp$10$$=$JSCompiler_temp_const$jscomp$1748_props_78534$$.onBlur,$on_opacity_change$$=$JSCompiler_temp_const$jscomp$1748_props_78534$$.onOpacityChange,$JSCompiler_temp_const$jscomp$1750_opacity$jscomp$44$$=$JSCompiler_temp_const$jscomp$1748_props_78534$$.opacity;$JSCompiler_temp_const$jscomp$1748_props_78534$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:$JSCompiler_temp_const$jscomp$1748_props_78534$$.className,children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_rows_color_row__color-bullet-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$JSCompiler_inline_result$jscomp$1751_color$jscomp$136_opacity$jscomp$inline_8841$$,onClick:$JSCompiler_temp_const$jscomp$1748_props_78534$$.handleClickColor,size:"small"})}),$children$jscomp$295$$]});$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$1750_opacity$jscomp$44$$)?($JSCompiler_temp_const$jscomp$1750_opacity$jscomp$44$$=
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_color_row__icon-text",children:"%"}),$JSCompiler_inline_result$jscomp$1751_color$jscomp$136_opacity$jscomp$inline_8841$$=$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1751_color$jscomp$136_opacity$jscomp$inline_8841$$),$JSCompiler_inline_result$jscomp$1751_color$jscomp$136_opacity$jscomp$inline_8841$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1751_color$jscomp$136_opacity$jscomp$inline_8841$$,
$APP.$cljs$cst$1621$multiple$$)?"":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$coalesce$$($JSCompiler_inline_result$jscomp$1751_color$jscomp$136_opacity$jscomp$inline_8841$$)*100)),$JSCompiler_temp$jscomp$1749_select_on_focus$jscomp$1$$=(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__opacity-element-wrapper",children:[$JSCompiler_temp_const$jscomp$1750_opacity$jscomp$44$$,
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_opacity_change$$,className:"main_ui_workspace_sidebar_options_rows_color_row__opacity-input",placeholder:"--",selectOnFocus:$JSCompiler_temp$jscomp$1749_select_on_focus$jscomp$1$$,max:100,"data-testid":"opacity-input",value:$JSCompiler_inline_result$jscomp$1751_color$jscomp$136_opacity$jscomp$inline_8841$$,onFocus:$on_focus$jscomp$7$$,onBlur:$on_blur$jscomp$10$$,"default":100})]})):$JSCompiler_temp$jscomp$1749_select_on_focus$jscomp$1$$=
null;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-info",children:[$JSCompiler_temp_const$jscomp$1748_props_78534$$,$JSCompiler_temp$jscomp$1749_select_on_focus$jscomp$1$$]})};
$app$main$ui$workspace$sidebar$options$rows$color_row$color_token_row_STAR_$$=function($active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$){var $detach_token$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$.detachToken,$color$jscomp$137$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$.color,$applied_token_name$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$.appliedTokenName,$on_swatch_click_token$$=
$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$.onSwatchClickToken,$open_modal_from_token$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$.openModalFromToken;$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$=$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$.activeTokens;var $active_tokens__$1_id$jscomp$928$$=$APP.$cljs$core$delay_QMARK_$$($active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$)?
$APP.$cljs$core$_deref$$($active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$):$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$;$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($active_tokens__$1_id$jscomp$928$$);var $token$jscomp$130$$=$APP.$cljs$core$some$$(function($p1__78539_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78539_SHARP_$$),
$applied_token_name$$)?$p1__78539_SHARP_$$:null},$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$);$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($detach_token$$),$APP.$rumext$v2$adapt$$($token$jscomp$130$$),$APP.$rumext$v2$adapt$$($applied_token_name$$)],function(){var $or__5025__auto__$jscomp$inline_8843_token_name$jscomp$19$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$130$$);
$or__5025__auto__$jscomp$inline_8843_token_name$jscomp$19$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8843_token_name$jscomp$19$$)?$or__5025__auto__$jscomp$inline_8843_token_name$jscomp$19$$:$applied_token_name$$;return $detach_token$$.$cljs$core$IFn$_invoke$arity$1$?$detach_token$$.$cljs$core$IFn$_invoke$arity$1$($or__5025__auto__$jscomp$inline_8843_token_name$jscomp$19$$):$detach_token$$($or__5025__auto__$jscomp$inline_8843_token_name$jscomp$19$$)});var $token_name$jscomp$18$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$130$$),
$resolved$jscomp$5$$=$APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$130$$),$all_tokens_map_name_tooltip_content_token_exists_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_map$$),$has_errors$jscomp$1$$=($all_tokens_map_name_tooltip_content_token_exists_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($all_tokens_map_name_tooltip_content_token_exists_QMARK_$$,$applied_token_name$$))&&$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$130$$)!=
null,$not_active$$=$all_tokens_map_name_tooltip_content_token_exists_QMARK_$$&&($APP.$cljs$core$empty_QMARK_$$($active_tokens__$1_id$jscomp$928$$)||$token$jscomp$130$$==null);$active_tokens__$1_id$jscomp$928$$=""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$130$$)??"")+"-name";var $token_name_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$broken_state$$=!$all_tokens_map_name_tooltip_content_token_exists_QMARK_$$||$has_errors$jscomp$1$$||$not_active$$,$swatch_tooltip_content$$=
$not_active$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("ds.inputs.token-field.no-active-token-option",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$applied_token_name$$])):$all_tokens_map_name_tooltip_content_token_exists_QMARK_$$?$has_errors$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.ref-not-valid",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$applied_token_name$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$resolved$jscomp$5$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("options.deleted-token-with-name",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$applied_token_name$$]));$all_tokens_map_name_tooltip_content_token_exists_QMARK_$$=$has_errors$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.ref-not-valid",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$applied_token_name$$])):
$not_active$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("ds.inputs.token-field.no-active-token-option",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$applied_token_name$$])):$all_tokens_map_name_tooltip_content_token_exists_QMARK_$$?function(){return(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name")??"")+": "}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_rows_color_row__token-name-tooltip",children:$applied_token_name$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.tabs.styles.token-resolved-value")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_color_row__resolved-value",children:" "+($resolved$jscomp$5$$??"")})]})]})}:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("options.deleted-token-with-name",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$applied_token_name$$]));return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-info",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__token-color-wrapper "+($broken_state$$?"main_ui_workspace_sidebar_options_rows_color_row__token-color-with-errors":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-bullet-wrapper",
children:[$broken_state$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__error-dot"}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color$jscomp$137$$,tooltipContent:$swatch_tooltip_content$$,onClick:$on_swatch_click_token$$,hasErrors:$broken_state$$,size:"small"})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$all_tokens_map_name_tooltip_content_token_exists_QMARK_$$,
id:$active_tokens__$1_id$jscomp$928$$,"aria-label":[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name")),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_name$$)].join(""),triggerRef:$token_name_ref$$,className:"main_ui_workspace_sidebar_options_rows_color_row__token-tooltip",children:(0,$APP.$rumext$v2$jsx$$)("div",{ref:$token_name_ref$$,"aria-labelledby":$active_tokens__$1_id$jscomp$928$$,
className:"main_ui_workspace_sidebar_options_rows_color_row__token-name",children:$APP.$cljs$core$truth_$$($token_name$jscomp$18$$)?$token_name$jscomp$18$$:$applied_token_name$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__token-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("token-actions.detach-token"),
onClick:$active_color_tokens_active_tokens$jscomp$4_on_detach_token_props_78541$$,icon:"detach"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.open-token-list-dropdown"),onClick:$open_modal_from_token$$,icon:"tokens"})]})]})})};
$app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$=function($props_78547_token_color$$){var $on_change$jscomp$38$$=$props_78547_token_color$$.onChange,$on_remove$$=$props_78547_token_color$$.onRemove,$on_open$$=$props_78547_token_color$$.onOpen,$on_detach_token$jscomp$1$$=$props_78547_token_color$$.onDetachToken,$disable_picker$$=$props_78547_token_color$$.disablePicker,$disable_gradient$$=$props_78547_token_color$$.disableGradient,$disable_opacity$jscomp$1$$=$props_78547_token_color$$.disableOpacity,
$on_token_change$jscomp$2$$=$props_78547_token_color$$.onTokenChange,$select_on_focus$jscomp$2$$=$props_78547_token_color$$.selectOnFocus,$select_only$jscomp$1$$=$props_78547_token_color$$.selectOnly,$index$jscomp$463$$=$props_78547_token_color$$.index,$color$jscomp$138$$=$props_78547_token_color$$.color,$disable_image$$=$props_78547_token_color$$.disableImage,$on_close$jscomp$15$$=$props_78547_token_color$$.onClose,$disable_drag$jscomp$1_dprops$jscomp$1$$=$props_78547_token_color$$.disableDrag,$on_focus$jscomp$8$$=
$props_78547_token_color$$.onFocus,$on_blur$jscomp$11$$=$props_78547_token_color$$.onBlur,$applied_token$jscomp$2$$=$props_78547_token_color$$.appliedToken,$on_reorder$$=$props_78547_token_color$$.onReorder,$class$$jscomp$62$$=$props_78547_token_color$$.className,$hidden$jscomp$11_row_class$$=$props_78547_token_color$$.hidden,$on_detach$$=$props_78547_token_color$$.onDetach,$origin$jscomp$68$$=$props_78547_token_color$$.origin;$props_78547_token_color$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1214$token_color$$);var $gradient_color_QMARK__libraries$jscomp$139_src_colors$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$color_without_hash$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$138$$)],function(){return $app$common$types$color$remove_hash$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$))}),$file_id$jscomp$369_image_color_QMARK_$$=function(){var $or__5025__auto__$jscomp$1126$$=
$APP.$cljs$cst$1742$ref_file$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1126$$)?$or__5025__auto__$jscomp$1126$$:$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$)}(),$color_id$jscomp$8_library_color_QMARK_$$=function(){var $or__5025__auto__$jscomp$1127$$=$APP.$cljs$cst$1741$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1127$$)?
$or__5025__auto__$jscomp$1127$$:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$)}();$gradient_color_QMARK__libraries$jscomp$139_src_colors$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_color_QMARK__libraries$jscomp$139_src_colors$$,$file_id$jscomp$369_image_color_QMARK_$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2220$colors$$);var $color_name$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_color_QMARK__libraries$jscomp$139_src_colors$$,$color_id$jscomp$8_library_color_QMARK_$$),$APP.$cljs$cst$725$name$$),$has_multiple_colors$$=$APP.$app$util$color$multiple_QMARK_$$($color$jscomp$138$$);$color_id$jscomp$8_library_color_QMARK_$$=function(){var $and__5023__auto__$jscomp$746_or__5025__auto__$jscomp$inline_8845$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$);
$and__5023__auto__$jscomp$746_or__5025__auto__$jscomp$inline_8845$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$746_or__5025__auto__$jscomp$inline_8845$$)?$and__5023__auto__$jscomp$746_or__5025__auto__$jscomp$inline_8845$$:$APP.$cljs$cst$1741$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$746_or__5025__auto__$jscomp$inline_8845$$)?$APP.$cljs$core$truth_$$($color_name$$)?!$has_multiple_colors$$:$color_name$$:$and__5023__auto__$jscomp$746_or__5025__auto__$jscomp$inline_8845$$}();
$gradient_color_QMARK__libraries$jscomp$139_src_colors$$=function(){var $and__5023__auto__$jscomp$747_and__5023__auto____$1$jscomp$128$$=!$has_multiple_colors$$;return $and__5023__auto__$jscomp$747_and__5023__auto____$1$jscomp$128$$?($and__5023__auto__$jscomp$747_and__5023__auto____$1$jscomp$128$$=$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$747_and__5023__auto____$1$jscomp$128$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$138$$,
$APP.$cljs$cst$1730$gradient$$),$APP.$cljs$cst$139$type$$):$and__5023__auto__$jscomp$747_and__5023__auto____$1$jscomp$128$$):$and__5023__auto__$jscomp$747_and__5023__auto____$1$jscomp$128$$}();$file_id$jscomp$369_image_color_QMARK_$$=function(){var $and__5023__auto__$jscomp$748$$=!$has_multiple_colors$$;return $and__5023__auto__$jscomp$748$$?$APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$):$and__5023__auto__$jscomp$748$$}();var $editing_text_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$is_editing_text$$=$APP.$cljs$core$_deref$$($editing_text_STAR_$$),$active_tokens_STAR_$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$active_tokens_by_type$$),$tokens$jscomp$45$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens_STAR_$$),$APP.$rumext$v2$adapt$$($origin$jscomp$68$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$($active_tokens_STAR_$$,$origin$jscomp$68$$)}),$on_focus_SINGLEQUOTE_$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$8$$)],function(){$APP.$cljs$core$reset_BANG_$$($editing_text_STAR_$$,!0);return $APP.$cljs$core$truth_$$($on_focus$jscomp$8$$)?$on_focus$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_focus$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_focus$jscomp$8$$():null}),$on_blur_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_blur$jscomp$11$$)],function(){$APP.$cljs$core$reset_BANG_$$($editing_text_STAR_$$,
!1);return $APP.$cljs$core$truth_$$($on_blur$jscomp$11$$)?$on_blur$jscomp$11$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$11$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$11$$():null}),$parse_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($color__$1$jscomp$19$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$19$$,$APP.$cljs$cst$1303$color$$,function($p1__78545_SHARP_$$){return $APP.$cljs$core$truth_$$($p1__78545_SHARP_$$)?
$p1__78545_SHARP_$$:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$19$$)})}),$detach_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$),$APP.$rumext$v2$adapt$$($color$jscomp$138$$)],function(){return $APP.$cljs$core$truth_$$($on_detach$$)?$on_detach$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$463$$,$color$jscomp$138$$):
$on_detach$$($index$jscomp$463$$,$color$jscomp$138$$):null}),$handle_select$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($select_only$jscomp$1$$),$APP.$rumext$v2$adapt$$($color$jscomp$138$$),$APP.$rumext$v2$adapt$$($applied_token$jscomp$2$$)],function(){var $color__$1$jscomp$20$$=$APP.$cljs$core$truth_$$($applied_token$jscomp$2$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$138$$,$APP.$cljs$cst$4252$has_token_applied$$,
!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4253$token_name$$,$applied_token$jscomp$2$$])):$color$jscomp$138$$;return $select_only$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$select_only$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$20$$):$select_only$jscomp$1$$($color__$1$jscomp$20$$)}),$on_color_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$138$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$38$$)],function($color__$1$jscomp$21_value$jscomp$793$$){$color__$1$jscomp$21_value$jscomp$793$$=$APP.$cljs$core$select_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$138$$,$APP.$cljs$cst$1303$color$$,$color__$1$jscomp$21_value$jscomp$793$$),$APP.$cljs$cst$1730$gradient$$),$APP.$app$common$types$color$color_attrs$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$add_recent_color$$($color__$1$jscomp$21_value$jscomp$793$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$on_change$jscomp$38$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$38$$.$cljs$core$IFn$_invoke$arity$2$($color__$1$jscomp$21_value$jscomp$793$$,$index$jscomp$463$$):$on_change$jscomp$38$$($color__$1$jscomp$21_value$jscomp$793$$,$index$jscomp$463$$)]))}),$on_opacity_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$138$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$38$$)],function($color__$1$jscomp$22_value$jscomp$794$$){$color__$1$jscomp$22_value$jscomp$794$$=$APP.$cljs$core$select_keys$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$138$$,$APP.$cljs$cst$1740$opacity$$,$color__$1$jscomp$22_value$jscomp$794$$/100),$APP.$cljs$cst$1741$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1742$ref_file$$])),
$APP.$app$common$types$color$color_attrs$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$add_recent_color$$($color__$1$jscomp$22_value$jscomp$794$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$on_change$jscomp$38$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$38$$.$cljs$core$IFn$_invoke$arity$2$($color__$1$jscomp$22_value$jscomp$794$$,$index$jscomp$463$$):$on_change$jscomp$38$$($color__$1$jscomp$22_value$jscomp$794$$,
$index$jscomp$463$$)]))}),$open_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disable_gradient$$),$APP.$rumext$v2$adapt$$($disable_opacity$jscomp$1$$),$APP.$rumext$v2$adapt$$($disable_image$$),$APP.$rumext$v2$adapt$$($disable_picker$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$38$$),$APP.$rumext$v2$adapt$$($on_close$jscomp$15$$),$APP.$rumext$v2$adapt$$($on_open$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$45$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$),
$APP.$rumext$v2$adapt$$($applied_token$jscomp$2$$)],function($color__$1$jscomp$23_color__$2$jscomp$1$$,$pos$jscomp$132_props$jscomp$302$$,$tab$jscomp$6$$){$color__$1$jscomp$23_color__$2$jscomp$1$$=$has_multiple_colors$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,"#B1B2B5",$APP.$cljs$cst$1740$opacity$$,1],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$23_color__$2$jscomp$1$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$23_color__$2$jscomp$1$$,$APP.$cljs$cst$1740$opacity$$,1):$color__$1$jscomp$23_color__$2$jscomp$1$$;$pos$jscomp$132_props$jscomp$302$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$4223$disable_gradient$$,$cljs$cst$5683$on_token_change$$,$APP.$cljs$cst$4222$disable_opacity$$,$cljs$cst$5684$disable_image$$,$APP.$cljs$cst$5108$on_close$$,$cljs$cst$5685$applied_token$$,$cljs$cst$5686$active_tokens$$,
$cljs$cst$5687$color_origin$$,$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$4224$on_change$$,$APP.$cljs$cst$5452$tab$$,$APP.$cljs$cst$142$data$$],[$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$132_props$jscomp$302$$),$disable_gradient$$,$on_token_change$jscomp$2$$,$disable_opacity$jscomp$1$$,$disable_image$$,function($value$jscomp$795$$,$opacity$jscomp$45$$,$id$jscomp$929$$,$file_id__$1$jscomp$10$$){return $APP.$cljs$core$truth_$$($on_close$jscomp$15$$)?
$on_close$jscomp$15$$.$cljs$core$IFn$_invoke$arity$4$?$on_close$jscomp$15$$.$cljs$core$IFn$_invoke$arity$4$($value$jscomp$795$$,$opacity$jscomp$45$$,$id$jscomp$929$$,$file_id__$1$jscomp$10$$):$on_close$jscomp$15$$($value$jscomp$795$$,$opacity$jscomp$45$$,$id$jscomp$929$$,$file_id__$1$jscomp$10$$):null},$applied_token$jscomp$2$$,$tokens$jscomp$45$$,$origin$jscomp$68$$,$cljs$cst$5688$sidebar$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$132_props$jscomp$302$$),function($p1__78546_SHARP_$$){return $on_change$jscomp$38$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change$jscomp$38$$.$cljs$core$IFn$_invoke$arity$2$($p1__78546_SHARP_$$,$index$jscomp$463$$):$on_change$jscomp$38$$($p1__78546_SHARP_$$,$index$jscomp$463$$)},$tab$jscomp$6$$,$color__$1$jscomp$23_color__$2$jscomp$1$$]);$APP.$cljs$core$fn_QMARK_$$($on_open$$)&&($on_open$$.$cljs$core$IFn$_invoke$arity$1$?$on_open$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$23_color__$2$jscomp$1$$):$on_open$$($color__$1$jscomp$23_color__$2$jscomp$1$$));return $APP.$cljs$core$truth_$$($disable_picker$$)?null:
$APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2247$colorpicker$$,$pos$jscomp$132_props$jscomp$302$$)}),$handle_click_color$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_modal$$)],function($color__$1$jscomp$24$$,$cpos$jscomp$1_event$jscomp$309$$){$cpos$jscomp$1_event$jscomp$309$$=$APP.$app$util$dom$get_client_position$$($cpos$jscomp$1_event$jscomp$309$$);return $open_modal$$.$cljs$core$IFn$_invoke$arity$3$?
$open_modal$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$24$$,$cpos$jscomp$1_event$jscomp$309$$,null):$open_modal$$($color__$1$jscomp$24$$,$cpos$jscomp$1_event$jscomp$309$$,null)}),$open_modal_from_token$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_modal$$),$APP.$rumext$v2$adapt$$($color$jscomp$138$$)],function($event$jscomp$310_pos$jscomp$133_x$jscomp$1247$$){var $cpos$jscomp$2_y$jscomp$468$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$310_pos$jscomp$133_x$jscomp$1247$$);
$event$jscomp$310_pos$jscomp$133_x$jscomp$1247$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cpos$jscomp$2_y$jscomp$468$$);$cpos$jscomp$2_y$jscomp$468$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cpos$jscomp$2_y$jscomp$468$$);$event$jscomp$310_pos$jscomp$133_x$jscomp$1247$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,$event$jscomp$310_pos$jscomp$133_x$jscomp$1247$$-215,$APP.$cljs$cst$1516$y$$,$cpos$jscomp$2_y$jscomp$468$$],null);return $open_modal$$.$cljs$core$IFn$_invoke$arity$3$?
$open_modal$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$138$$,$event$jscomp$310_pos$jscomp$133_x$jscomp$1247$$,$APP.$cljs$cst$1214$token_color$$):$open_modal$$($color$jscomp$138$$,$event$jscomp$310_pos$jscomp$133_x$jscomp$1247$$,$APP.$cljs$cst$1214$token_color$$)}),$on_swatch_click_token$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_modal$$)],function($color__$1$jscomp$25$$,$cpos$jscomp$3_event$jscomp$311$$){$cpos$jscomp$3_event$jscomp$311$$=
$APP.$app$util$dom$get_client_position$$($cpos$jscomp$3_event$jscomp$311$$);return $open_modal$$.$cljs$core$IFn$_invoke$arity$3$?$open_modal$$.$cljs$core$IFn$_invoke$arity$3$($color__$1$jscomp$25$$,$cpos$jscomp$3_event$jscomp$311$$,$APP.$cljs$cst$1214$token_color$$):$open_modal$$($color__$1$jscomp$25$$,$cpos$jscomp$3_event$jscomp$311$$,$APP.$cljs$cst$1214$token_color$$)}),$detach_token$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$1$$)],
function($token$jscomp$131$$){return $APP.$cljs$core$truth_$$($on_detach_token$jscomp$1$$)?$on_detach_token$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_detach_token$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$131$$):$on_detach_token$jscomp$1$$($token$jscomp$131$$):null}),$on_remove_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$463$$),$APP.$rumext$v2$adapt$$($on_remove$$)],function(){return $APP.$cljs$core$truth_$$($on_remove$$)?
$on_remove$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$463$$):$on_remove$$($index$jscomp$463$$):null}),$prev_color$jscomp$2$$=$APP.$app$main$ui$hooks$use_previous$$($color$jscomp$138$$),$dref$jscomp$1_on_drop$jscomp$3_vec__78550$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reorder$$),$APP.$rumext$v2$adapt$$($index$jscomp$463$$)],function($relative_pos_to_space_between_pos$jscomp$10$$,$data$jscomp$467_from_pos$jscomp$10$$){$data$jscomp$467_from_pos$jscomp$10$$=
$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$467_from_pos$jscomp$10$$);$relative_pos_to_space_between_pos$jscomp$10$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos_to_space_between_pos$jscomp$10$$,$APP.$cljs$cst$2963$bot$$)?$index$jscomp$463$$+1:$index$jscomp$463$$;return $on_reorder$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$467_from_pos$jscomp$10$$,$relative_pos_to_space_between_pos$jscomp$10$$):
$on_reorder$$($data$jscomp$467_from_pos$jscomp$10$$,$relative_pos_to_space_between_pos$jscomp$10$$)});$dref$jscomp$1_on_drop$jscomp$3_vec__78550$$=$on_reorder$$!=null?$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,"penpot/color-row",$APP.$cljs$cst$2966$on_drop$$,$dref$jscomp$1_on_drop$jscomp$3_vec__78550$$,$APP.$cljs$cst$2959$disabled$$,$disable_drag$jscomp$1_dprops$jscomp$1$$,
$APP.$cljs$cst$2969$detect_center_QMARK_$$,!1,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1801$index$$,$index$jscomp$463$$],null)])):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null],null);$disable_drag$jscomp$1_dprops$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$1_on_drop$jscomp$3_vec__78550$$,0,null);$dref$jscomp$1_on_drop$jscomp$3_vec__78550$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$1_on_drop$jscomp$3_vec__78550$$,
1,null);$hidden$jscomp$11_row_class$$="main_ui_workspace_sidebar_options_rows_color_row__color-data "+($APP.$cljs$core$truth_$$($hidden$jscomp$11_row_class$$)?"main_ui_workspace_sidebar_options_rows_color_row__hidden":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($disable_drag$jscomp$1_dprops$jscomp$1$$),$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_sidebar_options_rows_color_row__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($disable_drag$jscomp$1_dprops$jscomp$1$$),
$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_sidebar_options_rows_color_row__dnd-over-bot":"");$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$138$$),$APP.$rumext$v2$adapt$$($prev_color$jscomp$2$$),$APP.$rumext$v2$adapt$$($disable_picker$$)],function(){if($APP.$cljs$core$not$$($disable_picker$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prev_color$jscomp$2$$,$color$jscomp$138$$)){var $JSCompiler_temp$jscomp$1583_props$jscomp$inline_8848$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$142$data$$,$parse_color$$.$cljs$core$IFn$_invoke$arity$1$?$parse_color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$138$$):$parse_color$$($color$jscomp$138$$)],null);$JSCompiler_temp$jscomp$1583_props$jscomp$inline_8848$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$modal$update_props$$($JSCompiler_temp$jscomp$1583_props$jscomp$inline_8848$$))}else $JSCompiler_temp$jscomp$1583_props$jscomp$inline_8848$$=
null;return $JSCompiler_temp$jscomp$1583_props$jscomp$inline_8848$$});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($applied_token$jscomp$2$$),$APP.$rumext$v2$adapt$$($disable_picker$$)],function(){return $APP.$cljs$core$not$$($disable_picker$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$modal$update_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5685$applied_token$$,$applied_token$jscomp$2$$],null))):
null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:($class$$jscomp$62$$??"")+" "+($hidden$jscomp$11_row_class$$??""),children:[$on_reorder$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$1_on_drop$jscomp$3_vec__78550$$}):null,$APP.$cljs$core$truth_$$($props_78547_token_color$$?$applied_token$jscomp$2$$:$props_78547_token_color$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_token_row_STAR_$$,
{activeTokens:$tokens$jscomp$45$$,appliedTokenName:$applied_token$jscomp$2$$,color:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$138$$,$APP.$cljs$cst$1741$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1742$ref_file$$])),onSwatchClickToken:$on_swatch_click_token$jscomp$1$$,detachToken:$detach_token$jscomp$1$$,openModalFromToken:$open_modal_from_token$jscomp$1$$}):$APP.$cljs$core$truth_$$($color_id$jscomp$8_library_color_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper main_ui_workspace_sidebar_options_rows_color_row__library-name-wrapper",handleClickColor:$handle_click_color$jscomp$1$$,opacity:!1,color:$color$jscomp$138$$,children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($color_name$$),
className:"main_ui_workspace_sidebar_options_rows_color_row__color-name",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($color_name$$)}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_workspace_sidebar_options_rows_color_row__detach-btn","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.detach"),onClick:$detach_value$$,icon:"detach"})]})}):$APP.$cljs$core$truth_$$($gradient_color_QMARK__libraries$jscomp$139_src_colors$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper "+($disable_opacity$jscomp$1$$?"main_ui_workspace_sidebar_options_rows_color_row__no-opacity":"")+" main_ui_workspace_sidebar_options_rows_color_row__gradient-name-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name",children:$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$138$$,
$APP.$cljs$cst$1730$gradient$$),$APP.$cljs$cst$139$type$$))}),selectOnFocus:$select_on_focus$jscomp$2$$,onFocus:$on_focus_SINGLEQUOTE_$$,onOpacityChange:$on_opacity_change$jscomp$1$$,onBlur:$on_blur_SINGLEQUOTE_$$,handleClickColor:$handle_click_color$jscomp$1$$,color:$color$jscomp$138$$,opacity:!$disable_opacity$jscomp$1$$}):$APP.$cljs$core$truth_$$($file_id$jscomp$369_image_color_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,
{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper "+($disable_opacity$jscomp$1$$?"main_ui_workspace_sidebar_options_rows_color_row__no-opacity":""),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image")}),selectOnFocus:$select_on_focus$jscomp$2$$,onFocus:$on_focus_SINGLEQUOTE_$$,onOpacityChange:$on_opacity_change$jscomp$1$$,onBlur:$on_blur_SINGLEQUOTE_$$,
handleClickColor:$handle_click_color$jscomp$1$$,color:$color$jscomp$138$$,opacity:!$disable_opacity$jscomp$1$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_info_wrapper_STAR_$$,{className:"main_ui_workspace_sidebar_options_rows_color_row__color-name-wrapper "+($disable_opacity$jscomp$1$$||$has_multiple_colors$$?"main_ui_workspace_sidebar_options_rows_color_row__no-opacity":"")+" "+($APP.$cljs$core$truth_$$($is_editing_text$$)?"main_ui_workspace_sidebar_options_rows_color_row__editing":
""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_color_row__color-input-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$color_input$color_input_STAR_$$,{value:$has_multiple_colors$$?"":$color_without_hash$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),"data-index":$index$jscomp$463$$,className:"main_ui_workspace_sidebar_options_rows_color_row__color-input",onFocus:$on_focus_SINGLEQUOTE_$$,
onBlur:$on_blur_SINGLEQUOTE_$$,onChange:$on_color_change$$})}),selectOnFocus:$select_on_focus$jscomp$2$$,onFocus:$on_focus_SINGLEQUOTE_$$,onOpacityChange:$on_opacity_change$jscomp$1$$,onBlur:$on_blur_SINGLEQUOTE_$$,handleClickColor:$handle_click_color$jscomp$1$$,color:$color$jscomp$138$$,opacity:!($disable_opacity$jscomp$1$$||$has_multiple_colors$$)}),$on_remove$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.remove-color"),
onClick:$on_remove_SINGLEQUOTE_$$,icon:"remove"}):null,$APP.$cljs$core$truth_$$($select_only$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.select-this-color"),onClick:$handle_select$jscomp$1$$,tooltipPlacement:"top-left",icon:"move"}):null]})};
$app$main$ui$workspace$colorpicker$gradients$format_rgb$$=function($p__78572_r$jscomp$129$$){var $map__78573__$1_offset$jscomp$201$$=$APP.$cljs$core$__destructure_map$$($p__78572_r$jscomp$129$$);$p__78572_r$jscomp$129$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78573__$1_offset$jscomp$201$$,$APP.$cljs$cst$1749$r$$);var $g$jscomp$151$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78573__$1_offset$jscomp$201$$,$APP.$cljs$cst$1750$g$$),$b$jscomp$350$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78573__$1_offset$jscomp$201$$,
$APP.$cljs$cst$1525$b$$);$map__78573__$1_offset$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78573__$1_offset$jscomp$201$$,$APP.$cljs$cst$195$offset$$);return"rgb("+($p__78572_r$jscomp$129$$??"")+", "+($g$jscomp$151$$??"")+", "+($b$jscomp$350$$??"")+") "+$map__78573__$1_offset$jscomp$201$$*100+"%"};
$app$main$ui$workspace$colorpicker$gradients$gradient__GT_string$$=function($stops$jscomp$16$$){return"linear-gradient(90deg, "+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$colorpicker$gradients$format_rgb$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($opacity$jscomp$47_p__78576$$){var $map__78577__$1_offset$jscomp$202$$=$APP.$cljs$core$__destructure_map$$($opacity$jscomp$47_p__78576$$),
$color$jscomp$139_r$jscomp$130$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78577__$1_offset$jscomp$202$$,$APP.$cljs$cst$1303$color$$);$opacity$jscomp$47_p__78576$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78577__$1_offset$jscomp$202$$,$APP.$cljs$cst$1740$opacity$$);$map__78577__$1_offset$jscomp$202$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78577__$1_offset$jscomp$202$$,$APP.$cljs$cst$195$offset$$);var $b$jscomp$351_vec__78578$$=$APP.$app$common$types$color$hex__GT_rgb$$($color$jscomp$139_r$jscomp$130$$);
$color$jscomp$139_r$jscomp$130$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$351_vec__78578$$,0,null);var $g$jscomp$152$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$351_vec__78578$$,1,null);$b$jscomp$351_vec__78578$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$351_vec__78578$$,2,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1749$r$$,$color$jscomp$139_r$jscomp$130$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$152$$,
$APP.$cljs$cst$1525$b$$,$b$jscomp$351_vec__78578$$,$APP.$cljs$cst$746$alpha$$,$opacity$jscomp$47_p__78576$$,$APP.$cljs$cst$195$offset$$,$map__78577__$1_offset$jscomp$202$$],null)},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stops$jscomp$16$$))))??"")+")"};
$app$main$ui$workspace$colorpicker$gradients$stop_input_row_STAR_$$=function($offset$jscomp$203_props_78581$$){var $on_blur_stop_offset$$=$offset$jscomp$203_props_78581$$.onBlurStopOffset,$on_select_stop$$=$offset$jscomp$203_props_78581$$.onSelectStop,$on_remove_stop$$=$offset$jscomp$203_props_78581$$.onRemoveStop,$index$jscomp$464$$=$offset$jscomp$203_props_78581$$.index,$on_blur_stop_color$$=$offset$jscomp$203_props_78581$$.onBlurStopColor,$on_reorder_stops$$=$offset$jscomp$203_props_78581$$.onReorderStops,
$is_selected$jscomp$4$$=$offset$jscomp$203_props_78581$$.isSelected,$on_focus_stop_color$$=$offset$jscomp$203_props_78581$$.onFocusStopColor,$on_focus_stop_offset$$=$offset$jscomp$203_props_78581$$.onFocusStopOffset,$stop$jscomp$8$$=$offset$jscomp$203_props_78581$$.stop,$on_change_stop$$=$offset$jscomp$203_props_78581$$.onChangeStop;$offset$jscomp$203_props_78581$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stop$jscomp$8$$,$APP.$cljs$cst$195$offset$$);var $handle_change_stop_color$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_stop$$),
$APP.$rumext$v2$adapt$$($stop$jscomp$8$$)],function($G__78586_value$jscomp$796$$){$G__78586_value$jscomp$796$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$stop$jscomp$8$$,$G__78586_value$jscomp$796$$]));return $on_change_stop$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_stop$$.$cljs$core$IFn$_invoke$arity$2$($stop$jscomp$8$$,$G__78586_value$jscomp$796$$):$on_change_stop$$($stop$jscomp$8$$,$G__78586_value$jscomp$796$$)}),
$handle_change_offset$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_stop$$),$APP.$rumext$v2$adapt$$($stop$jscomp$8$$)],function($G__78588_value$jscomp$797$$){$G__78588_value$jscomp$797$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($stop$jscomp$8$$,$APP.$cljs$cst$195$offset$$,$APP.$app$common$math$precision$$($G__78588_value$jscomp$797$$/100,2));return $on_change_stop$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_stop$$.$cljs$core$IFn$_invoke$arity$2$($stop$jscomp$8$$,
$G__78588_value$jscomp$797$$):$on_change_stop$$($stop$jscomp$8$$,$G__78588_value$jscomp$797$$)}),$handle_remove_stop$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_remove_stop$$),$APP.$rumext$v2$adapt$$($index$jscomp$464$$)],function(){return $APP.$cljs$core$truth_$$($on_remove_stop$$)?$on_remove_stop$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$464$$):$on_remove_stop$$($index$jscomp$464$$):null}),
$handle_focus_stop_offset$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$$),$APP.$rumext$v2$adapt$$($on_focus_stop_offset$$),$APP.$rumext$v2$adapt$$($index$jscomp$464$$)],function(){$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$464$$):$on_select_stop$$($index$jscomp$464$$);return $APP.$cljs$core$truth_$$($on_focus_stop_offset$$)?$on_focus_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$?
$on_focus_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$():$on_focus_stop_offset$$():null}),$handle_blur_stop_offset$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$$),$APP.$rumext$v2$adapt$$($on_blur_stop_offset$$),$APP.$rumext$v2$adapt$$($index$jscomp$464$$)],function(){$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$464$$):$on_select_stop$$($index$jscomp$464$$);return $APP.$cljs$core$truth_$$($on_blur_stop_offset$$)?
$on_blur_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur_stop_offset$$():null}),$handle_focus_stop_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$$),$APP.$rumext$v2$adapt$$($on_focus_stop_offset$$),$APP.$rumext$v2$adapt$$($index$jscomp$464$$)],function(){$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$464$$):
$on_select_stop$$($index$jscomp$464$$);return $APP.$cljs$core$truth_$$($on_focus_stop_color$$)?$on_focus_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$?$on_focus_stop_offset$$.$cljs$core$IFn$_invoke$arity$0$():$on_focus_stop_offset$$():null}),$handle_blur_stop_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$$),$APP.$rumext$v2$adapt$$($on_blur_stop_color$$),$APP.$rumext$v2$adapt$$($index$jscomp$464$$)],function(){$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?
$on_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$464$$):$on_select_stop$$($index$jscomp$464$$);return $APP.$cljs$core$truth_$$($on_blur_stop_color$$)?$on_blur_stop_color$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur_stop_color$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur_stop_color$$():null}),$dprops$jscomp$2_on_drop$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$464$$),$APP.$rumext$v2$adapt$$($on_reorder_stops$$)],function($position$jscomp$196_to_index$jscomp$17$$,
$data$jscomp$468_from_index$jscomp$10$$){$data$jscomp$468_from_index$jscomp$10$$=$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$468_from_index$jscomp$10$$);$position$jscomp$196_to_index$jscomp$17$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$196_to_index$jscomp$17$$,$APP.$cljs$cst$2963$bot$$)?$index$jscomp$464$$+1:$index$jscomp$464$$;return $APP.$cljs$core$truth_$$($on_reorder_stops$$)?$on_reorder_stops$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder_stops$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$468_from_index$jscomp$10$$,
$position$jscomp$196_to_index$jscomp$17$$):$on_reorder_stops$$($data$jscomp$468_from_index$jscomp$10$$,$position$jscomp$196_to_index$jscomp$17$$):null}),$dref$jscomp$2_vec__78582$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,"penpot/stops",$APP.$cljs$cst$2966$on_drop$$,$dprops$jscomp$2_on_drop$jscomp$4$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1801$index$$,$index$jscomp$464$$],null),$APP.$cljs$cst$2970$draggable_QMARK_$$,!0]));$dprops$jscomp$2_on_drop$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$2_vec__78582$$,0,null);$dref$jscomp$2_vec__78582$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$2_vec__78582$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-stops-entry "+($APP.$cljs$core$truth_$$($is_selected$jscomp$4$$)?
"main_ui_workspace_colorpicker_gradients__is-selected":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$2_on_drop$jscomp$4$$),$APP.$cljs$cst$1672$center$$)?"main_ui_workspace_colorpicker_gradients__dnd-over":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$2_on_drop$jscomp$4$$),$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_colorpicker_gradients__dnd-over-top":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$2_on_drop$jscomp$4$$),$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_colorpicker_gradients__dnd-over-bot":""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$2_vec__78582$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__offset-input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_colorpicker_gradients__icon-text",children:"%"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{value:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$data$coalesce$$($offset$jscomp$203_props_78581$$)*100)),onChange:$handle_change_offset$$,"default":100,min:0,max:100,onFocus:$handle_focus_stop_offset$$,onBlur:$handle_blur_stop_offset$$})]}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{onRemove:$handle_remove_stop$$,origin:$APP.$cljs$cst$1730$gradient$$,index:$index$jscomp$464$$,onChange:$handle_change_stop_color$$,onFocus:$handle_focus_stop_color$$,disableGradient:!0,onBlur:$handle_blur_stop_color$$,color:$APP.$cljs$core$select_keys$$($stop$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1740$opacity$$],
null)),disablePicker:!0})]})};
$app$main$ui$workspace$colorpicker$gradients$gradients_STAR_$$=function($handle_change_type_props_78589$$){var $on_reverse_stops$$=$handle_change_type_props_78589$$.onReverseStops,$on_change_type$$=$handle_change_type_props_78589$$.onChangeType,$on_stop_edit_start$$=$handle_change_type_props_78589$$.onStopEditStart,$on_select_stop$jscomp$1$$=$handle_change_type_props_78589$$.onSelectStop,$on_rotate_stops$$=$handle_change_type_props_78589$$.onRotateStops,$on_add_stop_preview$$=$handle_change_type_props_78589$$.onAddStopPreview,
$stops$jscomp$17$$=$handle_change_type_props_78589$$.stops,$on_remove_stop$jscomp$1$$=$handle_change_type_props_78589$$.onRemoveStop,$on_add_stop_auto$$=$handle_change_type_props_78589$$.onAddStopAuto,$on_stop_edit_finish$$=$handle_change_type_props_78589$$.onStopEditFinish,$on_reorder_stops$jscomp$1$$=$handle_change_type_props_78589$$.onReorderStops,$type$jscomp$613$$=$handle_change_type_props_78589$$.type,$on_change_stop$jscomp$1$$=$handle_change_type_props_78589$$.onChangeStop,$editing_stop$jscomp$3$$=
$handle_change_type_props_78589$$.editingStop,$preview_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5689$hover_QMARK_$$,!1,$APP.$cljs$cst$195$offset$$,.5],null)}),$dragging_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$start_offset$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$background_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$handle_select_stop$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_stop$jscomp$1$$)],function($event$jscomp$313_index$jscomp$465$$){return $APP.$cljs$core$truth_$$($on_select_stop$jscomp$1$$)?($event$jscomp$313_index$jscomp$465$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$313_index$jscomp$465$$),"index")),$on_select_stop$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_stop$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$313_index$jscomp$465$$):
$on_select_stop$jscomp$1$$($event$jscomp$313_index$jscomp$465$$)):null});$handle_change_type_props_78589$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_type$$)],function($event$jscomp$314$$){return $APP.$cljs$core$truth_$$($on_change_type$$)?$on_change_type$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_type$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$314$$):$on_change_type$$($event$jscomp$314$$):null});var $handle_add_stop$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_add_stop_auto$$)],
function(){return $APP.$cljs$core$truth_$$($on_add_stop_auto$$)?$on_add_stop_auto$$.$cljs$core$IFn$_invoke$arity$0$?$on_add_stop_auto$$.$cljs$core$IFn$_invoke$arity$0$():$on_add_stop_auto$$():null}),$handle_preview_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($preview_state$$,$APP.$cljs$core$assoc$$,$cljs$cst$5689$hover_QMARK_$$,!0)}),$handle_preview_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($preview_state$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5689$hover_QMARK_$$,!1)}),$handle_preview_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$355_offset$jscomp$204$$){$e$jscomp$355_offset$jscomp$204$$=$APP.$app$common$math$precision$$($e$jscomp$355_offset$jscomp$204$$.nativeEvent.offsetX/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_current_target$$($e$jscomp$355_offset$jscomp$204$$))),2);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($preview_state$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,$e$jscomp$355_offset$jscomp$204$$)}),$handle_preview_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_add_stop_preview$$)],function($e$jscomp$356_offset$jscomp$205$$){$e$jscomp$356_offset$jscomp$205$$=$APP.$app$common$math$precision$$($e$jscomp$356_offset$jscomp$205$$.nativeEvent.offsetX/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_current_target$$($e$jscomp$356_offset$jscomp$205$$))),
2);return $APP.$cljs$core$truth_$$($on_add_stop_preview$$)?$on_add_stop_preview$$.$cljs$core$IFn$_invoke$arity$1$?$on_add_stop_preview$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$356_offset$jscomp$205$$):$on_add_stop_preview$$($e$jscomp$356_offset$jscomp$205$$):null}),$handle_stop_marker_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_stop_edit_start$$),$APP.$rumext$v2$adapt$$($handle_select_stop$$),$APP.$rumext$v2$adapt$$($stops$jscomp$17$$)],
function($event$jscomp$315$$){var $index$jscomp$466_stop$jscomp$9$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$315$$),"index"));$index$jscomp$466_stop$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$17$$,$index$jscomp$466_stop$jscomp$9$$);$APP.$app$util$dom$capture_pointer$$($event$jscomp$315$$);$handle_select_stop$$.$cljs$core$IFn$_invoke$arity$1$?$handle_select_stop$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$315$$):
$handle_select_stop$$($event$jscomp$315$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$2$$,!0);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$2$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$315$$));$APP.$rumext$v2$set_ref_val_BANG_$$($start_offset$jscomp$1$$,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$466_stop$jscomp$9$$));return $on_stop_edit_start$$.$cljs$core$IFn$_invoke$arity$0$?$on_stop_edit_start$$.$cljs$core$IFn$_invoke$arity$0$():
$on_stop_edit_start$$()}),$handle_stop_marker_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_stop$jscomp$1$$),$APP.$rumext$v2$adapt$$($stops$jscomp$17$$)],function($background_width_current_pt$jscomp$1_event$jscomp$316$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$2$$))){var $delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$=$APP.$rumext$v2$ref_val$$($start_ref$jscomp$2$$),$G__78591_new_offset$jscomp$2_start_offset__$1$$=
$APP.$rumext$v2$ref_val$$($start_offset$jscomp$1$$),$index$jscomp$467_stop$jscomp$10$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_target$$($background_width_current_pt$jscomp$1_event$jscomp$316$$),"index"));$background_width_current_pt$jscomp$1_event$jscomp$316$$=$APP.$app$util$dom$get_client_position$$($background_width_current_pt$jscomp$1_event$jscomp$316$$);$delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($background_width_current_pt$jscomp$1_event$jscomp$316$$)-
$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$);$background_width_current_pt$jscomp$1_event$jscomp$316$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$rumext$v2$ref_val$$($background_ref$$)));$delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$/=$background_width_current_pt$jscomp$1_event$jscomp$316$$;$index$jscomp$467_stop$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$17$$,
$index$jscomp$467_stop$jscomp$10$$);$G__78591_new_offset$jscomp$2_start_offset__$1$$=$APP.$app$common$math$precision$$($APP.$app$common$math$clamp$$($G__78591_new_offset$jscomp$2_start_offset__$1$$+$delta_offset_delta_x$jscomp$2_start_pt$jscomp$1$$,0,1),2);$G__78591_new_offset$jscomp$2_start_offset__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$467_stop$jscomp$10$$,$APP.$cljs$cst$195$offset$$,$G__78591_new_offset$jscomp$2_start_offset__$1$$);return $on_change_stop$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_stop$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$467_stop$jscomp$10$$,$G__78591_new_offset$jscomp$2_start_offset__$1$$):$on_change_stop$jscomp$1$$($index$jscomp$467_stop$jscomp$10$$,$G__78591_new_offset$jscomp$2_start_offset__$1$$)}return null}),$handle_stop_marker_lost_pointer_capture$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_stop_edit_finish$$)],function($event$jscomp$317$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$317$$);
$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$2$$,!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$2$$,null);return $on_stop_edit_finish$$.$cljs$core$IFn$_invoke$arity$0$?$on_stop_edit_finish$$.$cljs$core$IFn$_invoke$arity$0$():$on_stop_edit_finish$$()}),$handle_rotate_gradient$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_rotate_stops$$)],function(){return $APP.$cljs$core$truth_$$($on_rotate_stops$$)?$on_rotate_stops$$.$cljs$core$IFn$_invoke$arity$0$?
$on_rotate_stops$$.$cljs$core$IFn$_invoke$arity$0$():$on_rotate_stops$$():null}),$handle_reverse_gradient$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reverse_stops$$)],function(){return $APP.$cljs$core$truth_$$($on_reverse_stops$$)?$on_reverse_stops$$.$cljs$core$IFn$_invoke$arity$0$?$on_reverse_stops$$.$cljs$core$IFn$_invoke$arity$0$():$on_reverse_stops$$():null}),$add_stop_disabled_QMARK_$$=$APP.$app$main$features$use_feature$$("render-wasm/v1")?$APP.$cljs$core$count$$($stops$jscomp$17$$)>=
16:null;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-panel",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-preview",children:[(0,$APP.$rumext$v2$jsx$$)("div",{ref:$background_ref$$,style:{background:$app$main$ui$workspace$colorpicker$gradients$gradient__GT_string$$($stops$jscomp$17$$)},onPointerEnter:$handle_preview_enter$$,onPointerLeave:$handle_preview_leave$$,onPointerMove:$handle_preview_move$$,
onPointerDown:$handle_preview_down$$,className:"main_ui_workspace_colorpicker_gradients__gradient-background",children:$APP.$cljs$core$not$$($add_stop_disabled_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{display:$APP.$cljs$core$truth_$$($cljs$cst$5689$hover_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($preview_state$$)))?"block":"none","--preview-position":""+100*$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($preview_state$$))+"%"},
className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-preview"}):null}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-wrapper",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$120$$,$color$jscomp$140_map__78596_p__78592$$){var $index$jscomp$468$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color$jscomp$140_map__78596_p__78592$$,0,null);$color$jscomp$140_map__78596_p__78592$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($color$jscomp$140_map__78596_p__78592$$,1,null);var $alpha$jscomp$15_map__78596__$1$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$140_map__78596_p__78592$$);$color$jscomp$140_map__78596_p__78592$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78596__$1$$,$APP.$cljs$cst$1303$color$$);var $offset$jscomp$206$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78596__$1$$,$APP.$cljs$cst$195$offset$$),
$r$jscomp$131$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78596__$1$$,$APP.$cljs$cst$1749$r$$),$g$jscomp$153$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78596__$1$$,$APP.$cljs$cst$1750$g$$),$b$jscomp$352$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78596__$1$$,$APP.$cljs$cst$1525$b$$);$alpha$jscomp$15_map__78596__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$15_map__78596__$1$$,
$APP.$cljs$cst$746$alpha$$);$out_arr__44092__auto__$jscomp$120$$.push((0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--color-solid":$color$jscomp$140_map__78596_p__78592$$,"--color-alpha":"rgba("+($r$jscomp$131$$??"")+", "+($g$jscomp$153$$??"")+", "+($b$jscomp$352$$??"")+", "+($alpha$jscomp$15_map__78596__$1$$??"")+")","--position":""+$offset$jscomp$206$$*100+"%"},"data-index":$index$jscomp$468$$,onPointerDown:$handle_stop_marker_pointer_down$$,
onPointerMove:$handle_stop_marker_pointer_move$$,onLostPointerCapture:$handle_stop_marker_lost_pointer_capture$$,className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_stop$jscomp$3$$,$index$jscomp$468$$)?"main_ui_workspace_colorpicker_gradients__is-selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{pointerEvents:"none"},className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-color"}),
(0,$APP.$rumext$v2$jsx$$)("div",{style:{pointerEvents:"none"},className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-alpha"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--position":""+$offset$jscomp$206$$*100+"%"},className:"main_ui_workspace_colorpicker_gradients__gradient-preview-stop-decoration"})]},"preview-stop-"+($index$jscomp$468$$??"")));return $out_arr__44092__auto__$jscomp$120$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($stops$jscomp$17$$))})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-options",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$type$jscomp$613$$,options:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$4230$linear_gradient$$,$APP.$cljs$cst$2296$label$$,"Linear"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$4232$radial_gradient$$,$APP.$cljs$cst$2296$label$$,"Radial"],null)],null),"on-change":$handle_change_type_props_78589$$,"class":"main_ui_workspace_colorpicker_gradients__gradient-options-select"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_gradients__gradient-options-buttons",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":"Rotate gradient",onClick:$handle_rotate_gradient$$,
iconClass:"main_ui_workspace_colorpicker_gradients__rotate-icon",icon:"reload"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":"Reverse gradient",onClick:$handle_reverse_gradient$$,icon:"switch"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":"Add stop",disabled:$add_stop_disabled_QMARK_$$,onClick:$handle_add_stop$$,icon:"add"})]})]}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_colorpicker_gradients__gradient-stops-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$121$$,$p__78597_stop$jscomp$11$$){var $index$jscomp$469$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78597_stop$jscomp$11$$,0,null);$p__78597_stop$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78597_stop$jscomp$11$$,
1,null);$out_arr__44092__auto__$jscomp$121$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$gradients$stop_input_row_STAR_$$,{stop:$p__78597_stop$jscomp$11$$,onSelectStop:$on_select_stop$jscomp$1$$,index:$index$jscomp$469$$,onFocusStopOffset:$on_stop_edit_start$$,onBlurStopColor:$on_stop_edit_finish$$,onChangeStop:$on_change_stop$jscomp$1$$,onFocusStopColor:$on_stop_edit_start$$,onBlurStopOffset:$on_stop_edit_finish$$,onReorderStops:$on_reorder_stops$jscomp$1$$,isSelected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_stop$jscomp$3$$,
$index$jscomp$469$$),onRemoveStop:$on_remove_stop$jscomp$1$$},$index$jscomp$469$$));return $out_arr__44092__auto__$jscomp$121$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($stops$jscomp$17$$))})}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_workspace_colorpicker_gradients__gradient-separator"})]})};
$app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$=function($handle_start_drag_props_77263$$){function $calculate_pos$$($ev$jscomp$8_map__77265_x$jscomp$1248$$){if($APP.$cljs$core$truth_$$($on_change$jscomp$39$$)){var $left$jscomp$29_map__77264_value__$1$jscomp$39$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($ev$jscomp$8_map__77265_x$jscomp$1248$$)),$bottom$jscomp$5_map__77264__$1$$=$APP.$cljs$core$__destructure_map$$($left$jscomp$29_map__77264_value__$1$jscomp$39$$);
$left$jscomp$29_map__77264_value__$1$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$5_map__77264__$1$$,$APP.$cljs$cst$257$left$$);var $h_size_right$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$5_map__77264__$1$$,$APP.$cljs$cst$258$right$$),$top$jscomp$11_v_size$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$5_map__77264__$1$$,$APP.$cljs$cst$1567$top$$);$bottom$jscomp$5_map__77264__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$5_map__77264__$1$$,
$APP.$cljs$cst$1568$bottom$$);$ev$jscomp$8_map__77265_x$jscomp$1248$$=$APP.$app$util$dom$get_client_position$$($ev$jscomp$8_map__77265_x$jscomp$1248$$);var $map__77265__$1_y$jscomp$469$$=$APP.$cljs$core$__destructure_map$$($ev$jscomp$8_map__77265_x$jscomp$1248$$);$ev$jscomp$8_map__77265_x$jscomp$1248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77265__$1_y$jscomp$469$$,$APP.$cljs$cst$1515$x$$);$map__77265__$1_y$jscomp$469$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77265__$1_y$jscomp$469$$,
$APP.$cljs$cst$1516$y$$);$h_size_right$jscomp$23$$-=$left$jscomp$29_map__77264_value__$1$jscomp$39$$;$top$jscomp$11_v_size$$=$bottom$jscomp$5_map__77264__$1$$-$top$jscomp$11_v_size$$;$left$jscomp$29_map__77264_value__$1$jscomp$39$$=$min_value__$1$jscomp$1$$+($APP.$cljs$core$truth_$$($is_vertical$$)?$top$jscomp$11_v_size$$>0?$APP.$app$common$math$clamp$$(($bottom$jscomp$5_map__77264__$1$$-$map__77265__$1_y$jscomp$469$$)/$top$jscomp$11_v_size$$,0,1):0:$h_size_right$jscomp$23$$>0?$APP.$app$common$math$clamp$$(($ev$jscomp$8_map__77265_x$jscomp$1248$$-
$left$jscomp$29_map__77264_value__$1$jscomp$39$$)/$h_size_right$jscomp$23$$,0,1):0)*($max_value__$1$jscomp$1$$-$min_value__$1$jscomp$1$$);return $on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$29_map__77264_value__$1$jscomp$39$$):$on_change$jscomp$39$$($left$jscomp$29_map__77264_value__$1$jscomp$39$$)}return null}var $on_change$jscomp$39$$=$handle_start_drag_props_77263$$.onChange,$on_start_drag$$=$handle_start_drag_props_77263$$.onStartDrag,
$value$jscomp$798$$=$handle_start_drag_props_77263$$.value,$is_vertical$$=$handle_start_drag_props_77263$$.isVertical,$type$jscomp$614$$=$handle_start_drag_props_77263$$.type,$handle_stop_drag_min_value$jscomp$2$$=$handle_start_drag_props_77263$$.minValue,$max_value$jscomp$4$$=$handle_start_drag_props_77263$$.maxValue,$class$$jscomp$63$$=$handle_start_drag_props_77263$$.className,$on_finish_drag$$=$handle_start_drag_props_77263$$.onFinishDrag,$min_value__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($handle_stop_drag_min_value$jscomp$2$$)?
$handle_stop_drag_min_value$jscomp$2$$:0,$max_value__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($max_value$jscomp$4$$)?$max_value$jscomp$4$$:1,$dragging_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$handle_start_drag_props_77263$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_drag$$)],function($event$jscomp$318$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$318$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$2$$,
!0);return $APP.$cljs$core$truth_$$($on_start_drag$$)?$on_start_drag$$.$cljs$core$IFn$_invoke$arity$0$?$on_start_drag$$.$cljs$core$IFn$_invoke$arity$0$():$on_start_drag$$():null});$handle_stop_drag_min_value$jscomp$2$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_finish_drag$$)],function($event$jscomp$319$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$319$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$2$$,!1);return $APP.$cljs$core$truth_$$($on_finish_drag$$)?
$on_finish_drag$$.$cljs$core$IFn$_invoke$arity$0$?$on_finish_drag$$.$cljs$core$IFn$_invoke$arity$0$():$on_finish_drag$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$614$$,$APP.$cljs$cst$1740$opacity$$)?"slider-opacity":null,onPointerDown:$handle_start_drag_props_77263$$,onPointerUp:$handle_stop_drag_min_value$jscomp$2$$,onLostPointerCapture:$handle_stop_drag_min_value$jscomp$2$$,onClick:$calculate_pos$$,onPointerMove:function($p1__77262_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$2$$))?
$calculate_pos$$($p1__77262_SHARP_$$):null},className:""+($class$$jscomp$63$$??"")+(($APP.$cljs$core$truth_$$($is_vertical$$)?"main_ui_workspace_colorpicker_slider_selector__vertical":"")+" main_ui_workspace_colorpicker_slider_selector__slider-selector "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$614$$,$APP.$cljs$cst$2028$hue$$)?"main_ui_workspace_colorpicker_slider_selector__hue":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$614$$,$APP.$cljs$cst$1740$opacity$$)?
"main_ui_workspace_colorpicker_slider_selector__opacity":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$614$$,$APP.$cljs$cst$260$value$$)?"main_ui_workspace_colorpicker_slider_selector__value":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$614$$,$cljs$cst$5690$hsl_saturation$$)?"main_ui_workspace_colorpicker_slider_selector__hsl-saturation":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$614$$,$APP.$cljs$cst$5691$lightness$$)?
"main_ui_workspace_colorpicker_slider_selector__lightness":"")),children:function(){var $style_vertical_value_percent_str$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(($value$jscomp$798$$-$min_value__$1$jscomp$1$$)/($max_value__$1$jscomp$1$$-$min_value__$1$jscomp$1$$)*100),"%"].join(""),$style_common$$={pointerEvents:"none"},$style_horizontal$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({left:$style_vertical_value_percent_str$$},$style_common$$);$style_vertical_value_percent_str$$=
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({bottom:$style_vertical_value_percent_str$$},$style_common$$);return(0,$APP.$rumext$v2$jsx$$)("div",{style:$APP.$cljs$core$truth_$$($is_vertical$$)?$style_vertical_value_percent_str$$:$style_horizontal$$,className:"main_ui_workspace_colorpicker_slider_selector__handler"})}()})};
$app$main$ui$workspace$colorpicker$harmony$color__GT_point$$=function($hue$jscomp$2_hue_rad$$,$saturation$jscomp$1$$){$hue$jscomp$2_hue_rad$$=$APP.$goog$math$toRadians$$(-$hue$jscomp$2_hue_rad$$);return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(96+$saturation$jscomp$1$$*Math.cos($hue$jscomp$2_hue_rad$$)*96,96+$saturation$jscomp$1$$*Math.sin($hue$jscomp$2_hue_rad$$)*96)};
$app$main$ui$workspace$colorpicker$harmony$harmony_selector_STAR_$$=function($alpha$jscomp$16_map__77814__$1_props_77812$$){function $on_change_opacity$$($G__77839_new_alpha$$){$G__77839_new_alpha$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$746$alpha$$,$G__77839_new_alpha$$],null);return $on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$($G__77839_new_alpha$$):$on_change$jscomp$40$$($G__77839_new_alpha$$)}function $calculate_pos$jscomp$1$$($ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$){var $G__77829_map__77824_new_hue_top$jscomp$12$$=
$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$)),$bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$=$APP.$cljs$core$__destructure_map$$($G__77829_map__77824_new_hue_top$jscomp$12$$),$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$,
$APP.$cljs$cst$257$left$$),$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$,$APP.$cljs$cst$258$right$$);$G__77829_map__77824_new_hue_top$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$,$APP.$cljs$cst$1567$top$$);
$bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$,$APP.$cljs$cst$1568$bottom$$);$ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$=$APP.$app$util$dom$get_client_position$$($ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$);var $b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$=
$APP.$cljs$core$__destructure_map$$($ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$);$ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$,$APP.$cljs$cst$1515$x$$);$b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$,$APP.$cljs$cst$1516$y$$);
$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$=2*$APP.$app$common$math$clamp$$(($ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$-$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$)/($hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$-$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$),0,1)-
1;$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$=2*$APP.$app$common$math$clamp$$(($b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$-$G__77829_map__77824_new_hue_top$jscomp$12$$)/($bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$-$G__77829_map__77824_new_hue_top$jscomp$12$$),0,1)-1;$G__77829_map__77824_new_hue_top$jscomp$12$$=$APP.$cljs$core$mod$$(Math.atan2($JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$,
$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$)*180/Math.PI-90,360);$bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$,$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$],null);$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0],null);$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$,0,null);$bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$,
1,null);$ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$,0,null);$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$,1,null);$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$=
$APP.$app$common$math$precision$$($APP.$app$common$math$hypot$$($JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$-$ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$,$bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$-$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$),2);$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$=
$APP.$app$common$math$clamp$$($JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$,0,1);$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$=$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__77829_map__77824_new_hue_top$jscomp$12$$,$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$,
$value$jscomp$799$$],null));$b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$=$APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$);$bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$,0,null);$ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$,1,null);$b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$,2,null);$G__77829_map__77824_new_hue_top$jscomp$12$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2698$hex$$,$hex$jscomp$10_p__24259$jscomp$inline_8854_py__$1_right$jscomp$24_y2$jscomp$inline_8858$$,
$APP.$cljs$cst$1749$r$$,$bottom$jscomp$6_map__77824__$1_p__24258$jscomp$inline_8853_r$jscomp$132_y1$jscomp$inline_8856$$,$APP.$cljs$cst$1750$g$$,$ev$jscomp$9_g$jscomp$154_map__77825_x$jscomp$1250_x2$jscomp$inline_8857$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$353_map__77825__$1_vec__77826_y$jscomp$471$$,$APP.$cljs$cst$1907$h$$,$G__77829_map__77824_new_hue_top$jscomp$12$$,$APP.$cljs$cst$4235$s$$,$JSCompiler_inline_result$jscomp$1526_left$jscomp$30_new_saturation_px__$1_x1$jscomp$inline_8855$$],null);return $on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$($G__77829_map__77824_new_hue_top$jscomp$12$$):$on_change$jscomp$40$$($G__77829_map__77824_new_hue_top$jscomp$12$$)}var $on_change$jscomp$40$$=$alpha$jscomp$16_map__77814__$1_props_77812$$.onChange,$disable_opacity$jscomp$2$$=$alpha$jscomp$16_map__77814__$1_props_77812$$.disableOpacity,$color$jscomp$141_pos_current$$=$alpha$jscomp$16_map__77814__$1_props_77812$$.color,$on_start_drag$jscomp$1$$=$alpha$jscomp$16_map__77814__$1_props_77812$$.onStartDrag,
$on_finish_drag$jscomp$1$$=$alpha$jscomp$16_map__77814__$1_props_77812$$.onFinishDrag,$canvas_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null);$alpha$jscomp$16_map__77814__$1_props_77812$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$141_pos_current$$);var $hue$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$16_map__77814__$1_props_77812$$,$APP.$cljs$cst$1907$h$$),$saturation$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$16_map__77814__$1_props_77812$$,
$APP.$cljs$cst$4235$s$$),$value$jscomp$799$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$16_map__77814__$1_props_77812$$,$APP.$cljs$cst$3723$v$$);$alpha$jscomp$16_map__77814__$1_props_77812$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alpha$jscomp$16_map__77814__$1_props_77812$$,$APP.$cljs$cst$746$alpha$$);$color$jscomp$141_pos_current$$=$app$main$ui$workspace$colorpicker$harmony$color__GT_point$$($hue$jscomp$3$$,$saturation$jscomp$2$$);var $pos_complement$$=$app$main$ui$workspace$colorpicker$harmony$color__GT_point$$($APP.$cljs$core$mod$$($hue$jscomp$3$$+
180,360),$saturation$jscomp$2$$),$dragging_QMARK_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$handle_start_drag$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_drag$jscomp$1$$)],function($event$jscomp$320$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$320$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$3$$,!0);return $APP.$cljs$core$truth_$$($on_start_drag$jscomp$1$$)?$on_start_drag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$on_start_drag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_start_drag$jscomp$1$$():null}),$handle_stop_drag$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_finish_drag$jscomp$1$$)],function($event$jscomp$321$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$321$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK_$jscomp$3$$,!1);return $APP.$cljs$core$truth_$$($on_finish_drag$jscomp$1$$)?$on_finish_drag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$on_finish_drag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_finish_drag$jscomp$1$$():null}),$l1$jscomp$3_vec__77816$$=$APP.$app$common$types$color$hex__GT_hsl$$($app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$3$$,$saturation$jscomp$2$$,0],null))),$h1$jscomp$30$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$3_vec__77816$$,0,null),$s1$jscomp$20$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$3_vec__77816$$,
1,null);$l1$jscomp$3_vec__77816$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l1$jscomp$3_vec__77816$$,2,null);var $l2$jscomp$2_vec__77819$$=$APP.$app$common$types$color$hex__GT_hsl$$($app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$3$$,$saturation$jscomp$2$$,255],null))),$h2$jscomp$24$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l2$jscomp$2_vec__77819$$,0,null),$s2$jscomp$17$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l2$jscomp$2_vec__77819$$,1,null);$l2$jscomp$2_vec__77819$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($l2$jscomp$2_vec__77819$$,2,null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($canvas_ref$jscomp$2$$)],function(){if($APP.$cljs$core$truth_$$($canvas_ref$jscomp$2$$)){var $G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$=
$APP.$rumext$v2$ref_val$$($canvas_ref$jscomp$2$$);var $JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$=$G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$.getContext("2d");var $G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$,
"width"),$radius$jscomp$inline_8863$$=$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$/2,$cx$jscomp$inline_8864$$=$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$/2,$cy$jscomp$inline_8865$$=$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$/2;$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.clearRect(0,
0,$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$,"height"));$G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$=
$APP.$cljs$core$seq$$($APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$(0,360,.2));$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$=null;for(var $G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$=0,$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$=0;;)if($degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$<
$G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$){var $degrees_77853$jscomp$inline_8870$$=$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$.$cljs$core$IIndexed$_nth$arity$2$(null,$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$),$degrees_rad_77854$jscomp$inline_8871_y_77856$jscomp$inline_8873$$=
$APP.$goog$math$toRadians$$($degrees_77853$jscomp$inline_8870$$),$x_77855$jscomp$inline_8872$$=$radius$jscomp$inline_8863$$*Math.cos(-$degrees_rad_77854$jscomp$inline_8871_y_77856$jscomp$inline_8873$$);$degrees_rad_77854$jscomp$inline_8871_y_77856$jscomp$inline_8873$$=$radius$jscomp$inline_8863$$*Math.sin(-$degrees_rad_77854$jscomp$inline_8871_y_77856$jscomp$inline_8873$$);$APP.$app$util$object$set_BANG_$$($JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$,"strokeStyle",$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("hsl(%s, 100%, 50%)",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$degrees_77853$jscomp$inline_8870$$])));$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.beginPath();$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.moveTo($cx$jscomp$inline_8864$$,$cy$jscomp$inline_8865$$);$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.lineTo($cx$jscomp$inline_8864$$+$x_77855$jscomp$inline_8872$$,$cy$jscomp$inline_8865$$+$degrees_rad_77854$jscomp$inline_8871_y_77856$jscomp$inline_8873$$);$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.stroke();
$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$+=1}else if($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$=$APP.$cljs$core$seq$$($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$)?
($G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$=$APP.$cljs$core$_chunked_first$$($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$),$G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$=
$APP.$cljs$core$_chunked_rest$$($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$),$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$=$G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$,
$G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$=$APP.$cljs$core$count$$($G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$)):($G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$=$APP.$cljs$core$first$$($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$),
$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$=$APP.$goog$math$toRadians$$($G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$),$G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$=$radius$jscomp$inline_8863$$*Math.cos(-$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$),
$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$=$radius$jscomp$inline_8863$$*Math.sin(-$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$),$APP.$app$util$object$set_BANG_$$($JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$,"strokeStyle",$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("hsl(%s, 100%, 50%)",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$]))),
$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.beginPath(),$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.moveTo($cx$jscomp$inline_8864$$,$cy$jscomp$inline_8865$$),$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.lineTo($cx$jscomp$inline_8864$$+$G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$,$cy$jscomp$inline_8865$$+$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$),
$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.stroke(),$G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$=$APP.$cljs$core$next$$($G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$),$G__77865$jscomp$inline_8878_chunk__77777_77850$jscomp$inline_8867_degrees_77868$jscomp$inline_8880_width$jscomp$inline_8862$$=
null,$G__77866$jscomp$inline_8879_c__5548__auto___77863$jscomp$inline_8876_count__77778_77851$jscomp$inline_8868_x_77870$jscomp$inline_8882$$=0),$degrees_rad_77869$jscomp$inline_8881_i__77779_77852$jscomp$inline_8869_y_77871$jscomp$inline_8883$$=0;else break;$G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$=$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.createRadialGradient($cx$jscomp$inline_8864$$,
$cy$jscomp$inline_8865$$,0,$cx$jscomp$inline_8864$$,$cx$jscomp$inline_8864$$,$radius$jscomp$inline_8863$$);$G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$.addColorStop(0,"rgba(255, 255, 255, 1)");$G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$.addColorStop(1,
"rgba(255, 255, 255, 0)");$APP.$app$util$object$set_BANG_$$($JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$,"fillStyle",$G__77864$jscomp$inline_8877_canvas_node$jscomp$inline_8860_grd$jscomp$inline_8884_seq__77776_77849$jscomp$inline_8866_seq__77776_77862__$1$jscomp$inline_8875_temp__5825__auto___77861$jscomp$inline_8874$$);$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.beginPath();$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.arc($cx$jscomp$inline_8864$$,$cy$jscomp$inline_8865$$,
$radius$jscomp$inline_8863$$,0,2*$APP.$app$common$math$PI$$,!0);$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.closePath();$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$=$JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$.fill()}else $JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$=null;return $JSCompiler_temp$jscomp$1752_ctx$jscomp$inline_8861$$});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--hue-from":"hsl("+($h1$jscomp$30$$??"")+", "+$s1$jscomp$20$$*100+"%, "+$l1$jscomp$3_vec__77816$$*
100+"%)","--hue-to":"hsl("+($h2$jscomp$24$$??"")+", "+$s2$jscomp$17$$*100+"%, "+$l2$jscomp$2_vec__77819$$*100+"%)"},className:"main_ui_workspace_colorpicker_harmony__harmony-selector",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_harmony__handlers-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{type:$APP.$cljs$cst$260$value$$,isVertical:!0,value:$value$jscomp$799$$,maxValue:255,onChange:function($G__77833_new_value$jscomp$17$$){var $hex$jscomp$11$$=
$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$3$$,$saturation$jscomp$2$$,$G__77833_new_value$jscomp$17$$],null)),$b$jscomp$354_vec__77830$$=$APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$11$$),$r$jscomp$133$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$354_vec__77830$$,0,null),$g$jscomp$155$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$354_vec__77830$$,
1,null);$b$jscomp$354_vec__77830$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$354_vec__77830$$,2,null);$G__77833_new_value$jscomp$17$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2698$hex$$,$hex$jscomp$11$$,$APP.$cljs$cst$1749$r$$,$r$jscomp$133$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$155$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$354_vec__77830$$,$APP.$cljs$cst$3723$v$$,$G__77833_new_value$jscomp$17$$],null);return $on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$($G__77833_new_value$jscomp$17$$):$on_change$jscomp$40$$($G__77833_new_value$jscomp$17$$)},onStartDrag:$on_start_drag$jscomp$1$$,onFinishDrag:$on_finish_drag$jscomp$1$$}),$APP.$cljs$core$not$$($disable_opacity$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{type:$APP.$cljs$cst$1740$opacity$$,isVertical:!0,value:$alpha$jscomp$16_map__77814__$1_props_77812$$,maxValue:1,onChange:$on_change_opacity$$,
onStartDrag:$on_start_drag$jscomp$1$$,onFinishDrag:$on_finish_drag$jscomp$1$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_harmony__hue-wheel-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("canvas",{width:192,height:192,className:"main_ui_workspace_colorpicker_harmony__hue-wheel",onPointerUp:$handle_stop_drag$jscomp$1$$,onLostPointerCapture:$handle_stop_drag$jscomp$1$$,onClick:$calculate_pos$jscomp$1$$,onPointerMove:function($p1__77811_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($dragging_QMARK_$jscomp$3$$))?
$calculate_pos$jscomp$1$$($p1__77811_SHARP_$$):null},ref:$canvas_ref$jscomp$2$$,onPointerDown:$handle_start_drag$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{pointerEvents:"none",left:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$141_pos_current$$),top:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$141_pos_current$$)},className:"main_ui_workspace_colorpicker_harmony__handler"}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{left:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($pos_complement$$),
top:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($pos_complement$$),cursor:"pointer"},onClick:function(){var $G__77838_new_hue$jscomp$1$$=$APP.$cljs$core$mod$$($hue$jscomp$3$$+180,360),$hex$jscomp$12$$=$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__77838_new_hue$jscomp$1$$,$saturation$jscomp$2$$,$value$jscomp$799$$],null)),$b$jscomp$355_vec__77834$$=$APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$12$$),
$r$jscomp$134$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$355_vec__77834$$,0,null),$g$jscomp$156$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$355_vec__77834$$,1,null);$b$jscomp$355_vec__77834$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$355_vec__77834$$,2,null);$G__77838_new_hue$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2698$hex$$,$hex$jscomp$12$$,$APP.$cljs$cst$1749$r$$,$r$jscomp$134$$,$APP.$cljs$cst$1750$g$$,
$g$jscomp$156$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$355_vec__77834$$,$APP.$cljs$cst$1907$h$$,$G__77838_new_hue$jscomp$1$$,$APP.$cljs$cst$4235$s$$,$saturation$jscomp$2$$],null);return $on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$40$$.$cljs$core$IFn$_invoke$arity$1$($G__77838_new_hue$jscomp$1$$):$on_change$jscomp$40$$($G__77838_new_hue$jscomp$1$$)},className:"main_ui_workspace_colorpicker_harmony__handler main_ui_workspace_colorpicker_harmony__complement"})]})]})};
$app$main$ui$workspace$colorpicker$hsva$hsva_selector_STAR_$$=function($on_finish_drag$jscomp$2_props_77775$$){function $on_change_opacity$jscomp$1$$($G__77809_new_alpha$jscomp$1$$){$G__77809_new_alpha$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$746$alpha$$,$G__77809_new_alpha$jscomp$1$$],null);return $on_change$jscomp$41$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$41$$.$cljs$core$IFn$_invoke$arity$1$($G__77809_new_alpha$jscomp$1$$):$on_change$jscomp$41$$($G__77809_new_alpha$jscomp$1$$)}
function $handle_change_hsl$$($key$jscomp$413$$){return function($g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$){var $G__77807_new_s$jscomp$1_r$jscomp$136$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$413$$,$cljs$cst$5532$hsl_s$$)?$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$:$hsl_s$jscomp$1$$;$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$413$$,$cljs$cst$5531$hsl_l$$)?$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$:
$hsl_l$jscomp$1$$;var $b$jscomp$357_vec__77801$$=$app$common$types$color$hsl__GT_rgb$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$hue$jscomp$4$$,$G__77807_new_s$jscomp$1_r$jscomp$136$$,$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$],null));$G__77807_new_s$jscomp$1_r$jscomp$136$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$357_vec__77801$$,0,null);$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$357_vec__77801$$,
1,null);$b$jscomp$357_vec__77801$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$357_vec__77801$$,2,null);var $hex$jscomp$14$$=$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__77807_new_s$jscomp$1_r$jscomp$136$$,$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$,$b$jscomp$357_vec__77801$$],null)),$v$jscomp$662_vec__77804$$=$app$common$types$color$hex__GT_hsv$$($hex$jscomp$14$$),$h$jscomp$178$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$662_vec__77804$$,0,null),$s$jscomp$582$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$662_vec__77804$$,1,null);$v$jscomp$662_vec__77804$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$662_vec__77804$$,2,null);$G__77807_new_s$jscomp$1_r$jscomp$136$$=new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2698$hex$$,$hex$jscomp$14$$,$APP.$cljs$cst$1907$h$$,$h$jscomp$178$$,$APP.$cljs$cst$4235$s$$,
$s$jscomp$582$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$662_vec__77804$$,$APP.$cljs$cst$1749$r$$,$G__77807_new_s$jscomp$1_r$jscomp$136$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$158_new_l$jscomp$1_new_value$jscomp$19$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$357_vec__77801$$],null);return $on_change$jscomp$41$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$41$$.$cljs$core$IFn$_invoke$arity$1$($G__77807_new_s$jscomp$1_r$jscomp$136$$):$on_change$jscomp$41$$($G__77807_new_s$jscomp$1_r$jscomp$136$$)}}function $handle_change_hsv$$($key$jscomp$412$$){return function($G__77795_change$jscomp$33_new_value$jscomp$18$$){$G__77795_change$jscomp$33_new_value$jscomp$18$$=
$APP.$cljs$core$PersistentHashMap$fromArrays$$([$key$jscomp$412$$],[$G__77795_change$jscomp$33_new_value$jscomp$18$$]);var $h$jscomp$177_hex$jscomp$13_map__77791$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$color$jscomp$142$$,$G__77795_change$jscomp$33_new_value$jscomp$18$$])),$g$jscomp$157_map__77791__$1_v$jscomp$661$$=$APP.$cljs$core$__destructure_map$$($h$jscomp$177_hex$jscomp$13_map__77791$$);$h$jscomp$177_hex$jscomp$13_map__77791$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$157_map__77791__$1_v$jscomp$661$$,$APP.$cljs$cst$1907$h$$);var $r$jscomp$135_s$jscomp$581$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$157_map__77791__$1_v$jscomp$661$$,$APP.$cljs$cst$4235$s$$);$g$jscomp$157_map__77791__$1_v$jscomp$661$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$157_map__77791__$1_v$jscomp$661$$,$APP.$cljs$cst$3723$v$$);$h$jscomp$177_hex$jscomp$13_map__77791$$=$app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$177_hex$jscomp$13_map__77791$$,$r$jscomp$135_s$jscomp$581$$,$g$jscomp$157_map__77791__$1_v$jscomp$661$$],null));var $b$jscomp$356_vec__77792$$=$APP.$app$common$types$color$hex__GT_rgb$$($h$jscomp$177_hex$jscomp$13_map__77791$$);$r$jscomp$135_s$jscomp$581$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$356_vec__77792$$,0,null);$g$jscomp$157_map__77791__$1_v$jscomp$661$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$356_vec__77792$$,
1,null);$b$jscomp$356_vec__77792$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$356_vec__77792$$,2,null);$G__77795_change$jscomp$33_new_value$jscomp$18$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__77795_change$jscomp$33_new_value$jscomp$18$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2698$hex$$,$h$jscomp$177_hex$jscomp$13_map__77791$$,$APP.$cljs$cst$1749$r$$,$r$jscomp$135_s$jscomp$581$$,
$APP.$cljs$cst$1750$g$$,$g$jscomp$157_map__77791__$1_v$jscomp$661$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$356_vec__77792$$],null)]));return $on_change$jscomp$41$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$41$$.$cljs$core$IFn$_invoke$arity$1$($G__77795_change$jscomp$33_new_value$jscomp$18$$):$on_change$jscomp$41$$($G__77795_change$jscomp$33_new_value$jscomp$18$$)}}var $on_change$jscomp$41$$=$on_finish_drag$jscomp$2_props_77775$$.onChange,$disable_opacity$jscomp$3$$=$on_finish_drag$jscomp$2_props_77775$$.disableOpacity,
$color$jscomp$142$$=$on_finish_drag$jscomp$2_props_77775$$.color,$on_start_drag$jscomp$2$$=$on_finish_drag$jscomp$2_props_77775$$.onStartDrag,$hsl_mode_QMARK__mode$jscomp$48$$=$on_finish_drag$jscomp$2_props_77775$$.mode;$on_finish_drag$jscomp$2_props_77775$$=$on_finish_drag$jscomp$2_props_77775$$.onFinishDrag;var $b_val_map__77785__$1$$=$APP.$cljs$core$__destructure_map$$($color$jscomp$142$$),$hue$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77785__$1$$,$APP.$cljs$cst$1907$h$$),
$saturation$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77785__$1$$,$APP.$cljs$cst$4235$s$$),$value$jscomp$800$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77785__$1$$,$APP.$cljs$cst$3723$v$$),$alpha$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77785__$1$$,$APP.$cljs$cst$746$alpha$$),$r_val_vec__77786$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77785__$1$$,$APP.$cljs$cst$1749$r$$),$g_val$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77785__$1$$,$APP.$cljs$cst$1750$g$$);$b_val_map__77785__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($b_val_map__77785__$1$$,$APP.$cljs$cst$1525$b$$);$hsl_mode_QMARK__mode$jscomp$48$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hsl_mode_QMARK__mode$jscomp$48$$,$cljs$cst$5534$hsl$$);$r_val_vec__77786$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($r_val_vec__77786$$)?$APP.$cljs$core$truth_$$($g_val$$)?
$b_val_map__77785__$1$$:$g_val$$:$r_val_vec__77786$$)?$APP.$app$common$types$color$rgb__GT_hsl$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r_val_vec__77786$$,$g_val$$,$b_val_map__77785__$1$$],null)):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0,0,0],null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r_val_vec__77786$$,0,null);var $hsl_s$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r_val_vec__77786$$,
1,null),$hsl_l$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($r_val_vec__77786$$,2,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector-label",children:"H"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,
{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",type:$APP.$cljs$cst$2028$hue$$,maxValue:360,value:$hue$jscomp$4$$,onChange:$handle_change_hsv$$($APP.$cljs$cst$1907$h$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77775$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector-label",children:"S"}),$hsl_mode_QMARK__mode$jscomp$48$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",type:$cljs$cst$5690$hsl_saturation$$,maxValue:1,value:$hsl_s$jscomp$1$$,onChange:$handle_change_hsl$$($cljs$cst$5532$hsl_s$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77775$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",
type:$APP.$cljs$cst$2031$saturation$$,maxValue:1,value:$saturation$jscomp$3$$,onChange:$handle_change_hsv$$($APP.$cljs$cst$4235$s$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77775$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector-label",children:$hsl_mode_QMARK__mode$jscomp$48$$?"L":"B(V)"}),$hsl_mode_QMARK__mode$jscomp$48$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",type:$APP.$cljs$cst$5691$lightness$$,maxValue:1,value:$hsl_l$jscomp$1$$,onChange:$handle_change_hsl$$($cljs$cst$5531$hsl_l$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77775$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",
type:$APP.$cljs$cst$260$value$$,maxValue:255,value:$value$jscomp$800$$,onChange:$handle_change_hsv$$($APP.$cljs$cst$3723$v$$),onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77775$$})]}),$APP.$cljs$core$not$$($disable_opacity$jscomp$3$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_hsva__hsva-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_hsva__hsva-selector-label",children:"A"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,
{className:"main_ui_workspace_colorpicker_hsva__hsva-bar",type:$APP.$cljs$cst$1740$opacity$$,maxValue:1,value:$alpha$jscomp$17$$,onChange:$on_change_opacity$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$2$$,onFinishDrag:$on_finish_drag$jscomp$2_props_77775$$})]}):null]})};
$app$main$ui$workspace$sidebar$assets$common$apply_filters$$=function($G__77784__$1_G__77784__$2_coll$jscomp$1101$$,$map__77781__$1_p__77780$$){$map__77781__$1_p__77780$$=$APP.$cljs$core$__destructure_map$$($map__77781__$1_p__77780$$);var $ordering$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77781__$1_p__77780$$,$cljs$cst$5692$ordering$$),$term$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77781__$1_p__77780$$,$APP.$cljs$cst$2524$term$$),$reverse_QMARK_$jscomp$9$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2709$desc$$,$ordering$$);$G__77784__$1_G__77784__$2_coll$jscomp$1101$$=$APP.$cuerdas$core$empty_QMARK_$$($term$jscomp$7$$)?$G__77784__$1_G__77784__$2_coll$jscomp$1101$$:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($item$jscomp$126$$){var $or__5025__auto__$jscomp$1132_or__5025__auto____$1$jscomp$120$$=$app$util$strings$matches_search$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$126$$,
"!$!"),$term$jscomp$7$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1132_or__5025__auto____$1$jscomp$120$$))return $or__5025__auto__$jscomp$1132_or__5025__auto____$1$jscomp$120$$;$or__5025__auto__$jscomp$1132_or__5025__auto____$1$jscomp$120$$=$app$util$strings$matches_search$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$126$$,"!$!"),$term$jscomp$7$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1132_or__5025__auto____$1$jscomp$120$$)?$or__5025__auto__$jscomp$1132_or__5025__auto____$1$jscomp$120$$:
$app$util$strings$matches_search$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$2$($item$jscomp$126$$,"!$!"),$term$jscomp$7$$)},$G__77784__$1_G__77784__$2_coll$jscomp$1101$$);$G__77784__$1_G__77784__$2_coll$jscomp$1101$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$(function($p__77789_path$jscomp$259_path__$1$jscomp$8$$){var $map__77790__$1_name$jscomp$443$$=$APP.$cljs$core$__destructure_map$$($p__77789_path$jscomp$259_path__$1$jscomp$8$$);$p__77789_path$jscomp$259_path__$1$jscomp$8$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77790__$1_name$jscomp$443$$,$APP.$cljs$cst$296$path$$);$map__77790__$1_name$jscomp$443$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77790__$1_name$jscomp$443$$,$APP.$cljs$cst$725$name$$);$p__77789_path$jscomp$259_path__$1$jscomp$8$$=$APP.$cuerdas$core$empty_QMARK_$$($p__77789_path$jscomp$259_path__$1$jscomp$8$$)?$reverse_QMARK_$jscomp$9$$?"z":"a":$p__77789_path$jscomp$259_path__$1$jscomp$8$$;return $APP.$cuerdas$core$lower$$($APP.$app$common$path_names$merge_path_item$$($p__77789_path$jscomp$259_path__$1$jscomp$8$$,
$map__77790__$1_name$jscomp$443$$))},$reverse_QMARK_$jscomp$9$$?$APP.$cljs$core$_GT_$$:$APP.$cljs$core$_LT_$$,$G__77784__$1_G__77784__$2_coll$jscomp$1101$$);return $APP.$cljs$core$vec$$($G__77784__$1_G__77784__$2_coll$jscomp$1101$$)};
$app$main$ui$workspace$sidebar$assets$common$add_group$$=function($asset$jscomp$4$$,$group_name$$){return $APP.$app$common$path_names$merge_path_item$$($APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$4$$),$group_name$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$4$$))};
$app$main$ui$workspace$sidebar$assets$common$rename_group$$=function($asset$jscomp$5$$,$path$jscomp$260$$,$last_path$$){return $APP.$app$common$path_names$merge_path_item$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$path_names$join_path$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$vec$$($APP.$cljs$core$butlast$$($APP.$app$common$path_names$split_path$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$5$$),0,
$APP.$cljs$core$count$$($path$jscomp$260$$))))),$last_path$$))),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$5$$),$APP.$cljs$core$count$$($path$jscomp$260$$)))].join(""),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$5$$))};
$app$main$ui$workspace$sidebar$assets$common$ungroup$$=function($asset$jscomp$6$$,$path$jscomp$261$$){return $APP.$app$common$path_names$merge_path_item$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$path_names$join_path$$($APP.$cljs$core$butlast$$($APP.$app$common$path_names$split_path$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$6$$),0,$APP.$cljs$core$count$$($path$jscomp$261$$)))))),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$6$$),$APP.$cljs$core$count$$($path$jscomp$261$$)))].join(""),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$6$$))};
$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$=function($state$jscomp$1186$$,$left$jscomp$31_pos$jscomp$134$$){var $top$jscomp$13$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$31_pos$jscomp$134$$);$left$jscomp$31_pos$jscomp$134$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$31_pos$jscomp$134$$)+10;return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1186$$,$APP.$cljs$cst$4601$open_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1567$top$$,
$top$jscomp$13$$,$APP.$cljs$cst$257$left$$,$left$jscomp$31_pos$jscomp$134$$]))};$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$=function($state$jscomp$1187$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1187$$,$APP.$cljs$cst$4601$open_QMARK_$$,!1)};
$app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$=function($props_77810_state$jscomp$1188$$){var $options$jscomp$608$$=$props_77810_state$jscomp$1188$$.options,$on_close$jscomp$16$$=$props_77810_state$jscomp$1188$$.onClose;$props_77810_state$jscomp$1188$$=$props_77810_state$jscomp$1188$$.state;return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,{show:$APP.$cljs$cst$4601$open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($props_77810_state$jscomp$1188$$),
fixed:$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($props_77810_state$jscomp$1188$$),0)||$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($props_77810_state$jscomp$1188$$),0),onClose:$on_close$jscomp$16$$,top:$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($props_77810_state$jscomp$1188$$),left:$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($props_77810_state$jscomp$1188$$),
options:$options$jscomp$608$$})};$app$main$ui$workspace$sidebar$assets$common$section_icon$$=function($section$jscomp$26$$){switch($section$jscomp$26$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$26$$.$fqn$:null){case "colors":return"drop";case "components":return"component";case "typographies":return"text-palette";default:return"add"}};
$app$main$ui$workspace$sidebar$assets$common$should_display_asset_count_QMARK_$$=function($section$jscomp$27$$,$assets_count$$){return!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$27$$,$APP.$cljs$cst$2108$tokens$$)||0<$assets_count$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$27$$,$APP.$cljs$cst$2108$tokens$$)};
$app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$=function($buttons_props_77823$$){var $is_open$jscomp$3$$=$buttons_props_77823$$.isOpen,$assets_count$jscomp$1$$=$buttons_props_77823$$.assetsCount,$file_id$jscomp$370$$=$buttons_props_77823$$.fileId,$section$jscomp$28$$=$buttons_props_77823$$.section,$icon$jscomp$19_title__$1$jscomp$2$$=$buttons_props_77823$$.icon,$title$jscomp$36$$=$buttons_props_77823$$.title,$on_click$jscomp$37$$=$buttons_props_77823$$.onClick,$children__$1$jscomp$36_content$jscomp$245$$=
$app$util$array$without_nils$$($app$util$array$normalize_to_array$$($buttons_props_77823$$.children));$buttons_props_77823$$=$app$util$array$filter$$(function($p1__77815_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5693$title_button$$,$p1__77815_SHARP_$$.props.role)},$children__$1$jscomp$36_content$jscomp$245$$);$children__$1$jscomp$36_content$jscomp$245$$=$app$util$array$filter$$(function($p1__77822_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$content$$,
$p1__77822_SHARP_$$.props.role)},$children__$1$jscomp$36_content$jscomp$245$$);var $on_collapsed$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$370$$),$APP.$rumext$v2$adapt$$($section$jscomp$28$$),$APP.$rumext$v2$adapt$$($is_open$jscomp$3$$),$APP.$rumext$v2$adapt$$($assets_count$jscomp$1$$)],function(){return 0<$assets_count$jscomp$1$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$370$$,
$section$jscomp$28$$,$APP.$cljs$core$not$$($is_open$jscomp$3$$))):null});$icon$jscomp$19_title__$1$jscomp$2$$=(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_sidebar_assets_common__title-name "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$28$$,$APP.$cljs$cst$2108$tokens$$)?"main_ui_workspace_sidebar_assets_common__title-tokens":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($section$jscomp$28$$,$APP.$cljs$cst$2108$tokens$$)&&0<$assets_count$jscomp$1$$?
"main_ui_workspace_sidebar_assets_common__title-tokens-active":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_common__section-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($icon$jscomp$19_title__$1$jscomp$2$$)?$icon$jscomp$19_title__$1$jscomp$2$$:$app$main$ui$workspace$sidebar$assets$common$section_icon$$($section$jscomp$28$$),size:"s"})}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_assets_common__section-name",children:$title$jscomp$36$$}),$app$main$ui$workspace$sidebar$assets$common$should_display_asset_count_QMARK_$$($section$jscomp$28$$,$assets_count$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_common__num-assets",children:$assets_count$jscomp$1$$}):null]});return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_click$jscomp$37$$,className:"main_ui_workspace_sidebar_assets_common__asset-section "+
($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$751$$=0<$assets_count$jscomp$1$$;return $and__5023__auto__$jscomp$751$$?$is_open$jscomp$3$$:$and__5023__auto__$jscomp$751$$}())?"main_ui_workspace_sidebar_assets_common__opened":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:0<$assets_count$jscomp$1$$,collapsed:$APP.$cljs$core$not$$($is_open$jscomp$3$$),onCollapsed:$on_collapsed$jscomp$1$$,addIconGap:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,
$assets_count$jscomp$1$$),title:$icon$jscomp$19_title__$1$jscomp$2$$,children:$buttons_props_77823$$}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$752$$=0<$assets_count$jscomp$1$$;return $and__5023__auto__$jscomp$752$$?$is_open$jscomp$3$$:$and__5023__auto__$jscomp$752$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{className:$APP.$cljs$core$truth_$$($is_open$jscomp$3$$)?"main_ui_workspace_sidebar_assets_common__title-spacing":"",children:$children__$1$jscomp$36_content$jscomp$245$$}):
null]})};$app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$=function($props_77837$$){return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$props_77837$$.children})};
$app$main$ui$workspace$sidebar$assets$common$create_assets_group$$=function($rename$jscomp$1$$,$components_to_group$$,$group_name$jscomp$1$$){var $undo_id$jscomp$90$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$90$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($G__77842_p1__77840_SHARP_$$){var $G__77841$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__77842_p1__77840_SHARP_$$);
$G__77842_p1__77840_SHARP_$$=$app$main$ui$workspace$sidebar$assets$common$add_group$$($G__77842_p1__77840_SHARP_$$,$group_name$jscomp$1$$);return $rename$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$rename$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($G__77841$$,$G__77842_p1__77840_SHARP_$$):$rename$jscomp$1$$($G__77841$$,$G__77842_p1__77840_SHARP_$$)},$components_to_group$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$90$$))};
$app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$=function($map__77845__$1_p__77844$$){$map__77845__$1_p__77844$$=$APP.$cljs$core$__destructure_map$$($map__77845__$1_p__77844$$);var $assets$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77845__$1_p__77844$$,$APP.$cljs$cst$3767$assets$$),$on_clear_selection$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77845__$1_p__77844$$,$cljs$cst$5694$on_clear_selection$$),$delete_events$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77845__$1_p__77844$$,
$cljs$cst$5695$delete_events$$),$path_filter$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__77845__$1_p__77844$$,$cljs$cst$5696$path_filter$$,$APP.$cuerdas$core$starts_with_QMARK_$$);return function($path$jscomp$262$$){function $do_delete$$(){$on_clear_selection$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$91$$));
$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$delete_events$$.$cljs$core$IFn$_invoke$arity$1$?$delete_events$$.$cljs$core$IFn$_invoke$arity$1$($matching$$):$delete_events$$($matching$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$91$$))}var $matching$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__77846_p1__77843_SHARP_$$){$G__77846_p1__77843_SHARP_$$=
$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($G__77846_p1__77843_SHARP_$$);return $path_filter$$.$cljs$core$IFn$_invoke$arity$2$?$path_filter$$.$cljs$core$IFn$_invoke$arity$2$($G__77846_p1__77843_SHARP_$$,$path$jscomp$262$$):$path_filter$$($G__77846_p1__77843_SHARP_$$,$path$jscomp$262$$)},$assets$jscomp$1$$),$undo_id$jscomp$91$$=Symbol();return $APP.$cljs$core$seq$$($matching$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-asset-group.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("modals.delete-asset-group.message",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($matching$$))])),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),
$APP.$cljs$cst$2490$on_accept$$,$do_delete$$],null))):null}};
$app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$=function($components_to_group$jscomp$1_event$jscomp$322$$,$asset$jscomp$7$$,$dragging_STAR_$$,$selected$jscomp$142$$,$selected_full$$,$selected_paths$$,$create_typed_assets_group_rename$jscomp$2$$){$create_typed_assets_group_rename$jscomp$2$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$sidebar$assets$common$create_assets_group$$,$create_typed_assets_group_rename$jscomp$2$$);return $APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($components_to_group$jscomp$1_event$jscomp$322$$))&&
($APP.$cljs$core$reset_BANG_$$($dragging_STAR_$$,!1),!$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$142$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$7$$))&&$APP.$cljs$core$every_QMARK_$$(function($p1__77848_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__77848_SHARP_$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$7$$))},$selected_paths$$))?($components_to_group$jscomp$1_event$jscomp$322$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($selected_full$$,
$asset$jscomp$7$$),$APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5697$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$924$accept$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($create_typed_assets_group_rename$jscomp$2$$,$components_to_group$jscomp$1_event$jscomp$322$$)],null))):null};
$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$=function($event$jscomp$323$$,$asset$jscomp$8$$,$dragging_STAR_$jscomp$1$$,$selected$jscomp$143$$,$selected_paths$jscomp$1$$){return $APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$323$$))&&$APP.$cljs$core$every_QMARK_$$(function($p1__77872_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__77872_SHARP_$$,$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$8$$))},
$selected_paths$jscomp$1$$)&&!$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$143$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$8$$))?$APP.$cljs$core$reset_BANG_$$($dragging_STAR_$jscomp$1$$,!0):null};
$app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$=function($event$jscomp$324$$,$dragging_STAR_$jscomp$2$$){return $APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$324$$))?$APP.$cljs$core$reset_BANG_$$($dragging_STAR_$jscomp$2$$,!1):null};
$app$main$ui$workspace$sidebar$assets$common$create_counter_element$$=function($asset_count$$){var $counter_el$$=$APP.$app$util$dom$create_element$cljs$0core$0IFn$0_invoke$0arity$01$$("div");$APP.$app$util$dom$set_property_BANG_$$($counter_el$$,"class","main_ui_workspace_sidebar_assets_common__drag-counter");$APP.$app$util$dom$set_text_BANG_$$($counter_el$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.assets.sidebar.components",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($asset_count$$)])));
return $counter_el$$};
$app$main$ui$workspace$sidebar$assets$common$set_drag_image$$=function($event$jscomp$325$$,$item_ref$jscomp$1$$,$num_selected$$){var $offset$jscomp$207$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$325$$.nativeEvent),$item_el$$=$APP.$rumext$v2$ref_val$$($item_ref$jscomp$1$$),$counter_el$jscomp$1$$=$app$main$ui$workspace$sidebar$assets$common$create_counter_element$$($num_selected$$);$APP.$app$util$dom$append_child_BANG_$$($item_el$$,$counter_el$jscomp$1$$);$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$04$$($event$jscomp$325$$,$item_el$$,
$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$207$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($offset$jscomp$207$$));return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){if($APP.$cljs$core$truth_$$($APP.$app$util$dom$child_QMARK_$$($counter_el$jscomp$1$$,$item_el$$))){$item_el$$!=null&&$item_el$$.removeChild($counter_el$jscomp$1$$);var $JSCompiler_temp$jscomp$659$$=$item_el$$}else $JSCompiler_temp$jscomp$659$$=null;return $JSCompiler_temp$jscomp$659$$})};
$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$=function($event$jscomp$326$$,$file_id$jscomp$371$$,$asset$jscomp$9$$,$selected$jscomp$144$$,$item_ref$jscomp$2$$,$asset_type$jscomp$15$$,$on_drag_start$jscomp$1$$){var $id_asset$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($asset$jscomp$9$$),$num_selected$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$144$$,$id_asset$$)?$APP.$cljs$core$count$$($selected$jscomp$144$$):1;$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$144$$,
$id_asset$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$($file_id$jscomp$371$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$toggle_selected_assets$$($file_id$jscomp$371$$,$id_asset$$,$asset_type$jscomp$15$$)]));$on_drag_start$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_drag_start$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($asset$jscomp$9$$,
$event$jscomp$326$$):$on_drag_start$jscomp$1$$($asset$jscomp$9$$,$event$jscomp$326$$);return $num_selected$jscomp$1$$>1?$app$main$ui$workspace$sidebar$assets$common$set_drag_image$$($event$jscomp$326$$,$item_ref$jscomp$2$$,$num_selected$jscomp$1$$):null};
$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$=function($event$jscomp$327$$,$dragging_STAR_$jscomp$3$$,$prefix$jscomp$67$$,$selected_paths$jscomp$2$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$327$$);return $APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($event$jscomp$327$$))&&!$APP.$cljs$core$every_QMARK_$$(function($p1__77877_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__77877_SHARP_$$,$prefix$jscomp$67$$)},$selected_paths$jscomp$2$$)?
$APP.$cljs$core$reset_BANG_$$($dragging_STAR_$jscomp$3$$,!0):null};
$app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$=function($c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$,$G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$,$prefix$jscomp$68$$,$G__77916_count__77881_selected_paths$jscomp$3$$,$G__77914_i__77882_selected_full$jscomp$1$$,$rename$jscomp$3$$){$APP.$app$util$dom$stop_propagation$$($c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$);if($APP.$cljs$core$not$$($APP.$app$util$dom$dnd$from_child_QMARK_$$($c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$))){$APP.$cljs$core$reset_BANG_$$($G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$,
!1);if($APP.$cljs$core$every_QMARK_$$(function($p1__77878_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__77878_SHARP_$$,$prefix$jscomp$68$$)},$G__77916_count__77881_selected_paths$jscomp$3$$))return null;$c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$=$APP.$cljs$core$seq$$($G__77914_i__77882_selected_full$jscomp$1$$);$G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$=null;for($G__77914_i__77882_selected_full$jscomp$1$$=
$G__77916_count__77881_selected_paths$jscomp$3$$=0;;)if($G__77914_i__77882_selected_full$jscomp$1$$<$G__77916_count__77881_selected_paths$jscomp$3$$){var $target_asset$$=$G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__77914_i__77882_selected_full$jscomp$1$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $G__77887$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_asset$$),$G__77888$$=$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$68$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($target_asset$$));return $rename$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$rename$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($G__77887$$,$G__77888$$):$rename$jscomp$3$$($G__77887$$,$G__77888$$)}());$G__77914_i__77882_selected_full$jscomp$1$$+=1}else if($c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$))$G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$=
$c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$)?($c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$=$APP.$cljs$core$_chunked_first$$($G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$),$G__77914_i__77882_selected_full$jscomp$1$$=$APP.$cljs$core$_chunked_rest$$($G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$),
$G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$=$c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$,$G__77916_count__77881_selected_paths$jscomp$3$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$),$c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$=$G__77914_i__77882_selected_full$jscomp$1$$):($target_asset$$=$APP.$cljs$core$first$$($G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $G__77889$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($target_asset$$),$G__77890$$=$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$68$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($target_asset$$));return $rename$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$rename$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($G__77889$$,$G__77890$$):$rename$jscomp$3$$($G__77889$$,$G__77890$$)}()),
$c__5548__auto__$jscomp$45_event$jscomp$328_seq__77879_temp__5825__auto__$jscomp$364$$=$APP.$cljs$core$next$$($G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$),$G__77915_chunk__77880_dragging_STAR_$jscomp$4_seq__77879__$1$$=null,$G__77916_count__77881_selected_paths$jscomp$3$$=0),$G__77914_i__77882_selected_full$jscomp$1$$=0;else return null}else return null};
$app$main$ui$workspace$sidebar$assets$common$component_item_thumbnail_STAR_$$=function($on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$){var $file_id$jscomp$372$$=$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.fileId,$root_shape$jscomp$8$$=$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.rootShape,$component$jscomp$121$$=$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.component,
$class$$jscomp$64$$=$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.className,$container$jscomp$82$$=$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.container,$is_hidden$jscomp$2$$=$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$.isHidden,$page_id$jscomp$424$$=$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$121$$),$root_id$jscomp$9$$=
$APP.$cljs$cst$2070$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$121$$),$retry$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$wasm_QMARK_$jscomp$1$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1"),$current_page_id$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$current_page_id$$),$thumbnail_requested_QMARK_$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$object_id$jscomp$38$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$372$$),
$APP.$rumext$v2$adapt$$($page_id$jscomp$424$$),$APP.$rumext$v2$adapt$$($root_id$jscomp$9$$)],function(){return $APP.$app$common$thumbnails$fmt_object_id$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$372$$,$page_id$jscomp$424$$,$root_id$jscomp$9$$,"component")});$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($object_id$jscomp$38$$)],function(){return $APP.$app$main$refs$workspace_thumbnail_by_id$$($object_id$jscomp$38$$)});
var $thumbnail_uri$jscomp$2$$=$APP.$rumext$v2$deref$$($on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$);$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($object_id$jscomp$38$$)],function(){return $app$main$refs$workspace_thumbnail_rendered_at$$($object_id$jscomp$38$$)});$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$=
$APP.$rumext$v2$deref$$($on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$);var $modified_at$jscomp$14$$=function(){var $G__77892$$=$APP.$cljs$cst$1743$modified_at$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$121$$);return $G__77892$$==null?null:$G__77892$$.getTime()}(),$stale_QMARK_$$=$thumbnail_uri$jscomp$2$$!=null&&($on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$==null||$modified_at$jscomp$14$$!=null&&
$modified_at$jscomp$14$$>$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$);$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($retry$$))],function(){return $APP.$cljs$core$_deref$$($retry$$)<3?$retry$$+1:null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_hidden$jscomp$2$$),
$APP.$rumext$v2$adapt$$($thumbnail_uri$jscomp$2$$),$APP.$rumext$v2$adapt$$($stale_QMARK_$$),$APP.$rumext$v2$adapt$$($wasm_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($current_page_id$jscomp$2$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$372$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$424$$)],function(){return $thumbnail_uri$jscomp$2$$==null||$stale_QMARK_$$?$wasm_QMARK_$jscomp$1$$&&$APP.$cljs$core$not$$($is_hidden$jscomp$2$$)&&$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($thumbnail_requested_QMARK_$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$424$$,$current_page_id$jscomp$2$$)?($APP.$rumext$v2$set_ref_val_BANG_$$($thumbnail_requested_QMARK_$$,!0),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$thumbnails_wasm$render_thumbnail$$($file_id$jscomp$372$$,$page_id$jscomp$424$$,$root_id$jscomp$9$$))):null:$APP.$rumext$v2$set_ref_val_BANG_$$($thumbnail_requested_QMARK_$$,!1)});return $thumbnail_uri$jscomp$2$$==null||$stale_QMARK_$$||
!$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1238$component_thumbnails$$)&&!$wasm_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$component_svg$$,{"root-shape":$root_shape$jscomp$8$$,"class":$class$$jscomp$64$$,objects:$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$82$$),"show-grids?":!0,"is-hidden":$is_hidden$jscomp$2$$}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$component_svg_thumbnail$$,{"thumbnail-uri":$thumbnail_uri$jscomp$2$$,
"class":$class$$jscomp$64$$,"on-error":$on_error$jscomp$73_props_77891_rendered_at_rendered_at_STAR__thumbnail_uri_STAR_$jscomp$1$$,"root-shape":$root_shape$jscomp$8$$,objects:$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$82$$),"show-grids?":!0})};
$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$$=function($var_args$jscomp$1458$$){for(var $args__5755__auto__$jscomp$255$$=[],$len__5749__auto___77923$$=arguments.length,$i__5750__auto___77924$$=0;;)if($i__5750__auto___77924$$<$len__5749__auto___77923$$)$args__5755__auto__$jscomp$255$$.push(arguments[$i__5750__auto___77924$$]),$i__5750__auto___77924$$+=1;else break;return $app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],
1<$args__5755__auto__$jscomp$255$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$255$$.slice(1),0,null):null)};
$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$,$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77901__$1_p__77900$$){function $do_restore_component$$(){var $comps_to_restore$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($id_file_map$$,$component_id__$1$jscomp$1_p__77902$$){var $component_file$jscomp$7_map__77903__$1$$=$APP.$cljs$core$__destructure_map$$($component_id__$1$jscomp$1_p__77902$$);
$component_id__$1$jscomp$1_p__77902$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_file$jscomp$7_map__77903__$1$$,$APP.$cljs$cst$1632$component_id$$);$component_file$jscomp$7_map__77903__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_file$jscomp$7_map__77903__$1$$,$APP.$cljs$cst$1648$component_file$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($id_file_map$$,$component_id__$1$jscomp$1_p__77902$$,$component_file$jscomp$7_map__77903__$1$$)},
$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$restorable_copies$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$restore_components$$($comps_to_restore$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($comps_to_restore$$))?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,function(){return $do_show_component$$(null,!0)}):null}function $do_show_component$$($_$jscomp$3005_temp__5825__auto__$jscomp$inline_8893$$,
$JSCompiler_temp$jscomp$1754_update_layout_QMARK_$jscomp$7$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$hide_context_menu$$);$local_component_QMARK_$$?$JSCompiler_temp$jscomp$1754_update_layout_QMARK_$jscomp$7$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,
$component_id$jscomp$91$$]))):($_$jscomp$3005_temp__5825__auto__$jscomp$inline_8893$$=$find_component$$($shape$jscomp$989$$,!0),$JSCompiler_temp$jscomp$1754_update_layout_QMARK_$jscomp$7$$=$APP.$cljs$core$truth_$$($_$jscomp$3005_temp__5825__auto__$jscomp$inline_8893$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($library_id$jscomp$55$$,$_$jscomp$3005_temp__5825__auto__$jscomp$inline_8893$$,$JSCompiler_temp$jscomp$1754_update_layout_QMARK_$jscomp$7$$)):
null);return $JSCompiler_temp$jscomp$1754_update_layout_QMARK_$jscomp$7$$}function $do_add_new_property$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-property",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:design-tab-menu-variant"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($variant_id$jscomp$50$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3573$property_value$$,"Value 1",$APP.$cljs$cst$3571$editing_QMARK_$$,!0],null)]))]))}function $do_add_variant$$(){return $APP.$app$common$types$component$is_variant_QMARK_$$($shape$jscomp$989$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"add-new-variant",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$APP.$cljs$core$truth_$$($for_design_tab_QMARK_$$)?"workspace:design-tab-menu-variant":"workspace:context-menu-variant"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$160$$)])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"transform-in-variant",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$APP.$cljs$core$truth_$$($for_design_tab_QMARK_$$)?"workspace:design-tab-menu":"workspace:context-menu"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$01$$($shape_id$jscomp$160$$)]))}function $do_create_annotation$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$($shape_id$jscomp$160$$))}
function $do_update_component$$(){return $local_component_QMARK_$$?$do_update_component_sync$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$141$message$$,"",$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.update-remote-component.message"),$APP.$cljs$cst$275$hint$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.update-remote-component.hint"),$APP.$cljs$cst$2485$cancel_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.update-remote-component.cancel"),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.update-remote-component.accept"),$APP.$cljs$cst$2488$accept_style$$,$APP.$cljs$cst$2489$primary$$,$APP.$cljs$cst$2490$on_accept$$,$do_update_component_sync$$],null)))}function $do_update_component_sync$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$update_component_sync$cljs$0core$0IFn$0_invoke$0arity$03$$($shape_id$jscomp$160$$,
$library_id$jscomp$55$$))}function $do_reset_component$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$reset_components$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$touched_not_dangling$$)))}function $do_detach_component$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$detach_components$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$copies$jscomp$2$$)))}function $find_component$$($shape$jscomp$990$$,$include_deleted_QMARK_$jscomp$10$$){return $APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape$jscomp$990$$,$current_file$$,$libraries$jscomp$140$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2551$include_deleted_QMARK_$$,$include_deleted_QMARK_$jscomp$10$$],null)]))}$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77901__$1_p__77900$$=
$APP.$cljs$core$__destructure_map$$($can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77901__$1_p__77900$$);var $for_design_tab_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77901__$1_p__77900$$,$cljs$cst$5698$for_design_tab_QMARK_$$),$multi$jscomp$5$$=$APP.$cljs$core$count$$($menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$)>1,$copies$jscomp$2$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$in_component_copy_QMARK_$$,
$menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$),$current_file_id$jscomp$15$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77901__$1_p__77900$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_page_id$$);var $libraries$jscomp$140$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$files$$),$current_file$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$140$$,$current_file_id$jscomp$15$$),
$objects$jscomp$775$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($current_file$$),$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77901__$1_p__77900$$),$APP.$cljs$cst$1636$objects$$),$restorable_copies$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($library_id$jscomp$inline_8890_p1__77894_SHARP_$$){$library_id$jscomp$inline_8890_p1__77894_SHARP_$$=$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($library_id$jscomp$inline_8890_p1__77894_SHARP_$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($library_id$jscomp$inline_8890_p1__77894_SHARP_$$,$current_file_id$jscomp$15$$)||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$140$$,$library_id$jscomp$inline_8890_p1__77894_SHARP_$$)!=null},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77893_SHARP_$$){return $find_component$$($p1__77893_SHARP_$$,!1)==null},$copies$jscomp$2$$)),$touched_not_dangling$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77895_SHARP_$$){var $and__5023__auto__$jscomp$753$$=
$app$common$files$helpers$component_touched_QMARK_$$($objects$jscomp$775$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__77895_SHARP_$$));return $and__5023__auto__$jscomp$753$$?$find_component$$($p1__77895_SHARP_$$,!1):$and__5023__auto__$jscomp$753$$},$copies$jscomp$2$$);$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77901__$1_p__77900$$=$APP.$cljs$core$seq$$($touched_not_dangling$$);var $shape$jscomp$989$$=$APP.$cljs$core$first$$($menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$),
$shape_id$jscomp$160$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$),$main_instance_QMARK_$jscomp$3$$=$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$989$$),$variant_container_QMARK_$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$989$$),$component_id$jscomp$91$$=$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$),$variant_id$jscomp$50$$=$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$),
$library_id$jscomp$55$$=$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$),$local_component_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($library_id$jscomp$55$$,$current_file_id$jscomp$15$$),$can_show_component_QMARK__component$jscomp$122$$=$find_component$$($shape$jscomp$989$$,!1),$lacks_annotation_QMARK_$$=$APP.$cljs$cst$2553$annotation$$.$cljs$core$IFn$_invoke$arity$1$($can_show_component_QMARK__component$jscomp$122$$)==null,$can_update_main_QMARK__is_dangling_QMARK_$$=
$can_show_component_QMARK__component$jscomp$122$$==null;$can_show_component_QMARK__component$jscomp$122$$=!$multi$jscomp$5$$&&!$main_instance_QMARK_$jscomp$3$$&&!$can_update_main_QMARK__is_dangling_QMARK_$$;$can_update_main_QMARK__is_dangling_QMARK_$$=!$multi$jscomp$5$$&&!$can_update_main_QMARK__is_dangling_QMARK_$$&&!$main_instance_QMARK_$jscomp$3$$&&$APP.$cljs$core$not$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$775$$,$shape$jscomp$989$$))&&$app$common$files$helpers$component_touched_QMARK_$$($objects$jscomp$775$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$));var $can_detach_QMARK_$jscomp$1$$=$APP.$cljs$core$seq$$($copies$jscomp$2$$)&&$APP.$cljs$core$every_QMARK_$$(function($p1__77896_SHARP_$$){return $APP.$cljs$core$not$$($APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$775$$,$p1__77896_SHARP_$$))},$copies$jscomp$2$$),$same_variant_QMARK_$$=$app$common$types$variant$same_variant_QMARK_$$($menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$);
$menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$=$APP.$cljs$core$every_QMARK_$$(function($and__5023__auto__$jscomp$754_objects__$1$jscomp$39_shape__$1$jscomp$104$$){var $and__5023__auto____$1$jscomp$130_component__$1$jscomp$6$$=$find_component$$($and__5023__auto__$jscomp$754_objects__$1$jscomp$39_shape__$1$jscomp$104$$,!0),$main$jscomp$4_parent$jscomp$298$$=$APP.$app$common$types$component$get_deleted_component_root$$($and__5023__auto____$1$jscomp$130_component__$1$jscomp$6$$);$and__5023__auto__$jscomp$754_objects__$1$jscomp$39_shape__$1$jscomp$104$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$140$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto__$jscomp$754_objects__$1$jscomp$39_shape__$1$jscomp$104$$)),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$1635$pages_index$$),
$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$1$jscomp$130_component__$1$jscomp$6$$)),$APP.$cljs$cst$1636$objects$$);$main$jscomp$4_parent$jscomp$298$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$754_objects__$1$jscomp$39_shape__$1$jscomp$104$$,$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($main$jscomp$4_parent$jscomp$298$$));$and__5023__auto__$jscomp$754_objects__$1$jscomp$39_shape__$1$jscomp$104$$=
$APP.$cljs$cst$2552$deleted$$.$cljs$core$IFn$_invoke$arity$1$($and__5023__auto____$1$jscomp$130_component__$1$jscomp$6$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$754_objects__$1$jscomp$39_shape__$1$jscomp$104$$)?($and__5023__auto____$1$jscomp$130_component__$1$jscomp$6$$=$APP.$app$common$types$component$is_variant_QMARK_$$($and__5023__auto____$1$jscomp$130_component__$1$jscomp$6$$))?$main$jscomp$4_parent$jscomp$298$$:$and__5023__auto____$1$jscomp$130_component__$1$jscomp$6$$:$and__5023__auto__$jscomp$754_objects__$1$jscomp$39_shape__$1$jscomp$104$$},
$restorable_copies$$);var $do_show_in_assets$$=function(){var $component_id__$1$$=$variant_container_QMARK_$$?$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77897_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$775$$,$p1__77897_SHARP_$$)},$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$989$$)))):$component_id$jscomp$91$$;
return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_component_in_assets$$($component_id__$1$$))}}();$menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$=new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1134$$=!$multi$jscomp$5$$&&($variant_container_QMARK_$$||$main_instance_QMARK_$jscomp$3$$);return $or__5025__auto__$jscomp$1134$$?
$or__5025__auto__$jscomp$1134$$:$multi$jscomp$5$$?$same_variant_QMARK_$$:$multi$jscomp$5$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show-in-assets"),$APP.$cljs$cst$2694$action$$,$do_show_in_assets$$],null):null,!$multi$jscomp$5$$&&$main_instance_QMARK_$jscomp$3$$&&$local_component_QMARK_$$&&$lacks_annotation_QMARK_$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.create-annotation"),$APP.$cljs$cst$2694$action$$,$do_create_annotation$$],null):null,$can_detach_QMARK_$jscomp$1$$?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$cljs$core$count$$($copies$jscomp$2$$)>1?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.detach-instances-in-bulk"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.detach-instance"),
$APP.$cljs$cst$2694$action$$,$do_detach_component$$,$cljs$cst$5699$shortcut$$,$APP.$cljs$cst$4982$detach_component$$],null):null,$can_reset_overrides_QMARK__current_page_id$jscomp$3_map__77901__$1_p__77900$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.reset-overrides"),$APP.$cljs$cst$2694$action$$,$do_reset_component$$],null):null,$APP.$cljs$core$seq$$($restorable_copies$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$939$title$$,$menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.restore-variant"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.restore-main"),$APP.$cljs$cst$2694$action$$,$do_restore_component$$],null):null,$can_show_component_QMARK__component$jscomp$122$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show-main"),
$APP.$cljs$cst$2694$action$$,$do_show_component$$],null):null,$can_update_main_QMARK__is_dangling_QMARK_$$?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.update-main"),$APP.$cljs$cst$2694$action$$,$do_update_component$$],null):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$756_or__5025__auto__$jscomp$inline_8895$$=($and__5023__auto__$jscomp$756_or__5025__auto__$jscomp$inline_8895$$=
!$multi$jscomp$5$$)?$and__5023__auto__$jscomp$756_or__5025__auto__$jscomp$inline_8895$$:$same_variant_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$756_or__5025__auto__$jscomp$inline_8895$$)?$main_instance_QMARK_$jscomp$3$$:$and__5023__auto__$jscomp$756_or__5025__auto__$jscomp$inline_8895$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),$cljs$cst$5699$shortcut$$,
$APP.$cljs$cst$4981$create_component_variant$$,$APP.$cljs$cst$2694$action$$,$do_add_variant$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($same_variant_QMARK_$$)?$main_instance_QMARK_$jscomp$3$$?$APP.$cljs$core$truth_$$($variant_id$jscomp$50$$)?$for_design_tab_QMARK_$$:$variant_id$jscomp$50$$:$main_instance_QMARK_$jscomp$3$$:$same_variant_QMARK_$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant-property"),
$APP.$cljs$cst$2694$action$$,$do_add_new_property$$],null):null],null);return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$complement$$($APP.$cljs$core$nil_QMARK_$$),$menu_entries_restorable_variants_QMARK__shapes$jscomp$191$$)};
$app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$=function($other_path$jscomp$1_props_77906$$){var $on_group_combine_variants$$=$other_path$jscomp$1_props_77906$$.onGroupCombineVariants,$path$jscomp$263$$=$other_path$jscomp$1_props_77906$$.path,$is_group_open$$=$other_path$jscomp$1_props_77906$$.isGroupOpen,$is_can_combine$$=$other_path$jscomp$1_props_77906$$.isCanCombine,$file_id$jscomp$373$$=$other_path$jscomp$1_props_77906$$.fileId,$section$jscomp$29$$=$other_path$jscomp$1_props_77906$$.section,
$on_ungroup$$=$other_path$jscomp$1_props_77906$$.onUngroup,$on_rename$$=$other_path$jscomp$1_props_77906$$.onRename,$on_add$$=$other_path$jscomp$1_props_77906$$.onAdd,$on_delete_group$$=$other_path$jscomp$1_props_77906$$.onDeleteGroup;if($APP.$cljs$core$empty_QMARK_$$($path$jscomp$263$$))return null;var $truncated_vec__77907$$=$app$common$path_names$compact_path$$($path$jscomp$263$$);$other_path$jscomp$1_props_77906$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($truncated_vec__77907$$,
0,null);var $last_path$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($truncated_vec__77907$$,1,null);$truncated_vec__77907$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($truncated_vec__77907$$,2,null);var $menu_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$),$on_fold_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$373$$),
$APP.$rumext$v2$adapt$$($section$jscomp$29$$),$APP.$rumext$v2$adapt$$($path$jscomp$263$$),$APP.$rumext$v2$adapt$$($is_group_open$$)],function($event$jscomp$329$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$329$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_group_open$$($file_id$jscomp$373$$,$section$jscomp$29$$,$path$jscomp$263$$,$APP.$cljs$core$not$$($is_group_open$$)))}),$on_context_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$330_pos$jscomp$135$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$330_pos$jscomp$135$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$330_pos$jscomp$135$$);$event$jscomp$330_pos$jscomp$135$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$330_pos$jscomp$135$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($menu_state$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,$event$jscomp$330_pos$jscomp$135$$)}),$on_close_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_state$$,
$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__group-title-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onContextMenu:$on_context_menu$jscomp$2$$,className:"main_ui_workspace_sidebar_assets_groups__group-title",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($is_group_open$$),onCollapsed:$on_fold_group$$,
title:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$empty_QMARK_$$($other_path$jscomp$1_props_77906$$)?null:(0,$APP.$rumext$v2$jsxs$$)("span",{title:$APP.$cljs$core$truth_$$($truncated_vec__77907$$)?$path$jscomp$263$$:null,className:"main_ui_workspace_sidebar_assets_groups__pre-path",children:[$other_path$jscomp$1_props_77906$$," • "]}),(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$core$truth_$$($truncated_vec__77907$$)?$path$jscomp$263$$:null,className:"main_ui_workspace_sidebar_assets_groups__path",
children:$last_path$jscomp$1$$})]})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,{onClose:$on_close_menu$$,state:$APP.$cljs$core$_deref$$($menu_state$$),options:function(){var $G__77922_G__77922__$1$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),
$APP.$cljs$cst$266$id$$,"assets-rename-group",$APP.$cljs$cst$2413$handler$$,function($p1__77905_SHARP_$$){return $on_rename$$.$cljs$core$IFn$_invoke$arity$3$?$on_rename$$.$cljs$core$IFn$_invoke$arity$3$($p1__77905_SHARP_$$,$path$jscomp$263$$,$last_path$jscomp$1$$):$on_rename$$($p1__77905_SHARP_$$,$path$jscomp$263$$,$last_path$jscomp$1$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.ungroup"),
$APP.$cljs$cst$266$id$$,"assets-ungroup-group",$APP.$cljs$cst$2413$handler$$,function(){return $on_ungroup$$.$cljs$core$IFn$_invoke$arity$1$?$on_ungroup$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$263$$):$on_ungroup$$($path$jscomp$263$$)}],null)],null);$G__77922_G__77922__$1$$=$APP.$cljs$core$truth_$$($on_delete_group$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77922_G__77922__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete-group"),
$APP.$cljs$cst$266$id$$,"assets-delete-group",$APP.$cljs$cst$2413$handler$$,function(){return $on_delete_group$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete_group$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$263$$):$on_delete_group$$($path$jscomp$263$$)}],null)):$G__77922_G__77922__$1$$;return $APP.$cljs$core$truth_$$($is_can_combine$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__77922_G__77922__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants"),
$APP.$cljs$cst$266$id$$,"assets-combine-as-variants",$APP.$cljs$cst$2413$handler$$,function(){return $on_group_combine_variants$$.$cljs$core$IFn$_invoke$arity$1$?$on_group_combine_variants$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$263$$):$on_group_combine_variants$$($path$jscomp$263$$)}],null)):$G__77922_G__77922__$1$$}()})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__title-menu",children:[$APP.$cljs$core$truth_$$($on_add$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.add-typography"),onClick:$on_add$$,icon:"add"}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.component-group-options"),onClick:$on_context_menu$jscomp$2$$,icon:"menu"})]})]})};
$app$main$ui$workspace$sidebar$assets$groups$sort_groups$$=function($groups$jscomp$3$$,$reverse_sort_QMARK_$$){var $cmp$$=$APP.$cljs$core$truth_$$($reverse_sort_QMARK_$$)?function($p1__77927_SHARP_$$,$p2__77926_SHARP_$$){return $APP.$cljs$core$compare$$($p2__77926_SHARP_$$,$p1__77927_SHARP_$$)}:$APP.$cljs$core$compare$$;return function $app$main$ui$workspace$sidebar$assets$groups$sort_groups_$_sort_tree$$($m$jscomp$238$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$sorted_map_by$$($cmp$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p__77928_v$jscomp$663$$){var $k$jscomp$693$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77928_v$jscomp$663$$,0,null);$p__77928_v$jscomp$663$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77928_v$jscomp$663$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$693$$,$APP.$cljs$core$map_QMARK_$$($p__77928_v$jscomp$663$$)?$app$main$ui$workspace$sidebar$assets$groups$sort_groups_$_sort_tree$$($p__77928_v$jscomp$663$$):
$p__77928_v$jscomp$663$$],null)}),$m$jscomp$238$$)}($groups$jscomp$3$$)};
$app$main$ui$workspace$sidebar$assets$groups$group_assets$$=function($assets$jscomp$2$$,$reverse_sort_QMARK_$jscomp$1$$){return $APP.$cljs$core$empty_QMARK_$$($assets$jscomp$2$$)?null:$app$main$ui$workspace$sidebar$assets$groups$sort_groups$$($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($groups$jscomp$4$$,$p__77932_path$jscomp$264_path__$1$jscomp$9$$){var $map__77933__$1$$=$APP.$cljs$core$__destructure_map$$($p__77932_path$jscomp$264_path__$1$jscomp$9$$);$p__77932_path$jscomp$264_path__$1$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77933__$1$$,$APP.$cljs$cst$296$path$$);$p__77932_path$jscomp$264_path__$1$jscomp$9$$=$APP.$app$common$path_names$split_path$$($APP.$cljs$core$truth_$$($p__77932_path$jscomp$264_path__$1$jscomp$9$$)?$p__77932_path$jscomp$264_path__$1$jscomp$9$$:"");return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$4$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__77932_path$jscomp$264_path__$1$jscomp$9$$,""),function($group$jscomp$50$$){return $APP.$cljs$core$truth_$$($group$jscomp$50$$)?
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($group$jscomp$50$$,$map__77933__$1$$):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__77933__$1$$],null)})},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$assets$jscomp$2$$),$reverse_sort_QMARK_$jscomp$1$$)};
$app$main$ui$workspace$sidebar$assets$groups$name_group_dialog$$=function($initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$){$initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$=$APP.$rumext$v2$util$wrap_props$$($initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$);$initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$=$APP.$cljs$core$__destructure_map$$($initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$);
var $path$jscomp$265$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$,$APP.$cljs$cst$296$path$$,""),$last_path$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$,$cljs$cst$5700$last_path$$,""),$accept$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$,
$APP.$cljs$cst$924$accept$$);$initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($last_path$jscomp$2$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5701$asset_name$$,$last_path$jscomp$2$$],null)});var $form$jscomp$188$$=$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$util$forms$use_form$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$298$schema$$,
$app$main$ui$workspace$sidebar$assets$groups$schema_COLON_group_form$$,$APP.$cljs$cst$4840$initial$$,$initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$):$APP.$app$util$forms$use_form$$($APP.$cljs$cst$298$schema$$,$app$main$ui$workspace$sidebar$assets$groups$schema_COLON_group_form$$,$APP.$cljs$cst$4840$initial$$,$initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$),$create_QMARK_$$=$APP.$cljs$core$empty_QMARK_$$($path$jscomp$265$$);$initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$188$$)],function(){var $asset_name$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$188$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4838$clean_data$$,$APP.$cljs$cst$725$name$$],null));$create_QMARK_$$?$accept$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$accept$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($asset_name$$):
$accept$jscomp$11$$($asset_name$$):$accept$jscomp$11$$.$cljs$core$IFn$_invoke$arity$2$?$accept$jscomp$11$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$265$$,$asset_name$$):$accept$jscomp$11$$($path$jscomp$265$$,$asset_name$$);return $APP.$app$main$data$modal$hide_BANG_$$()});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__modal-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_assets_groups__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_workspace_sidebar_assets_groups__modal-title",children:$create_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.create-group"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename-group")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_sidebar_assets_groups__modal-close-btn",
children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__modal-content",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$form$$,{form:$form$jscomp$188$$,"on-submit":$initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$forms$input$$,{name:$APP.$cljs$cst$725$name$$,"class":"main_ui_workspace_sidebar_assets_groups__input-wrapper",
"auto-focus?":!0,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.group-name"),hint:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.create-group-hint")})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_groups__action-buttons",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",value:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel"),
onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_sidebar_assets_groups__cancel-button"}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"button",disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$4839$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$188$$))),value:$create_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.create"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"),onClick:$initial$jscomp$36_map__77935_map__77935__$1_on_accept$jscomp$11_props_77934$$,
className:"main_ui_workspace_sidebar_assets_groups__accept-btn "+($APP.$cljs$core$not$$($APP.$cljs$cst$4839$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$188$$)))?"disabled":"")})]})})]})})};
$app$main$ui$workspace$colorpicker$libraries$libraries_STAR_$$=function($layout$jscomp$18_props_77944$$){var $disable_gradient$jscomp$1$$=$layout$jscomp$18_props_77944$$.disableGradient,$on_add_library_color$$=$layout$jscomp$18_props_77944$$.onAddLibraryColor,$disable_opacity$jscomp$4$$=$layout$jscomp$18_props_77944$$.disableOpacity,$disable_image$jscomp$1$$=$layout$jscomp$18_props_77944$$.disableImage,$state$jscomp$1189$$=$layout$jscomp$18_props_77944$$.state,$on_select_color$$=$layout$jscomp$18_props_77944$$.onSelectColor,
$selected_STAR_$jscomp$1$$=$app$main$ui$hooks$use_shared_state$$($APP.$cljs$cst$4192$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpicker_selected$$),$selected$jscomp$145$$=$APP.$cljs$core$_deref$$($selected_STAR_$jscomp$1$$);$layout$jscomp$18_props_77944$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_layout$$);var $view_mode_STAR_$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5703$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_view_mode$$,$APP.$cljs$cst$1664$grid$$),
$view_mode$$=$APP.$cljs$core$_deref$$($view_mode_STAR_$$),$file_id$jscomp$374$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$current_colors_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),$current_colors$$=$APP.$cljs$core$_deref$$($current_colors_STAR_$$),$grouped_colors_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$grouped_colors$$=
$APP.$cljs$core$_deref$$($grouped_colors_STAR_$$),$open_groups_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$open_groups$jscomp$1$$=$APP.$cljs$core$_deref$$($open_groups_STAR_$$),$libraries$jscomp$141$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$),$recent_colors$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$recent_colors$$),$recent_colors__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($recent_colors$jscomp$1$$)],
function(){return $APP.$cljs$core$filterv$$($APP.$app$common$types$color$valid_color_QMARK_$$,$recent_colors$jscomp$1$$)}),$library_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,"recent",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.recent-colors"),
$APP.$cljs$cst$266$id$$,"recent"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,"file",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.file-library"),$APP.$cljs$cst$266$id$$,"file"],null)],null)}),$options$jscomp$609$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($library_options$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$141$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$)],
function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($library_options$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($lib$jscomp$15$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$app$common$data$name$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$15$$)),$APP.$cljs$cst$2296$label$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$15$$),$APP.$cljs$cst$266$id$$,$APP.$app$common$data$name$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$15$$))],null)})),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$141$$,$file_id$jscomp$374$$))}),$on_library_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$331$$){return $APP.$cljs$core$reset_BANG_$$($selected_STAR_$jscomp$1$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$331$$,
"recent")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$331$$,"file")?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$331$$):$APP.$app$common$uuid$parse$$($event$jscomp$331$$))}),$valid_color_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disable_gradient$jscomp$1$$),$APP.$rumext$v2$adapt$$($disable_opacity$jscomp$4$$),$APP.$rumext$v2$adapt$$($disable_image$jscomp$1$$)],function($color$jscomp$145$$){return($APP.$cljs$core$not$$($disable_gradient$jscomp$1$$)||
$APP.$cljs$core$not$$($APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$145$$)))&&($APP.$cljs$core$not$$($disable_opacity$jscomp$4$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$145$$)))&&($APP.$cljs$core$not$$($disable_image$jscomp$1$$)||$APP.$cljs$core$not$$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$145$$)))}),$toggle_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$145$$)],
function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1568$bottom$$;$APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("color-palette"),"fade-out-down");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3790$textpalette$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$data$workspace$colors$toggle_palette$$($selected$jscomp$145$$),
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-colorpicker")]))}),$toggle_view_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($view_mode$$)],function(){var $new_mode$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($view_mode$$,$APP.$cljs$cst$1664$grid$$)?$APP.$cljs$cst$201$list$$:$APP.$cljs$cst$1664$grid$$;return $APP.$cljs$core$reset_BANG_$$($view_mode_STAR_$$,$new_mode$$)}),$on_color_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1189$$),
$APP.$rumext$v2$adapt$$($selected$jscomp$145$$),$APP.$rumext$v2$adapt$$($on_select_color$$)],function($color$jscomp$146$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5702$recent$$,$selected$jscomp$145$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-color",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"colorpicker",$APP.$cljs$cst$4001$external_library$$,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$208$file$$,$selected$jscomp$145$$)],null)));return $on_select_color$$.$cljs$core$IFn$_invoke$arity$2$?$on_select_color$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1189$$,$color$jscomp$146$$):$on_select_color$$($state$jscomp$1189$$,$color$jscomp$146$$)}),$on_toggle_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($path$jscomp$266$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_groups_STAR_$$,
function($s$jscomp$583$$){return $APP.$cljs$core$contains_QMARK_$$($s$jscomp$583$$,$path$jscomp$266$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$583$$,$path$jscomp$266$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$583$$,$path$jscomp$266$$)})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$145$$),$APP.$rumext$v2$adapt$$($recent_colors__$1$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$141$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$374$$),
$APP.$rumext$v2$adapt$$($valid_color_QMARK_$$)],function(){var $resolved_file_id$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$145$$,$APP.$cljs$cst$208$file$$)?$file_id$jscomp$374$$:$selected$jscomp$145$$;$APP.$cljs$core$reset_BANG_$$($open_groups_STAR_$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$145$$,$cljs$cst$5702$recent$$)){var $colors$jscomp$9_flat_colors$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($valid_color_QMARK_$$),$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$470$$,$color$jscomp$147_color__$1$jscomp$26$$){$color$jscomp$147_color__$1$jscomp$26$$=$APP.$cljs$core$map_QMARK_$$($color$jscomp$147_color__$1$jscomp$26$$)?$color$jscomp$147_color__$1$jscomp$26$$:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1303$color$$,$color$jscomp$147_color__$1$jscomp$26$$],
null);return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($color$jscomp$147_color__$1$jscomp$26$$,$cljs$cst$5704$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$,""+($index$jscomp$470$$??""))}),$cljs$core$take_while$cljs$0core$0IFn$0_invoke$0arity$01$$()),$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$types$color$sort_colors$$,$APP.$cljs$core$reverse$$($recent_colors__$1$$)));$APP.$cljs$core$reset_BANG_$$($current_colors_STAR_$$,$colors$jscomp$9_flat_colors$$);
return $APP.$cljs$core$reset_BANG_$$($grouped_colors_STAR_$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}var $raw_colors$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($valid_color_QMARK_$$,$APP.$cljs$core$vals$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$141$$,$resolved_file_id$jscomp$2$$),
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2220$colors$$))));$colors$jscomp$9_flat_colors$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$471$$,$color$jscomp$148$$){return $APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($app$common$types$color$library_color__GT_color$$($color$jscomp$148$$,$resolved_file_id$jscomp$2$$),$cljs$cst$5704$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$,
""+($index$jscomp$471$$??""))}),$raw_colors$$);var $grouped$jscomp$2$$=function(){var $G__77945$$=$app$main$ui$workspace$sidebar$assets$groups$group_assets$$($raw_colors$$,!1);return $G__77945$$==null?null:$app$main$ui$workspace$colorpicker$libraries$convert_grouped_colors$$($G__77945$$,$resolved_file_id$jscomp$2$$)}();$APP.$cljs$core$reset_BANG_$$($current_colors_STAR_$$,$colors$jscomp$9_flat_colors$$);return $APP.$cljs$core$reset_BANG_$$($grouped_colors_STAR_$$,$APP.$cljs$core$truth_$$($grouped$jscomp$2$$)?
$grouped$jscomp$2$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_libraries__libraries",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_libraries__select-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{onChange:$on_library_change$$,options:$options$jscomp$609$$,className:"main_ui_workspace_colorpicker_libraries__library-select",defaultSelected:function(){var $or__5025__auto__$jscomp$1138$$=
$APP.$app$common$data$name$$($selected$jscomp$145$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1138$$)?$or__5025__auto__$jscomp$1138$$:"recent"}()}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.toggle-color-palette"),onClick:$toggle_palette$$,"aria-pressed":$APP.$cljs$core$boolean$0$$($APP.$cljs$core$contains_QMARK_$$($layout$jscomp$18_props_77944$$,
$APP.$cljs$cst$3764$colorpalette$$)),icon:"swatches"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1664$grid$$,$view_mode$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.list-view"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.grid-view"),onClick:$toggle_view_mode$$,icon:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1664$grid$$,
$view_mode$$)?"view-as-list":"view-as-icons"}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$145$$,$APP.$cljs$cst$208$file$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.add-library-color"),onClick:$on_add_library_color$$,icon:"add"}):null]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($view_mode$$,$APP.$cljs$cst$1664$grid$$)?
$APP.$cljs$core$seq$$($current_colors$$)?(0,$APP.$rumext$v2$jsx$$)("ul",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors"),className:"main_ui_workspace_colorpicker_libraries__selected-colors",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$124$$,$color$jscomp$149$$){$out_arr__44092__auto__$jscomp$124$$.push((0,$APP.$rumext$v2$jsx$$)("li",{children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,
{background:$color$jscomp$149$$,onClick:$on_color_click$jscomp$1$$,size:"medium"})},$cljs$cst$5704$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($color$jscomp$149$$))));return $out_arr__44092__auto__$jscomp$124$$},[],$current_colors$$)}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"swatches",className:"main_ui_workspace_colorpicker_libraries__empty-state",text:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$145$$,
$cljs$cst$5702$recent$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.empty-recent-colors"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.empty-palette")}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$145$$,$cljs$cst$5702$recent$$)?$APP.$cljs$core$seq$$($current_colors$$)?(0,$APP.$rumext$v2$jsx$$)("ul",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors"),
className:"main_ui_workspace_colorpicker_libraries__selected-colors-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$125$$,$color$jscomp$150$$){$out_arr__44092__auto__$jscomp$125$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$libraries$color_row_colorpicker_STAR_$$,{colorItem:$color$jscomp$150$$,onClick:$on_color_click$jscomp$1$$},$cljs$cst$5704$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($color$jscomp$150$$))));
return $out_arr__44092__auto__$jscomp$125$$},[],$current_colors$$)}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"swatches",className:"main_ui_workspace_colorpicker_libraries__empty-state",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.empty-recent-colors")}):$APP.$cljs$core$seq$$($grouped_colors$$)?function(){var $resolved_file_id$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$145$$,
$APP.$cljs$cst$208$file$$)?$file_id$jscomp$374$$:$selected$jscomp$145$$;return(0,$APP.$rumext$v2$jsx$$)("ul",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors"),className:"main_ui_workspace_colorpicker_libraries__selected-colors-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$libraries$color_group_list_STAR_$$,{groups:$grouped_colors$$,prefix:"",resolvedFileId:$resolved_file_id$jscomp$3$$,onColorClick:$on_color_click$jscomp$1$$,
openGroups:$open_groups$jscomp$1$$,onToggleGroup:$on_toggle_group$jscomp$1$$})})}():$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"swatches",className:"main_ui_workspace_colorpicker_libraries__empty-state",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.empty-palette")})]})};
$app$main$ui$workspace$colorpicker$ramp$value_saturation_selector_STAR_$$=function($handle_start_drag$jscomp$2_props_77774$$){function $calculate_pos$jscomp$2$$($ev$jscomp$10_map__77783_x$jscomp$1251$$){var $map__77782_py$jscomp$11_top$jscomp$14$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($ev$jscomp$10_map__77783_x$jscomp$1251$$)),$bottom$jscomp$7_map__77782__$1$$=$APP.$cljs$core$__destructure_map$$($map__77782_py$jscomp$11_top$jscomp$14$$),$left$jscomp$32_px$jscomp$12$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$7_map__77782__$1$$,$APP.$cljs$cst$257$left$$),$right$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$7_map__77782__$1$$,$APP.$cljs$cst$258$right$$);$map__77782_py$jscomp$11_top$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$7_map__77782__$1$$,$APP.$cljs$cst$1567$top$$);$bottom$jscomp$7_map__77782__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bottom$jscomp$7_map__77782__$1$$,
$APP.$cljs$cst$1568$bottom$$);$ev$jscomp$10_map__77783_x$jscomp$1251$$=$APP.$app$util$dom$get_client_position$$($ev$jscomp$10_map__77783_x$jscomp$1251$$);var $map__77783__$1_y$jscomp$472$$=$APP.$cljs$core$__destructure_map$$($ev$jscomp$10_map__77783_x$jscomp$1251$$);$ev$jscomp$10_map__77783_x$jscomp$1251$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77783__$1_y$jscomp$472$$,$APP.$cljs$cst$1515$x$$);$map__77783__$1_y$jscomp$472$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77783__$1_y$jscomp$472$$,
$APP.$cljs$cst$1516$y$$);$left$jscomp$32_px$jscomp$12$$=$APP.$app$common$math$clamp$$(($ev$jscomp$10_map__77783_x$jscomp$1251$$-$left$jscomp$32_px$jscomp$12$$)/($right$jscomp$25$$-$left$jscomp$32_px$jscomp$12$$),0,1);$map__77782_py$jscomp$11_top$jscomp$14$$=255*(1-$APP.$app$common$math$clamp$$(($map__77783__$1_y$jscomp$472$$-$map__77782_py$jscomp$11_top$jscomp$14$$)/($bottom$jscomp$7_map__77782__$1$$-$map__77782_py$jscomp$11_top$jscomp$14$$),0,1));return $on_change$jscomp$42$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change$jscomp$42$$.$cljs$core$IFn$_invoke$arity$2$($left$jscomp$32_px$jscomp$12$$,$map__77782_py$jscomp$11_top$jscomp$14$$):$on_change$jscomp$42$$($left$jscomp$32_px$jscomp$12$$,$map__77782_py$jscomp$11_top$jscomp$14$$)}var $on_change$jscomp$42$$=$handle_start_drag$jscomp$2_props_77774$$.onChange,$saturation$jscomp$4$$=$handle_start_drag$jscomp$2_props_77774$$.saturation,$on_start_drag$jscomp$3$$=$handle_start_drag$jscomp$2_props_77774$$.onStartDrag,$value$jscomp$802$$=$handle_start_drag$jscomp$2_props_77774$$.value,
$on_finish_drag$jscomp$3$$=$handle_start_drag$jscomp$2_props_77774$$.onFinishDrag,$dragging_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($dragging_QMARK__STAR_$$);$handle_start_drag$jscomp$2_props_77774$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_drag$jscomp$3$$)],function($event$jscomp$332$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$332$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK__STAR_$$,
!0);return $on_start_drag$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_start_drag$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_start_drag$jscomp$3$$()});var $handle_stop_drag$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_finish_drag$jscomp$3$$)],function($event$jscomp$333$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$333$$);$APP.$cljs$core$reset_BANG_$$($dragging_QMARK__STAR_$$,!1);return $on_finish_drag$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?
$on_finish_drag$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_finish_drag$jscomp$3$$()}),$handle_change_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_pos$jscomp$2$$),$APP.$rumext$v2$adapt$$($dragging_QMARK_$jscomp$4$$)],function($event$jscomp$334$$){return $APP.$cljs$core$truth_$$($dragging_QMARK_$jscomp$4$$)?$calculate_pos$jscomp$2$$($event$jscomp$334$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"value-saturation-selector",
onPointerDown:$handle_start_drag$jscomp$2_props_77774$$,onPointerUp:$handle_stop_drag$jscomp$2$$,onClick:$calculate_pos$jscomp$2$$,onPointerMove:$handle_change_pointer_move$$,className:"main_ui_workspace_colorpicker_ramp__value-saturation-selector",children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"ramp-handler",style:{pointerEvents:"none",left:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(100*$saturation$jscomp$4$$),"%"].join(""),top:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(100*
(1-$value$jscomp$802$$/255)),"%"].join("")},className:"main_ui_workspace_colorpicker_ramp__handler"})})};
$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$=function($map__77797__$1_p__77796$$){$map__77797__$1_p__77796$$=$APP.$cljs$core$__destructure_map$$($map__77797__$1_p__77796$$);var $h$jscomp$179_h__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77797__$1_p__77796$$,$APP.$cljs$cst$1907$h$$),$s$jscomp$584_s__$1$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77797__$1_p__77796$$,$APP.$cljs$cst$4235$s$$),$v$jscomp$664_v__$1$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77797__$1_p__77796$$,
$APP.$cljs$cst$3723$v$$);$h$jscomp$179_h__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($h$jscomp$179_h__$1$jscomp$2$$,0);$s$jscomp$584_s__$1$jscomp$50$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($s$jscomp$584_s__$1$jscomp$50$$,0);$v$jscomp$664_v__$1$jscomp$32$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$664_v__$1$jscomp$32$$,0);var $hsv$jscomp$2$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$h$jscomp$179_h__$1$jscomp$2$$,$s$jscomp$584_s__$1$jscomp$50$$,$v$jscomp$664_v__$1$jscomp$32$$],null),$b$jscomp$358_vec__77798$$=$app$common$types$color$hsv__GT_rgb$$($hsv$jscomp$2$$),$r$jscomp$137$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$358_vec__77798$$,0,null),$g$jscomp$159$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$358_vec__77798$$,1,null);$b$jscomp$358_vec__77798$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$358_vec__77798$$,
2,null);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__77797__$1_p__77796$$,$APP.$cljs$cst$2698$hex$$,$app$common$types$color$hsv__GT_hex$$($hsv$jscomp$2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1907$h$$,$h$jscomp$179_h__$1$jscomp$2$$,$APP.$cljs$cst$4235$s$$,$s$jscomp$584_s__$1$jscomp$50$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$664_v__$1$jscomp$32$$,$APP.$cljs$cst$1749$r$$,$r$jscomp$137$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$159$$,$APP.$cljs$cst$1525$b$$,
$b$jscomp$358_vec__77798$$]))};
$app$main$ui$workspace$colorpicker$ramp$ramp_selector_STAR_$$=function($on_finish_drag$jscomp$4_props_77808$$){var $on_change$jscomp$43$$=$on_finish_drag$jscomp$4_props_77808$$.onChange,$disable_opacity$jscomp$5$$=$on_finish_drag$jscomp$4_props_77808$$.disableOpacity,$color$jscomp$152$$=$on_finish_drag$jscomp$4_props_77808$$.color,$on_start_drag$jscomp$4$$=$on_finish_drag$jscomp$4_props_77808$$.onStartDrag;$on_finish_drag$jscomp$4_props_77808$$=$on_finish_drag$jscomp$4_props_77808$$.onFinishDrag;var $internal_color_STAR_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$($color$jscomp$152$$)}),$internal_color$$=$APP.$cljs$core$_deref$$($internal_color_STAR_$$),$h$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,$APP.$cljs$cst$1907$h$$),$s$jscomp$585$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,$APP.$cljs$cst$4235$s$$),$v$jscomp$665$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,
$APP.$cljs$cst$3723$v$$),$hex$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,$APP.$cljs$cst$2698$hex$$),$alpha$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($internal_color$$,$APP.$cljs$cst$746$alpha$$),$bullet_color$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hex$jscomp$15$$),$APP.$rumext$v2$adapt$$($alpha$jscomp$18$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,
$hex$jscomp$15$$,$APP.$cljs$cst$1740$opacity$$,$alpha$jscomp$18$$],null)}),$on_change_value_saturation$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_color$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$43$$)],function($color__$1$jscomp$27_saturation$jscomp$5$$,$value$jscomp$803$$){$color__$1$jscomp$27_saturation$jscomp$5$$=$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($internal_color$$,
$APP.$cljs$cst$4235$s$$,$color__$1$jscomp$27_saturation$jscomp$5$$),$APP.$cljs$cst$3723$v$$,$value$jscomp$803$$));$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$$,$color__$1$jscomp$27_saturation$jscomp$5$$);return $on_change$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$27_saturation$jscomp$5$$):$on_change$jscomp$43$$($color__$1$jscomp$27_saturation$jscomp$5$$)}),$on_change_hue$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_color$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$43$$)],function($color__$1$jscomp$28_hue$jscomp$5$$){$color__$1$jscomp$28_hue$jscomp$5$$=$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($internal_color$$,$APP.$cljs$cst$1907$h$$,$color__$1$jscomp$28_hue$jscomp$5$$));$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$$,$color__$1$jscomp$28_hue$jscomp$5$$);return $on_change$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$28_hue$jscomp$5$$):
$on_change$jscomp$43$$($color__$1$jscomp$28_hue$jscomp$5$$)}),$on_change_opacity$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_color$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$43$$)],function($color__$1$jscomp$29_opacity$jscomp$48$$){$color__$1$jscomp$29_opacity$jscomp$48$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($internal_color$$,$APP.$cljs$cst$746$alpha$$,$color__$1$jscomp$29_opacity$jscomp$48$$);$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$$,
$color__$1$jscomp$29_opacity$jscomp$48$$);return $on_change$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$43$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$29_opacity$jscomp$48$$):$on_change$jscomp$43$$($color__$1$jscomp$29_opacity$jscomp$48$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$152$$)],function(){return $APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$$,$app$main$ui$workspace$colorpicker$ramp$enrich_color_map$$($color$jscomp$152$$))});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$ramp$value_saturation_selector_STAR_$$,{hue:$h$jscomp$180$$,saturation:$s$jscomp$585$$,value:$v$jscomp$665$$,onChange:$on_change_value_saturation$$,onStartDrag:$on_start_drag$jscomp$4$$,onFinishDrag:$on_finish_drag$jscomp$4_props_77808$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--bullet-size":"52px"},className:"main_ui_workspace_colorpicker_ramp__shade-selector",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet_STAR_$$,
{color:$bullet_color$$,area:!0}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker_ramp__sliders-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,{type:$APP.$cljs$cst$2028$hue$$,maxValue:360,value:$h$jscomp$180$$,onChange:$on_change_hue$$,onStartDrag:$on_start_drag$jscomp$4$$,onFinishDrag:$on_finish_drag$jscomp$4_props_77808$$}),$APP.$cljs$core$not$$($disable_opacity$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$slider_selector$slider_selector_STAR_$$,
{type:$APP.$cljs$cst$1740$opacity$$,maxValue:1,value:$alpha$jscomp$18$$,onChange:$on_change_opacity$jscomp$2$$,onStartDrag:$on_start_drag$jscomp$4$$,onFinishDrag:$on_finish_drag$jscomp$4_props_77808$$}):null]})]})]})};
$app$main$ui$workspace$colorpicker$use_color_picker_css_variables_BANG_$$=function($node_ref$jscomp$3$$,$current_color$jscomp$2$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_color$jscomp$2$$)],function(){function $format_hsl$$($G__78615_l$jscomp$109_p__78607$$){var $h__$1$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__78615_l$jscomp$109_p__78607$$,0,null),$G__78614_s$jscomp$586$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__78615_l$jscomp$109_p__78607$$,
1,null);$G__78615_l$jscomp$109_p__78607$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__78615_l$jscomp$109_p__78607$$,2,null);$G__78614_s$jscomp$586$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78614_s$jscomp$586$$*100),"%"].join("");$G__78615_l$jscomp$109_p__78607$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78615_l$jscomp$109_p__78607$$*100),"%"].join("");return $APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$4$("hsl(%s, %s, %s)",
$h__$1$jscomp$3$$,$G__78614_s$jscomp$586$$,$G__78615_l$jscomp$109_p__78607$$):$APP.$cuerdas$core$format$$("hsl(%s, %s, %s)",$h__$1$jscomp$3$$,$G__78614_s$jscomp$586$$,$G__78615_l$jscomp$109_p__78607$$)}var $node$jscomp$406$$=$APP.$rumext$v2$ref_val$$($node_ref$jscomp$3$$),$hsl_to_map__78601__$1_v$jscomp$666$$=$APP.$cljs$core$__destructure_map$$($current_color$jscomp$2$$),$r$jscomp$138_rgb$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78601__$1_v$jscomp$666$$,$APP.$cljs$cst$1749$r$$),
$g$jscomp$160_hue_rgb$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78601__$1_v$jscomp$666$$,$APP.$cljs$cst$1750$g$$),$b$jscomp$359_hsl_from$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78601__$1_v$jscomp$666$$,$APP.$cljs$cst$1525$b$$),$h$jscomp$181_lightness_mid$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78601__$1_v$jscomp$666$$,$APP.$cljs$cst$1907$h$$);$hsl_to_map__78601__$1_v$jscomp$666$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hsl_to_map__78601__$1_v$jscomp$666$$,
$APP.$cljs$cst$3723$v$$);$r$jscomp$138_rgb$jscomp$6$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$r$jscomp$138_rgb$jscomp$6$$,$g$jscomp$160_hue_rgb$$,$b$jscomp$359_hsl_from$$],null);$g$jscomp$160_hue_rgb$$=$app$common$types$color$hsv__GT_rgb$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,1,255],null));$b$jscomp$359_hsl_from$$=$APP.$app$common$types$color$hex__GT_hsl$$($app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,0,$hsl_to_map__78601__$1_v$jscomp$666$$],null)));$hsl_to_map__78601__$1_v$jscomp$666$$=$APP.$app$common$types$color$hex__GT_hsl$$($app$common$types$color$hsv__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,1,$hsl_to_map__78601__$1_v$jscomp$666$$],null)));var $hsl_sat_from_vec__78603$$=$APP.$app$common$types$color$rgb__GT_hsl$$($r$jscomp$138_rgb$jscomp$6$$);
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hsl_sat_from_vec__78603$$,0,null);var $cur_hsl_s$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hsl_sat_from_vec__78603$$,1,null),$cur_hsl_l_hsl_sat_to$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($hsl_sat_from_vec__78603$$,2,null);$hsl_sat_from_vec__78603$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,0,$cur_hsl_l_hsl_sat_to$$],null);
$cur_hsl_l_hsl_sat_to$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,1,$cur_hsl_l_hsl_sat_to$$],null);$h$jscomp$181_lightness_mid$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$h$jscomp$181_lightness_mid$$,$cur_hsl_s$$,.5],null);$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$406$$,"--color",$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$r$jscomp$138_rgb$jscomp$6$$));
$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$406$$,"--hue-rgb",$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$g$jscomp$160_hue_rgb$$));$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$406$$,"--saturation-grad-from",$format_hsl$$($b$jscomp$359_hsl_from$$));$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$406$$,"--saturation-grad-to",$format_hsl$$($hsl_to_map__78601__$1_v$jscomp$666$$));$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$406$$,"--hsl-saturation-grad-from",
$format_hsl$$($hsl_sat_from_vec__78603$$));$APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$406$$,"--hsl-saturation-grad-to",$format_hsl$$($cur_hsl_l_hsl_sat_to$$));return $APP.$app$util$dom$set_css_property_BANG_$$($node$jscomp$406$$,"--lightness-grad-mid",$format_hsl$$($h$jscomp$181_lightness_mid$$))})};
$app$main$ui$workspace$colorpicker$colorpicker_STAR_$$=function($origin$jscomp$69_props_78623$$){var $tab$jscomp$7_toggle_token_color$$=$origin$jscomp$69_props_78623$$.tab,$on_change$jscomp$44$$=$origin$jscomp$69_props_78623$$.onChange,$data$jscomp$469$$=$origin$jscomp$69_props_78623$$.data,$disable_gradient$jscomp$2$$=$origin$jscomp$69_props_78623$$.disableGradient,$disable_opacity$jscomp$6$$=$origin$jscomp$69_props_78623$$.disableOpacity,$on_token_change$jscomp$3$$=$origin$jscomp$69_props_78623$$.onTokenChange,
$combined_tokens$jscomp$3$$=$origin$jscomp$69_props_78623$$.combinedTokens,$disable_image$jscomp$2$$=$origin$jscomp$69_props_78623$$.disableImage,$applied_token$jscomp$3$$=$origin$jscomp$69_props_78623$$.appliedToken,$on_accept$jscomp$12$$=$origin$jscomp$69_props_78623$$.onAccept,$color_origin$jscomp$2$$=$origin$jscomp$69_props_78623$$.colorOrigin;$origin$jscomp$69_props_78623$$=$origin$jscomp$69_props_78623$$.origin;var $state$jscomp$1190$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$colorpicker$$),
$node_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(),$should_update_QMARK_$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$token_color$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1214$token_color$$),$color_style_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($tab$jscomp$7_toggle_token_color$$,$cljs$cst$5706$direct_color$$)),$color_style$jscomp$1$$=$APP.$cljs$core$_deref$$($color_style_STAR_$$);
$tab$jscomp$7_toggle_token_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_style$jscomp$1$$)],function(){var $new_style$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5706$direct_color$$,$color_style$jscomp$1$$)?$APP.$cljs$cst$1214$token_color$$:$cljs$cst$5706$direct_color$$;return $APP.$cljs$core$reset_BANG_$$($color_style_STAR_$$,$new_style$jscomp$1$$)});var $picking_color_QMARK_$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$colorpicker$picking_color_QMARK_$$),
$picked_color$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$colorpicker$picked_color$$),$picked_color_select$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$colorpicker$picked_color_select$$),$current_color$jscomp$3$$=$APP.$cljs$cst$4231$current_color$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$),$active_fill_tab$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$469$$))?$APP.$cljs$cst$1617$image$$:function(){var $G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$=
$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$469$$);if($APP.$cljs$core$truth_$$($G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$))switch($G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$),$G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$=$G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$ instanceof $APP.$cljs$core$Keyword$$?$G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$.$fqn$:
null,$G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$){case "linear":return $APP.$cljs$cst$4230$linear_gradient$$;case "radial":return $APP.$cljs$cst$4232$radial_gradient$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78624_G__78624__$1_temp__5823__auto__$jscomp$228$$)].join(""));}else return $APP.$cljs$cst$1303$color$$}(),$active_color_tab_STAR_$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5707$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_color_tab$$,
"ramp"),$active_color_tab$$=$APP.$cljs$core$_deref$$($active_color_tab_STAR_$$),$hsb_mode_STAR_$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5708$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_hsb_mode$$,$cljs$cst$5530$hsb$$),$hsb_mode$jscomp$1$$=$APP.$cljs$core$_deref$$($hsb_mode_STAR_$$),$drag_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$drag_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($drag_QMARK__STAR_$$),$type$jscomp$615$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_color_tab$$,
"hsva")?$cljs$cst$5530$hsb$$:$cljs$cst$5533$rgb$$,$fill_image_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$color_type$jscomp$2_selected_mode$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1190$$,$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1303$color$$);switch($color_type$jscomp$2_selected_mode$$ instanceof $APP.$cljs$core$Keyword$$?$color_type$jscomp$2_selected_mode$$.$fqn$:null){case "linear-gradient":case "radial-gradient":$color_type$jscomp$2_selected_mode$$=$APP.$cljs$cst$1730$gradient$$}var $disabled_color_accept_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_type$jscomp$2_selected_mode$$,$APP.$cljs$cst$1617$image$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$)),$on_fill_image_success$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($image$jscomp$37$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1617$image$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$select_keys$$($image$jscomp$37$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1732$mtype$$,$APP.$cljs$cst$725$name$$],null)),$APP.$cljs$cst$1733$keep_aspect_ratio$$,!0)],null),$APP.$cljs$core$not$$($drag_QMARK_$jscomp$1$$)))}),$on_fill_image_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($fill_image_ref$$))}),
$on_fill_image_selected$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($file$jscomp$159$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$media$upload_fill_image$$($file$jscomp$159$$,$on_fill_image_success$$))}),$handle_change_keep_aspect_ratio$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_color$jscomp$3$$)],function(){var $keep_aspect_ratio_QMARK_$$=$APP.$cljs$core$not$$($APP.$cljs$cst$1733$keep_aspect_ratio$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$))),
$image$jscomp$38$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$),$APP.$cljs$cst$1733$keep_aspect_ratio$$,$keep_aspect_ratio_QMARK_$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$update_colorpicker_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1617$image$$,$image$jscomp$38$$],null),!0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"toggle-image-aspect-ratio",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:colorpicker",$cljs$cst$5709$checked$$,$keep_aspect_ratio_QMARK_$$],null))]))}),$on_change_tab$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78616_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($active_color_tab_STAR_$$,$p1__78616_SHARP_$$)}),$handle_change_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$804$$){switch($value$jscomp$804$$ instanceof
$APP.$cljs$core$Keyword$$?$value$jscomp$804$$.$fqn$:null){case "color":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$activate_colorpicker_color$$());case "gradient":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$activate_colorpicker_gradient$$($APP.$cljs$cst$4230$linear_gradient$$));case "image":return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$activate_colorpicker_image$$());
default:return null}}),$handle_change_color$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_color$jscomp$3$$),$APP.$rumext$v2$adapt$$($drag_QMARK_$jscomp$1$$)],function($color$jscomp$153_color__$1$jscomp$30_color__$2$jscomp$2$$){$color$jscomp$153_color__$1$jscomp$30_color__$2$jscomp$2$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$current_color$jscomp$3$$,$color$jscomp$153_color__$1$jscomp$30_color__$2$jscomp$2$$]));
$color$jscomp$153_color__$1$jscomp$30_color__$2$jscomp$2$$=$app$main$data$workspace$colors$materialize_color_components$$($color$jscomp$153_color__$1$jscomp$30_color__$2$jscomp$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_color$$($color$jscomp$153_color__$1$jscomp$30_color__$2$jscomp$2$$,$APP.$cljs$core$not$$($drag_QMARK_$jscomp$1$$)))}),$handle_click_picker$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($picking_color_QMARK_$$)],
function(){if($APP.$cljs$core$truth_$$($picking_color_QMARK_$$))return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$(),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$stop_picker$$());$app$main$data$modal$allow_click_outside_BANG_$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$start_picker$$())}),$on_select_library_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$469$$),
$APP.$rumext$v2$adapt$$($handle_change_color$jscomp$1$$)],function($G__78627__$jscomp$3010_color__$1$jscomp$31$$,$color$jscomp$154$$){if($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$154$$)!=null&&$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$469$$)!=null)return $G__78627__$jscomp$3010_color__$1$jscomp$31$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2698$hex$$,$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$154$$),
$APP.$cljs$cst$746$alpha$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$154$$)],null),$handle_change_color$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change_color$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__78627__$jscomp$3010_color__$1$jscomp$31$$):$handle_change_color$jscomp$1$$($G__78627__$jscomp$3010_color__$1$jscomp$31$$);$G__78627__$jscomp$3010_color__$1$jscomp$31$$=$APP.$app$common$data$without_qualified$cljs$0core$0IFn$0_invoke$0arity$01$$($color$jscomp$154$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$add_recent_color$$($G__78627__$jscomp$3010_color__$1$jscomp$31$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$apply_color_from_colorpicker$$($G__78627__$jscomp$3010_color__$1$jscomp$31$$)]));return $on_change$jscomp$44$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$44$$.$cljs$core$IFn$_invoke$arity$1$($G__78627__$jscomp$3010_color__$1$jscomp$31$$):
$on_change$jscomp$44$$($G__78627__$jscomp$3010_color__$1$jscomp$31$$)}),$on_add_library_color$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1190$$)],function(){var $JSCompiler_temp_const$jscomp$1675$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1677_color$jscomp$inline_8898$$=$app$main$data$workspace$colors$get_color_from_colorpicker_state$$($state$jscomp$1190$$);$JSCompiler_inline_result$jscomp$1677_color$jscomp$inline_8898$$=
$APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1677_color$jscomp$inline_8898$$,null);return $JSCompiler_temp_const$jscomp$1675$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1677_color$jscomp$inline_8898$$)}),$on_start_drag$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($drag_QMARK__STAR_$$),$APP.$rumext$v2$adapt$$($node_ref$jscomp$4$$)],function(){$APP.$cljs$core$reset_BANG_$$($should_update_QMARK_$$,
!1);$APP.$cljs$core$reset_BANG_$$($drag_QMARK__STAR_$$,!0);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($APP.$rumext$v2$ref_val$$($node_ref$jscomp$4$$)))}),$on_finish_drag$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($drag_QMARK__STAR_$$),$APP.$rumext$v2$adapt$$($node_ref$jscomp$4$$)],function(){$APP.$cljs$core$reset_BANG_$$($should_update_QMARK_$$,!0);$APP.$cljs$core$reset_BANG_$$($drag_QMARK__STAR_$$,
!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($APP.$rumext$v2$ref_val$$($node_ref$jscomp$4$$)))}),$on_color_accept$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1190$$)],function(){var $G__78628_78678$$=$app$main$data$workspace$colors$get_color_from_colorpicker_state$$($state$jscomp$1190$$);$on_accept$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$on_accept$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($G__78628_78678$$):
$on_accept$jscomp$12$$($G__78628_78678$$);return $APP.$app$main$data$modal$hide_BANG_$$()}),$options$jscomp$610$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_type$jscomp$2_selected_mode$$),$APP.$rumext$v2$adapt$$($disable_gradient$jscomp$2$$),$APP.$rumext$v2$adapt$$($disable_image$jscomp$2$$)],function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.solid")],null)],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$not$$($disable_gradient$jscomp$2$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1730$gradient$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.gradient")],null)],null):null,$APP.$cljs$core$not$$($disable_image$jscomp$2$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1617$image$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image")],
null)],null):null]))}),$handle_change_gradient_selected_stop$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$472$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$select_colorpicker_gradient_stop$$($index$jscomp$472$$))}),$handle_change_gradient_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($type__$1$jscomp$14$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$activate_colorpicker_gradient$$($type__$1$jscomp$14$$))}),
$handle_gradient_change_stop$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1190$$)],function($prev_stop$$,$new_stop$jscomp$2$$){var $stops$jscomp$18$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78618_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__78618_SHARP_$$,$prev_stop$$)?$new_stop$jscomp$2$$:$p1__78618_SHARP_$$},$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($stops$jscomp$18$$))}),$handle_gradient_add_stop_auto$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_add_auto$$())}),$handle_gradient_add_stop_preview$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($offset$jscomp$208$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_add_stop$$($offset$jscomp$208$$))}),
$handle_gradient_remove_stop$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$473$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_gradient_stop$cljs$0core$0IFn$0_invoke$0arity$01$$($index$jscomp$473$$))}),$handle_stop_edit_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($should_update_QMARK_$$,!1)}),$handle_stop_edit_finish$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($should_update_QMARK_$$,
!0);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$sort_colorpicker_stops$$())})}),$handle_rotate_stops$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1190$$)],function(){var $end_p$jscomp$2_gradient$jscomp$28$$=$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$),$mtx$jscomp$8$$=
$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$(90,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(.5,.5)),$start_p$jscomp$9$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1735$start_x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$28$$),$APP.$cljs$cst$1736$start_y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$28$$)),$mtx$jscomp$8$$);
$end_p$jscomp$2_gradient$jscomp$28$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1737$end_x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$28$$),$APP.$cljs$cst$1738$end_y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$28$$)),$mtx$jscomp$8$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_gradient$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1735$start_x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$9$$),$APP.$cljs$cst$1736$start_y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$9$$),$APP.$cljs$cst$1737$end_x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$28$$),$APP.$cljs$cst$1738$end_y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$2_gradient$jscomp$28$$)],null)))}),$handle_reverse_stops$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$))],
function(){var $stops$jscomp$19$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($it$jscomp$277$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($it$jscomp$277$$,$APP.$cljs$cst$195$offset$$,function($p1__78619_SHARP_$$){return 1+-1*$p1__78619_SHARP_$$})},$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$))));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($stops$jscomp$19$$))}),$handle_reorder_stops$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$))],function($from_index$jscomp$11_new_stops$jscomp$1$$,$to_index$jscomp$18$$){var $stops$jscomp$20_stops__$1$jscomp$7$$=$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$);
$from_index$jscomp$11_new_stops$jscomp$1$$=$APP.$app$common$data$insert_at_index$$($stops$jscomp$20_stops__$1$jscomp$7$$,$to_index$jscomp$18$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$20_stops__$1$jscomp$7$$,$from_index$jscomp$11_new_stops$jscomp$1$$)],null));$stops$jscomp$20_stops__$1$jscomp$7$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$3$(function($p1__78621_SHARP_$$,
$p2__78620_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p2__78620_SHARP_$$,$APP.$cljs$cst$195$offset$$,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($p1__78621_SHARP_$$))},$stops$jscomp$20_stops__$1$jscomp$7$$,$from_index$jscomp$11_new_stops$jscomp$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($stops$jscomp$20_stops__$1$jscomp$7$$))}),$render_wasm_QMARK_$jscomp$3$$=
$APP.$app$main$features$use_feature$$("render-wasm/v1"),$tabs$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4634$aria_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.rgba"),$APP.$cljs$cst$1727$icon$$,"rgba",$APP.$cljs$cst$266$id$$,"ramp"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4634$aria_label$$,"Harmony",$APP.$cljs$cst$1727$icon$$,"rgba-complementary",$APP.$cljs$cst$266$id$$,"harmony"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4634$aria_label$$,"HSBA",$APP.$cljs$cst$1727$icon$$,"hsva",$APP.$cljs$cst$266$id$$,"hsva"],null)],null)}),$show_tokens_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5710$color_selection$$,null,$APP.$cljs$cst$1745$stroke_color$$,
null,$APP.$cljs$cst$1408$fill$$,null],null),null),$color_origin$jscomp$2$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$initialize_colorpicker$$($on_change$jscomp$44$$,$active_fill_tab$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$stop_picker$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$finalize_colorpicker$$()]))}});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$469$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($should_update_QMARK_$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker$$($data$jscomp$469$$)):null});$app$main$ui$workspace$colorpicker$use_color_picker_css_variables_BANG_$$($node_ref$jscomp$4$$,$current_color$jscomp$3$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($picking_color_QMARK_$$),
$APP.$rumext$v2$adapt$$($picked_color$$),$APP.$rumext$v2$adapt$$($picked_color_select$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($picking_color_QMARK_$$)?$APP.$cljs$core$truth_$$($picked_color$$)?$picked_color_select$$:$picked_color$$:$picking_color_QMARK_$$)){var $G__78635_r$jscomp$139$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($picked_color$$,0,null),$g$jscomp$161$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($picked_color$$,1,null),$b$jscomp$360$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($picked_color$$,2,null),$alpha$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($picked_color$$,3,null),$hex$jscomp$16$$=$APP.$app$common$types$color$rgb__GT_hex$$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__78635_r$jscomp$139$$,$g$jscomp$161$$,$b$jscomp$360$$],null)),$v$jscomp$667_vec__78632$$=$app$common$types$color$hex__GT_hsv$$($hex$jscomp$16$$),$h$jscomp$182$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$667_vec__78632$$,
0,null),$s$jscomp$587$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$667_vec__78632$$,1,null);$v$jscomp$667_vec__78632$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$667_vec__78632$$,2,null);$G__78635_r$jscomp$139$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$2698$hex$$,$hex$jscomp$16$$,$APP.$cljs$cst$1749$r$$,$G__78635_r$jscomp$139$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$161$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$360$$,$APP.$cljs$cst$1907$h$$,
$h$jscomp$182$$,$APP.$cljs$cst$4235$s$$,$s$jscomp$587$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$667_vec__78632$$,$APP.$cljs$cst$746$alpha$$,$alpha$jscomp$19$$/255],null);return $handle_change_color$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change_color$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__78635_r$jscomp$139$$):$handle_change_color$jscomp$1$$($G__78635_r$jscomp$139$$)}return null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{ref:$node_ref$jscomp$4$$,style:{touchAction:"none"},className:"main_ui_workspace_colorpicker__colorpicker",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker__top-actions",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker__top-actions-right",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_style$jscomp$1$$,$cljs$cst$5706$direct_color$$)&&($APP.$cljs$core$not$$($disable_gradient$jscomp$2$$)||$APP.$cljs$core$not$$($disable_image$jscomp$2$$))?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$color_type$jscomp$2_selected_mode$$,options:$options$jscomp$610$$,"on-change":$handle_change_mode$$})}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($origin$jscomp$69_props_78623$$,$cljs$cst$5688$sidebar$$)&&$show_tokens_QMARK_$$&&$token_color$jscomp$1$$?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,
{selected:$color_style$jscomp$1$$,"on-change":$tab$jscomp$7_toggle_token_color$$,name:"color-style",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"swatches",value:$cljs$cst$5706$direct_color$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.color"),id:"opt-color"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"tokens",value:$APP.$cljs$cst$1214$token_color$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.colorpicker.color-tokens"),
id:"opt-token-color"})]}):null]}),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_type$jscomp$2_selected_mode$$,$APP.$cljs$cst$1617$image$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_style$jscomp$1$$,$cljs$cst$5706$direct_color$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_click_picker$$,className:"main_ui_workspace_colorpicker__picker-btn "+($APP.$cljs$core$truth_$$($picking_color_QMARK_$$)?"main_ui_workspace_colorpicker__selected":""),children:$APP.$app$main$ui$icons$picker$$}):
null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_style$jscomp$1$$,$APP.$cljs$cst$1214$token_color$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__token-color-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.colorpicker.color-tokens")}):null]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_style$jscomp$1$$,$cljs$cst$5706$direct_color$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_type$jscomp$2_selected_mode$$,
$APP.$cljs$cst$1730$gradient$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$gradients$gradients_STAR_$$,{stops:$render_wasm_QMARK_$jscomp$3$$?$APP.$cljs$core$vec$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(16,$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$))):$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$),onSelectStop:$handle_change_gradient_selected_stop$$,onStopEditStart:$handle_stop_edit_start$$,onReverseStops:$handle_reverse_stops$$,
onAddStopPreview:$handle_gradient_add_stop_preview$$,onChangeStop:$handle_gradient_change_stop$$,onStopEditFinish:$handle_stop_edit_finish$$,editingStop:$APP.$cljs$cst$4229$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$),onChangeType:$handle_change_gradient_type$$,onReorderStops:$handle_reorder_stops$$,type:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1190$$),onRemoveStop:$handle_gradient_remove_stop$$,onAddStopAuto:$handle_gradient_add_stop_auto$$,
onRotateStops:$handle_rotate_stops$$}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_type$jscomp$2_selected_mode$$,$APP.$cljs$cst$1617$image$$)?function(){var $uri$jscomp$113$$=$APP.$app$config$resolve_file_media$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$)),$keep_aspect_ratio_QMARK_$jscomp$1$$=$APP.$cljs$cst$1733$keep_aspect_ratio$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$));
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker__select-image",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__content",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$))?(0,$APP.$rumext$v2$jsx$$)("img",{src:$uri$jscomp$113$$}):null}),$APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($current_color$jscomp$3$$)!=null?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_colorpicker__checkbox-option",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"keep-aspect-ratio",className:$APP.$cljs$core$truth_$$($keep_aspect_ratio_QMARK_$jscomp$1$$)?"checked":"",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$truth_$$($keep_aspect_ratio_QMARK_$jscomp$1$$)?"checked":"",children:$APP.$cljs$core$truth_$$($keep_aspect_ratio_QMARK_$jscomp$1$$)?$APP.$app$main$ui$icons$status_tick$$:null}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.keep-aspect-ratio"),
(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"keep-aspect-ratio",checked:$keep_aspect_ratio_QMARK_$jscomp$1$$,onChange:$handle_change_keep_aspect_ratio$$})]})}):null,(0,$APP.$rumext$v2$jsxs$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.choose-image"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.choose-image"),onClick:$on_fill_image_click$$,className:"main_ui_workspace_colorpicker__choose-image",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.choose-image"),
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{"input-id":"fill-image-upload",accept:"image/jpeg,image/png",multi:!1,ref:$fill_image_ref$$,"on-selected":$on_fill_image_selected$$})]})]})}():(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__colorpicker-tabs",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,{tabs:$tabs$jscomp$3$$,
selected:$active_color_tab$$,onChange:$on_change_tab$$,children:$APP.$cljs$core$truth_$$($picking_color_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_colorpicker__picker-detail-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__center-circle"}),(0,$APP.$rumext$v2$jsx$$)("canvas",{id:"picker-detail",width:256,height:140,className:"main_ui_workspace_colorpicker__picker-detail"})]}):function(){switch($active_color_tab$$){case "ramp":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$ramp$ramp_selector_STAR_$$,
{color:$current_color$jscomp$3$$,disableOpacity:$disable_opacity$jscomp$6$$,onChange:$handle_change_color$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$5$$,onFinishDrag:$on_finish_drag$jscomp$5$$});case "harmony":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$harmony$harmony_selector_STAR_$$,{color:$current_color$jscomp$3$$,disableOpacity:$disable_opacity$jscomp$6$$,onChange:$handle_change_color$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$5$$,onFinishDrag:$on_finish_drag$jscomp$5$$});
case "hsva":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$hsva$hsva_selector_STAR_$$,{color:$current_color$jscomp$3$$,disableOpacity:$disable_opacity$jscomp$6$$,mode:$hsb_mode$jscomp$1$$,onChange:$handle_change_color$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$5$$,onFinishDrag:$on_finish_drag$jscomp$5$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($active_color_tab$$)].join(""));}}()})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_inputs$color_inputs_STAR_$$,
{type:$type$jscomp$615$$,disableOpacity:$disable_opacity$jscomp$6$$,mode:$hsb_mode$jscomp$1$$,onModeChange:function($p1__78622_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($hsb_mode_STAR_$$,$p1__78622_SHARP_$$)},color:$current_color$jscomp$3$$,onChange:$handle_change_color$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$libraries$libraries_STAR_$$,{state:$state$jscomp$1190$$,currentColor:$current_color$jscomp$3$$,disableGradient:$disable_gradient$jscomp$2$$,disableOpacity:$disable_opacity$jscomp$6$$,
disableImage:$disable_image$jscomp$2$$,onSelectColor:$on_select_library_color$$,onAddLibraryColor:$on_add_library_color$jscomp$1$$})]})]}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$color_tokens$token_section_STAR_$$,{combinedTokens:$combined_tokens$jscomp$3$$,onTokenChange:$on_token_change$jscomp$3$$,appliedToken:$applied_token$jscomp$3$$,colorOrigin:$color_origin$jscomp$2$$})]}),$APP.$cljs$core$fn_QMARK_$$($on_accept$jscomp$12$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_colorpicker__actions",
children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_color_accept$$,disabled:$disabled_color_accept_QMARK_$$,className:"main_ui_workspace_colorpicker__accept-color "+($disabled_color_accept_QMARK_$$?"main_ui_workspace_colorpicker__btn-disabled":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.save-color")})}):null]})};
$app$main$ui$workspace$colorpicker$calculate_position$$=function($left_offset_map__78638__$1_p__78637_rulers_QMARK_$$,$position$jscomp$197$$,$x$jscomp$1252$$,$y$jscomp$473$$,$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$){$left_offset_map__78638__$1_p__78637_rulers_QMARK_$$=$APP.$cljs$core$__destructure_map$$($left_offset_map__78638__$1_p__78637_rulers_QMARK_$$);$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($left_offset_map__78638__$1_p__78637_rulers_QMARK_$$,
$APP.$cljs$cst$1527$height$$)-($APP.$cljs$core$truth_$$($gradient_QMARK_$jscomp$1_max_y$jscomp$2$$)?820:510);$left_offset_map__78638__$1_p__78637_rulers_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$rulers_QMARK_$$);$left_offset_map__78638__$1_p__78637_rulers_QMARK_$$=$APP.$cljs$core$truth_$$($left_offset_map__78638__$1_p__78637_rulers_QMARK_$$)?40:18;var $top_offset$$=""+($y$jscomp$473$$-70)+"px",$max_height_top$$=["calc(100vh - ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($top_offset$$)].join("");
return $x$jscomp$1252$$==null||$y$jscomp$473$$==null?{left:"auto",right:"16rem",top:"4rem",maxHeight:"calc(100vh - 4rem)"}:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$197$$,$APP.$cljs$cst$257$left$$)?$y$jscomp$473$$>$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$?{left:""+($x$jscomp$1252$$-324)+"px",bottom:"1rem",maxHeight:"calc(100vh -1rem"}:{left:""+($x$jscomp$1252$$-324)+"px",top:$top_offset$$,maxHeight:$max_height_top$$}:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$197$$,
$APP.$cljs$cst$258$right$$)?$y$jscomp$473$$>$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$?{left:""+($x$jscomp$1252$$+80??"")+"px",bottom:"1rem",maxHeight:"calc(100vh -1rem"}:{left:""+($x$jscomp$1252$$+80??"")+"px",top:$top_offset$$,maxHeight:$max_height_top$$}:$y$jscomp$473$$>$gradient_QMARK_$jscomp$1_max_y$jscomp$2$$?{left:""+($x$jscomp$1252$$+$left_offset_map__78638__$1_p__78637_rulers_QMARK_$$??"")+"px",bottom:"1rem",maxHeight:"calc(100vh -1rem"}:{left:""+($x$jscomp$1252$$+$left_offset_map__78638__$1_p__78637_rulers_QMARK_$$??
"")+"px",top:$top_offset$$,maxHeight:$max_height_top$$}};
$app$main$ui$workspace$colorpicker$group_sets$$=function($sets$jscomp$17$$){return $APP.$cljs$core$flatten$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($grouped_sets_p__78639$$){var $group$jscomp$51$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($grouped_sets_p__78639$$,0,null);$grouped_sets_p__78639$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($grouped_sets_p__78639$$,1,null);return $APP.$cljs$core$truth_$$($group$jscomp$51$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1613$group$$,$group$jscomp$51$$,$APP.$cljs$cst$2116$sets$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$930_p__78644$$){var $map__78645__$1_set$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$930_p__78644$$);$id$jscomp$930_p__78644$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78645__$1_set$jscomp$18$$,$APP.$cljs$cst$266$id$$);$map__78645__$1_set$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78645__$1_set$jscomp$18$$,
$APP.$cljs$cst$203$set$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$id$jscomp$930_p__78644$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$last$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($map__78645__$1_set$jscomp$18$$,/\//))],null)},$grouped_sets_p__78639$$),$APP.$cljs$cst$2108$tokens$$,$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2108$tokens$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$grouped_sets_p__78639$$]))))],null):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$931_p__78646$$){var $map__78647__$1_tokens$jscomp$46$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$931_p__78646$$);$id$jscomp$931_p__78646$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78647__$1_tokens$jscomp$46$$,$APP.$cljs$cst$266$id$$);var $set$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78647__$1_tokens$jscomp$46$$,
$APP.$cljs$cst$203$set$$);$map__78647__$1_tokens$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78647__$1_tokens$jscomp$46$$,$APP.$cljs$cst$2108$tokens$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1613$group$$,null,$APP.$cljs$cst$2116$sets$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$id$jscomp$931_p__78646$$,$APP.$cljs$cst$725$name$$,
$set$jscomp$19$$],null)],null),$APP.$cljs$cst$2108$tokens$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$map__78647__$1_tokens$jscomp$46$$)],null)},$grouped_sets_p__78639$$)},$APP.$cljs$core$group_by$$(function($map__78652__$1_p__78651_set$jscomp$20$$){$map__78652__$1_p__78651_set$jscomp$20$$=$APP.$cljs$core$__destructure_map$$($map__78652__$1_p__78651_set$jscomp$20$$);$map__78652__$1_p__78651_set$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78652__$1_p__78651_set$jscomp$20$$,
$APP.$cljs$cst$203$set$$);return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($map__78652__$1_p__78651_set$jscomp$20$$,"/"))?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("/",$APP.$cljs$core$butlast$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($map__78652__$1_p__78651_set$jscomp$20$$,/\//))):null},$sets$jscomp$17$$)))};
$app$main$ui$workspace$colorpicker$combine_groups_with_resolved$$=function($groups$jscomp$7$$,$resolved_tokens$jscomp$24$$){var $token_map$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$identity$$),$resolved_tokens$jscomp$24$$));return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($group$jscomp$52_p__78656$$){var $map__78657__$1_tokens$jscomp$47$$=
$APP.$cljs$core$__destructure_map$$($group$jscomp$52_p__78656$$);$group$jscomp$52_p__78656$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78657__$1_tokens$jscomp$47$$,$APP.$cljs$cst$1613$group$$);var $sets$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78657__$1_tokens$jscomp$47$$,$APP.$cljs$cst$2116$sets$$);$map__78657__$1_tokens$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78657__$1_tokens$jscomp$47$$,$APP.$cljs$cst$2108$tokens$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1613$group$$,$group$jscomp$52_p__78656$$,$APP.$cljs$cst$2116$sets$$,$sets$jscomp$18$$,$APP.$cljs$cst$2108$tokens$$,$APP.$cljs$core$vec$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78654_SHARP_$$){var $or__5025__auto__$jscomp$1139_or__5025__auto____$1$jscomp$121$$=$p1__78654_SHARP_$$==null;if($or__5025__auto__$jscomp$1139_or__5025__auto____$1$jscomp$121$$)return $or__5025__auto__$jscomp$1139_or__5025__auto____$1$jscomp$121$$;
$or__5025__auto__$jscomp$1139_or__5025__auto____$1$jscomp$121$$=$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($p1__78654_SHARP_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1139_or__5025__auto____$1$jscomp$121$$)?$or__5025__auto__$jscomp$1139_or__5025__auto____$1$jscomp$121$$:$APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($p1__78654_SHARP_$$)==null},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78653_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token_map$jscomp$1$$,
$p1__78653_SHARP_$$)},$map__78657__$1_tokens$jscomp$47$$)))],null)},$groups$jscomp$7$$)};
$app$main$ui$workspace$colorpicker$filter_non_empty_sets$$=function($sets$jscomp$19$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($map__78661__$1_p__78660_tokens$jscomp$48$$){$map__78661__$1_p__78660_tokens$jscomp$48$$=$APP.$cljs$core$__destructure_map$$($map__78661__$1_p__78660_tokens$jscomp$48$$);$map__78661__$1_p__78660_tokens$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78661__$1_p__78660_tokens$jscomp$48$$,$APP.$cljs$cst$2108$tokens$$);
return $APP.$cljs$core$some$$(function($p1__78658_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78658_SHARP_$$),$APP.$cljs$cst$1303$color$$)},$map__78661__$1_p__78660_tokens$jscomp$48$$)},$sets$jscomp$19$$)};
$app$main$ui$workspace$colorpicker$add_tokens_to_sets$$=function($sets$jscomp$20$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($s$jscomp$588$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$203$set$$,$APP.$app$common$types$tokens_lib$get_name$$($s$jscomp$588$$),$APP.$cljs$cst$266$id$$,$APP.$app$common$types$tokens_lib$get_id$$($s$jscomp$588$$),$APP.$cljs$cst$2108$tokens$$,$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens_$$($s$jscomp$588$$))],
null)},$sets$jscomp$20$$)};$app$main$ui$workspace$colorpicker$filter_active_sets$$=function($sets$jscomp$21$$,$active_set_names$jscomp$5$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78662_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($active_set_names$jscomp$5$$,$APP.$cljs$cst$203$set$$.$cljs$core$IFn$_invoke$arity$1$($p1__78662_SHARP_$$))},$sets$jscomp$21$$)};
$app$main$ui$workspace$colorpicker$colorpicker_modal$$=function($props_78664_vport$jscomp$8$$){var $style$jscomp$71_x$jscomp$1253$$=$props_78664_vport$jscomp$8$$.x,$tab$jscomp$8$$=$props_78664_vport$jscomp$8$$.tab,$on_change$jscomp$45$$=$props_78664_vport$jscomp$8$$["on-change"],$data$jscomp$470$$=$props_78664_vport$jscomp$8$$.data,$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$=$props_78664_vport$jscomp$8$$.y,$disable_gradient$jscomp$3$$=$props_78664_vport$jscomp$8$$["disable-gradient"],
$disable_opacity$jscomp$7$$=$props_78664_vport$jscomp$8$$["disable-opacity"],$on_token_change$jscomp$4$$=$props_78664_vport$jscomp$8$$["on-token-change"],$disable_image$jscomp$3$$=$props_78664_vport$jscomp$8$$["disable-image"],$on_close$jscomp$17$$=$props_78664_vport$jscomp$8$$["on-close"],$applied_token$jscomp$4$$=$props_78664_vport$jscomp$8$$["applied-token"],$active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$=$props_78664_vport$jscomp$8$$["active-tokens"],$on_accept$jscomp$13$$=$props_78664_vport$jscomp$8$$["on-accept"],
$color_origin$jscomp$3$$=$props_78664_vport$jscomp$8$$["color-origin"],$origin$jscomp$70$$=$props_78664_vport$jscomp$8$$.origin,$position$jscomp$198_position__$1$jscomp$8$$=$props_78664_vport$jscomp$8$$.position;$props_78664_vport$jscomp$8$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$colorpicker$viewport$$);var $dirty_QMARK_$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$last_change$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$position$jscomp$198_position__$1$jscomp$8$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$198_position__$1$jscomp$8$$,$APP.$cljs$cst$257$left$$);$style$jscomp$71_x$jscomp$1253$$=$app$main$ui$workspace$colorpicker$calculate_position$$($props_78664_vport$jscomp$8$$,$position$jscomp$198_position__$1$jscomp$8$$,$style$jscomp$71_x$jscomp$1253$$,$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$,$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$470$$)!=null);
$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$=$APP.$cljs$core$object_QMARK_$$($active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$)?$APP.$rumext$v2$util$bean$$($active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$):$active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$;$active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$45$$)],function($new_data$jscomp$3$$){$APP.$cljs$core$reset_BANG_$$($dirty_QMARK_$$,
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$470$$,$new_data$jscomp$3$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_data$jscomp$3$$,$APP.$cljs$core$_deref$$($last_change$$))?($APP.$cljs$core$reset_BANG_$$($last_change$$,$new_data$jscomp$3$$),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$45$$)?$on_change$jscomp$45$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$45$$.$cljs$core$IFn$_invoke$arity$1$($new_data$jscomp$3$$):$on_change$jscomp$45$$($new_data$jscomp$3$$):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker$$($new_data$jscomp$3$$))):null});var $tokens_lib$jscomp$38$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$),$active_sets_names$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$38$$)],function(){return $tokens_lib$jscomp$38$$==null?null:$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($tokens_lib$jscomp$38$$)});
$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$=$APP.$cljs$core$delay_QMARK_$$($active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$)?$APP.$cljs$core$_deref$$($active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$):$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$;var $color_tokens$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$);
$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$38$$),$APP.$rumext$v2$adapt$$($active_sets_names$$),$APP.$rumext$v2$adapt$$($color_tokens$$)],function(){var $G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$=$tokens_lib$jscomp$38$$==null?null:$APP.$app$common$types$tokens_lib$get_sets$$($tokens_lib$jscomp$38$$);$G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$=
$G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$==null?null:$app$main$ui$workspace$colorpicker$add_tokens_to_sets$$($G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$);$G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$=$G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$==null?null:$app$main$ui$workspace$colorpicker$filter_active_sets$$($G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$,$active_sets_names$$);$G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$=
$G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$==null?null:$app$main$ui$workspace$colorpicker$filter_non_empty_sets$$($G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$);$G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$=$G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$==null?null:$app$main$ui$workspace$colorpicker$group_sets$$($G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$);return $G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$==
null?null:$app$main$ui$workspace$colorpicker$combine_groups_with_resolved$$($G__78670__$1_G__78670__$2_G__78670__$3_G__78670__$4_G__78670__$5$$,$color_tokens$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($cljs$cst$5711$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_colorpicker$$,
$app$main$ui$workspace$colorpicker$shortcuts$shortcuts$$)));return function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($cljs$cst$5711$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_colorpicker$$));var $G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$=$APP.$cljs$core$_deref$$($dirty_QMARK_$$);$APP.$cljs$core$truth_$$($G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$)&&
($G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$=$APP.$cljs$core$_deref$$($last_change$$),$G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$=$APP.$cljs$core$truth_$$($G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$)?$on_close$jscomp$17$$:$G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$);
return $APP.$cljs$core$truth_$$($G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$)?($G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$=$APP.$cljs$core$_deref$$($last_change$$),$on_close$jscomp$17$$.$cljs$core$IFn$_invoke$arity$1$?$on_close$jscomp$17$$.$cljs$core$IFn$_invoke$arity$1$($G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$):
$on_close$jscomp$17$$($G__78671_JSCompiler_inline_result$jscomp$1755_and__5023__auto__$jscomp$inline_8900_and__5023__auto____$1$jscomp$inline_8901$$)):null}});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"colorpicker",style:$style$jscomp$71_x$jscomp$1253$$,className:"main_ui_workspace_colorpicker__colorpicker-tooltip",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$colorpicker_STAR_$$,{tab:$tab$jscomp$8$$,origin:$origin$jscomp$70$$,onChange:$active_tokens$jscomp$5_on_change_SINGLEQUOTE_$jscomp$4$$,
disableOpacity:$disable_opacity$jscomp$7$$,colorOrigin:$color_origin$jscomp$3$$,onTokenChange:$on_token_change$jscomp$4$$,appliedToken:$applied_token$jscomp$4$$,disableGradient:$disable_gradient$jscomp$3$$,disableImage:$disable_image$jscomp$3$$,onAccept:$on_accept$jscomp$13$$,data:$data$jscomp$470$$,combinedTokens:$active_tokens__$1$jscomp$1_active_tokens__$2_grouped_tokens_by_set_y$jscomp$474$$})})};
$app$main$ui$workspace$context_menu$prevent_default$$=function($event$jscomp$335$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$335$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$335$$)};
$app$main$ui$workspace$context_menu$menu_entry_STAR_$$=function($on_unmount_props_77946$$){var $children$jscomp$298$$=$on_unmount_props_77946$$.children,$on_pointer_leave$jscomp$4$$=$on_unmount_props_77946$$.onPointerLeave,$disabled$jscomp$14$$=$on_unmount_props_77946$$.disabled,$is_selected$jscomp$5$$=$on_unmount_props_77946$$.isSelected,$on_pointer_enter$jscomp$4$$=$on_unmount_props_77946$$.onPointerEnter,$value$jscomp$805$$=$on_unmount_props_77946$$.value,$icon$jscomp$20$$=$on_unmount_props_77946$$.icon,
$title$jscomp$37$$=$on_unmount_props_77946$$.title,$shortcut$jscomp$7$$=$on_unmount_props_77946$$.shortcut,$on_click$jscomp$39$$=$on_unmount_props_77946$$.onClick;$on_unmount_props_77946$$=$on_unmount_props_77946$$.onUnmount;var $submenu_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$hovering_QMARK_$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$on_click_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$39$$)],function($event$jscomp$336$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$hide_context_menu$$);
return $APP.$cljs$core$truth_$$($on_click$jscomp$39$$)?$on_click$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$39$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$336$$):$on_click$jscomp$39$$($event$jscomp$336$$):null}),$on_pointer_enter__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($hovering_QMARK_$$,!0);var $submenu_node_78130$$=$APP.$rumext$v2$ref_val$$($submenu_ref$$);$submenu_node_78130$$!=null&&$APP.$app$util$dom$set_css_property_BANG_$$($submenu_node_78130$$,
"display","block");return $APP.$cljs$core$truth_$$($on_pointer_enter$jscomp$4$$)?$on_pointer_enter$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_pointer_enter$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_pointer_enter$jscomp$4$$():null}),$on_pointer_leave__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($hovering_QMARK_$$,!1);var $submenu_node_78131$$=$APP.$rumext$v2$ref_val$$($submenu_ref$$);$submenu_node_78131$$!=null&&$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(200,
function(){return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($hovering_QMARK_$$))?null:$APP.$app$util$dom$set_css_property_BANG_$$($submenu_node_78131$$,"display","none")});return $APP.$cljs$core$truth_$$($on_pointer_leave$jscomp$4$$)?$on_pointer_leave$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_pointer_leave$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_pointer_leave$jscomp$4$$():null}),$set_dom_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($dom$jscomp$1$$){var $submenu_node$$=
$APP.$rumext$v2$ref_val$$($submenu_ref$$);return $dom$jscomp$1$$!=null&&$submenu_node$$!=null?$APP.$app$util$dom$set_css_property_BANG_$$($submenu_node$$,"top",[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($dom$jscomp$1$$.offsetTop),"px"].join("")):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_unmount_props_77946$$)],$APP.$cljs$core$constantly$$($on_unmount_props_77946$$));return $APP.$cljs$core$truth_$$($icon$jscomp$20$$)?(0,$APP.$rumext$v2$jsxs$$)("li",
{disabled:$disabled$jscomp$14$$,"data-value":$value$jscomp$805$$,ref:$set_dom_node$$,onClick:$on_click_SINGLEQUOTE_$$,onPointerEnter:$on_pointer_enter__$1$$,onPointerLeave:$on_pointer_leave__$1$$,className:"main_ui_workspace_context_menu__icon-menu-item",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_context_menu__icon-wrapper",children:[$APP.$cljs$core$truth_$$($is_selected$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__selected-icon",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s"})}):(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__selected-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__shape-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$20$$,size:"s"})})]}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__title",
children:$title$jscomp$37$$})]}):(0,$APP.$rumext$v2$jsxs$$)("li",{disabled:$disabled$jscomp$14$$,ref:$set_dom_node$$,"data-value":$value$jscomp$805$$,onClick:$on_click_SINGLEQUOTE_$$,onPointerEnter:$on_pointer_enter__$1$$,onPointerLeave:$on_pointer_leave__$1$$,className:"main_ui_workspace_context_menu__context-menu-item",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__title",children:$title$jscomp$37$$}),$APP.$cljs$core$truth_$$($shortcut$jscomp$7$$)?(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_context_menu__shortcut",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$126$$,$p__77947_sc$jscomp$9$$){var $idx$jscomp$114$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77947_sc$jscomp$9$$,0,null);$p__77947_sc$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77947_sc$jscomp$9$$,1,null);$out_arr__44092__auto__$jscomp$126$$.push((0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__shortcut-key",
children:$p__77947_sc$jscomp$9$$},""+($shortcut$jscomp$7$$??"")+"-"+($idx$jscomp$114$$??"")));return $out_arr__44092__auto__$jscomp$126$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$main$data$shortcuts$split_sc$$($shortcut$jscomp$7$$)))}):null,$APP.$cljs$core$count$$($children$jscomp$298$$)>1?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_context_menu__submenu-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow",size:"s"})}):null,$APP.$cljs$core$count$$($children$jscomp$298$$)>1?(0,$APP.$rumext$v2$jsx$$)("ul",{ref:$submenu_ref$$,style:{display:"none",left:250},onContextMenu:$app$main$ui$workspace$context_menu$prevent_default$$,className:"main_ui_workspace_context_menu__workspace-context-submenu",children:$children$jscomp$298$$}):null]})};$app$main$ui$workspace$context_menu$menu_separator_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_context_menu__separator"})};
$app$main$ui$workspace$context_menu$context_menu_edit_STAR_$$=function($props_77953_shapes$jscomp$192$$){$props_77953_shapes$jscomp$192$$=$props_77953_shapes$jscomp$192$$.shapes;var $multiple_QMARK_$jscomp$2$$=$APP.$cljs$core$count$$($props_77953_shapes$jscomp$192$$)>1,$enabled_paste_props_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$handle_copy_css$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_selected_css$$())}),
$handle_copy_css_nested$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_selected_css_nested$$())}),$handle_copy_props$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_selected_props$$())}),$handle_paste_props$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$paste_selected_props$$())}),$handle_copy_svg$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_selected_svg$$())}),$handle_copy_text$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_selected_text$$())}),
$handle_copy_as_image$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$copy_as_image$$())}),$handle_hover_copy_paste$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($data$jscomp$471$$){try{var $pdata$jscomp$12$$=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$471$$),
$and__5023__auto__$jscomp$inline_8903$$=(0,$APP.$app$main$data$workspace$clipboard$paste_data_valid_QMARK_$$)($pdata$jscomp$12$$);var $JSCompiler_inline_result$jscomp$1756$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_8903$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4177$copied_props$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($pdata$jscomp$12$$)):$and__5023__auto__$jscomp$inline_8903$$;return $APP.$cljs$core$reset_BANG_$$($enabled_paste_props_STAR_$$,
$JSCompiler_inline_result$jscomp$1756$$)}catch($e77954$$){return $APP.$cljs$core$reset_BANG_$$($enabled_paste_props_STAR_$$,!1)}},function(){return $APP.$cljs$core$reset_BANG_$$($enabled_paste_props_STAR_$$,!1)},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$mapcat$$(function($p1__77952_SHARP_$$){return $p1__77952_SHARP_$$.text()},$APP.$app$util$clipboard$from_navigator$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$clipboard$default_options$$))))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4910$copy$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_selected$$())}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-link"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4948$copy_link$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$clipboard$copy_link_to_clipboard$$())}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.cut"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4993$cut$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$clipboard$copy_selected$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$delete_selected$$()]))}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.paste"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4944$paste$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$paste_from_clipboard$$.$cljs$core$IFn$_invoke$arity$0$())}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.duplicate"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4903$duplicate$$),
onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$duplicate_or_add_variant$$())}}),(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-paste-as"),onPointerEnter:$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1356$chrome$$)?$handle_hover_copy_paste$$:null,children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-css"),onClick:$handle_copy_css$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-css-nested"),onClick:$handle_copy_css_nested$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-svg"),
onClick:$handle_copy_svg$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$props_77953_shapes$jscomp$192$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-as-image"),disabled:$multiple_QMARK_$jscomp$2$$,onClick:$handle_copy_as_image$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-text"),onClick:$handle_copy_text$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.copy-props"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4942$copy_props$$),disabled:$multiple_QMARK_$jscomp$2$$,
onClick:$handle_copy_props$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.paste-props"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4984$paste_props$$),disabled:$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1356$chrome$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($enabled_paste_props_STAR_$$)),onClick:$handle_paste_props$$})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{})]})};
$app$main$ui$workspace$context_menu$context_menu_layer_position_STAR_$$=function($do_bring_forward_props_77956$$){function $on_unmount$jscomp$1$$($id$jscomp$935$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$highlight$dehighlight_shape$$($id$jscomp$935$$))}}function $on_pointer_leave$jscomp$5$$($id$jscomp$934$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$highlight$dehighlight_shape$$($id$jscomp$934$$))}}function $on_pointer_enter$jscomp$5$$($id$jscomp$933$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$highlight$highlight_shape$$($id$jscomp$933$$))}}
function $select_shapes$$($id$jscomp$932$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_shape$cljs$0core$0IFn$0_invoke$0arity$01$$($id$jscomp$932$$))}}var $shapes$jscomp$193$$=$do_bring_forward_props_77956$$.shapes;$do_bring_forward_props_77956$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1970$up$$,
null))});var $do_bring_to_front$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1567$top$$,null))}),$do_send_backward$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1969$down$$,
null))}),$do_send_to_back$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$vertical_order_selected$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1568$bottom$$,null))}),$hover_ids_hover_objs$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$current_hover_ids$$),$objects$jscomp$776$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);$hover_ids_hover_objs$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$776$$)),$hover_ids_hover_objs$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$count$$($hover_ids_hover_objs$$)>1?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.select-layer"),
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$127$$,$object$jscomp$39$$){$out_arr__44092__auto__$jscomp$127$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$),isSelected:$APP.$cljs$core$some$$(function($p1__77955_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($object$jscomp$39$$,$p1__77955_SHARP_$$)},
$shapes$jscomp$193$$),onClick:$select_shapes$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)),onPointerEnter:$on_pointer_enter$jscomp$5$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)),onPointerLeave:$on_pointer_leave$jscomp$5$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)),onUnmount:$on_unmount$jscomp$1$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)),icon:$APP.$app$util$shape_icon$get_shape_icon$$($object$jscomp$39$$)},
""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($object$jscomp$39$$)??"")));return $out_arr__44092__auto__$jscomp$127$$},[],$hover_ids_hover_objs$$)}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.forward"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4939$bring_forward$$),onClick:$do_bring_forward_props_77956$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.front"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4932$bring_front$$),onClick:$do_bring_to_front$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.backward"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4967$bring_backward$$),onClick:$do_send_backward$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.back"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4992$bring_back$$),onClick:$do_send_to_back$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{})]})};
$app$main$ui$workspace$context_menu$context_menu_flip_STAR_$$=function(){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flip-vertical"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4951$flip_vertical$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$flip_vertical_selected$$.$cljs$core$IFn$_invoke$arity$0$())}}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flip-horizontal"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4940$flip_horizontal$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$flip_horizontal_selected$$.$cljs$core$IFn$_invoke$arity$0$())}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{})]})};
$app$main$ui$workspace$context_menu$context_menu_thumbnail_STAR_$$=function($props_77958_shapes$jscomp$194$$){function $do_toggle_thumbnail$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$toggle_file_thumbnail_selected$$())}$props_77958_shapes$jscomp$194$$=$props_77958_shapes$jscomp$194$$.shapes;var $single_QMARK_$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_77958_shapes$jscomp$194$$),1),
$has_frame_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$props_77958_shapes$jscomp$194$$);return $APP.$cljs$core$truth_$$($single_QMARK_$jscomp$6$$?$has_frame_QMARK_$$:$single_QMARK_$jscomp$6$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$every_QMARK_$$($APP.$cljs$cst$2975$use_for_thumbnail$$,$props_77958_shapes$jscomp$194$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.thumbnail-remove"),
onClick:$do_toggle_thumbnail$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.thumbnail-set"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4988$thumbnail_set$$),onClick:$do_toggle_thumbnail$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{})]}):null};
$app$main$ui$workspace$context_menu$context_menu_rename_STAR_$$=function($props_77959$$){function $do_rename$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_rename_selected$$())}return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_77959$$.shapes),1)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.rename"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4946$rename$$),onClick:$do_rename$$})]}):null};
$app$main$ui$workspace$context_menu$context_menu_group_STAR_$$=function($props_77963_shapes$jscomp$196$$){function $do_create_artboard_from_selection$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$create_artboard_from_selection$cljs$0core$0IFn$0_invoke$0arity$05$$(null,null,null,null))}function $do_unmask_group$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$unmask_group$$.$cljs$core$IFn$_invoke$arity$0$())}
function $do_mask_group$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$mask_group$$.$cljs$core$IFn$_invoke$arity$0$())}function $do_remove_group$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$groups$ungroup_selected$$())}function $do_create_group$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$groups$group_selected$$())}
$props_77963_shapes$jscomp$196$$=$props_77963_shapes$jscomp$196$$.shapes;var $multiple_QMARK_$jscomp$3$$=$APP.$cljs$core$count$$($props_77963_shapes$jscomp$196$$)>1,$single_QMARK_$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_77963_shapes$jscomp$196$$),1),$objects$jscomp$777$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$any_in_copy_QMARK_$$=$APP.$cljs$core$some$$(function($p1__77960_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$777$$,
$p1__77960_SHARP_$$)},$props_77963_shapes$jscomp$196$$),$any_is_variant_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$props_77963_shapes$jscomp$196$$),$has_frame_QMARK_$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77961_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__77961_SHARP_$$)&&!$APP.$app$common$types$component$instance_head_QMARK_$$($p1__77961_SHARP_$$)&&
!$APP.$app$common$types$component$is_variant_container_QMARK_$$($p1__77961_SHARP_$$)},$props_77963_shapes$jscomp$196$$),$has_group_QMARK_$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77962_SHARP_$$){return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__77962_SHARP_$$)&&!$APP.$app$common$types$component$instance_head_QMARK_$$($p1__77962_SHARP_$$)&&!$APP.$app$common$types$component$is_variant_container_QMARK_$$($p1__77962_SHARP_$$)},
$props_77963_shapes$jscomp$196$$),$has_bool_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$bool_shape_QMARK_$$,$props_77963_shapes$jscomp$196$$),$has_mask_QMARK_$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$1614$masked_group$$,$props_77963_shapes$jscomp$196$$),$is_group_QMARK_$jscomp$1$$=$single_QMARK_$jscomp$7$$?$has_group_QMARK_$jscomp$1$$:$single_QMARK_$jscomp$7$$,$is_bool_QMARK_$$=$single_QMARK_$jscomp$7$$?
$has_bool_QMARK_$$:$single_QMARK_$jscomp$7$$;return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($any_in_copy_QMARK_$$)?$any_in_copy_QMARK_$$:$any_is_variant_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_bool_QMARK_$$)?$has_bool_QMARK_$$:$APP.$cljs$core$truth_$$($has_group_QMARK_$jscomp$1$$)?$has_group_QMARK_$jscomp$1$$:$APP.$cljs$core$truth_$$($has_mask_QMARK_$jscomp$1$$)?
$has_mask_QMARK_$jscomp$1$$:$has_frame_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.ungroup"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4973$ungroup$$),onClick:$do_remove_group$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.group"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$1613$group$$),onClick:$do_create_group$$}),$APP.$cljs$core$truth_$$(function(){if($multiple_QMARK_$jscomp$3$$)return $multiple_QMARK_$jscomp$3$$;var $or__5025__auto____$1$jscomp$123$$=$APP.$cljs$core$truth_$$($is_group_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($has_mask_QMARK_$jscomp$1$$):$is_group_QMARK_$jscomp$1$$;return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$123$$)?$or__5025__auto____$1$jscomp$123$$:$is_bool_QMARK_$$}())?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.mask"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$2700$mask$$),onClick:$do_mask_group$$}):null,$APP.$cljs$core$truth_$$($has_mask_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unmask"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4978$unmask$$),onClick:$do_unmask_group$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.create-artboard-from-selection"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4974$artboard_selection$$),onClick:$do_create_artboard_from_selection$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{})]}):null})};
$app$main$ui$workspace$context_menu$context_focus_mode_menu_STAR_$$=function(){var $focus$jscomp$15$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$cljs$core$empty_QMARK_$$($focus$jscomp$15$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.focus.focus-on"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.focus.focus-off"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4950$toggle_focus_mode$$),
onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$toggle_focus_mode$$())}})};
$app$main$ui$workspace$context_menu$context_menu_path_STAR_$$=function($has_path_QMARK_$jscomp$1_props_77979$$){function $make_do_bool$$($bool_type$jscomp$9$$){return function(){if($multiple_QMARK_$jscomp$4$$)var $JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$create_bool$$)($bool_type$jscomp$9$$));
else if($APP.$cljs$core$truth_$$($is_group_QMARK_$jscomp$2$$)){$JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1691_JSCompiler_inline_result$jscomp$1694_param72407$jscomp$inline_8905_param72416$jscomp$inline_8908$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$197$$));
$JSCompiler_inline_result$jscomp$1691_JSCompiler_inline_result$jscomp$1694_param72407$jscomp$inline_8905_param72416$jscomp$inline_8908$$=$app$main$data$workspace$bool$group_to_bool$$($JSCompiler_inline_result$jscomp$1691_JSCompiler_inline_result$jscomp$1694_param72407$jscomp$inline_8905_param72416$jscomp$inline_8908$$,$bool_type$jscomp$9$$);$JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$=$JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$.call($APP.$app$main$store$emit_BANG_$$,
$JSCompiler_inline_result$jscomp$1691_JSCompiler_inline_result$jscomp$1694_param72407$jscomp$inline_8905_param72416$jscomp$inline_8908$$)}else $APP.$cljs$core$truth_$$($is_bool_QMARK_$jscomp$1$$)?($JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$,$JSCompiler_inline_result$jscomp$1691_JSCompiler_inline_result$jscomp$1694_param72407$jscomp$inline_8905_param72416$jscomp$inline_8908$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$197$$)),$JSCompiler_inline_result$jscomp$1691_JSCompiler_inline_result$jscomp$1694_param72407$jscomp$inline_8905_param72416$jscomp$inline_8908$$=$app$main$data$workspace$bool$change_bool_type$$($JSCompiler_inline_result$jscomp$1691_JSCompiler_inline_result$jscomp$1694_param72407$jscomp$inline_8905_param72416$jscomp$inline_8908$$,$bool_type$jscomp$9$$),$JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$=
$JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1691_JSCompiler_inline_result$jscomp$1694_param72407$jscomp$inline_8905_param72416$jscomp$inline_8908$$)):$JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$=null;return $JSCompiler_temp$jscomp$1686_JSCompiler_temp$jscomp$1687_JSCompiler_temp$jscomp$1688_JSCompiler_temp_const$jscomp$1689_JSCompiler_temp_const$jscomp$1692$$}}
function $do_strokes_to_path$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$convert_selected_strokes_to_path$$.$cljs$core$IFn$_invoke$arity$0$())}function $do_transform_to_path$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$convert_selected_to_path$$.$cljs$core$IFn$_invoke$arity$0$())}function $do_start_editing$$(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_editing_selected$$())})}
var $shapes$jscomp$197$$=$has_path_QMARK_$jscomp$1_props_77979$$.shapes,$objects$jscomp$778$$=$has_path_QMARK_$jscomp$1_props_77979$$.objects,$disable_flatten$$=$has_path_QMARK_$jscomp$1_props_77979$$.disableFlatten,$disable_booleans$$=$has_path_QMARK_$jscomp$1_props_77979$$.disableBooleans,$multiple_QMARK_$jscomp$4$$=$APP.$cljs$core$count$$($shapes$jscomp$197$$)>1,$single_QMARK_$jscomp$8$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$197$$),1),$has_group_QMARK_$jscomp$2_is_frame_QMARK_$jscomp$4$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$group_shape_QMARK_$$,$shapes$jscomp$197$$),$has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$bool_shape_QMARK_$$,$shapes$jscomp$197$$),$has_frame_QMARK_$jscomp$2$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$shapes$jscomp$197$$);$has_path_QMARK_$jscomp$1_props_77979$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$path_shape_QMARK_$$,$shapes$jscomp$197$$);var $is_group_QMARK_$jscomp$2$$=$single_QMARK_$jscomp$8$$?$has_group_QMARK_$jscomp$2_is_frame_QMARK_$jscomp$4$$:$single_QMARK_$jscomp$8$$,$is_bool_QMARK_$jscomp$1$$=$single_QMARK_$jscomp$8$$?$has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$:$single_QMARK_$jscomp$8$$;$has_group_QMARK_$jscomp$2_is_frame_QMARK_$jscomp$4$$=$single_QMARK_$jscomp$8$$?$has_frame_QMARK_$jscomp$2$$:
$single_QMARK_$jscomp$8$$;$has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$=function(){var $or__5025__auto__$jscomp$1143$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77973_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$1641$strokes$$.$cljs$core$IFn$_invoke$arity$1$($p1__77973_SHARP_$$))},$shapes$jscomp$197$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1143$$)?$or__5025__auto__$jscomp$1143$$:$APP.$cljs$core$truth_$$($objects$jscomp$778$$)?$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($shape$jscomp$992$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__77974_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$1641$strokes$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$778$$,
$p1__77974_SHARP_$$)))},$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$778$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$992$$)))},$shapes$jscomp$197$$):null}();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$single_QMARK_$jscomp$8$$&&$APP.$cljs$core$not$$($has_group_QMARK_$jscomp$2_is_frame_QMARK_$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.edit"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4971$start_editing$$),onClick:$do_start_editing$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($disable_flatten$$)?$disable_flatten$$:$APP.$cljs$core$truth_$$($has_frame_QMARK_$jscomp$2$$)?$has_frame_QMARK_$jscomp$2$$:$has_path_QMARK_$jscomp$1_props_77979$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flatten"),
onClick:$do_transform_to_path$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$)?$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1193$stroke_path$$):$has_bool_QMARK_$jscomp$1_has_strokes_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.stroke-to-path"),
onClick:$do_strokes_to_path$$}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$769_and__5023__auto____$1$jscomp$134$$=$APP.$cljs$core$not$$($has_frame_QMARK_$jscomp$2$$);return $and__5023__auto__$jscomp$769_and__5023__auto____$1$jscomp$134$$?($and__5023__auto__$jscomp$769_and__5023__auto____$1$jscomp$134$$=$APP.$cljs$core$not$$($disable_booleans$$))?$multiple_QMARK_$jscomp$4$$?$multiple_QMARK_$jscomp$4$$:$single_QMARK_$jscomp$8$$?$APP.$cljs$core$truth_$$($is_group_QMARK_$jscomp$2$$)?
$is_group_QMARK_$jscomp$2$$:$is_bool_QMARK_$jscomp$1$$:$single_QMARK_$jscomp$8$$:$and__5023__auto__$jscomp$769_and__5023__auto____$1$jscomp$134$$:$and__5023__auto__$jscomp$769_and__5023__auto____$1$jscomp$134$$}())?(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.path"),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.union"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4941$bool_union$$),onClick:$make_do_bool$$($APP.$cljs$cst$736$union$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.difference"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4943$bool_difference$$),onClick:$make_do_bool$$($APP.$cljs$cst$2035$difference$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.intersection"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4907$bool_intersection$$),onClick:$make_do_bool$$($APP.$cljs$cst$2044$intersection$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.exclude"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4962$bool_exclude$$),
onClick:$make_do_bool$$($APP.$cljs$cst$2043$exclude$$)}),$APP.$cljs$core$truth_$$($single_QMARK_$jscomp$8$$?$APP.$cljs$core$truth_$$($is_bool_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($disable_flatten$$):$is_bool_QMARK_$jscomp$1$$:$single_QMARK_$jscomp$8$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flatten"),
onClick:$do_transform_to_path$$})]}):null]}):null]})};
$app$main$ui$workspace$context_menu$context_menu_layer_options_STAR_$$=function($props_77985_shapes$jscomp$198$$){function $do_unlock_shape$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$($ids$jscomp$278$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1628$blocked$$,!1],null)))}function $do_lock_shape$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$($ids$jscomp$278$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1628$blocked$$,!0],null)))}function $do_hide_shape$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$($ids$jscomp$278$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1625$hidden$$,!0],null)))}function $do_show_shape$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_shape_flags$$($ids$jscomp$278$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1625$hidden$$,!1],null)))}$props_77985_shapes$jscomp$198$$=$props_77985_shapes$jscomp$198$$.shapes;var $ids$jscomp$278$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$props_77985_shapes$jscomp$198$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$every_QMARK_$$($APP.$cljs$cst$1625$hidden$$,$props_77985_shapes$jscomp$198$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show"),
shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4958$toggle_visibility$$),onClick:$do_show_shape$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.hide"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4958$toggle_visibility$$),onClick:$do_hide_shape$$}),$APP.$cljs$core$every_QMARK_$$($APP.$cljs$cst$1628$blocked$$,$props_77985_shapes$jscomp$198$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unlock"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4980$toggle_lock$$),onClick:$do_unlock_shape$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.lock"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4980$toggle_lock$$),
onClick:$do_lock_shape$$})]})};
$app$main$ui$workspace$context_menu$context_menu_prototype_STAR_$$=function($props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$){function $do_add_flow$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$add_flow_selected_frame$$())}$props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$=$props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$.shapes;var $flows$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_flows$$),$options_mode_prototype_QMARK_$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$options_mode_global$$);$options_mode_prototype_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode_prototype_QMARK_$$,$APP.$cljs$cst$3781$prototype$$);var $single_QMARK_$jscomp$9$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$),1),$has_frame_QMARK_$jscomp$3$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,
$props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$);return $APP.$cljs$core$truth_$$($options_mode_prototype_QMARK_$$?$single_QMARK_$jscomp$9$$?$has_frame_QMARK_$jscomp$3$$:$single_QMARK_$jscomp$9$$:$options_mode_prototype_QMARK_$$)?($props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$=$APP.$app$common$types$page$get_frame_flow$$($flows$jscomp$7$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$))),
$APP.$cljs$core$truth_$$($props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.delete-flow-start"),onClick:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($props_77991_shapes$jscomp$199_temp__5823__auto__$jscomp$229$$)))}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flow-start"),onClick:$do_add_flow$$})):null};
$app$main$ui$workspace$context_menu$context_menu_layout_STAR_$$=function($props_78004_single_QMARK_$jscomp$10$$){var $shapes$jscomp$200$$=$props_78004_single_QMARK_$jscomp$10$$.shapes;$props_78004_single_QMARK_$jscomp$10$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$200$$),1);var $objects$jscomp$779$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$any_in_copy_QMARK_$jscomp$1$$=$APP.$cljs$core$some$$($APP.$cljs$core$true_QMARK_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77999_SHARP_$$){return $APP.$app$common$types$container$has_any_copy_parent_QMARK_$$($objects$jscomp$779$$,$p1__77999_SHARP_$$)},$shapes$jscomp$200$$)),$has_flex_QMARK_$$=$props_78004_single_QMARK_$jscomp$10$$&&$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$,$shapes$jscomp$200$$),$has_grid_QMARK_$$=$props_78004_single_QMARK_$jscomp$10$$&&$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$,
$shapes$jscomp$200$$),$any_is_variant_QMARK_$jscomp$1$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$shapes$jscomp$200$$),$on_add_layout$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$337_type$jscomp$616$$){$event$jscomp$337_type$jscomp$616$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$337_type$jscomp$616$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$shape_layout$create_layout$$($event$jscomp$337_type$jscomp$616$$),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:context-menu"],null)))}),$on_remove_layout$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$200$$)],function(){var $ids$jscomp$279$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$shapes$jscomp$200$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout$$($ids$jscomp$279$$))});
return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$not$$($any_in_copy_QMARK_$jscomp$1$$)?$has_flex_QMARK_$$||$has_grid_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),$has_flex_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-flex"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4916$toggle_layout_flex$$),
onClick:$on_remove_layout$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-grid"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4935$toggle_layout_grid$$),onClick:$on_remove_layout$$})]}):$props_78004_single_QMARK_$jscomp$10$$||$APP.$cljs$core$not$$($any_is_variant_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-flex"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4916$toggle_layout_flex$$),value:"flex",onClick:$on_add_layout$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-grid"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4935$toggle_layout_grid$$),
value:"grid",onClick:$on_add_layout$$})]}):null:null})};
$app$main$ui$workspace$context_menu$context_menu_component_STAR_$$=function($props_78010_single_QMARK_$jscomp$11$$){var $shapes$jscomp$201$$=$props_78010_single_QMARK_$jscomp$11$$.shapes;$props_78010_single_QMARK_$jscomp$11$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($shapes$jscomp$201$$),1);var $objects$jscomp$780$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$can_make_component$jscomp$2$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$true_QMARK_$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78009_SHARP_$$){return $APP.$app$common$types$container$valid_shape_for_component_QMARK_$$($objects$jscomp$780$$,$p1__78009_SHARP_$$)},$shapes$jscomp$201$$)),$components_menu_entries$$=$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$$($shapes$jscomp$201$$),$variant_container_QMARK_$jscomp$1$$=$props_78010_single_QMARK_$jscomp$11$$&&$APP.$app$common$types$component$is_variant_container_QMARK_$$($APP.$cljs$core$first$$($shapes$jscomp$201$$)),
$all_main_QMARK_$jscomp$3$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$component$main_instance_QMARK_$$,$shapes$jscomp$201$$),$any_variant_QMARK_$jscomp$1$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$shapes$jscomp$201$$),$do_add_component$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$add_component$cljs$0core$0IFn$0_invoke$0arity$02$$(null,
null))}),$do_add_multiple_components$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$add_multiple_components$$())}),$do_combine_as_variants$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$variants$combine_selected_as_variants$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$4491$trigger$$,"workspace:context-menu-component"],null)))}),$do_add_variant$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$201$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-variant",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace:context-menu-component"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$201$$)))]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$can_make_component$jscomp$2$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.create-component"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4981$create_component_variant$$),onClick:$do_add_component$$}),$props_78010_single_QMARK_$jscomp$11$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.create-multiple-components"),
onClick:$do_add_multiple_components$$})]}):null,$APP.$cljs$core$seq$$($components_menu_entries$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$128$$,$entry$jscomp$71$$){$out_arr__44092__auto__$jscomp$128$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$cljs$cst$939$title$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$71$$),shortcut:$APP.$cljs$core$contains_QMARK_$$($entry$jscomp$71$$,$cljs$cst$5699$shortcut$$)?$app$main$data$workspace$shortcuts$get_tooltip$$($cljs$cst$5699$shortcut$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$71$$)):null,onClick:$APP.$cljs$cst$2694$action$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$71$$)},$APP.$cljs$cst$939$title$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$71$$)));return $out_arr__44092__auto__$jscomp$128$$},
[],$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$some_QMARK_$$,$components_menu_entries$$))]}):null,$variant_container_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4981$create_component_variant$$),
onClick:$do_add_variant$jscomp$1$$})]}):null,!$props_78010_single_QMARK_$jscomp$11$$&&$all_main_QMARK_$jscomp$3$$&&$APP.$cljs$core$not$$($any_variant_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants"),
onClick:$do_combine_as_variants$$})]}):null]})};
$app$main$ui$workspace$context_menu$context_menu_guides_STAR_$$=function($do_remove_guides_guides$jscomp$12_props_78012_shapes$jscomp$202$$){$do_remove_guides_guides$jscomp$12_props_78012_shapes$jscomp$202$$=$do_remove_guides_guides$jscomp$12_props_78012_shapes$jscomp$202$$.shapes;var $frame_ids$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$frame_shape_QMARK_$$),$APP.$app$common$data$xf_COLON_map_id$$),
$do_remove_guides_guides$jscomp$12_props_78012_shapes$jscomp$202$$);$do_remove_guides_guides$jscomp$12_props_78012_shapes$jscomp$202$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_guides$$);var $has_guides_QMARK_$$=$APP.$cljs$core$some$$(function($p1__78011_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($frame_ids$jscomp$7$$,$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78011_SHARP_$$))},$APP.$cljs$core$vals$$($do_remove_guides_guides$jscomp$12_props_78012_shapes$jscomp$202$$));
$do_remove_guides_guides$jscomp$12_props_78012_shapes$jscomp$202$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_ids$jscomp$7$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$guides$remove_frame_guides$$($frame_ids$jscomp$7$$))});return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$773$$=$APP.$cljs$core$seq$$($frame_ids$jscomp$7$$);return $and__5023__auto__$jscomp$773$$?
$has_guides_QMARK_$$:$and__5023__auto__$jscomp$773$$}())?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.clear-guides"),onClick:$do_remove_guides_guides$jscomp$12_props_78012_shapes$jscomp$202$$})]}):null};
$app$main$ui$workspace$context_menu$context_menu_delete_STAR_$$=function(){return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.delete"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4945$delete$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$delete_selected$$())}})]})};
$app$main$ui$workspace$context_menu$page_item_context_menu_STAR_$$=function($page$jscomp$164_props_78023$$){function $do_delete$jscomp$2$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.title"),$APP.$cljs$cst$141$message$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.body"),$APP.$cljs$cst$2490$on_accept$$,$delete_fn$jscomp$4$$],null)))}function $delete_fn$jscomp$4$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$delete_page$$($id$jscomp$936$$))}var $deletable_QMARK__mdata$jscomp$15$$=$page$jscomp$164_props_78023$$.mdata;$page$jscomp$164_props_78023$$=$APP.$cljs$cst$1629$page$$.$cljs$core$IFn$_invoke$arity$1$($deletable_QMARK__mdata$jscomp$15$$);
$deletable_QMARK__mdata$jscomp$15$$=$cljs$cst$5714$deletable_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($deletable_QMARK__mdata$jscomp$15$$);var $id$jscomp$936$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$164_props_78023$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($deletable_QMARK__mdata$jscomp$15$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),
onClick:$do_delete$jscomp$2$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$start_rename_page_item$$($id$jscomp$936$$))}}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate"),
onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$pages$duplicate_page$$($id$jscomp$936$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"duplicate-page"],null))]))}})]})};
$app$main$ui$workspace$context_menu$viewport_context_menu_STAR_$$=function(){function $do_toggle_focus_mode$jscomp$1$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$toggle_focus_mode$$())}function $do_paste$jscomp$1$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$paste_from_clipboard$$.$cljs$core$IFn$_invoke$arity$0$())}var $focus$jscomp$16$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),
$read_only_QMARK_$jscomp$8$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$read_only_QMARK_$jscomp$8$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.paste"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4944$paste$$),onClick:$do_paste$jscomp$1$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.hide-ui"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$3046$hide_ui$$),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3046$hide_ui$$),
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-context-menu"))}}),$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$16$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.focus.focus-off"),shortcut:$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4950$toggle_focus_mode$$),onClick:$do_toggle_focus_mode$jscomp$1$$}):null]})};
$app$main$ui$workspace$context_menu$grid_track_context_menu_STAR_$$=function($do_delete_track_map__78032__$1_props_78031$$){$do_delete_track_map__78032__$1_props_78031$$=$APP.$cljs$core$__destructure_map$$($do_delete_track_map__78032__$1_props_78031$$.mdata);var $type$jscomp$617$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($do_delete_track_map__78032__$1_props_78031$$,$APP.$cljs$cst$139$type$$),$index$jscomp$474$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($do_delete_track_map__78032__$1_props_78031$$,
$APP.$cljs$cst$1801$index$$),$grid_id$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($do_delete_track_map__78032__$1_props_78031$$,$APP.$cljs$cst$4487$grid_id$$);$do_delete_track_map__78032__$1_props_78031$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$617$$),$APP.$rumext$v2$adapt$$($index$jscomp$474$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$617$$,$index$jscomp$474$$))});var $do_add_track_before$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$617$$),$APP.$rumext$v2$adapt$$($index$jscomp$474$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$617$$,$APP.$app$common$types$shape$layout$default_track_value$$,$index$jscomp$474$$))}),$do_add_track_after$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$617$$),$APP.$rumext$v2$adapt$$($index$jscomp$474$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$617$$,$APP.$app$common$types$shape$layout$default_track_value$$,$index$jscomp$474$$+1))}),$do_duplicate_track$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$617$$),$APP.$rumext$v2$adapt$$($index$jscomp$474$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$duplicate_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$617$$,$index$jscomp$474$$))}),$do_delete_track_shapes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$27$$),$APP.$rumext$v2$adapt$$($type$jscomp$617$$),$APP.$rumext$v2$adapt$$($index$jscomp$474$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$grid_id$jscomp$27$$],null),$type$jscomp$617$$,$index$jscomp$474$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4471$with_shapes_QMARK_$$,!0],null)])))});return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$617$$,$APP.$cljs$cst$216$column$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.duplicate"),onClick:$do_duplicate_track$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.add-before"),onClick:$do_add_track_before$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.add-after"),
onClick:$do_add_track_after$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.delete"),onClick:$do_delete_track_map__78032__$1_props_78031$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.column.delete-shapes"),onClick:$do_delete_track_shapes$$})]}):
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.duplicate"),onClick:$do_duplicate_track$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.add-before"),onClick:$do_add_track_before$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.add-after"),onClick:$do_add_track_after$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.delete"),onClick:$do_delete_track_map__78032__$1_props_78031$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-track.row.delete-shapes"),onClick:$do_delete_track_shapes$$})]})};
$app$main$ui$workspace$context_menu$grid_cells_context_menu_STAR_$$=function($map__78047__$1_props_78042_single_QMARK_$jscomp$12$$){$map__78047__$1_props_78042_single_QMARK_$jscomp$12$$=$APP.$cljs$core$__destructure_map$$($map__78047__$1_props_78042_single_QMARK_$jscomp$12$$.mdata);var $grid$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78047__$1_props_78042_single_QMARK_$jscomp$12$$,$APP.$cljs$cst$1664$grid$$),$cells$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78047__$1_props_78042_single_QMARK_$jscomp$12$$,
$APP.$cljs$cst$4580$cells$$),$grid_id$jscomp$28$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$10$$);$map__78047__$1_props_78042_single_QMARK_$jscomp$12$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($cells$jscomp$29$$),1);var $can_merge_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){return $app$common$types$shape$layout$valid_area_cells_QMARK_$$($cells$jscomp$29$$)}),
$can_copy_rows_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$10$$),$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){var $first_column$jscomp$inline_8915_map__71581$jscomp$inline_8913$$=$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$29$$),$last_column$jscomp$inline_8916_map__71581__$1$jscomp$inline_8914$$=$APP.$cljs$core$__destructure_map$$($first_column$jscomp$inline_8915_map__71581$jscomp$inline_8913$$);
$first_column$jscomp$inline_8915_map__71581$jscomp$inline_8913$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$inline_8916_map__71581__$1$jscomp$inline_8914$$,$APP.$cljs$cst$1721$first_column$$);$last_column$jscomp$inline_8916_map__71581__$1$jscomp$inline_8914$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$inline_8916_map__71581__$1$jscomp$inline_8914$$,$APP.$cljs$cst$1723$last_column$$);var $num_columns$jscomp$inline_8917$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1700$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$10$$));
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first_column$jscomp$inline_8915_map__71581$jscomp$inline_8913$$,1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_column$jscomp$inline_8916_map__71581__$1$jscomp$inline_8914$$,$num_columns$jscomp$inline_8917$$)}),$can_copy_columns_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$10$$),$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){var $first_row$jscomp$inline_8923_map__71582$jscomp$inline_8921$$=
$APP.$app$common$types$shape$layout$cells_coordinates$$($cells$jscomp$29$$),$last_row$jscomp$inline_8924_map__71582__$1$jscomp$inline_8922$$=$APP.$cljs$core$__destructure_map$$($first_row$jscomp$inline_8923_map__71582$jscomp$inline_8921$$);$first_row$jscomp$inline_8923_map__71582$jscomp$inline_8921$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_row$jscomp$inline_8924_map__71582__$1$jscomp$inline_8922$$,$APP.$cljs$cst$1720$first_row$$);$last_row$jscomp$inline_8924_map__71582__$1$jscomp$inline_8922$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($last_row$jscomp$inline_8924_map__71582__$1$jscomp$inline_8922$$,$APP.$cljs$cst$1722$last_row$$);var $num_rows$jscomp$inline_8925$$=$APP.$cljs$core$count$$($APP.$cljs$cst$1699$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$10$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first_row$jscomp$inline_8923_map__71582$jscomp$inline_8921$$,1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_row$jscomp$inline_8924_map__71582__$1$jscomp$inline_8922$$,
$num_rows$jscomp$inline_8925$$)}),$grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$)],function(){return $app$main$refs$workspace_grid_edition_id$$($grid_id$jscomp$28$$)});$grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$=$APP.$rumext$v2$deref$$($grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$);$grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$=$APP.$cljs$cst$4485$copied_tracks$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$)!=
null;var $do_merge_cells$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$),$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$merge_cells$$($grid_id$jscomp$28$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$cells$jscomp$29$$)))}),$do_create_board$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$),
$APP.$rumext$v2$adapt$$($cells$jscomp$29$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$create_cell_board$$($grid_id$jscomp$28$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$cells$jscomp$29$$)))}),$do_copy_rows$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$copy_grid_tracks$$($grid_id$jscomp$28$$,
$APP.$cljs$cst$1661$row$$))}),$do_copy_columns$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$copy_grid_tracks$$($grid_id$jscomp$28$$,$APP.$cljs$cst$216$column$$))}),$do_paste_tracks$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_id$jscomp$28$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$paste_grid_tracks$$($grid_id$jscomp$28$$))});
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$map__78047__$1_props_78042_single_QMARK_$jscomp$12$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.merge"),onClick:$do_merge_cells$$,disabled:$APP.$cljs$core$not$$($can_merge_QMARK_$$)}),$map__78047__$1_props_78042_single_QMARK_$jscomp$12$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.area"),onClick:$do_merge_cells$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.create-board"),onClick:$do_create_board$$,disabled:!$map__78047__$1_props_78042_single_QMARK_$jscomp$12$$&&$APP.$cljs$core$not$$($can_merge_QMARK_$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.copy-rows"),onClick:$do_copy_rows$$,disabled:$APP.$cljs$core$not$$($can_copy_rows_QMARK_$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.copy-columns"),onClick:$do_copy_columns$$,disabled:$APP.$cljs$core$not$$($can_copy_columns_QMARK_$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.grid-cells.paste-tracks"),onClick:$do_paste_tracks$$,disabled:!$grid_edition_grid_edition_ref_has_copied_tracks_QMARK_$$})]})};
$app$main$ui$workspace$context_menu$guide_color_context_menu_STAR_$$=function($do_remove_guide_map__78097__$1_props_78092$$){$do_remove_guide_map__78097__$1_props_78092$$=$APP.$cljs$core$__destructure_map$$($do_remove_guide_map__78097__$1_props_78092$$.mdata);var $guide$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($do_remove_guide_map__78097__$1_props_78092$$,$APP.$cljs$cst$3916$guide$$),$guide_id$jscomp$4$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$12$$),
$current_color$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1146$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$12$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1146$$)?$or__5025__auto__$jscomp$1146$$:$APP.$cljs$core$first$$($app$main$ui$workspace$context_menu$guide_color_presets$$)}(),$do_set_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($guide_id$jscomp$4$$)],function($color$jscomp$155_event$jscomp$338$$){$color$jscomp$155_event$jscomp$338$$=
$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($color$jscomp$155_event$jscomp$338$$),"color");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$hide_context_menu$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$guides$update_guide_color$$($guide_id$jscomp$4$$,$color$jscomp$155_event$jscomp$338$$)]))});$do_remove_guide_map__78097__$1_props_78092$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($guide$jscomp$12$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$hide_context_menu$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$12$$)]))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_context_menu__context-menu-item main_ui_workspace_context_menu__guide-color-label",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_context_menu__title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.guides.change-color")})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_context_menu__guide-color-swatches",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$129$$,$color$jscomp$156$$){$out_arr__44092__auto__$jscomp$129$$.push((0,$APP.$rumext$v2$jsx$$)("span",{"data-color":$color$jscomp$156$$,
onClick:$do_set_color$$,title:$color$jscomp$156$$,style:{backgroundColor:$color$jscomp$156$$},className:"main_ui_workspace_context_menu__guide-color-swatch "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$156$$,$current_color$jscomp$4$$)?"main_ui_workspace_context_menu__selected":"")},$color$jscomp$156$$));return $out_arr__44092__auto__$jscomp$129$$},[],$app$main$ui$workspace$context_menu$guide_color_presets$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_separator_STAR_$$,
{}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.context-menu.guides.remove"),onClick:$do_remove_guide_map__78097__$1_props_78092$$})]})};
$app$main$ui$workspace$context_menu$context_menu_STAR_$$=function(){var $mdata$jscomp$19$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$context_menu$menu_ref$$),$top$jscomp$15$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$19$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1516$y$$],null))-20,$left$jscomp$33$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$19$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1515$x$$],null)),$dropdown_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$read_only_QMARK_$jscomp$9$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mdata$jscomp$19$$)],function(){var $temp__5825__auto__$jscomp$366$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$$);
if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$366$$)){var $bounding_rect$jscomp$1$$=$APP.$app$util$dom$get_bounding_rect$$($temp__5825__auto__$jscomp$366$$),$window_size$jscomp$4$$=$APP.$app$util$dom$get_window_size$$(),$delta_x$jscomp$3$$=function(){var $x__5110__auto__$jscomp$135$$=$APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($bounding_rect$jscomp$1$$)+250-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($window_size$jscomp$4$$);return $x__5110__auto__$jscomp$135$$>
0?$x__5110__auto__$jscomp$135$$:0}(),$delta_y$jscomp$2$$=function(){var $x__5110__auto__$jscomp$136$$=$APP.$cljs$cst$1568$bottom$$.$cljs$core$IFn$_invoke$arity$1$($bounding_rect$jscomp$1$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($window_size$jscomp$4$$);return $x__5110__auto__$jscomp$136$$>0?$x__5110__auto__$jscomp$136$$:0}(),$new_style$jscomp$2$$=["top: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($top$jscomp$15$$-$delta_y$jscomp$2$$),"px; left: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($left$jscomp$33$$-
$delta_x$jscomp$3$$),"px;"].join("");return $delta_x$jscomp$3$$>0||$delta_y$jscomp$2$$>0?$temp__5825__auto__$jscomp$366$$.setAttribute("style",$new_style$jscomp$2$$):null}return null});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$boolean$0$$($mdata$jscomp$19$$),"on-close":function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$hide_context_menu$$)},children:(0,$APP.$rumext$v2$jsx$$)("div",
{ref:$dropdown_ref$$,style:{top:$top$jscomp$15$$,left:$left$jscomp$33$$},"data-testid":"context-menu",onContextMenu:$app$main$ui$workspace$context_menu$prevent_default$$,className:"main_ui_workspace_context_menu__workspace-context-menu",children:(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_context_menu__context-list",children:$read_only_QMARK_$jscomp$9$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$viewport_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$}):function(){var $G__78117$$=
$APP.$cljs$cst$947$kind$$.$cljs$core$IFn$_invoke$arity$1$($mdata$jscomp$19$$);switch($G__78117$$ instanceof $APP.$cljs$core$Keyword$$?$G__78117$$.$fqn$:null){case "shape":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$shape_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$});case "page":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$page_item_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$});case "grid-track":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$grid_track_context_menu_STAR_$$,
{mdata:$mdata$jscomp$19$$});case "grid-cells":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$grid_cells_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$});case "guide":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$guide_color_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$});default:return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$viewport_context_menu_STAR_$$,{mdata:$mdata$jscomp$19$$})}}()})})})};
$app$main$ui$workspace$coordinates$coordinates_STAR_$$=function($is_colorpalette_props_78361$$){$is_colorpalette_props_78361$$=$is_colorpalette_props_78361$$.isColorpalette;var $coords$jscomp$3$$=$app$main$ui$hooks$use_rxsub$$();return(0,$APP.$rumext$v2$jsxs$$)("div",{className:($APP.$cljs$core$truth_$$($is_colorpalette_props_78361$$)?"main_ui_workspace_coordinates__container-color-palette-open":"")+" main_ui_workspace_coordinates__container",children:[(0,$APP.$rumext$v2$jsx$$)("span",{alt:"x",className:"main_ui_workspace_coordinates__coordinate",
children:["X: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$2$($coords$jscomp$3$$,"-"))].join("")}),(0,$APP.$rumext$v2$jsx$$)("span",{alt:"y",className:"main_ui_workspace_coordinates__coordinate",children:["Y: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$2$($coords$jscomp$3$$,"-"))].join("")})]})};
$app$main$ui$workspace$tokens$import_from_library$import_modal_library_STAR_$$=function($cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$){$cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0]));$cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$=
$APP.$cljs$core$__destructure_map$$($cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$);var $file_id$jscomp$375$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$,$APP.$cljs$cst$1649$file_id$$),$library_id$jscomp$57$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$,$APP.$cljs$cst$4033$library_id$$);$cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($library_id$jscomp$57$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1191$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1191$$,$APP.$cljs$cst$1933$files$$),$library_id$jscomp$57$$),$APP.$cljs$cst$142$data$$)},$APP.$app$main$store$state$$)});
var $library_data$jscomp$36$$=$APP.$rumext$v2$deref$$($cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$),$show_libraries_dialog$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$375$$)],function(){$APP.$app$main$data$modal$hide_BANG_$$();return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4038$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,
$file_id$jscomp$375$$],null))});$cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $show_libraries_dialog$$.$cljs$core$IFn$_invoke$arity$0$?$show_libraries_dialog$$.$cljs$core$IFn$_invoke$arity$0$():$show_libraries_dialog$$()});var $import$$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$375$$),$APP.$rumext$v2$adapt$$($library_id$jscomp$57$$),
$APP.$rumext$v2$adapt$$($library_data$jscomp$36$$)],function(){var $tokens_lib_78370$$=$APP.$cljs$cst$2147$tokens_lib$$.$cljs$core$IFn$_invoke$arity$1$($library_data$jscomp$36$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$import_tokens_lib$$($tokens_lib_78370$$));return $show_libraries_dialog$$.$cljs$core$IFn$_invoke$arity$0$?$show_libraries_dialog$$.$cljs$core$IFn$_invoke$arity$0$():$show_libraries_dialog$$()});return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_tokens_import_from_library__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import_from_library__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_import_from_library__close-btn",onClick:$cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
variant:"ghost",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_import_from_library__modal-header",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,id:"modal-title",typography:"headline-large",className:"main_ui_workspace_tokens_import_from_library__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.import-library-tokens.title")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_import_from_library__modal-content",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"p",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.import-library-tokens.description")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{type:$APP.$cljs$cst$2320$context$$,appearance:"neutral",level:"default",isHtml:!0,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-warning")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_import_from_library__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import_from_library__action-buttons",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$cancel$jscomp$2_library_file_ref_map__78363_map__78363__$1_props_78362$$,type:"button",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$import$$$,type:"button",variant:"primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.import-library-tokens.import")})]})})]})})};
$app$main$ui$workspace$libraries$get_library_summary$$=function($data$jscomp$472$$){var $colors$jscomp$10$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$472$$)),$typographies$jscomp$1$$=$APP.$cljs$core$count$$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$472$$)),$components$jscomp$8$$=$APP.$cljs$core$count$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78394_SHARP_$$){return $APP.$app$common$files$variant$is_secondary_variant_QMARK_$$($p1__78394_SHARP_$$,
$data$jscomp$472$$)},$APP.$app$common$types$components_list$components_seq$$($data$jscomp$472$$)));return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5716$is_empty$$,$components$jscomp$8$$===0&&$colors$jscomp$10$$===0&&$typographies$jscomp$1$$===0,$APP.$cljs$cst$2220$colors$$,$colors$jscomp$10$$,$APP.$cljs$cst$2483$graphics$$,0,$APP.$cljs$cst$2223$typographies$$,$typographies$jscomp$1$$,$APP.$cljs$cst$1643$components$$,$components$jscomp$8$$],null)};
$app$main$ui$workspace$libraries$adapt_backend_summary$$=function($summary$jscomp$3$$){var $components$jscomp$9$$=function(){var $or__5025__auto__$jscomp$1147$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$3$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1147$$)?$or__5025__auto__$jscomp$1147$$:0}(),$graphics$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1148$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1644$media$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$3$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1148$$)?$or__5025__auto__$jscomp$1148$$:0}(),$typographies$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1149$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$3$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1149$$)?$or__5025__auto__$jscomp$1149$$:0}(),$colors$jscomp$11$$=function(){var $or__5025__auto__$jscomp$1150$$=$APP.$cljs$cst$1080$count$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($summary$jscomp$3$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1150$$)?$or__5025__auto__$jscomp$1150$$:0}();return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5716$is_empty$$,$components$jscomp$9$$===0&&$graphics$jscomp$1$$===0&&$colors$jscomp$11$$===0&&$typographies$jscomp$2$$===0,$APP.$cljs$cst$1643$components$$,$components$jscomp$9$$,$APP.$cljs$cst$2483$graphics$$,$graphics$jscomp$1$$,$APP.$cljs$cst$2223$typographies$$,$typographies$jscomp$2$$,$APP.$cljs$cst$2220$colors$$,$colors$jscomp$11$$],
null)};
$app$main$ui$workspace$libraries$describe_library$$=function($G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$,$G__78401__$3$jscomp$inline_8930_colors_count$$,$JSCompiler_inline_result$jscomp$1761_typography_count$$){var $all_zero_QMARK_$$=$G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$===0&&$G__78401__$3$jscomp$inline_8930_colors_count$$===0&&$JSCompiler_inline_result$jscomp$1761_typography_count$$===0,$JSCompiler_temp_const$jscomp$1760$$=$APP.$cljs$core$str$$,
$JSCompiler_temp_const$jscomp$1759$$=$JSCompiler_temp_const$jscomp$1760$$.$cljs$core$IFn$_invoke$arity$1$,$JSCompiler_temp_const$jscomp$1757$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$,$G__78401$jscomp$inline_8927$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$=$all_zero_QMARK_$$||$G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$>0?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78401$jscomp$inline_8927$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.components",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$)]))):$G__78401$jscomp$inline_8927$$;$G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$=$all_zero_QMARK_$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.graphics",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$(0)]))):$G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$;$G__78401__$3$jscomp$inline_8930_colors_count$$=$all_zero_QMARK_$$||$G__78401__$3$jscomp$inline_8930_colors_count$$>0?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.colors",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($G__78401__$3$jscomp$inline_8930_colors_count$$)]))):$G__78401__$1$jscomp$inline_8928_G__78401__$2$jscomp$inline_8929_components_count$$;$JSCompiler_inline_result$jscomp$1761_typography_count$$=$all_zero_QMARK_$$||$JSCompiler_inline_result$jscomp$1761_typography_count$$>0?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78401__$3$jscomp$inline_8930_colors_count$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.typography",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($JSCompiler_inline_result$jscomp$1761_typography_count$$)]))):$G__78401__$3$jscomp$inline_8930_colors_count$$;return[$JSCompiler_temp_const$jscomp$1759$$.call($JSCompiler_temp_const$jscomp$1760$$,$JSCompiler_temp_const$jscomp$1757$$.call($APP.$cuerdas$core$join$$," · ",$JSCompiler_inline_result$jscomp$1761_typography_count$$)),
" "].join("")};
$app$main$ui$workspace$libraries$library_description_STAR_$$=function($components_count$jscomp$1_props_78405$$){var $colors_count$jscomp$1_summary$jscomp$4$$=$components_count$jscomp$1_props_78405$$.summary;$components_count$jscomp$1_props_78405$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors_count$jscomp$1_summary$jscomp$4$$,$APP.$cljs$cst$1643$components$$);var $graphics_count$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors_count$jscomp$1_summary$jscomp$4$$,$APP.$cljs$cst$2483$graphics$$),
$typography_count$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors_count$jscomp$1_summary$jscomp$4$$,$APP.$cljs$cst$2223$typographies$$);$colors_count$jscomp$1_summary$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($colors_count$jscomp$1_summary$jscomp$4$$,$APP.$cljs$cst$2220$colors$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$components_count$jscomp$1_props_78405$$>0?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_libraries__element-count",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.components",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($components_count$jscomp$1_props_78405$$)]))}):null,$graphics_count$jscomp$1$$>0?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_libraries__element-count",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.graphics",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($graphics_count$jscomp$1$$)]))}):
null,$colors_count$jscomp$1_summary$jscomp$4$$>0?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_libraries__element-count",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.colors",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($colors_count$jscomp$1_summary$jscomp$4$$)]))}):null,$typography_count$jscomp$1$$>0?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_libraries__element-count",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.typography",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($typography_count$jscomp$1$$)]))}):null]})};
$app$main$ui$workspace$libraries$sample_library_entry_STAR_$$=function($library$jscomp$33_props_78407$$){var $importing$$=$library$jscomp$33_props_78407$$.importing;$library$jscomp$33_props_78407$$=$library$jscomp$33_props_78407$$.library;var $id$jscomp$937$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$33_props_78407$$),$importing_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($importing$$),$team_id$jscomp$162$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_team_id$$),
$on_error$jscomp$74$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($importing$$,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.libraries-and-templates.import-error")))}),$on_success$jscomp$57$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$162$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$($team_id$jscomp$162$$))}),
$import_library$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_success$jscomp$57$$),$APP.$rumext$v2$adapt$$($on_error$jscomp$74$$)],function(){$APP.$cljs$core$reset_BANG_$$($importing$$,$id$jscomp$937$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$dashboard$clone_template$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5081$template_id$$,$id$jscomp$937$$],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2499$on_success$$,$on_success$jscomp$57$$,$APP.$cljs$cst$1300$on_error$$,$on_error$jscomp$74$$],null))))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__sample-library-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__sample-library-item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$33_props_78407$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,
{variant:"secondary",disabled:$importing_QMARK_$jscomp$1$$!=null,onClick:$import_library$$,className:"main_ui_workspace_libraries__sample-library-button",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($importing_QMARK_$jscomp$1$$,$id$jscomp$937$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.adding"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.add")})]},""+($id$jscomp$937$$??""))};
$app$main$ui$workspace$libraries$libraries_tab_STAR_$$=function($is_shared$jscomp$5_props_78424$$){var $shared_libraries$$=$is_shared$jscomp$5_props_78424$$.sharedLibraries,$linked_libraries$$=$is_shared$jscomp$5_props_78424$$.linkedLibraries;$is_shared$jscomp$5_props_78424$$=$is_shared$jscomp$5_props_78424$$.isShared;var $file_id$jscomp$376$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$search_term_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),
$search_term$jscomp$3$$=$APP.$cljs$core$_deref$$($search_term_STAR_$$),$local_library_summary$jscomp$6$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_data$$);$local_library_summary$jscomp$6$$=$app$main$ui$workspace$libraries$get_library_summary$$($local_library_summary$jscomp$6$$);var $empty_library_QMARK_$$=$APP.$cljs$core$boolean$0$$($cljs$cst$5716$is_empty$$.$cljs$core$IFn$_invoke$arity$1$($local_library_summary$jscomp$6$$)),$selected$jscomp$146$$=$app$main$ui$hooks$use_shared_state$$($APP.$cljs$cst$4193$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpalette_selected$$),
$dependencies$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shared_libraries$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$cljs$cst$5717$library_file_ids$$),$APP.$cljs$core$vals$$($shared_libraries$$)))}),$library_names$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shared_libraries$$)],
function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$938_p__78430$$){var $map__78431__$1_name$jscomp$445$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$938_p__78430$$);$id$jscomp$938_p__78430$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78431__$1_name$jscomp$445$$,$APP.$cljs$cst$266$id$$);$map__78431__$1_name$jscomp$445$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78431__$1_name$jscomp$445$$,
$APP.$cljs$cst$725$name$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$938_p__78430$$,$map__78431__$1_name$jscomp$445$$],null)},$APP.$cljs$core$vals$$($shared_libraries$$)))}),$find_connected_to$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dependencies$$)],function($library_id$jscomp$58$$){return $APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p__78438_v$jscomp$668$$){var $k$jscomp$694$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78438_v$jscomp$668$$,0,null);$p__78438_v$jscomp$668$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78438_v$jscomp$668$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($p__78438_v$jscomp$668$$,$library_id$jscomp$58$$)?$k$jscomp$694$$:null},$dependencies$$)}),$shared_libraries__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shared_libraries$$),$APP.$rumext$v2$adapt$$($linked_libraries$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$),$APP.$rumext$v2$adapt$$($search_term$jscomp$3$$)],function(){return $APP.$cljs$core$truth_$$($shared_libraries$$)?$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$,$APP.$cljs$cst$725$name$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78414_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78414_SHARP_$$,$cljs$cst$5718$connected_to_names$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($library_names$$,$cljs$cst$5719$connected_to$$.$cljs$core$IFn$_invoke$arity$1$($p1__78414_SHARP_$$)))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78413_SHARP_$$){var $JSCompiler_temp_const$jscomp$1762$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__78447$jscomp$inline_8932_JSCompiler_inline_result$jscomp$1764$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78413_SHARP_$$);$G__78447$jscomp$inline_8932_JSCompiler_inline_result$jscomp$1764$$=
$find_connected_to$$.$cljs$core$IFn$_invoke$arity$1$?$find_connected_to$$.$cljs$core$IFn$_invoke$arity$1$($G__78447$jscomp$inline_8932_JSCompiler_inline_result$jscomp$1764$$):$find_connected_to$$($G__78447$jscomp$inline_8932_JSCompiler_inline_result$jscomp$1764$$);return $JSCompiler_temp_const$jscomp$1762$$.call($APP.$cljs$core$assoc$$,$p1__78413_SHARP_$$,$cljs$cst$5719$connected_to$$,$G__78447$jscomp$inline_8932_JSCompiler_inline_result$jscomp$1764$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78412_SHARP_$$){return $app$util$strings$matches_search$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78412_SHARP_$$),
$search_term$jscomp$3$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78411_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($linked_libraries$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78411_SHARP_$$))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78410_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78410_SHARP_$$),$file_id$jscomp$376$$)},
$APP.$cljs$core$vals$$($shared_libraries$$))))))):null}),$linked_libraries__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($linked_libraries$$),$APP.$rumext$v2$adapt$$($find_connected_to$$),$APP.$rumext$v2$adapt$$($library_names$$)],function(){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$,$APP.$cljs$cst$725$name$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78416_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78416_SHARP_$$,
$cljs$cst$5718$connected_to_names$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($library_names$$,$cljs$cst$5719$connected_to$$.$cljs$core$IFn$_invoke$arity$1$($p1__78416_SHARP_$$)))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78415_SHARP_$$){var $JSCompiler_temp_const$jscomp$1765$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$;var $G__78453$jscomp$inline_8934_JSCompiler_inline_result$jscomp$1767$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78415_SHARP_$$);
$G__78453$jscomp$inline_8934_JSCompiler_inline_result$jscomp$1767$$=$find_connected_to$$.$cljs$core$IFn$_invoke$arity$1$?$find_connected_to$$.$cljs$core$IFn$_invoke$arity$1$($G__78453$jscomp$inline_8934_JSCompiler_inline_result$jscomp$1767$$):$find_connected_to$$($G__78453$jscomp$inline_8934_JSCompiler_inline_result$jscomp$1767$$);return $JSCompiler_temp_const$jscomp$1765$$.call($APP.$cljs$core$assoc$$,$p1__78415_SHARP_$$,$cljs$cst$5719$connected_to$$,$G__78453$jscomp$inline_8934_JSCompiler_inline_result$jscomp$1767$$)},
$APP.$cljs$core$vals$$($linked_libraries$$))))}),$linked_libraries_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($linked_libraries__$1$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$app$common$data$xf_COLON_map_id$$,$linked_libraries__$1$$)}),$importing_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$sample_libraries$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"penpot-design-system",$APP.$cljs$cst$725$name$$,"Design system example"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"wireframing-kit",$APP.$cljs$cst$725$name$$,"Wireframe library"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,"whiteboarding-kit",
$APP.$cljs$cst$725$name$$,"Whiteboarding Kit"],null)],null)}),$change_search_term$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$339$$){return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$$,$event$jscomp$339$$)}),$link_library$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],function($G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$){$G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$=
$APP.$app$util$dom$get_current_target$$($G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$);$G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$=$G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$==null?null:$APP.$app$util$dom$get_data$$($G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$,"library-id");$G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$=
$G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$==null?null:$APP.$app$common$uuid$parse$$($G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$);$APP.$cljs$core$reset_BANG_$$($selected$jscomp$146$$,$G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$link_file_to_library$$($file_id$jscomp$376$$,
$G__78456$jscomp$inline_8936_G__78456__$1$jscomp$inline_8937_event$jscomp$340_library_id$jscomp$59$$))}),$unlink_library$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],function($G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$){$G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$=$APP.$app$util$dom$get_current_target$$($G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$);
$G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$=$G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$==null?null:$APP.$app$util$dom$get_data$$($G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$,"library-id");$G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$=$G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$==
null?null:$APP.$app$common$uuid$parse$$($G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$,$APP.$cljs$core$_deref$$($selected$jscomp$146$$))&&$APP.$cljs$core$reset_BANG_$$($selected$jscomp$146$$,$APP.$cljs$cst$208$file$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$libraries$unlink_file_from_library$$($file_id$jscomp$376$$,
$G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$376$$,$G__78460$jscomp$inline_8939_G__78460__$1$jscomp$inline_8940_event$jscomp$341_library_id$jscomp$60$$,null,null)]))}),$import_tokens$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],
function($G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$){$G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$=$APP.$app$util$dom$get_current_target$$($G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$);$G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$=$G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$==
null?null:$APP.$app$util$dom$get_data$$($G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$,"library-id");$G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$=$G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$==null?null:$APP.$app$common$uuid$parse$$($G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5715$tokens_SLASH_import_from_library$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$376$$,$APP.$cljs$cst$4033$library_id$$,$G__78462$jscomp$inline_8942_G__78462__$1$jscomp$inline_8943_event$jscomp$342_library_id$jscomp$61$$],null)))}),$on_delete_accept$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$libraries$set_file_shared$$($file_id$jscomp$376$$,
!1),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4038$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$376$$],null))]))}),$on_delete_cancel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4038$libraries_dialog$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$376$$],null)))}),$publish$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],function($event$jscomp$343_input_node$jscomp$6$$){function $cancel_publish$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4038$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$376$$],null)))}function $publish_library$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$set_file_shared$$($file_id$jscomp$376$$,!0))}$event$jscomp$343_input_node$jscomp$6$$=$APP.$app$util$dom$get_target$$($event$jscomp$343_input_node$jscomp$6$$);$empty_library_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.publish-empty-library.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.publish-empty-library.message"),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.publish-empty-library.accept"),$APP.$cljs$cst$2490$on_accept$$,$publish_library$$,$APP.$cljs$cst$5720$on_cancel$$,
$cancel_publish$$],null))):$publish_library$$();return $APP.$app$util$dom$blur_BANG_$$($event$jscomp$343_input_node$jscomp$6$$)}),$unpublish$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$376$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5721$delete_shared_libraries$$,
$APP.$cljs$cst$1729$ids$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$file_id$jscomp$376$$]),$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$5722$unpublish$$,$APP.$cljs$cst$2490$on_accept$$,$on_delete_accept$$,$APP.$cljs$cst$5720$on_cancel$$,$on_delete_cancel$$,$APP.$cljs$cst$5723$count_libraries$$,1],null)))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__libraries-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__lib-section",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.in-this-file"),className:"main_ui_workspace_libraries__title-spacing-lib"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__section-list",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__section-list-publish",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__item-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__item-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.file-library")}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_libraries__item-contents",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$library_description_STAR_$$,{summary:$local_library_summary$jscomp$6$$})})]}),$is_shared$jscomp$5_props_78424$$?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$unpublish$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.unpublish")}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",onClick:$publish$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("common.publish")})]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$130$$,
$p__78476$$){var $map__78477__$1$$=$APP.$cljs$core$__destructure_map$$($p__78476$$),$id$jscomp$939$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78477__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$446$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78477__$1$$,$APP.$cljs$cst$725$name$$),$data$jscomp$474$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78477__$1$$,$APP.$cljs$cst$142$data$$),$connected_to$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78477__$1$$,
$cljs$cst$5719$connected_to$$),$connected_to_names$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78477__$1$$,$cljs$cst$5718$connected_to_names$$);$out_arr__44092__auto__$jscomp$130$$.push(function(){var $disabled_QMARK_$jscomp$6$$=$APP.$cljs$core$some$$(function($p1__78420_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($linked_libraries_ids$$,$p1__78420_SHARP_$$)},$connected_to$$),$has_tokens_QMARK_$$=function(){var $and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$=
$APP.$cljs$core$__destructure_map$$($map__78477__$1$$);$and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$,$APP.$cljs$cst$142$data$$);$and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$,$APP.$cljs$cst$2147$tokens_lib$$);$and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$)?$APP.$cljs$core$not$$($APP.$app$common$types$tokens_lib$empty_lib_QMARK_$$($and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$)):
null;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$)?$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1215$token_import_from_library$$):$and__5023__auto__$jscomp$774_data$jscomp$inline_8947_map__78409__$1$jscomp$inline_8946_temp__5825__auto__$jscomp$inline_8948$$}();return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"library-item",className:"main_ui_workspace_libraries__section-list-item",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__item-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__item-name "+($APP.$cljs$core$truth_$$($has_tokens_QMARK_$$)?"main_ui_workspace_libraries__item-name-short":""),children:$name$jscomp$446$$}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_libraries__item-contents",children:function(){var $summary__$1$$=$app$main$ui$workspace$libraries$get_library_summary$$($data$jscomp$474$$);
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$library_description_STAR_$$,{summary:$summary__$1$$}),$APP.$cljs$core$seq$$($connected_to$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__connected-to-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{children:["(",$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.connected-to")," "]}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_libraries__connected-to-values",children:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$connected_to_names$$)}),(0,$APP.$rumext$v2$jsx$$)("span",{children:")"})]}):null]})}()})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__library-actions",children:[$has_tokens_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{type:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-tokens"),
icon:"import-export","data-library-id":""+($id$jscomp$939$$??""),variant:"secondary",onClick:$import_tokens$$}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{type:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.unlink-library-btn"),icon:"detach","data-library-id":""+($id$jscomp$939$$??""),variant:"secondary",disabled:$disabled_QMARK_$jscomp$6$$,onClick:$unlink_library$$})]})]},""+($id$jscomp$939$$??
""))}());return $out_arr__44092__auto__$jscomp$130$$},[],$linked_libraries__$1$$)]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__shared-section",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.shared-libraries"),className:"main_ui_workspace_libraries__title-spacing-lib"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,
{onChange:$change_search_term$$,value:$search_term$jscomp$3$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.search-shared-libraries"),iconId:"search"}),$APP.$cljs$core$seq$$($shared_libraries__$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-list-shared",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$131$$,$id$jscomp$940_p__78478$$){var $JSCompiler_inline_result$jscomp$1771_map__78479__$1_summary__$1$jscomp$inline_8950$$=
$APP.$cljs$core$__destructure_map$$($id$jscomp$940_p__78478$$);$id$jscomp$940_p__78478$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1771_map__78479__$1_summary__$1$jscomp$inline_8950$$,$APP.$cljs$cst$266$id$$);var $JSCompiler_temp_const$jscomp$1768_name$jscomp$447$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1771_map__78479__$1_summary__$1$jscomp$inline_8950$$,$APP.$cljs$cst$725$name$$),$JSCompiler_temp_const$jscomp$1769$$=
$out_arr__44092__auto__$jscomp$131$$.push;$JSCompiler_temp_const$jscomp$1768_name$jscomp$447$$=(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__item-name",children:$JSCompiler_temp_const$jscomp$1768_name$jscomp$447$$});$JSCompiler_inline_result$jscomp$1771_map__78479__$1_summary__$1$jscomp$inline_8950$$=$app$main$ui$workspace$libraries$adapt_backend_summary$$($APP.$cljs$cst$4049$library_summary$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1771_map__78479__$1_summary__$1$jscomp$inline_8950$$));
$JSCompiler_inline_result$jscomp$1771_map__78479__$1_summary__$1$jscomp$inline_8950$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$library_description_STAR_$$,{summary:$JSCompiler_inline_result$jscomp$1771_map__78479__$1_summary__$1$jscomp$inline_8950$$});$JSCompiler_temp_const$jscomp$1769$$.call($out_arr__44092__auto__$jscomp$131$$,(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"library-item",className:"main_ui_workspace_libraries__section-list-item",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__item-content",children:[$JSCompiler_temp_const$jscomp$1768_name$jscomp$447$$,(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_libraries__item-contents",children:$JSCompiler_inline_result$jscomp$1771_map__78479__$1_summary__$1$jscomp$inline_8950$$})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_libraries__item-button-shared",variant:"secondary","data-library-id":""+($id$jscomp$940_p__78478$$??
""),icon:"add","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.shared-library-btn"),onClick:$link_library$$})]},""+($id$jscomp$940_p__78478$$??"")));return $out_arr__44092__auto__$jscomp$131$$},[],$shared_libraries__$1$$)}):$APP.$cljs$core$empty_QMARK_$$($shared_libraries__$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-list-empty",children:$shared_libraries__$1$$==null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.loading"):
$APP.$cuerdas$core$empty_QMARK_$$($search_term$jscomp$3$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__sample-libraries-info",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.empty.no-libraries"),(0,$APP.$rumext$v2$jsx$$)("a",{target:"_blank",href:"https://penpot.app/libraries-templates",className:"main_ui_workspace_libraries__sample-libraries-link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.empty.some-templates")})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__sample-libraries-container",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.empty.add-some"),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$132$$,$library$jscomp$36$$){$out_arr__44092__auto__$jscomp$132$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$sample_library_entry_STAR_$$,{library:$library$jscomp$36$$,importing:$importing_STAR_$$},
""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$36$$)??"")));return $out_arr__44092__auto__$jscomp$132$$},[],$sample_libraries$$)]})]}):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.libraries.no-matches-for",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$search_term$jscomp$3$$]))}):null]})]})};
$app$main$ui$workspace$libraries$extract_assets$$=function($color_ids_colors$jscomp$12_file_data$jscomp$114$$,$library$jscomp$37$$,$summary_QMARK_$$){function $truncate$jscomp$14$$($asset_type$jscomp$16$$,$items$jscomp$61$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($summary_QMARK_$$)?$APP.$cljs$core$count$$($items$jscomp$61$$)>5:$summary_QMARK_$$)?($exceeded$$.$cljs$core$IVolatile$_vreset_BANG_$arity$2$(null,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($exceeded$$.$cljs$core$IDeref$_deref$arity$1$(null),
$asset_type$jscomp$16$$,!0)),$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(5,$items$jscomp$61$$)):$items$jscomp$61$$}var $exceeded$$=$APP.$cljs$core$volatile_BANG_$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1643$components$$,!1,$APP.$cljs$cst$2220$colors$$,!1,$APP.$cljs$cst$2223$typographies$$,!1],null)),$assets$jscomp$3_typographies$jscomp$3_typography_ids$$=$APP.$app$main$data$workspace$libraries$assets_need_sync$cljs$0core$0IFn$0_invoke$0arity$03$$($library$jscomp$37$$,
$color_ids_colors$jscomp$12_file_data$jscomp$114$$,null),$component_ids$jscomp$8_components$jscomp$10$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2555$asset_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78480_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2556$asset_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78480_SHARP_$$),
$APP.$cljs$cst$1630$component$$)},$assets$jscomp$3_typographies$jscomp$3_typography_ids$$)));$color_ids_colors$jscomp$12_file_data$jscomp$114$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2555$asset_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78481_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2556$asset_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78481_SHARP_$$),
$APP.$cljs$cst$1303$color$$)},$assets$jscomp$3_typographies$jscomp$3_typography_ids$$)));$assets$jscomp$3_typographies$jscomp$3_typography_ids$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2555$asset_id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78482_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2556$asset_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78482_SHARP_$$),
$APP.$cljs$cst$1997$typography$$)},$assets$jscomp$3_typographies$jscomp$3_typography_ids$$)));$component_ids$jscomp$8_components$jscomp$10$$=$truncate$jscomp$14$$($APP.$cljs$cst$1643$components$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78484_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78484_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78483_SHARP_$$){return $APP.$app$common$types$components_list$get_component$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$37$$),
$p1__78483_SHARP_$$)},$component_ids$jscomp$8_components$jscomp$10$$)));$color_ids_colors$jscomp$12_file_data$jscomp$114$$=$truncate$jscomp$14$$($APP.$cljs$cst$2220$colors$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78486_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78486_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78485_SHARP_$$){return $APP.$app$common$types$library$get_color$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$37$$),
$p1__78485_SHARP_$$)},$color_ids_colors$jscomp$12_file_data$jscomp$114$$)));$assets$jscomp$3_typographies$jscomp$3_typography_ids$$=$truncate$jscomp$14$$($APP.$cljs$cst$2223$typographies$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78488_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78488_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78487_SHARP_$$){return $APP.$app$common$types$typographies_list$get_typography$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$37$$),
$p1__78487_SHARP_$$)},$assets$jscomp$3_typographies$jscomp$3_typography_ids$$)));return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$library$jscomp$37$$,$APP.$cljs$core$_deref$$($exceeded$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1643$components$$,$component_ids$jscomp$8_components$jscomp$10$$,$APP.$cljs$cst$2220$colors$$,$color_ids_colors$jscomp$12_file_data$jscomp$114$$,$APP.$cljs$cst$2223$typographies$$,$assets$jscomp$3_typographies$jscomp$3_typography_ids$$],
null)],null)};
$app$main$ui$workspace$libraries$updates_tab_STAR_$$=function($libs_assets_props_78494$$){var $file_id$jscomp$377$$=$libs_assets_props_78494$$.fileId,$libraries$jscomp$142$$=$libs_assets_props_78494$$.libraries,$summary_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$summary_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($summary_QMARK__STAR_$$),$updating_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$updating_library$$),$file_data$jscomp$115$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_data$$),
$see_all_assets$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($summary_QMARK__STAR_$$,!1)});$libs_assets_props_78494$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_data$jscomp$115$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$142$$),$APP.$rumext$v2$adapt$$($summary_QMARK__STAR_$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($components$jscomp$11_map__78502_p__78498$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$11_map__78502_p__78498$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$11_map__78502_p__78498$$,1,null);$components$jscomp$11_map__78502_p__78498$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$11_map__78502_p__78498$$,2,null);var $map__78502__$1_typographies$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($components$jscomp$11_map__78502_p__78498$$);$components$jscomp$11_map__78502_p__78498$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78502__$1_typographies$jscomp$4$$,
$APP.$cljs$cst$1643$components$$);var $colors$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78502__$1_typographies$jscomp$4$$,$APP.$cljs$cst$2220$colors$$);$map__78502__$1_typographies$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78502__$1_typographies$jscomp$4$$,$APP.$cljs$cst$2223$typographies$$);return $APP.$cljs$core$seq$$($components$jscomp$11_map__78502_p__78498$$)||$APP.$cljs$core$seq$$($colors$jscomp$13$$)||$APP.$cljs$core$seq$$($map__78502__$1_typographies$jscomp$4$$)},
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78491_SHARP_$$){return $app$main$ui$workspace$libraries$extract_assets$$($file_data$jscomp$115$$,$p1__78491_SHARP_$$,$summary_QMARK_$jscomp$1$$)},$APP.$cljs$core$vals$$($libraries$jscomp$142$$)))});var $update$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$377$$)],function($G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$){if($APP.$cljs$core$truth_$$($updating_QMARK_$jscomp$2$$))return null;
$G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$=$APP.$app$util$dom$get_current_target$$($G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$);$G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$=$G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$==null?null:$APP.$app$util$dom$get_data$$($G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$,
"library-id");$G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$=$G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$==null?null:$APP.$app$common$uuid$parse$$($G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$);return $APP.$cljs$core$truth_$$($G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$libraries$set_updating_library$$(!0),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$377$$,$G__78504$jscomp$inline_8952_G__78504__$1$jscomp$inline_8953_event$jscomp$344_library_id$jscomp$62$$,null,null)])):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__updates-content",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__update-section",children:$APP.$cljs$core$empty_QMARK_$$($libs_assets_props_78494$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-list-empty",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"library",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.no-libraries-need-sync")})}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.library-updates")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__section-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$133$$,$components$jscomp$12_map__78514_p__78509$$){var $id$jscomp$941_map__78513$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$12_map__78514_p__78509$$,0,null),$map__78513__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$941_map__78513$$);$id$jscomp$941_map__78513$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78513__$1$$,
$APP.$cljs$cst$266$id$$);var $name$jscomp$448$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78513__$1$$,$APP.$cljs$cst$725$name$$),$exceeded$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$12_map__78514_p__78509$$,1,null);$components$jscomp$12_map__78514_p__78509$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$12_map__78514_p__78509$$,2,null);var $map__78514__$1_typographies$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($components$jscomp$12_map__78514_p__78509$$);
$components$jscomp$12_map__78514_p__78509$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78514__$1_typographies$jscomp$5$$,$APP.$cljs$cst$1643$components$$);var $colors$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78514__$1_typographies$jscomp$5$$,$APP.$cljs$cst$2220$colors$$);$map__78514__$1_typographies$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78514__$1_typographies$jscomp$5$$,$APP.$cljs$cst$2223$typographies$$);$out_arr__44092__auto__$jscomp$133$$.push((0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__section-list-item",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__item-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__item-name-long",children:$name$jscomp$448$$}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_libraries__item-contents",children:$app$main$ui$workspace$libraries$describe_library$$($APP.$cljs$core$count$$($components$jscomp$12_map__78514_p__78509$$),
$APP.$cljs$core$count$$($colors$jscomp$14$$),$APP.$cljs$core$count$$($map__78514__$1_typographies$jscomp$5$$))})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_workspace_libraries__item-update",disabled:$updating_QMARK_$jscomp$2$$,variant:"primary","data-library-id":""+($id$jscomp$941_map__78513$$??""),onClick:$update$jscomp$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.update")}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__libraries-updates",children:[$APP.$cljs$core$empty_QMARK_$$($components$jscomp$12_map__78514_p__78509$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-column",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$15$$,$component$jscomp$123$$){var $JSCompiler_temp_const$jscomp$1772$$=$out_arr__44092__auto____$1$jscomp$15$$.push;var $JSCompiler_inline_result$jscomp$1774_component__$1$jscomp$inline_8955$$=
$APP.$app$common$types$file$load_component_objects$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($map__78513__$1$$),$component$jscomp$123$$);var $root_shape$jscomp$inline_8956$$=$APP.$app$common$types$file$get_component_root$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($map__78513__$1$$),$JSCompiler_inline_result$jscomp$1774_component__$1$jscomp$inline_8955$$);$JSCompiler_inline_result$jscomp$1774_component__$1$jscomp$inline_8955$$=(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$render$component_svg$$,{"root-shape":$root_shape$jscomp$inline_8956$$,"class":"main_ui_workspace_libraries__component-svg",objects:$APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_component__$1$jscomp$inline_8955$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_component__$1$jscomp$inline_8955$$),
className:"main_ui_workspace_libraries__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1774_component__$1$jscomp$inline_8955$$)})})]});$JSCompiler_temp_const$jscomp$1772$$.call($out_arr__44092__auto____$1$jscomp$15$$,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",children:$JSCompiler_inline_result$jscomp$1774_component__$1$jscomp$inline_8955$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$123$$)??
"")));return $out_arr__44092__auto____$1$jscomp$15$$},[],$components$jscomp$12_map__78514_p__78509$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block main_ui_workspace_libraries__ellipsis",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_libraries__item-name",
children:"(...)"})})},$APP.$app$common$uuid$next$$()):null]}),$APP.$cljs$core$empty_QMARK_$$($colors$jscomp$14$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--bullet-size":"24px"},className:"main_ui_workspace_libraries__libraries-updates-column",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$16$$,$JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$){var $JSCompiler_temp_const$jscomp$1775$$=$out_arr__44092__auto____$1$jscomp$16$$.push,
$default_name$jscomp$inline_8958$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$))?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1730$gradient$$,$APP.$cljs$cst$139$type$$],null))):
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$))?$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$):$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$);$JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$=(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",
children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet_STAR_$$,{color:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$),
$APP.$cljs$cst$1740$opacity$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$)],null)}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__name-block",children:[(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$),className:"main_ui_workspace_libraries__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$)}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$),$default_name$jscomp$inline_8958$$)?null:(0,$APP.$rumext$v2$jsx$$)("span",{className:"color-value",children:$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$)})]})]})},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$)??
""));$JSCompiler_temp_const$jscomp$1775$$.call($out_arr__44092__auto____$1$jscomp$16$$,$JSCompiler_inline_result$jscomp$1777_color$jscomp$157$$);return $out_arr__44092__auto____$1$jscomp$16$$},[],$colors$jscomp$14$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block.ellipsis",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_libraries__item-name",children:"(...)"})})},$APP.$app$common$uuid$next$$()):null]}),$APP.$cljs$core$empty_QMARK_$$($map__78514__$1_typographies$jscomp$5$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-column",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$17$$,$typography$jscomp$30$$){$out_arr__44092__auto____$1$jscomp$17$$.push((0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_libraries__libraries-updates-item",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$),fontWeight:$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$),fontStyle:$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$)},children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block",children:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$),className:"main_ui_workspace_libraries__item-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$)})})]})},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$30$$)??"")));return $out_arr__44092__auto____$1$jscomp$17$$},
[],$map__78514__$1_typographies$jscomp$5$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__libraries-updates-item",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__name-block.ellipsis",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_libraries__item-name",children:"(...)"})})},$APP.$app$common$uuid$next$$()):
null]})]}),$APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$)>0||$APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$)>0||$APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($exceeded$jscomp$1$$)>0?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$link_button$link_button_STAR_$$,{onClick:$see_all_assets$$,className:"main_ui_workspace_libraries__libraries-updates-see-all",value:["(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.update.see-all-changes")),
")"].join("")}):null]},""+($id$jscomp$941_map__78513$$??"")));return $out_arr__44092__auto__$jscomp$133$$},[],$libs_assets_props_78494$$)})]})})})};
$app$main$ui$workspace$libraries$libraries_dialog$$=function($close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$){$close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$=$APP.$rumext$v2$util$wrap_props$$($close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$);$close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$=$APP.$cljs$core$__destructure_map$$($close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$);
var $starting_tab$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$,$APP.$cljs$cst$4039$starting_tab$$),$file_id$jscomp$378$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$,$APP.$cljs$cst$1649$file_id$$),$files$jscomp$26$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$);$close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$26$$,$file_id$jscomp$378$$);var $JSCompiler_inline_result$jscomp$1780_shared_QMARK_$jscomp$4$$=$APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$),$linked_libraries$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$26$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$378$$)],function(){return $APP.$app$main$refs$select_libraries$$($files$jscomp$26$$,
$file_id$jscomp$378$$)}),$linked_libraries__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($linked_libraries$jscomp$1$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$378$$)],function(){return $APP.$app$common$data$removem$$(function($lib$jscomp$16_p__78525$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lib$jscomp$16_p__78525$$,0,null);$lib$jscomp$16_p__78525$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lib$jscomp$16_p__78525$$,
1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$16_p__78525$$),$file_id$jscomp$378$$)},$linked_libraries$jscomp$1$$)}),$shared_libraries$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$shared_files$$);$close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$345$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_target$$($event$jscomp$345$$),
$APP.$app$util$dom$get_current_target$$($event$jscomp$345$$))?$APP.$app$main$data$modal$hide_BANG_$$():null});var $JSCompiler_temp_const$jscomp$1779_close_dialog$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()}),$selected_tab_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($starting_tab$$,"libraries")}),$selected_tab$$=$APP.$cljs$core$_deref$$($selected_tab_STAR_$$),
$on_change_tab$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78515_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($selected_tab_STAR_$$,$p1__78515_SHARP_$$)}),$tabs$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.libraries"),
$APP.$cljs$cst$266$id$$,"libraries"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.updates"),$APP.$cljs$cst$266$id$$,"updates"],null)],null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$fetch_shared_files$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});$JSCompiler_temp_const$jscomp$1779_close_dialog$$=
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_libraries__close-btn",onClick:$JSCompiler_temp_const$jscomp$1779_close_dialog$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),variant:"ghost",icon:"close"});var $JSCompiler_temp_const$jscomp$1778$$=(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.libraries")});
a:switch($selected_tab$$){case "libraries":$JSCompiler_inline_result$jscomp$1780_shared_QMARK_$jscomp$4$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$libraries_tab_STAR_$$,{isShared:$JSCompiler_inline_result$jscomp$1780_shared_QMARK_$jscomp$4$$,linkedLibraries:$linked_libraries__$1$jscomp$1$$,sharedLibraries:$shared_libraries$jscomp$1$$});break a;case "updates":$JSCompiler_inline_result$jscomp$1780_shared_QMARK_$jscomp$4$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$libraries$updates_tab_STAR_$$,
{fileId:$file_id$jscomp$378$$,libraries:$linked_libraries__$1$jscomp$1$$});break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($selected_tab$$)].join(""));}return(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$close_dialog_outside_file$jscomp$160_map__78522_map__78522__$1_props_78520$$,"data-testid":"libraries-modal",className:"main_ui_workspace_libraries__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__modal-dialog",
children:[$JSCompiler_temp_const$jscomp$1779_close_dialog$$,$JSCompiler_temp_const$jscomp$1778$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,{tabs:$tabs$jscomp$4$$,selected:$selected_tab$$,onChange:$on_change_tab$jscomp$1$$,children:$JSCompiler_inline_result$jscomp$1780_shared_QMARK_$jscomp$4$$})]})})};
$app$main$ui$workspace$libraries$v2_info_dialog$$=function(){var $handle_gotit_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$data$modal$hide_BANG_$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$update_profile_props$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5724$v2_info_shown$$,!0],null)))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__modal-overlay",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__modal-dialog main_ui_workspace_libraries__modal-v2-info",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__modal-v2-title",children:"IMPORTANT INFORMATION ABOUT NEW COMPONENTS"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__modal-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__info-block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-icon",children:$APP.$app$main$ui$icons$v2_icon_1$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-block-title",children:"One physical source of truth"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block-content",children:["Main components are now found at the design space. They act as a single source ",
"of truth and can be worked on with their copies. This ensures consistency and ","allows better control and synchronization."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-icon",children:$APP.$app$main$ui$icons$v2_icon_2$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-block-title",children:"Swap components"}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_libraries__info-block-content",children:["Now, you can replace one component copy with another within your libraries. ","The swap components functionality streamlines making changes, testing ","variations, or updating elements without extensive manual adjustments."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-icon",children:$APP.$app$main$ui$icons$v2_icon_3$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-block-title",children:"Graphic assets no longer exist"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block-content",children:["Graphic assets now disappear, so that all graphic assets become components. ","This way, swapping between them is possible, and we avoid confusion about ","what should go in each typology."]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-icon",children:$APP.$app$main$ui$icons$v2_icon_4$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-block-title",children:"Main components page"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_libraries__info-block-content",children:["You might find that a new page called 'Main components' has appeared in ","your file. On that page, you'll find all the main components that were ",
"created in your files previously to this new version."]})]})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_libraries__info-bottom",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:"main_ui_workspace_libraries__primary-button",variant:"primary",onClick:$handle_gotit_click$$,children:"I GOT IT"})})]})]})})};
$app$main$ui$workspace$nudge$on_keydown$$=function($event$jscomp$346$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$346$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$346$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$346$$),$APP.$app$main$data$modal$hide_BANG_$$()):null};
$app$main$ui$workspace$nudge$nudge_modal$$=function(){var $profile$jscomp$76$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$nudge$jscomp$3$$=function(){var $or__5025__auto__$jscomp$1151$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$76$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$575$props$$,$APP.$cljs$cst$3943$nudge$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1151$$)?$or__5025__auto__$jscomp$1151$$:
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3944$big$$,10,$APP.$cljs$cst$3945$small$$,1],null)}(),$update_big$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78531_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_nudge$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3944$big$$,$p1__78531_SHARP_$$],null)))}),$update_small$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78532_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_nudge$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3945$small$$,$p1__78532_SHARP_$$],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$APP.$goog$events$listen$$(document,"keydown",$app$main$ui$workspace$nudge$on_keydown$$))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_nudge__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__modal-container",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)("h2",{className:"main_ui_workspace_nudge__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.nudge-title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_nudge__modal-close-btn",children:$APP.$app$main$ui$icons$close$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__modal-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"nudge-small",className:"main_ui_workspace_nudge__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.small-nudge")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,id:"nudge-small",value:$APP.$cljs$cst$3945$small$$.$cljs$core$IFn$_invoke$arity$1$($nudge$jscomp$3$$),onChange:$update_small$$})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_nudge__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"nudge-big",className:"main_ui_workspace_nudge__modal-msg",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.big-nudge")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,id:"nudge-big",value:$APP.$cljs$cst$3944$big$$.$cljs$core$IFn$_invoke$arity$1$($nudge$jscomp$3$$),onChange:$update_big$$})]})]})]})})};
$app$main$ui$workspace$color_palette$recent_colors_palette_STAR_$$=function($props_78521$$){var $libraries$jscomp$143$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$colors$jscomp$16$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$recent_colors$$),$colors__$1$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$16$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$143$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($map__78524__$1_p__78523$$){$map__78524__$1_p__78523$$=
$APP.$cljs$core$__destructure_map$$($map__78524__$1_p__78523$$);var $G__78529$jscomp$inline_13786_ref_id$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78524__$1_p__78523$$,$APP.$cljs$cst$1741$ref_id$$),$or__5025__auto__$jscomp$1153_ref_file$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78524__$1_p__78523$$,$APP.$cljs$cst$1742$ref_file$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__78529$jscomp$inline_13786_ref_id$jscomp$12$$)?$or__5025__auto__$jscomp$1153_ref_file$jscomp$12$$:
$G__78529$jscomp$inline_13786_ref_id$jscomp$12$$)){var $fdata$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$143$$,$or__5025__auto__$jscomp$1153_ref_file$jscomp$12$$),$APP.$cljs$cst$142$data$$);$G__78529$jscomp$inline_13786_ref_id$jscomp$12$$=$APP.$app$common$types$library$get_color$$($fdata$jscomp$22$$,$G__78529$jscomp$inline_13786_ref_id$jscomp$12$$);$or__5025__auto__$jscomp$1153_ref_file$jscomp$12$$=$G__78529$jscomp$inline_13786_ref_id$jscomp$12$$==
null?null:$app$common$types$color$library_color__GT_color$$($G__78529$jscomp$inline_13786_ref_id$jscomp$12$$,$or__5025__auto__$jscomp$1153_ref_file$jscomp$12$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1153_ref_file$jscomp$12$$)?$or__5025__auto__$jscomp$1153_ref_file$jscomp$12$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__78524__$1_p__78523$$,$APP.$cljs$cst$1741$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1742$ref_file$$]))}return $map__78524__$1_p__78523$$},
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$valid_color_QMARK_$$,$APP.$cljs$core$reverse$$($colors$jscomp$16$$))))});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$color_palette$palette_STAR_$$,{...$props_78521$$,colors:$colors__$1$jscomp$3$$})};
$app$main$ui$workspace$color_palette$make_library_colors_ref$$=function($file_id$jscomp$379$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($files$jscomp$27$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($files$jscomp$27$$,$file_id$jscomp$379$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2220$colors$$)},$APP.$app$main$refs$files$$)};
$app$main$ui$workspace$color_palette$file_color_palette_STAR_$$=function($props_78536$$){var $file_id$jscomp$380$$=$props_78536$$.fileId,$colors__$1$jscomp$4_colors_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$380$$)],function(){return $app$main$ui$workspace$color_palette$make_library_colors_ref$$($file_id$jscomp$380$$)}),$colors$jscomp$17$$=$APP.$rumext$v2$deref$$($colors__$1$jscomp$4_colors_ref$$);$colors__$1$jscomp$4_colors_ref$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$17$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$380$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78535_SHARP_$$){return $app$common$types$color$library_color__GT_color$$($p1__78535_SHARP_$$,$file_id$jscomp$380$$)},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$color$valid_library_color_QMARK_$$,
$APP.$cljs$core$vals$$($colors$jscomp$17$$)))))});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$color_palette$palette_STAR_$$,{...$props_78536$$,colors:$colors__$1$jscomp$4_colors_ref$$})};
$app$main$ui$workspace$color_palette_ctx_menu$extract_colors$$=function($map__78543__$1_p__78542$$){$map__78543__$1_p__78542$$=$APP.$cljs$core$__destructure_map$$($map__78543__$1_p__78542$$);var $all_colors$jscomp$2_data$jscomp$475$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78543__$1_p__78542$$,$APP.$cljs$cst$142$data$$);$all_colors$jscomp$2_data$jscomp$475$$=$APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($all_colors$jscomp$2_data$jscomp$475$$);var $colors$jscomp$18$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$workspace$color_palette_ctx_menu$xf_COLON_sample_colors$$,$all_colors$jscomp$2_data$jscomp$475$$);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__78543__$1_p__78542$$,$APP.$cljs$cst$2220$colors$$,$colors$jscomp$18$$),$APP.$cljs$cst$2328$total_colors$$,$APP.$cljs$core$count$$($all_colors$jscomp$2_data$jscomp$475$$)),
$APP.$cljs$cst$142$data$$)};
$app$main$ui$workspace$color_palette_ctx_menu$color_palette_ctx_menu_STAR_$$=function($local_colors_props_78544$$){var $show$jscomp$7$$=$local_colors_props_78544$$.show,$selected$jscomp$150$$=$local_colors_props_78544$$.selected,$on_close$jscomp$18$$=$local_colors_props_78544$$.onClose,$on_select$$=$local_colors_props_78544$$.onSelect,$recent_colors$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$recent_colors$$),$libraries$jscomp$144$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$),$file_id$jscomp$382$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);$local_colors_props_78544$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($libraries$jscomp$144$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$382$$)],function(){var $colors$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$144$$,$file_id$jscomp$382$$),
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2220$colors$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$workspace$color_palette_ctx_menu$xf_COLON_sample_colors$$,$colors$jscomp$19$$)});var $local_colors_count$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($libraries$jscomp$144$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$382$$)],function(){return $APP.$cljs$core$count$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$144$$,
$file_id$jscomp$382$$),$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2220$colors$$))}),$libraries__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($libraries$jscomp$144$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$382$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$color_palette_ctx_menu$extract_colors$$,$APP.$cljs$core$vals$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$144$$,$file_id$jscomp$382$$)))}),
$recent_colors__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($recent_colors$jscomp$2$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$475$$,$color$jscomp$160$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$160$$,$cljs$cst$5728$app_DOT_main_DOT_ui_DOT_workspace_DOT_color_palette_ctx_menu_SLASH_id$$,""+($index$jscomp$475$$??""))},
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(7,$APP.$cljs$core$reverse$$($recent_colors$jscomp$2$$))))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show$jscomp$7$$,"on-close":$on_close$jscomp$18$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_color_palette_ctx_menu__palette-menu",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$135$$,$map__78549__$1_p__78548$$){$map__78549__$1_p__78548$$=
$APP.$cljs$core$__destructure_map$$($map__78549__$1_p__78548$$);var $id$jscomp$942$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78549__$1_p__78548$$,$APP.$cljs$cst$266$id$$),$colors$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78549__$1_p__78548$$,$APP.$cljs$cst$2220$colors$$);$out_arr__44092__auto__$jscomp$135$$.push((0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_select$$,"data-palette":""+($id$jscomp$942$$??""),className:"main_ui_workspace_color_palette_ctx_menu__palette-library "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$150$$,$id$jscomp$942$$)?"main_ui_workspace_color_palette_ctx_menu__selected":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__option-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__library-name",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_color_palette_ctx_menu__lib-name",children:""+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($map__78549__$1_p__78548$$)??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$cst$2328$total_colors$$.$cljs$core$IFn$_invoke$arity$1$($map__78549__$1_p__78548$$)??"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$150$$,$id$jscomp$942$$)?(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_color_palette_ctx_menu__icon-wrapper",children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--bullet-size":"20px"},className:"main_ui_workspace_color_palette_ctx_menu__color-sample",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$18$$,$color$jscomp$161$$){$out_arr__44092__auto____$1$jscomp$18$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet_STAR_$$,
{mini:!0,color:$color$jscomp$161$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$161$$)??"")));return $out_arr__44092__auto____$1$jscomp$18$$},[],$colors$jscomp$20$$)})]})},"library-"+($id$jscomp$942$$??"")));return $out_arr__44092__auto__$jscomp$135$$},[],$libraries__$1$$),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_select$$,"data-palette":"file",className:"main_ui_workspace_color_palette_ctx_menu__file-library "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$150$$,
$APP.$cljs$cst$208$file$$)?"main_ui_workspace_color_palette_ctx_menu__selected":""),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__option-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__library-name",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name",
children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.file-library")??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-num",children:"("+($local_colors_count$$??"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$150$$,$APP.$cljs$cst$208$file$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__icon-wrapper",children:$APP.$app$main$ui$icons$tick$$}):
null]}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--bullet-size":"20px"},className:"main_ui_workspace_color_palette_ctx_menu__color-sample",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$136$$,$color$jscomp$162$$){$out_arr__44092__auto__$jscomp$136$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet_STAR_$$,{mini:!0,color:$color$jscomp$162$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$162$$)??
"")));return $out_arr__44092__auto__$jscomp$136$$},[],$local_colors_props_78544$$)})]})}),(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$on_select$$,"data-palette":"recent",className:"main_ui_workspace_color_palette_ctx_menu__recent-colors main_ui_workspace_color_palette_ctx_menu__selected",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__option-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__library-name",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-name",children:""+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.recent-colors")??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$core$count$$($recent_colors__$1$jscomp$1$$)??
"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$150$$,$cljs$cst$5702$recent$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_color_palette_ctx_menu__icon-wrapper",children:$APP.$app$main$ui$icons$tick$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{"--bullet-size":"20px"},className:"main_ui_workspace_color_palette_ctx_menu__color-sample",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$137$$,
$color$jscomp$163$$){$out_arr__44092__auto__$jscomp$137$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet_STAR_$$,{mini:!0,color:$color$jscomp$163$$},""+($cljs$cst$5728$app_DOT_main_DOT_ui_DOT_workspace_DOT_color_palette_ctx_menu_SLASH_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$163$$)??"")));return $out_arr__44092__auto__$jscomp$137$$},[],$recent_colors__$1$jscomp$1$$)})]})})]})})};
$app$main$ui$workspace$text_palette$typography_item_STAR_$$=function($font_data$jscomp$11_props_78555$$){var $file_id$jscomp$383$$=$font_data$jscomp$11_props_78555$$.fileId,$size$jscomp$153$$=$font_data$jscomp$11_props_78555$$.size,$selected_ids$jscomp$7$$=$font_data$jscomp$11_props_78555$$.selectedIds,$current_file_id$jscomp$16$$=$font_data$jscomp$11_props_78555$$.currentFileId,$typography$jscomp$31$$=$font_data$jscomp$11_props_78555$$.typography;$font_data$jscomp$11_props_78555$$=$APP.$app$main$fonts$get_font_data$$($APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$));
var $font_variant_id$jscomp$17$$=$APP.$cljs$cst$1765$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$),$variant_data$jscomp$1$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78553_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78553_SHARP_$$),$font_variant_id$jscomp$17$$)},$APP.$cljs$cst$2687$variants$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$11_props_78555$$)),
$handle_click$jscomp$4$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$31$$),$APP.$rumext$v2$adapt$$($selected_ids$jscomp$7$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$383$$),$APP.$rumext$v2$adapt$$($current_file_id$jscomp$16$$)],function(){var $attrs$jscomp$173$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$1647$typography_ref_file$$,$file_id$jscomp$383$$,$APP.$cljs$cst$1762$typography_ref_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$)],null),$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($typography$jscomp$31$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$]))]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-typography",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"text-palette",$APP.$cljs$cst$4001$external_library$$,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$383$$,$current_file_id$jscomp$16$$)],null)));return $APP.$cljs$core$run_BANG_$$(function($p1__78554_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_text_attrs$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$266$id$$,$p1__78554_SHARP_$$,$APP.$cljs$cst$1599$editor$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_editor_state$$),$p1__78554_SHARP_$$),$APP.$cljs$cst$2656$attrs$$,$attrs$jscomp$173$$],null)))},$selected_ids$jscomp$7$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$handle_click$jscomp$4$$,className:"main_ui_workspace_text_palette__typography-item "+($size$jscomp$153$$<=72?"main_ui_workspace_text_palette__mid-item":
"")+" "+($size$jscomp$153$$<=64?"main_ui_workspace_text_palette__small-item":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$),style:{fontFamily:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$),fontWeight:$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$),fontStyle:$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$)},
className:"main_ui_workspace_text_palette__typography-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_text_palette__typography-font",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$11_props_78555$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_text_palette__typography-data",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$31$$)),
"px | ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $or__5025__auto__$jscomp$1154$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($variant_data$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1154$$)?$or__5025__auto__$jscomp$1154$$:"--"}())].join("")})]})};
$app$main$ui$workspace$text_palette$palette_STAR_$$=function($props_78563_width__$1$jscomp$9$$){var $file_typographies$$=$props_78563_width__$1$jscomp$9$$.fileTypographies,$selected$jscomp$151$$=$props_78563_width__$1$jscomp$9$$.selected,$libraries$jscomp$145$$=$props_78563_width__$1$jscomp$9$$.libraries,$show_arrows_QMARK_$jscomp$1_width$jscomp$192$$=$props_78563_width__$1$jscomp$9$$.width,$size$jscomp$154$$=$props_78563_width__$1$jscomp$9$$.size,$selected_ids$jscomp$8$$=$props_78563_width__$1$jscomp$9$$.selectedIds,
$current_file_id$jscomp$17$$=$props_78563_width__$1$jscomp$9$$.currentFileId,$file_id$jscomp$384$$=function(){switch($selected$jscomp$151$$ instanceof $APP.$cljs$core$Keyword$$?$selected$jscomp$151$$.$fqn$:null){case "recent":return null;case "file":return $current_file_id$jscomp$17$$;default:return $selected$jscomp$151$$}}(),$current_typographies$$=function(){switch($selected$jscomp$151$$ instanceof $APP.$cljs$core$Keyword$$?$selected$jscomp$151$$.$fqn$:null){case "recent":return $APP.$cljs$core$PersistentVector$EMPTY$$;
case "file":return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78561_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78561_SHARP_$$))},$APP.$cljs$core$vals$$($file_typographies$$));default:return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78562_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78562_SHARP_$$))},$APP.$cljs$core$vals$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$145$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selected$jscomp$151$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2223$typographies$$],null))))}}(),$state$jscomp$1193$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$195$offset$$,0],null));$props_78563_width__$1$jscomp$9$$=$show_arrows_QMARK_$jscomp$1_width$jscomp$192$$-($size$jscomp$154$$<=64?164:$size$jscomp$154$$<=72?164:
132);var $on_wheel_visible$jscomp$2$$=$props_78563_width__$1$jscomp$9$$/144|0;$show_arrows_QMARK_$jscomp$1_width$jscomp$192$$=$APP.$cljs$core$count$$($current_typographies$$)>$on_wheel_visible$jscomp$2$$;var $offset$jscomp$210$$=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($state$jscomp$1193$$),0),$max_offset$jscomp$3$$=$APP.$cljs$core$count$$($current_typographies$$)-$on_wheel_visible$jscomp$2$$,$container$jscomp$84$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_left_arrow_click$jscomp$1$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_wheel_visible$jscomp$2$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1193$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$195$offset$$,function($offset__$1$jscomp$25_x__5110__auto__$jscomp$138$$){return $offset__$1$jscomp$25_x__5110__auto__$jscomp$138$$>0?(--$offset__$1$jscomp$25_x__5110__auto__$jscomp$138$$,$offset__$1$jscomp$25_x__5110__auto__$jscomp$138$$>
0?$offset__$1$jscomp$25_x__5110__auto__$jscomp$138$$:0):$offset__$1$jscomp$25_x__5110__auto__$jscomp$138$$})}),$on_right_arrow_click$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_wheel_visible$jscomp$2$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1193$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$195$offset$$,function($offset__$1$jscomp$26_y__5114__auto__$jscomp$77$$){return $offset__$1$jscomp$26_y__5114__auto__$jscomp$77$$<
$max_offset$jscomp$3$$?($offset__$1$jscomp$26_y__5114__auto__$jscomp$77$$+=1,$max_offset$jscomp$3$$<$offset__$1$jscomp$26_y__5114__auto__$jscomp$77$$?$max_offset$jscomp$3$$:$offset__$1$jscomp$26_y__5114__auto__$jscomp$77$$):$offset__$1$jscomp$26_y__5114__auto__$jscomp$77$$})});$on_wheel_visible$jscomp$2$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$3$$)],function($event$jscomp$349_event__$1$jscomp$5$$){$event$jscomp$349_event__$1$jscomp$5$$=
$event$jscomp$349_event__$1$jscomp$5$$.nativeEvent;return $event$jscomp$349_event__$1$jscomp$5$$.deltaY+$event$jscomp$349_event__$1$jscomp$5$$.deltaX>0?$on_right_arrow_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_right_arrow_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$349_event__$1$jscomp$5$$):$on_right_arrow_click$jscomp$1$$($event$jscomp$349_event__$1$jscomp$5$$):$on_left_arrow_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_left_arrow_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$349_event__$1$jscomp$5$$):
$on_left_arrow_click$jscomp$1$$($event$jscomp$349_event__$1$jscomp$5$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_typographies$$)],function(){var $fonts$jscomp$29$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1763$font_id$$),$current_typographies$$);return $APP.$cljs$core$run_BANG_$$($APP.$app$main$fonts$ensure_loaded_BANG_$$,
$fonts$jscomp$29$$)});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1193$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$84$$),"clientWidth"))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($props_78563_width__$1$jscomp$9$$),
$APP.$rumext$v2$adapt$$($selected$jscomp$151$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1193$$)))?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1193$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,0):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--height":[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$154$$),
"px"].join("")},className:"main_ui_workspace_text_palette__text-palette",children:[$show_arrows_QMARK_$jscomp$1_width$jscomp$192$$?(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$210$$,0),onClick:$on_left_arrow_click$jscomp$1$$,className:"main_ui_workspace_text_palette__left-arrow",children:$APP.$app$main$ui$icons$arrow$$}):null,(0,$APP.$rumext$v2$jsx$$)("div",{ref:$container$jscomp$84$$,onWheel:$on_wheel_visible$jscomp$2$$,className:"main_ui_workspace_text_palette__text-palette-content",
children:$APP.$cljs$core$empty_QMARK_$$($current_typographies$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"absolute",left:"50%",top:"50%",transform:"translate(-50%, -50%)"},className:"main_ui_workspace_text_palette__text-palette-empty",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.empty-typography-palette")}):(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"relative",maxWidth:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($props_78563_width__$1$jscomp$9$$),
"px"].join(""),right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(144*$offset$jscomp$210$$),"px"].join("")},className:"main_ui_workspace_text_palette__text-palette-inside",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$138$$,$item$jscomp$129_p__78566$$){var $idx$jscomp$116$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$129_p__78566$$,0,null);$item$jscomp$129_p__78566$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$129_p__78566$$,
1,null);$out_arr__44092__auto__$jscomp$138$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$text_palette$typography_item_STAR_$$,{fileId:$file_id$jscomp$384$$,currentFileId:$current_file_id$jscomp$17$$,selectedIds:$selected_ids$jscomp$8$$,typography:$item$jscomp$129_p__78566$$,size:$size$jscomp$154$$},$idx$jscomp$116$$));return $out_arr__44092__auto__$jscomp$138$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$current_typographies$$))})}),$show_arrows_QMARK_$jscomp$1_width$jscomp$192$$?
(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$210$$,$max_offset$jscomp$3$$),onClick:$on_right_arrow_click$jscomp$1$$,className:"main_ui_workspace_text_palette__right-arrow",children:$APP.$app$main$ui$icons$arrow$$}):null]})};
$app$main$ui$workspace$text_palette_ctx_menu$text_palette_ctx_menu_STAR_$$=function($props_78556_show_menu$$){var $close_menu$$=$props_78556_show_menu$$.closeMenu,$selected$jscomp$153$$=$props_78556_show_menu$$.selected,$on_select_palette$$=$props_78556_show_menu$$.onSelectPalette;$props_78556_show_menu$$=$props_78556_show_menu$$.showMenu;var $typographies$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),$libraries$jscomp$147$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$);
return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$props_78556_show_menu$$,"on-close":$close_menu$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_text_palette_ctx_menu__text-context-menu",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$139$$,$p__78557$$){var $idx$jscomp$117$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78557$$,0,null),$cur_library$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78557$$,
1,null);$out_arr__44092__auto__$jscomp$139$$.push(function(){var $typographies__$1$$=$APP.$cljs$core$vals$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($cur_library$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2223$typographies$$],null)));return(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:function(){return $on_select_palette$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_palette$$.$cljs$core$IFn$_invoke$arity$1$($cur_library$$):
$on_select_palette$$($cur_library$$)},className:"main_ui_workspace_text_palette_ctx_menu__palette-library "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$153$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cur_library$$))?"main_ui_workspace_text_palette_ctx_menu__selected":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_text_palette_ctx_menu__library-name",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__lib-name",
children:""+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($cur_library$$)??"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$core$count$$($typographies__$1$$)??"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$153$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cur_library$$))?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__icon-wrapper",
children:$APP.$app$main$ui$icons$tick$$}):null]},["library-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($idx$jscomp$117$$)].join(""))}());return $out_arr__44092__auto__$jscomp$139$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$core$vals$$($libraries$jscomp$147$$))),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:function(){return $on_select_palette$$.$cljs$core$IFn$_invoke$arity$1$?$on_select_palette$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$208$file$$):
$on_select_palette$$($APP.$cljs$cst$208$file$$)},className:"main_ui_workspace_text_palette_ctx_menu__file-library "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$153$$,$APP.$cljs$cst$208$file$$)?"main_ui_workspace_text_palette_ctx_menu__selected":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_text_palette_ctx_menu__library-name",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__lib-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.file-library")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__lib-num",children:"("+($APP.$cljs$core$count$$($typographies$jscomp$6$$)??"")+")"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$153$$,$APP.$cljs$cst$208$file$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_text_palette_ctx_menu__icon-wrapper",children:$APP.$app$main$ui$icons$tick$$}):null]})]})})};
$app$main$ui$workspace$palette$calculate_palette_style$$=function($rulers_QMARK_$jscomp$1$$){var $left_sidebar$jscomp$1_left_sidebar_size$$=$APP.$goog$dom$getElement$$("left-sidebar-aside");$left_sidebar$jscomp$1_left_sidebar_size$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($left_sidebar$jscomp$1_left_sidebar_size$$,"width"));return{paddingLeft:""+(($APP.$cljs$core$truth_$$($rulers_QMARK_$jscomp$1$$)?22:0)+($APP.$cljs$core$truth_$$($left_sidebar$jscomp$1_left_sidebar_size$$)?
$left_sidebar$jscomp$1_left_sidebar_size$$:318)+4+1??"")+"px",paddingRight:"322px"}};
$app$main$ui$workspace$palette$palette_STAR_$$=function($color_palette_QMARK__props_78606$$){var $map__78611_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$=$color_palette_QMARK__props_78606$$.onChangeSize,$hide_palettes_QMARK__layout$jscomp$19$$=$color_palette_QMARK__props_78606$$.layout;$color_palette_QMARK__props_78606$$=$APP.$cljs$cst$3764$colorpalette$$.$cljs$core$IFn$_invoke$arity$1$($hide_palettes_QMARK__layout$jscomp$19$$);var $text_palette_QMARK_$$=$APP.$cljs$cst$3790$textpalette$$.$cljs$core$IFn$_invoke$arity$1$($hide_palettes_QMARK__layout$jscomp$19$$);
$hide_palettes_QMARK__layout$jscomp$19$$=$APP.$cljs$cst$3776$hide_palettes$$.$cljs$core$IFn$_invoke$arity$1$($hide_palettes_QMARK__layout$jscomp$19$$);var $read_only_QMARK_$jscomp$10$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$container$jscomp$85$$=(0,$APP.$rumext$v2$use_ref$$)(null),$state_STAR_$jscomp$9$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5727$show_menu$$,
!1],null)}),$show_menu_QMARK__state$jscomp$1194$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$9$$);$show_menu_QMARK__state$jscomp$1194$$=$cljs$cst$5727$show_menu$$.$cljs$core$IFn$_invoke$arity$1$($show_menu_QMARK__state$jscomp$1194$$);var $selected$jscomp$154$$=$app$main$ui$hooks$use_shared_state$$($APP.$cljs$cst$4193$app_DOT_main_DOT_data_DOT_workspace_DOT_colors_SLASH_colorpalette_selected$$),$selected_text_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$208$file$$),
$selected_text$$=$APP.$cljs$core$_deref$$($selected_text_STAR_$$),$on_select$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78602_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($selected$jscomp$154$$,$p1__78602_SHARP_$$)}),$rulers_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$rulers_QMARK_$$),$vport$jscomp$9_vport_width$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$palette$ref_COLON_viewport$$);$vport$jscomp$9_vport_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vport$jscomp$9_vport_width$$,
$APP.$cljs$cst$290$width$$);$map__78611_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$4867$palette$$,72,54,80,$APP.$cljs$cst$1516$y$$,!0,$APP.$cljs$cst$1568$bottom$$,$map__78611_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$);var $map__78611__$1_size$jscomp$156$$=$APP.$cljs$core$__destructure_map$$($map__78611_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$);$map__78611_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78611__$1_size$jscomp$156$$,$APP.$cljs$cst$4610$on_pointer_down$$);var $on_lost_pointer_capture$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78611__$1_size$jscomp$156$$,$APP.$cljs$cst$4611$on_lost_pointer_capture$$),$on_pointer_move$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78611__$1_size$jscomp$156$$,$APP.$cljs$cst$4612$on_pointer_move$$),$parent_ref$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78611__$1_size$jscomp$156$$,
$APP.$cljs$cst$4613$parent_ref$$);$map__78611__$1_size$jscomp$156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78611__$1_size$jscomp$156$$,$APP.$cljs$cst$874$size$$);var $on_resize$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$9$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$85$$),
"clientWidth"))}),$on_close_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$9$$,$APP.$cljs$core$assoc$$,$cljs$cst$5727$show_menu$$,!1)}),$on_select_palette$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select$jscomp$1$$)],function($G__78617_event$jscomp$350_value$jscomp$806$$){$G__78617_event$jscomp$350_value$jscomp$806$$=
$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$get_current_target$$($G__78617_event$jscomp$350_value$jscomp$806$$),"data-palette");$G__78617_event$jscomp$350_value$jscomp$806$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("file",$G__78617_event$jscomp$350_value$jscomp$806$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("recent",$G__78617_event$jscomp$350_value$jscomp$806$$)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__78617_event$jscomp$350_value$jscomp$806$$):
$APP.$app$common$uuid$parse$$($G__78617_event$jscomp$350_value$jscomp$806$$);return $on_select$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__78617_event$jscomp$350_value$jscomp$806$$):$on_select$jscomp$1$$($G__78617_event$jscomp$350_value$jscomp$806$$)}),$on_select_text_palette_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select$jscomp$1$$)],function($lib$jscomp$17$$){return $lib$jscomp$17$$==
null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$208$file$$,$lib$jscomp$17$$)?$APP.$cljs$core$reset_BANG_$$($selected_text_STAR_$$,$APP.$cljs$cst$208$file$$):$APP.$cljs$core$reset_BANG_$$($selected_text_STAR_$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($lib$jscomp$17$$))}),$toggle_palettes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1567$top$$;$APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("color-palette"),
"fade-out-down");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3776$hide_palettes$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-left-toolbar"))}),$on_select_color_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$351_node$jscomp$408$$){$event$jscomp$351_node$jscomp$408$$=
$APP.$app$util$dom$get_current_target$$($event$jscomp$351_node$jscomp$408$$);$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1567$top$$;$APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("color-palette"),"fade-out-down");$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(300,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3776$hide_palettes$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3790$textpalette$$),$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3764$colorpalette$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-left-toolbar")]))});return $APP.$app$util$dom$blur_BANG_$$($event$jscomp$351_node$jscomp$408$$)}),$on_select_text_palette$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$352_node$jscomp$409$$){$event$jscomp$352_node$jscomp$409$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$352_node$jscomp$409$$);$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1567$top$$;$APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("color-palette"),"fade-out-down");$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(300,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3776$hide_palettes$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3764$colorpalette$$),$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3790$textpalette$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-left-toolbar")]))});return $APP.$app$util$dom$blur_BANG_$$($event$jscomp$352_node$jscomp$409$$)}),$any_palette_QMARK_$$=
$APP.$cljs$core$truth_$$($color_palette_QMARK__props_78606$$)?$color_palette_QMARK__props_78606$$:$text_palette_QMARK_$$,$size_classname$$=$map__78611__$1_size$jscomp$156$$<=64?"main_ui_workspace_palette__small-palette":$map__78611__$1_size$jscomp$156$$<=72?"main_ui_workspace_palette__mid-palette":$map__78611__$1_size$jscomp$156$$<=80?"main_ui_workspace_palette__big-palette":null;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key1$jscomp$7$$=$APP.$goog$events$listen$$(window,
"resize",$on_resize$$);return function(){return $APP.$goog$events$unlistenByKey$$($key1$jscomp$7$$)}});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$9$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($parent_ref$jscomp$2$$),"clientWidth"))});return(0,$APP.$rumext$v2$jsx$$)("section",
{id:"palette-wrapper",style:$app$main$ui$workspace$palette$calculate_palette_style$$($rulers_QMARK_$jscomp$2$$),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.palette-bar"),"data-testid":"palette",className:"main_ui_workspace_palette__palette-wrapper",children:$read_only_QMARK_$jscomp$10$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$parent_ref$jscomp$2$$,style:{"--height":""+($map__78611__$1_size$jscomp$156$$??"")+"px"},className:""+($size_classname$$??"")+
" main_ui_workspace_palette__palettes "+(($APP.$cljs$core$truth_$$($any_palette_QMARK_$$)?"main_ui_workspace_palette__wide":"")+" "+($APP.$cljs$core$truth_$$($hide_palettes_QMARK__layout$jscomp$19$$)?"main_ui_workspace_palette__hidden-bts":"")),children:[(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__78611_on_change_size$jscomp$1_on_pointer_down$jscomp$3$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$1$$,onPointerMove:$on_pointer_move$jscomp$2$$,className:"main_ui_workspace_palette__resize-area"}),
(0,$APP.$rumext$v2$jsxs$$)("ul",{className:""+($size_classname$$??"")+" main_ui_workspace_palette__palette-btn-list "+($APP.$cljs$core$truth_$$($hide_palettes_QMARK__layout$jscomp$19$$)?"main_ui_workspace_palette__hidden-bts":""),children:[(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_palette__palette-item",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.color-palette",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4920$toggle_colorpalette$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.color-palette",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4920$toggle_colorpalette$$)])),onClick:$on_select_color_palette$$,className:"main_ui_workspace_palette__palette-btn "+($APP.$cljs$core$truth_$$($color_palette_QMARK__props_78606$$)?"main_ui_workspace_palette__selected":""),children:$APP.$app$main$ui$icons$drop_icon$$})}),
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_palette__palette-item",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.text-palette",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4965$toggle_textpalette$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.text-palette",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4965$toggle_textpalette$$)])),
onClick:$on_select_text_palette$$,className:"main_ui_workspace_palette__palette-btn "+($APP.$cljs$core$truth_$$($text_palette_QMARK_$$)?"main_ui_workspace_palette__selected":""),children:$APP.$app$main$ui$icons$text_palette$$})})]}),$APP.$cljs$core$truth_$$($any_palette_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$9$$,$APP.$cljs$core$update$$,
$cljs$cst$5727$show_menu$$,$APP.$cljs$core$not$$)},className:"main_ui_workspace_palette__palette-actions",children:$APP.$app$main$ui$icons$menu$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$container$jscomp$85$$,className:"main_ui_workspace_palette__palette",children:[$APP.$cljs$core$truth_$$($text_palette_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$text_palette_ctx_menu$text_palette_ctx_menu_STAR_$$,{showMenu:$show_menu_QMARK__state$jscomp$1194$$,
closeMenu:$on_close_menu$jscomp$1$$,onSelectPalette:$on_select_text_palette_menu$$,selected:$selected_text$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$text_palette$text_palette_STAR_$$,{size:$map__78611__$1_size$jscomp$156$$,selected:$selected_text$$,width:$vport$jscomp$9_vport_width$$})]}):null,$APP.$cljs$core$truth_$$($color_palette_QMARK__props_78606$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$color_palette_ctx_menu$color_palette_ctx_menu_STAR_$$,
{show:$show_menu_QMARK__state$jscomp$1194$$,onClose:$on_close_menu$jscomp$1$$,onSelect:$on_select_palette$jscomp$1$$,selected:$APP.$cljs$core$_deref$$($selected$jscomp$154$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$color_palette$color_palette_STAR_$$,{size:$map__78611__$1_size$jscomp$156$$,selected:$APP.$cljs$core$_deref$$($selected$jscomp$154$$),width:$vport$jscomp$9_vport_width$$})]}):null]})]}):(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$toggle_palettes$$,"data-testid":"toggle-palettes-visibility",
className:"main_ui_workspace_palette__handler",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_palette__handler-btn"})})]})})};
$app$main$ui$workspace$main_menu$shortcuts_STAR_$$=function($props_78640$$){return(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__shortcut",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$140$$,$sc$jscomp$10$$){$out_arr__44092__auto__$jscomp$140$$.push((0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__shortcut-key",children:$sc$jscomp$10$$},$sc$jscomp$10$$));return $out_arr__44092__auto__$jscomp$140$$},
[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$workspace$shortcuts$get_tooltip$$($props_78640$$.id)))})};
$app$main$ui$workspace$main_menu$file_menu_STAR_$$=function($props_78682_shared_QMARK_$jscomp$5$$){var $on_close$jscomp$23$$=$props_78682_shared_QMARK_$jscomp$5$$.onClose,$file$jscomp$162$$=$props_78682_shared_QMARK_$jscomp$5$$.file,$file_id$jscomp$385$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$162$$);$props_78682_shared_QMARK_$jscomp$5$$=$APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$162$$);var $all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$selected$jscomp$155$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$);$all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$=$APP.$cljs$core$filterv$$($APP.$app$common$files$helpers$frame_shape_QMARK_$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$,$APP.$app$common$uuid$zero$$));var $on_remove_shared_key_down_selected_frames$jscomp$1$$=
$APP.$cljs$core$filterv$$(function($p1__78680_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected$jscomp$155$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78680_SHARP_$$))},$all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$),$frames$jscomp$26$$=$APP.$cljs$core$seq$$($on_remove_shared_key_down_selected_frames$jscomp$1$$)?$on_remove_shared_key_down_selected_frames$jscomp$1$$:$all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$;$all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$);$all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$);var $on_remove_shared$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$385$$)],function($event$jscomp$386$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$386$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$386$$);
return $app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5721$delete_shared_libraries$$,$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$5722$unpublish$$,$APP.$cljs$cst$1729$ids$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$file_id$jscomp$385$$]),$APP.$cljs$cst$2490$on_accept$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$set_file_shared$$($file_id$jscomp$385$$,
!1))},$APP.$cljs$cst$5723$count_libraries$$,1],null))});$on_remove_shared_key_down_selected_frames$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_remove_shared$$)],function($event$jscomp$387$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$387$$))?$on_remove_shared$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove_shared$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$387$$):$on_remove_shared$$($event$jscomp$387$$):
null});var $on_add_shared$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$385$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$show_shared_dialog$$($file_id$jscomp$385$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$set_file_shared$$($file_id$jscomp$385$$,!0))}))}),$on_add_shared_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_add_shared$$)],
function($event$jscomp$388$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$388$$))?$on_add_shared$$.$cljs$core$IFn$_invoke$arity$1$?$on_add_shared$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$388$$):$on_add_shared$$($event$jscomp$388$$):null}),$on_show_version_history$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$385$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3768$document_history$$))}),
$on_show_version_history_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_show_version_history$$)],function($event$jscomp$389$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$389$$))?$on_show_version_history$$.$cljs$core$IFn$_invoke$arity$1$?$on_show_version_history$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$389$$):$on_show_version_history$$($event$jscomp$389$$):null}),$on_pin_version$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$create_version$$())}),
$on_pin_version_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_pin_version$$)],function($event$jscomp$390$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$390$$))?$on_pin_version$$.$cljs$core$IFn$_invoke$arity$1$?$on_pin_version$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$390$$):$on_pin_version$$($event$jscomp$390$$):null}),$on_export_shapes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$exports$assets$show_workspace_export_dialog$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1792$origin$$,"workspace:menu"],null)))}),$on_export_shapes_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_export_shapes$$)],function($event$jscomp$391$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$391$$))?$on_export_shapes$$.$cljs$core$IFn$_invoke$arity$1$?$on_export_shapes$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$391$$):$on_export_shapes$$($event$jscomp$391$$):null}),$on_export_file$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$162$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$exports$files$open_export_dialog$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file$jscomp$162$$],null)),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace:menu"],null)))}),$on_export_file_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_export_file$$)],function($event$jscomp$392$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$392$$))?$on_export_file$$.$cljs$core$IFn$_invoke$arity$1$?$on_export_file$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$392$$):$on_export_file$$($event$jscomp$392$$):null}),$on_export_frames$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frames$jscomp$26$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$exports$assets$show_workspace_export_frames_dialog$$($APP.$cljs$core$reverse$$($frames$jscomp$26$$)))}),$on_export_frames_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_export_frames$$)],function($event$jscomp$393$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$393$$))?$on_export_frames$$.$cljs$core$IFn$_invoke$arity$1$?
$on_export_frames$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$393$$):$on_export_frames$$($event$jscomp$393$$):null});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-1",onClose:$on_close$jscomp$23$$,children:[$props_78682_shared_QMARK_$jscomp$5$$?$APP.$cljs$core$truth_$$($all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_remove_shared$$,onKeyDown:$on_remove_shared_key_down_selected_frames$jscomp$1$$,id:"file-menu-remove-shared",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.unpublish-shared")})}):
null:$APP.$cljs$core$truth_$$($all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_add_shared$$,onKeyDown:$on_add_shared_key_down$$,id:"file-menu-add-shared",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.add-shared")})}):
null,$APP.$cljs$core$truth_$$($all_frames_can_edit$jscomp$4_objects$jscomp$782_perms$jscomp$2$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_main_menu__separator"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_pin_version$$,onKeyDown:$on_pin_version_key_down$$,
id:"file-menu-create-version",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.create-version-menu")})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_show_version_history$$,onKeyDown:$on_show_version_history_key_down$$,id:"file-menu-show-version-history",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.show-version-history")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4956$toggle_history$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_main_menu__separator"})]}):null,$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_export_shapes$$,onKeyDown:$on_export_shapes_key_down$$,id:"file-menu-export-shapes",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-shapes")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4191$export_shapes$$})]}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_export_file$$,onKeyDown:$on_export_file_key_down$$,"data-format":"binfile-v3",id:"file-menu-binary-file",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.download-binary-file")})}),
$APP.$cljs$core$seq$$($frames$jscomp$26$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_export_frames$$,onKeyDown:$on_export_frames_key_down$$,id:"file-menu-export-frames",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.export-frames")})}):
null]})};
$app$main$ui$workspace$main_menu$mcp_menu_STAR_$$=function($plugins_enabled_QMARK__props_78689$$){var $on_close$jscomp$25$$=$plugins_enabled_QMARK__props_78689$$.onClose,$conn_status_mcp_on_nav_to_integrations_key_down$$=$plugins_enabled_QMARK__props_78689$$.mcp;$plugins_enabled_QMARK__props_78689$$=$APP.$app$main$features$use_feature$$("plugins/runtime");var $has_valid_token_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($conn_status_mcp_on_nav_to_integrations_key_down$$,$APP.$cljs$cst$4409$token_valid$$),
$enabled_QMARK_$jscomp$7_show_enabled_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($conn_status_mcp_on_nav_to_integrations_key_down$$,$APP.$cljs$cst$3133$enabled$$);$conn_status_mcp_on_nav_to_integrations_key_down$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($conn_status_mcp_on_nav_to_integrations_key_down$$,$APP.$cljs$cst$4398$connection_status$$);var $connected_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($conn_status_mcp_on_nav_to_integrations_key_down$$,
"connected");$enabled_QMARK_$jscomp$7_show_enabled_QMARK_$$=$APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$7_show_enabled_QMARK_$$)?$has_valid_token_QMARK_$$:$enabled_QMARK_$jscomp$7_show_enabled_QMARK_$$;var $on_nav_to_integrations$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"manage-mpc-option",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("/#/settings/integrations")});$conn_status_mcp_on_nav_to_integrations_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$397$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$397$$))?$on_nav_to_integrations$$.$cljs$core$IFn$_invoke$arity$0$?
$on_nav_to_integrations$$.$cljs$core$IFn$_invoke$arity$0$():$on_nav_to_integrations$$():null});var $on_toggle_mcp_plugin$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($connected_QMARK_$$)],function(){return $connected_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$mcp$user_disconnect_mcp$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"disconnect-mcp-plugin",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null))])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$mcp$connect_mcp$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"connect-mcp-plugin",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null))]))}),$on_toggle_mcp_plugin_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$398$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$398$$))?$on_toggle_mcp_plugin$$.$cljs$core$IFn$_invoke$arity$0$?$on_toggle_mcp_plugin$$.$cljs$core$IFn$_invoke$arity$0$():$on_toggle_mcp_plugin$$():null});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu "+($plugins_enabled_QMARK__props_78689$$?"":"main_ui_workspace_main_menu__pos-5")+" "+($plugins_enabled_QMARK__props_78689$$?"main_ui_workspace_main_menu__pos-6":""),onClose:$on_close$jscomp$25$$,children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$7_show_enabled_QMARK_$$)?$has_valid_token_QMARK_$$:$enabled_QMARK_$jscomp$7_show_enabled_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{id:"mcp-menu-toggle-mcp-plugin",className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_toggle_mcp_plugin$$,onKeyDown:$on_toggle_mcp_plugin_key_down$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$connected_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.mcp.plugin.status.disconnect"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.mcp.plugin.status.connect")})}):
null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{id:"mcp-menu-nav-to-integrations",className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$on_nav_to_integrations$$,onKeyDown:$conn_status_mcp_on_nav_to_integrations_key_down$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$7_show_enabled_QMARK_$$)?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.mcp.server.status.enabled"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.mcp.server.status.disabled")})})]})};
$app$main$ui$workspace$main_menu$menu_STAR_$$=function($props_78691_toggle_menu$$){var $layout$jscomp$23$$=$props_78691_toggle_menu$$.layout,$file$jscomp$163$$=$props_78691_toggle_menu$$.file,$profile$jscomp$78$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$show_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_menu_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($show_menu_STAR_$$),$selected_sub_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$selected_sub_menu$$=$APP.$cljs$core$_deref$$($selected_sub_menu_STAR_$$),$mcp$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$mcp$$);$props_78691_toggle_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$399$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$399$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_menu_STAR_$$,$APP.$cljs$core$not$$);return $APP.$cljs$core$not$$($show_menu_QMARK_$jscomp$1$$)?$APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,
null):null});var $close_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$400$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$400$$);return $APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$$,!1)}),$close_sub_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$401$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$401$$);return $APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,null)}),$close_all_menus$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,null)}),$on_menu_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$402_menu$jscomp$1$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$402_menu$jscomp$1$$);$event$jscomp$402_menu$jscomp$1$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$402_menu$jscomp$1$$),
"testid"));return $APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,$event$jscomp$402_menu$jscomp$1$$)}),$on_power_up_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-pricing-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/pricing")}),$toggle_flag$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$403_flag$jscomp$13$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$403_flag$jscomp$13$$);$event$jscomp$403_flag$jscomp$13$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$403_flag$jscomp$13$$),
"testid"));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($event$jscomp$403_flag$jscomp$13$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"));$APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,null)}),$toggle_theme$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$404$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$404$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$profile$toggle_theme$$())}),$toggle_render$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile$jscomp$78$$)],function($event$jscomp$405_next_renderer_renderer$jscomp$2$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$405_next_renderer_renderer$jscomp$2$$);$event$jscomp$405_next_renderer_renderer$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1160$$=
$APP.$cljs$cst$3129$renderer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$78$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1160$$)?$or__5025__auto__$jscomp$1160$$:$APP.$cljs$cst$1543$svg$$}();$event$jscomp$405_next_renderer_renderer$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$405_next_renderer_renderer$jscomp$2$$,$APP.$cljs$cst$3128$wasm$$)?$APP.$cljs$cst$1543$svg$$:$APP.$cljs$cst$3128$wasm$$;
var $ev_name$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$405_next_renderer_renderer$jscomp$2$$,$APP.$cljs$cst$3128$wasm$$)?"enable-webgl-rendering":"disable-webgl-rendering";$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function(){return $APP.$app$util$dom$reload_current_window$$.$cljs$core$IFn$_invoke$arity$1$(!0)},function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$error$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.generic")))},
$APP.$beicon$v2$core$timeout$cljs$0core$0IFn$0_invoke$0arity$03$$(2E3,(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2364$timeout$$),$APP.$beicon$v2$core$zip$$($APP.$app$main$repo$cmd_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3221$update_profile_props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$575$props$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3129$renderer$$,$event$jscomp$405_next_renderer_renderer$jscomp$2$$],null)],null)),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2336$app_DOT_main_DOT_data_DOT_event_SLASH_chunk_persisted$$),
$APP.$app$main$store$stream$$))));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,$ev_name$jscomp$1$$,$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2339$app_DOT_main_DOT_data_DOT_event_SLASH_force_persist$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))}),$open_plugins_manager$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$406$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$406$$);$APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$$,!1);$APP.$cljs$core$reset_BANG_$$($selected_sub_menu_STAR_$$,null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"open-plugins-manager",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5006$plugin_management$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))}),$subscription$jscomp$9_subscription_type$jscomp$9$$=$APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$78$$));
$subscription$jscomp$9_subscription_type$jscomp$9$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($subscription$jscomp$9_subscription_type$jscomp$9$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $disposable$jscomp$7$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($close_all_menus$$,$APP.$beicon$v2$core$filter$$(function($p1__78690_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2177$interrupt$$,
$p1__78690_SHARP_$$)},$APP.$app$main$store$stream$$));return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$beicon$v2$core$dispose_BANG_$$,$disposable$jscomp$7$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-pressed":$show_menu_QMARK_$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-subsection.main-menu"),
onClick:$props_78691_toggle_menu$$,icon:"menu"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:$show_menu_QMARK_$jscomp$1$$,id:"workspace:menu",onClose:$close_menu$jscomp$1$$,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__menu",children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",
onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$407$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$407$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$407$$):$on_menu_click$jscomp$2$$($event$jscomp$407$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"file",id:"file-menu-file",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.file")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$408$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$408$$))?
$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$408$$):$on_menu_click$jscomp$2$$($event$jscomp$408$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"edit",id:"file-menu-edit",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.edit")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$409$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$409$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$409$$):
$on_menu_click$jscomp$2$$($event$jscomp$409$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"view",id:"file-menu-view",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.view")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$410$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$410$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$410$$):$on_menu_click$jscomp$2$$($event$jscomp$410$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"preferences",
id:"file-menu-preferences",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.preferences")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")?
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$411$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$411$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$411$$):$on_menu_click$jscomp$2$$($event$jscomp$411$$):
null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"plugins",id:"file-menu-plugins",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.menu.title")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1237$mcp$$)?function(){var $enabled_QMARK_$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mcp$jscomp$1$$,$APP.$cljs$cst$3133$enabled$$),$active_QMARK_$jscomp$4_conn_status$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mcp$jscomp$1$$,$APP.$cljs$cst$4398$connection_status$$),$has_valid_token_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mcp$jscomp$1$$,$APP.$cljs$cst$4409$token_valid$$),$connected_QMARK_$jscomp$1_failed_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_QMARK_$jscomp$4_conn_status$jscomp$1$$,"connected"),$error_QMARK_$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_QMARK_$jscomp$4_conn_status$jscomp$1$$,"error");$active_QMARK_$jscomp$4_conn_status$jscomp$1$$=$APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$8$$)?$connected_QMARK_$jscomp$1_failed_QMARK_$$:$enabled_QMARK_$jscomp$8$$;$connected_QMARK_$jscomp$1_failed_QMARK_$$=function(){var $or__5025__auto__$jscomp$1161$$=
$APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$8$$)?$error_QMARK_$jscomp$3$$:$enabled_QMARK_$jscomp$8$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1161$$)?$or__5025__auto__$jscomp$1161$$:$APP.$cljs$core$not$$($has_valid_token_QMARK_$jscomp$1$$)}();return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$412$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$412$$))?
$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$412$$):$on_menu_click$jscomp$2$$($event$jscomp$412$$):null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"mcp",id:"file-menu-mcp",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.mcp")}),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-indicator "+($APP.$cljs$core$truth_$$($active_QMARK_$jscomp$4_conn_status$jscomp$1$$)?"main_ui_workspace_main_menu__active":"")+" "+($APP.$cljs$core$truth_$$($connected_QMARK_$jscomp$1_failed_QMARK_$$)?"main_ui_workspace_main_menu__failed":"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]})}():null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_main_menu__separator"}),
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",onClick:$on_menu_click$jscomp$2$$,onKeyDown:function($event$jscomp$413$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$413$$))?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_menu_click$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$413$$):$on_menu_click$jscomp$2$$($event$jscomp$413$$):
null},onPointerEnter:$on_menu_click$jscomp$2$$,"data-testid":"help-info",id:"file-menu-help-info",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.option.help-info")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_workspace_main_menu__item-arrow"})]}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1224$subscriptions$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("enterprise",$subscription$jscomp$9_subscription_type$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$dashboard$subscription$main_menu_power_up_STAR_$$,{closeSubMenu:$close_sub_menu$jscomp$2$$}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1186$subscriptions_old$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__menu-item",
onClick:$on_power_up_click$jscomp$1$$,onKeyDown:function($event$jscomp$414$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$414$$))?$on_power_up_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_power_up_click$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_power_up_click$jscomp$1$$():null},onPointerEnter:$close_sub_menu$jscomp$2$$,id:"file-menu-power-up",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("subscription.workspace.header.menu.option.power-up")})}):
null]}),function(){switch($selected_sub_menu$$ instanceof $APP.$cljs$core$Keyword$$?$selected_sub_menu$$.$fqn$:null){case "file":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$file_menu_STAR_$$,{file:$file$jscomp$163$$,onClose:$close_sub_menu$jscomp$2$$});case "edit":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$edit_menu_STAR_$$,{onClose:$close_sub_menu$jscomp$2$$});case "view":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$view_menu_STAR_$$,
{layout:$layout$jscomp$23$$,toggleFlag:$toggle_flag$jscomp$2$$,onClose:$close_sub_menu$jscomp$2$$});case "preferences":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$preferences_menu_STAR_$$,{layout:$layout$jscomp$23$$,profile:$profile$jscomp$78$$,toggleFlag:$toggle_flag$jscomp$2$$,toggleTheme:$toggle_theme$jscomp$1$$,toggleRender:$toggle_render$jscomp$1$$,onClose:$close_sub_menu$jscomp$2$$});case "plugins":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$plugins_menu_STAR_$$,
{openPlugins:$open_plugins_manager$$,onClose:$close_sub_menu$jscomp$2$$});case "mcp":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$mcp_menu_STAR_$$,{onClose:$close_sub_menu$jscomp$2$$,mcp:$mcp$jscomp$1$$});case "help-info":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$help_info_menu_STAR_$$,{layout:$layout$jscomp$23$$,onClose:$close_sub_menu$jscomp$2$$});default:return null}}()]})};
$app$main$ui$workspace$left_header$left_header_STAR_$$=function($class$$jscomp$65_props_78693$$){var $layout$jscomp$24$$=$class$$jscomp$65_props_78693$$.layout,$file$jscomp$164$$=$class$$jscomp$65_props_78693$$.file,$project$jscomp$21$$=$class$$jscomp$65_props_78693$$.project;$class$$jscomp$65_props_78693$$=$class$$jscomp$65_props_78693$$.className;var $file_id$jscomp$386$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$164$$),$file_name$jscomp$8$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$164$$),
$project_id$jscomp$35$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$21$$),$shared_QMARK_$jscomp$6$$=$APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$164$$),$handle_name_keydown_persistence$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$persistence$$),$persistence_status$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_name_keydown_persistence$jscomp$1$$,$APP.$cljs$cst$109$status$$),$editing_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$editing_QMARK_$jscomp$3$$=$APP.$cljs$core$_deref$$($editing_STAR_$$),$input_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(null),$handle_blur$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$386$$)],function(){var $value$jscomp$807$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$6$$)));$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$807$$,
"")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$rename_file$$($file_id$jscomp$386$$,$value$jscomp$807$$));return $APP.$cljs$core$reset_BANG_$$($editing_STAR_$$,!1)});$handle_name_keydown_persistence$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_blur$jscomp$3$$)],function($event$jscomp$415$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$415$$))?$handle_blur$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?
$handle_blur$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$415$$):$handle_blur$jscomp$3$$($event$jscomp$415$$):null});var $start_editing_name$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$416$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$416$$);return $APP.$cljs$core$reset_BANG_$$($editing_STAR_$$,!0)}),$close_modals$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$stop_picker$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}),$go_back$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$close_modals$$.$cljs$core$IFn$_invoke$arity$0$?$close_modals$$.$cljs$core$IFn$_invoke$arity$0$():$close_modals$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$set_options_mode$$($APP.$cljs$cst$3782$design$$),
$APP.$app$main$data$common$go_to_dashboard_recent$$()]))}),$nav_to_project$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($project_id$jscomp$35$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$common$go_to_dashboard_files$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2467$app_DOT_main_DOT_router_SLASH_new_window$$,
!0,$APP.$cljs$cst$2189$project_id$$,$project_id$jscomp$35$$]))]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$3$$)],function(){return $editing_QMARK_$jscomp$3$$?$APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$6$$)):null});return(0,$APP.$rumext$v2$jsxs$$)("header",{className:""+($class$$jscomp$65_props_78693$$??"")+" main_ui_workspace_left_header__workspace-header-left",children:[(0,$APP.$rumext$v2$jsx$$)("a",
{onClick:$go_back$jscomp$1$$,className:"main_ui_workspace_left_header__main-icon",children:$APP.$app$main$ui$icons$logo_icon$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sitemap"),className:"main_ui_workspace_left_header__project-tree",children:[(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$nav_to_project$$,className:"main_ui_workspace_left_header__project-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($project$jscomp$21$$)}),
$editing_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$input_ref$jscomp$6$$,onBlur:$handle_blur$jscomp$3$$,onKeyDown:$handle_name_keydown_persistence$jscomp$1$$,autoFocus:!0,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$164$$,""),className:"main_ui_workspace_left_header__file-name-input"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$file_name$jscomp$8$$,onDoubleClick:$start_editing_name$$,className:"main_ui_workspace_left_header__file-name",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:function(){switch($persistence_status$$ instanceof $APP.$cljs$core$Keyword$$?$persistence_status$$.$fqn$:null){case "pending":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.saving");case "saving":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.saving");case "saved":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.saved");case "error":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.save-error");
default:return null}}(),className:function(){switch($persistence_status$$ instanceof $APP.$cljs$core$Keyword$$?$persistence_status$$.$fqn$:null){case "pending":return"main_ui_workspace_left_header__status-notification main_ui_workspace_left_header__pending-status";case "saving":return"main_ui_workspace_left_header__status-notification main_ui_workspace_left_header__saving-status";case "saved":return"main_ui_workspace_left_header__status-notification main_ui_workspace_left_header__saved-status";case "error":return"main_ui_workspace_left_header__status-notification main_ui_workspace_left_header__error-status";
default:return"main_ui_workspace_left_header__status-notification"}}(),children:function(){switch($persistence_status$$ instanceof $APP.$cljs$core$Keyword$$?$persistence_status$$.$fqn$:null){case "pending":return $APP.$app$main$ui$icons$status_alert$$;case "saving":return $APP.$app$main$ui$icons$status_alert$$;case "saved":return $APP.$app$main$ui$icons$status_tick$$;case "error":return $APP.$app$main$ui$icons$status_wrong$$;default:return null}}()}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_left_header__file-name-label",
children:$file_name$jscomp$8$$})]})]}),$shared_QMARK_$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_left_header__shared-badge",children:$APP.$app$main$ui$icons$library$$}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_left_header__menu-section",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$menu_STAR_$$,{layout:$layout$jscomp$24$$,file:$file$jscomp$164$$})})]})};
$app$main$data$workspace$history$initialize_history$$=function(){typeof $app$main$data$workspace$history$initialize_history_78648$$==="undefined"&&($app$main$data$workspace$history$initialize_history_78648$$=function($meta78649$$){this.$meta78649$=$meta78649$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$history$initialize_history_78648$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$history$initialize_history_78648$$.prototype.$potok$v2$core$Event$_type$arity$1$=
function(){return $cljs$cst$5730$app_DOT_main_DOT_data_DOT_workspace_DOT_history_SLASH_initialize_history$$},$app$main$data$workspace$history$initialize_history_78648$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_78650$$,$meta78649__$1$$){return new $app$main$data$workspace$history$initialize_history_78648$$($meta78649__$1$$)},$app$main$data$workspace$history$initialize_history_78648$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta78649$},$app$main$data$workspace$history$initialize_history_78648$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$history$initialize_history_78648$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3036$$,$___$1$jscomp$2096$$,$stream$jscomp$107$$){return $APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$layout$toggle_layout_flag$$($APP.$cljs$cst$3768$document_history$$)),$APP.$beicon$v2$core$map$$(function(){return $APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3768$document_history$$)},
$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$($APP.$app$main$data$workspace$common$interrupt_QMARK_$$,$stream$jscomp$107$$))))});return new $app$main$data$workspace$history$initialize_history_78648$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$right_header$right_header_STAR_$$=function($props_78703_zoom$jscomp$69$$){var $file_id$jscomp$387$$=$props_78703_zoom$jscomp$69$$.fileId,$layout$jscomp$25$$=$props_78703_zoom$jscomp$69$$.layout,$page_id$jscomp$425$$=$props_78703_zoom$jscomp$69$$.pageId,$threads_map$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comment_threads$$);$props_78703_zoom$jscomp$69$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$);var $read_only_QMARK_$jscomp$12$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),
$selected_drawtool$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_drawing_tool$$),$on_increase$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}),$on_decrease$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}),
$on_zoom_reset$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$reset_zoom$$)}),$on_zoom_fit$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$)}),$on_zoom_selected$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$)}),
$editing_STAR_$jscomp$1_has_unread_comments_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$editing_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($editing_STAR_$jscomp$1_has_unread_comments_QMARK_$$),$input_ref$jscomp$7$$=(0,$APP.$rumext$v2$use_ref$$)(null),$team$jscomp$67$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$),$permissions$jscomp$34$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($team$jscomp$67$$,$APP.$cljs$cst$1728$permissions$$);$editing_STAR_$jscomp$1_has_unread_comments_QMARK_$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($threads_map$jscomp$6$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$)],function(){return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$(function($p1__78702_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78702_SHARP_$$),$file_id$jscomp$387$$)&&$APP.$cljs$cst$3481$count_unread_comments$$.$cljs$core$IFn$_invoke$arity$1$($p1__78702_SHARP_$$)>
0},$APP.$cljs$core$vals$$($threads_map$jscomp$6$$)))});var $display_share_button_QMARK_$$=function(){var $and__5023__auto__$jscomp$781_or__5025__auto__$jscomp$1162$$=$APP.$cljs$core$not$$($APP.$cljs$cst$5017$is_default$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$67$$));return $and__5023__auto__$jscomp$781_or__5025__auto__$jscomp$1162$$?($and__5023__auto__$jscomp$781_or__5025__auto__$jscomp$1162$$=$APP.$cljs$cst$1602$is_admin$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$34$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$781_or__5025__auto__$jscomp$1162$$)?
$and__5023__auto__$jscomp$781_or__5025__auto__$jscomp$1162$$:$APP.$cljs$cst$1603$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$34$$)):$and__5023__auto__$jscomp$781_or__5025__auto__$jscomp$1162$$}(),$nav_to_viewer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$387$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$425$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$425$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$387$$,$APP.$cljs$cst$1371$section$$,"interactions"],null)])))}),$active_comments$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout$jscomp$25$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$(),
$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3768$document_history$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-header"),$APP.$app$main$data$workspace$drawing$select_for_drawing$$($APP.$cljs$cst$3489$comments$$)]))}),$toggle_comments$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_drawtool$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_drawtool$$,
$APP.$cljs$cst$3489$comments$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$drawing$common$clear_drawing$$()):$active_comments$$.$cljs$core$IFn$_invoke$arity$0$?$active_comments$$.$cljs$core$IFn$_invoke$arity$0$():$active_comments$$()}),$toggle_history$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_drawtool$$)],function(){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3489$comments$$,
$selected_drawtool$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$data$workspace$history$initialize_history$$(),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"workspace-header"))}),$open_share_dialog$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team$jscomp$67$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$team$check_and_invite_members$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1944$team_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($team$jscomp$67$$),$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$2543$workspace$$],
null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$4$$)],function(){return $editing_QMARK_$jscomp$4$$?$APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$7$$)):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_right_header__workspace-header-right",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__users-section",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$presence$active_sessions_STAR_$$,
{})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$exports$assets$progress_widget$$,{}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__separator"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__zoom-section",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$right_header$zoom_widget_workspace$$,{zoom:$props_78703_zoom$jscomp$69$$,"on-increase":$on_increase$jscomp$2$$,"on-decrease":$on_decrease$jscomp$2$$,"on-zoom-reset":$on_zoom_reset$jscomp$2$$,
"on-zoom-fit":$on_zoom_fit$jscomp$2$$,"on-zoom-selected":$on_zoom_selected$jscomp$1$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__comments-section",children:(0,$APP.$rumext$v2$jsxs$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.comments",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4917$add_comment$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.comments",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4917$add_comment$$)])),onClick:$toggle_comments$$,"data-tool":"comments",style:{position:"relative"},className:"main_ui_workspace_right_header__comments-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_drawtool$$,$APP.$cljs$cst$3489$comments$$)?"main_ui_workspace_right_header__selected":""),children:[$APP.$app$main$ui$icons$comments$$,$editing_STAR_$jscomp$1_has_unread_comments_QMARK_$$?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__unread"}):null]})}),$read_only_QMARK_$jscomp$12$$?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_right_header__history-section",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.history"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.history"),onClick:$toggle_history$$,className:($APP.$cljs$core$contains_QMARK_$$($layout$jscomp$25$$,
$APP.$cljs$cst$3768$document_history$$)?"main_ui_workspace_right_header__selected":"")+" main_ui_workspace_right_header__history-button",children:$APP.$app$main$ui$icons$history$$})}),$APP.$cljs$core$truth_$$($display_share_button_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("a",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.share"),onClick:$open_share_dialog$jscomp$1$$,className:"main_ui_workspace_right_header__viewer-btn",children:$APP.$app$main$ui$icons$share$$}):null,
(0,$APP.$rumext$v2$jsx$$)("a",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.header.viewer",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4953$open_viewer$$)])),onClick:$nav_to_viewer$$,className:"main_ui_workspace_right_header__viewer-btn",children:$APP.$app$main$ui$icons$play$$})]})};
$app$main$ui$workspace$sidebar$assets$colors$color_item_STAR_$$=function($dragging_QMARK_$jscomp$5_props_78706$$){var $selected_paths$jscomp$4$$=$dragging_QMARK_$jscomp$5_props_78706$$.selectedPaths,$on_asset_click$$=$dragging_QMARK_$jscomp$5_props_78706$$.onAssetClick,$selected_full$jscomp$2$$=$dragging_QMARK_$jscomp$5_props_78706$$.selectedFull,$on_assets_delete$$=$dragging_QMARK_$jscomp$5_props_78706$$.onAssetsDelete,$selected$jscomp$156$$=$dragging_QMARK_$jscomp$5_props_78706$$.selected,$file_id$jscomp$388$$=
$dragging_QMARK_$jscomp$5_props_78706$$.fileId,$color$jscomp$165$$=$dragging_QMARK_$jscomp$5_props_78706$$.color,$move_color$$=$dragging_QMARK_$jscomp$5_props_78706$$.moveColor,$is_multi_colors$$=$dragging_QMARK_$jscomp$5_props_78706$$.isMultiColors,$is_local$jscomp$1$$=$dragging_QMARK_$jscomp$5_props_78706$$.isLocal,$on_clear_selection$jscomp$1$$=$dragging_QMARK_$jscomp$5_props_78706$$.onClearSelection,$on_group$$=$dragging_QMARK_$jscomp$5_props_78706$$.onGroup,$is_multi_assets$$=$dragging_QMARK_$jscomp$5_props_78706$$.isMultiAssets,
$color__$1$jscomp$32$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$165$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$388$$)],function(){var $G__78707__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$165$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$165$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$165$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1740$opacity$$,1])):$color$jscomp$165$$;return $APP.$cljs$core$truth_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$165$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__78707__$1$$,$APP.$cljs$cst$260$value$$):$G__78707__$1$$}),$color_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$item_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(),
$dragging_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$dragging_QMARK_$jscomp$5_props_78706$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$5$$);var $default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3972$color_for_rename$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_local$$)),$color_id$jscomp$9$$),$input_ref$jscomp$8$$=(0,$APP.$rumext$v2$use_ref$$)(),
$editing_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$),$editing_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($editing_STAR_$jscomp$2$$),$menu_state$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$),$read_only_QMARK_$jscomp$13$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);
$default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$=$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$);var $alpha_suffix_display_name$$=typeof $default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$==="number"&&$default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$<1?" "+($APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$*100)??"")+"%":null;$default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$=
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$))?$APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color__$1$jscomp$32$$,$APP.$cljs$cst$1730$gradient$$),$APP.$cljs$cst$139$type$$)):$APP.$cljs$core$truth_$$($APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$))?$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$):
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$);$alpha_suffix_display_name$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($alpha_suffix_display_name$$)?$APP.$cljs$core$not$$($APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$)):$alpha_suffix_display_name$$)?""+($default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$??"")+($alpha_suffix_display_name$$??""):$default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$;
var $rename_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$388$$),$APP.$rumext$v2$adapt$$($color_id$jscomp$9$$)],function($name$jscomp$450$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$rename_color$$($file_id$jscomp$388$$,$color_id$jscomp$9$$,$name$jscomp$450$$))}),$edit_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$388$$)],function($attrs$jscomp$174_color__$2$jscomp$3$$){var $name$jscomp$451$$=$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$));$attrs$jscomp$174_color__$2$jscomp$3$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($attrs$jscomp$174_color__$2$jscomp$3$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$)),$APP.$cljs$cst$725$name$$,$name$jscomp$451$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_color$$($attrs$jscomp$174_color__$2$jscomp$3$$,$file_id$jscomp$388$$))}),$delete_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_multi_colors$$),$APP.$rumext$v2$adapt$$($is_multi_assets$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$388$$),$APP.$rumext$v2$adapt$$($color_id$jscomp$9$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_multi_colors$$)?$is_multi_colors$$:$is_multi_assets$$))return $on_assets_delete$$.$cljs$core$IFn$_invoke$arity$0$?$on_assets_delete$$.$cljs$core$IFn$_invoke$arity$0$():$on_assets_delete$$();var $undo_id$jscomp$92$$=Symbol();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$92$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$delete_color$$($color__$1$jscomp$32$$),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$388$$,$file_id$jscomp$388$$,$APP.$cljs$cst$2220$colors$$,$color_id$jscomp$9$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$92$$)]))}),$duplicate_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$388$$),
$APP.$rumext$v2$adapt$$($color_id$jscomp$9$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$duplicate_color$$($file_id$jscomp$388$$,$color_id$jscomp$9$$))}),$rename_color_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$13$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$1$$)],function($event$jscomp$421$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$1$$)?
$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$13$$):$is_local$jscomp$1$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$421$$),$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$2$$,!0)):null}),$input_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($rename_color$$)],function($event$jscomp$422_name$jscomp$452$$){$event$jscomp$422_name$jscomp$452$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$422_name$jscomp$452$$);$rename_color$$.$cljs$core$IFn$_invoke$arity$1$?
$rename_color$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$422_name$jscomp$452$$):$rename_color$$($event$jscomp$422_name$jscomp$452$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$clear_color_for_rename$$);return $APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$2$$,!1)}),$input_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($input_blur$$)],function($event$jscomp$423$$){$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$423$$))&&
($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$clear_color_for_rename$$),$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$2$$,!1));return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$423$$))?$input_blur$$.$cljs$core$IFn$_invoke$arity$1$?$input_blur$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$423$$):$input_blur$$($event$jscomp$423$$):null}),$edit_color_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($edit_color$$),
$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$)],function($event$jscomp$424$$){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2247$colorpicker$$,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1515$x$$,$event$jscomp$424$$.clientX,$APP.$cljs$cst$1516$y$$,$event$jscomp$424$$.clientY,$APP.$cljs$cst$2490$on_accept$$,$edit_color$$,$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$3767$assets$$,$APP.$cljs$cst$142$data$$,$color__$1$jscomp$32$$,$APP.$cljs$cst$1681$position$$,
$APP.$cljs$cst$258$right$$],null))}),$on_context_menu$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_id$jscomp$9$$),$APP.$rumext$v2$adapt$$($selected$jscomp$156$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$1$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$13$$)],function($event$jscomp$425_pos$jscomp$136$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$425_pos$jscomp$136$$);$event$jscomp$425_pos$jscomp$136$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$425_pos$jscomp$136$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$1$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$13$$):$is_local$jscomp$1$$)?($APP.$cljs$core$contains_QMARK_$$($selected$jscomp$156$$,$color_id$jscomp$9$$)||($on_clear_selection$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$1$$()),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($menu_state$jscomp$1$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,
$event$jscomp$425_pos$jscomp$136$$)):null}),$on_close_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_state$jscomp$1$$,$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$)}),$on_drop$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$5$$),$APP.$rumext$v2$adapt$$($selected$jscomp$156$$),
$APP.$rumext$v2$adapt$$($selected_full$jscomp$2$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$4$$),$APP.$rumext$v2$adapt$$($move_color$$)],function($event$jscomp$426$$){return $app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$($event$jscomp$426$$,$color__$1$jscomp$32$$,$dragging_STAR_$jscomp$5$$,$selected$jscomp$156$$,$selected_full$jscomp$2$$,$selected_paths$jscomp$4$$,$move_color$$)}),$on_drag_enter$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),
$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$5$$),$APP.$rumext$v2$adapt$$($selected$jscomp$156$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$4$$)],function($event$jscomp$427$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$($event$jscomp$427$$,$color__$1$jscomp$32$$,$dragging_STAR_$jscomp$5$$,$selected$jscomp$156$$,$selected_paths$jscomp$4$$)}),$on_drag_leave$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$5$$)],
function($event$jscomp$428$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$428$$,$dragging_STAR_$jscomp$5$$)}),$on_color_drag_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$388$$),$APP.$rumext$v2$adapt$$($selected$jscomp$156$$),$APP.$rumext$v2$adapt$$($item_ref$jscomp$3$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$13$$),$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$5$$)],
function($event$jscomp$429$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$13$$)?$read_only_QMARK_$jscomp$13$$:$editing_QMARK_$jscomp$5$$)?$APP.$app$util$dom$prevent_default$$($event$jscomp$429$$):$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$($event$jscomp$429$$,$file_id$jscomp$388$$,$color__$1$jscomp$32$$,$selected$jscomp$156$$,$item_ref$jscomp$3$$,$APP.$cljs$cst$2220$colors$$,$APP.$cljs$core$identity$$)}),$on_click$jscomp$41$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color__$1$jscomp$32$$),
$APP.$rumext$v2$adapt$$($on_asset_click$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$13$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$388$$)],function($event$jscomp$430$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$13$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-color",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,
"sidebar",$APP.$cljs$cst$4001$external_library$$,$APP.$cljs$core$not$$($is_local$jscomp$1$$)],null)));var $G__78709$jscomp$inline_8963_JSCompiler_inline_result$jscomp$1782$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$);$G__78709$jscomp$inline_8963_JSCompiler_inline_result$jscomp$1782$$=$on_asset_click$$.$cljs$core$IFn$_invoke$arity$2$?$on_asset_click$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$430$$,$G__78709$jscomp$inline_8963_JSCompiler_inline_result$jscomp$1782$$):
$on_asset_click$$($event$jscomp$430$$,$G__78709$jscomp$inline_8963_JSCompiler_inline_result$jscomp$1782$$);return $APP.$cljs$core$truth_$$($G__78709$jscomp$inline_8963_JSCompiler_inline_result$jscomp$1782$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$apply_color_from_assets$$($file_id$jscomp$388$$,$color__$1$jscomp$32$$,$event$jscomp$430$$.altKey))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$5$$)],
function(){$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$5$$)&&$APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$8$$));return null});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$2$$,onDragLeave:$on_drag_leave$jscomp$2$$,className:"main_ui_workspace_sidebar_assets_colors__asset-list-item "+($APP.$cljs$core$contains_QMARK_$$($selected$jscomp$156$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$))?"main_ui_workspace_sidebar_assets_colors__selected":
"")+" "+($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$5$$)?"main_ui_workspace_sidebar_assets_colors__editing":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_colors__bullet-block",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$color_bullet$color_bullet_STAR_$$,{color:$color__$1$jscomp$32$$,mini:!0})}),$editing_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$input_ref$jscomp$8$$,onBlur:$input_blur$$,onKeyDown:$input_key_down$$,
autoFocus:!0,maxLength:255,defaultValue:$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$)),className:"main_ui_workspace_sidebar_assets_colors__element-name"}):(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$)?
$alpha_suffix_display_name$$:""+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$)??"")+" ("+($alpha_suffix_display_name$$??"")+")",onDoubleClick:$rename_color_clicked$$,className:"main_ui_workspace_sidebar_assets_colors__name-block",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),$default_name$jscomp$1_opacity$jscomp$50_rename_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_assets_colors__default-name",children:$alpha_suffix_display_name$$}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_colors__default-name main_ui_workspace_sidebar_assets_colors__default-name-with-color",children:$alpha_suffix_display_name$$})]})}),$APP.$cljs$core$truth_$$($is_local$jscomp$1$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,{onClose:$on_close_menu$jscomp$2$$,state:$APP.$cljs$core$_deref$$($menu_state$jscomp$1$$),options:new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_multi_colors$$)?$is_multi_colors$$:$is_multi_assets$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),
$APP.$cljs$cst$266$id$$,"assets-rename-color",$APP.$cljs$cst$2413$handler$$,$rename_color_clicked$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_multi_colors$$)?$is_multi_colors$$:$is_multi_assets$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.edit"),$APP.$cljs$cst$266$id$$,"assets-edit-color",$APP.$cljs$cst$2413$handler$$,$edit_color_clicked$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_multi_colors$$)?
$is_multi_colors$$:$is_multi_assets$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate"),$APP.$cljs$cst$266$id$$,"assets-duplicate-color",$APP.$cljs$cst$2413$handler$$,$duplicate_color$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),$APP.$cljs$cst$266$id$$,"assets-delete-color",
$APP.$cljs$cst$2413$handler$$,$delete_color$$],null),$APP.$cljs$core$truth_$$($is_multi_assets$$)?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.group"),$APP.$cljs$cst$266$id$$,"assets-group-color",$APP.$cljs$cst$2413$handler$$,function(){var $G__78710$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color__$1$jscomp$32$$);return $on_group$$.$cljs$core$IFn$_invoke$arity$1$?$on_group$$.$cljs$core$IFn$_invoke$arity$1$($G__78710$$):
$on_group$$($G__78710$$)}()],null)],null)}):null,$dragging_QMARK_$jscomp$5_props_78706$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_colors__dragging"}):null],onContextMenu:$on_context_menu$jscomp$3$$,onDrop:$on_drop$jscomp$5$$,style:{"--bullet-size":"16px"},onDragOver:$APP.$app$util$dom$prevent_default$$,draggable:$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$13$$)&&$APP.$cljs$core$not$$($editing_QMARK_$jscomp$5$$),onClick:$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$5$$)?
null:$on_click$jscomp$41$$,ref:$item_ref$jscomp$3$$,onDragStart:$on_color_drag_start$$})};
$app$main$ui$workspace$sidebar$assets$colors$colors_section_STAR_$$=function($props_78729_selected_full$jscomp$4$$){var $on_asset_click$jscomp$2_on_asset_click__$1$$=$props_78729_selected_full$jscomp$4$$.onAssetClick,$is_open$jscomp$4$$=$props_78729_selected_full$jscomp$4$$.isOpen,$open_status_ref$$=$props_78729_selected_full$jscomp$4$$.openStatusRef,$on_assets_delete$jscomp$2$$=$props_78729_selected_full$jscomp$4$$.onAssetsDelete,$file_id$jscomp$390$$=$props_78729_selected_full$jscomp$4$$.fileId,
$is_force_open$$=$props_78729_selected_full$jscomp$4$$.isForceOpen,$colors$jscomp$22$$=$props_78729_selected_full$jscomp$4$$.colors,$is_local$jscomp$2$$=$props_78729_selected_full$jscomp$4$$.isLocal,$on_clear_selection$jscomp$3$$=$props_78729_selected_full$jscomp$4$$.onClearSelection,$is_reverse_sort$$=$props_78729_selected_full$jscomp$4$$.isReverseSort,$selected__$1$jscomp$15$$=$APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($props_78729_selected_full$jscomp$4$$.selected);$props_78729_selected_full$jscomp$4$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$15$$),$APP.$rumext$v2$adapt$$($colors$jscomp$22$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78718_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$15$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78718_SHARP_$$))}),
$colors$jscomp$22$$)});var $open_groups$jscomp$3_open_groups_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_status_ref$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4449$groups$$,$APP.$cljs$cst$2220$colors$$],null)),$open_status_ref$$)});$open_groups$jscomp$3_open_groups_ref$$=
$APP.$rumext$v2$deref$$($open_groups$jscomp$3_open_groups_ref$$);var $multi_colors_QMARK_$jscomp$1$$=$APP.$cljs$core$count$$($selected__$1$jscomp$15$$)>1,$multi_assets_QMARK_$jscomp$1$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$15$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2483$graphics$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$15$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$15$$)),
$groups$jscomp$9$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$),$APP.$rumext$v2$adapt$$($is_reverse_sort$$)],function(){return $app$main$ui$workspace$sidebar$assets$groups$group_assets$$($colors$jscomp$22$$,$is_reverse_sort$$)}),$read_only_QMARK_$jscomp$14$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$add_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$808$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$add_color$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$808$$,
null))}),$add_color_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$390$$)],function($event$jscomp$434_x_position$$){var $bounds$jscomp$82_y_position$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_current_target$$($event$jscomp$434_x_position$$));$event$jscomp$434_x_position$$=$APP.$cljs$cst$258$right$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$82_y_position$$);$bounds$jscomp$82_y_position$$=$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($bounds$jscomp$82_y_position$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$390$$,$APP.$cljs$cst$2220$colors$$,!0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-asset-to-library",$APP.$cljs$cst$2556$asset_type$$,"color"],null)),$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2247$colorpicker$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$1515$x$$,$event$jscomp$434_x_position$$,$APP.$cljs$cst$1516$y$$,$bounds$jscomp$82_y_position$$,$APP.$cljs$cst$2490$on_accept$$,$add_color$$,$APP.$cljs$cst$1792$origin$$,$APP.$cljs$cst$3767$assets$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,"#406280",$APP.$cljs$cst$1740$opacity$$,1],null),$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$258$right$$],null))]))}),$create_group$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$15$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$3$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$390$$)],function($color_id$jscomp$10$$){return function($group_name$jscomp$3$$){$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$3$$();var $undo_id$jscomp$93$$=
Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$93$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78720_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_color$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78720_SHARP_$$,$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$add_group$$($p1__78720_SHARP_$$,
$group_name$jscomp$3$$)),$file_id$jscomp$390$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78719_SHARP_$$){return $multi_colors_QMARK_$jscomp$1$$?$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$15$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78719_SHARP_$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color_id$jscomp$10$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78719_SHARP_$$))},$colors$jscomp$22$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$93$$))}}),
$rename_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$)],function($path$jscomp$267$$,$last_path$jscomp$3$$){$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$3$$();var $undo_id$jscomp$94$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$94$$));
$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78725_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_color$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78725_SHARP_$$,$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$rename_group$$($p1__78725_SHARP_$$,$path$jscomp$267$$,$last_path$jscomp$3$$)),$file_id$jscomp$390$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78724_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78724_SHARP_$$),
$path$jscomp$267$$)},$colors$jscomp$22$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$94$$))}),$on_group$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$15$$)],function($color_id$jscomp$11$$){return function($event$jscomp$435$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$435$$);
return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5697$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$924$accept$$,$create_group$$.$cljs$core$IFn$_invoke$arity$1$?$create_group$$.$cljs$core$IFn$_invoke$arity$1$($color_id$jscomp$11$$):$create_group$$($color_id$jscomp$11$$)],null))}}),$on_rename_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$)],function($event$jscomp$436$$,
$path$jscomp$268$$,$last_path$jscomp$4$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$436$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5697$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$296$path$$,$path$jscomp$268$$,$cljs$cst$5700$last_path$$,$last_path$jscomp$4$$,$APP.$cljs$cst$924$accept$$,$rename_group$$],null))}),$on_ungroup$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$)],
function($path$jscomp$269$$){$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$3$$();var $undo_id$jscomp$95$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$95$$));$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78727_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_color$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78727_SHARP_$$,
$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$ungroup$$($p1__78727_SHARP_$$,$path$jscomp$269$$)),$file_id$jscomp$390$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78726_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78726_SHARP_$$),$path$jscomp$269$$)},$colors$jscomp$22$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$95$$))}),
$on_delete_group$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$22$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$3$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3767$assets$$,$colors$jscomp$22$$,$cljs$cst$5694$on_clear_selection$$,$on_clear_selection$jscomp$3$$,$cljs$cst$5695$delete_events$$,function($p1__78728_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($c$jscomp$315$$){return $APP.$app$main$data$workspace$libraries$delete_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$315$$)],null))},$p1__78728_SHARP_$$)}],null))});$on_asset_click$jscomp$2_on_asset_click__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$9$$),$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$2_on_asset_click__$1$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$2_on_asset_click__$1$$,$groups$jscomp$9$$));return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$,
{fileId:$file_id$jscomp$390$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors"),section:$APP.$cljs$cst$2220$colors$$,assetsCount:$APP.$cljs$core$count$$($colors$jscomp$22$$),isOpen:$is_open$jscomp$4$$,children:[$APP.$cljs$core$truth_$$($is_local$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$cljs$cst$5693$title_button$$,children:$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$14$$)?null:
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors.add-color"),onClick:$add_color_clicked$$,icon:"add"})}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$APP.$cljs$cst$1642$content$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$colors$colors_group$$,{"selected-full":$props_78729_selected_full$jscomp$4$$,
"on-assets-delete":$on_assets_delete$jscomp$2$$,"force-open?":$is_force_open$$,selected:$selected__$1$jscomp$15$$,"file-id":$file_id$jscomp$390$$,"multi-assets?":$multi_assets_QMARK_$jscomp$1$$,"on-ungroup":$on_ungroup$jscomp$2$$,"local?":$is_local$jscomp$2$$,colors:$colors$jscomp$22$$,"open-groups":$open_groups$jscomp$3_open_groups_ref$$,prefix:"","on-group":$on_group$jscomp$2$$,"on-clear-selection":$on_clear_selection$jscomp$3$$,"multi-colors?":$multi_colors_QMARK_$jscomp$1$$,"on-delete-group":$on_delete_group$jscomp$2$$,
groups:$groups$jscomp$9$$,"on-asset-click":$on_asset_click$jscomp$2_on_asset_click__$1$$,"on-rename-group":$on_rename_group$jscomp$1$$})})]})};
$app$main$ui$components$editable_label$editable_label_STAR_$$=function($display_value_props_78705$$){var $on_change$jscomp$46$$=$display_value_props_78705$$.onChange,$on_cancel$jscomp$7$$=$display_value_props_78705$$.onCancel,$tooltip$$=$display_value_props_78705$$.tooltip,$class_label$$=$display_value_props_78705$$.classLabel,$value$jscomp$809$$=$display_value_props_78705$$.value,$class_input$$=$display_value_props_78705$$.classInput,$is_editing$$=$display_value_props_78705$$.isEditing;$display_value_props_78705$$=
$display_value_props_78705$$.displayValue;var $input_ref$jscomp$9$$=(0,$APP.$rumext$v2$use_ref$$)(null),$internal_editing_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$internal_editing_QMARK_$$=$APP.$cljs$core$_deref$$($internal_editing_STAR_$$),$start_edition$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($internal_editing_STAR_$$,!0);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(100,
function(){var $temp__5825__auto__$jscomp$368$$=$APP.$rumext$v2$ref_val$$($input_ref$jscomp$9$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$368$$)?$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$368$$):null})}),$stop_edition$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($internal_editing_STAR_$$,!1)}),$accept_edition$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($internal_editing_QMARK_$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$46$$),$APP.$rumext$v2$adapt$$($stop_edition$$)],function(){if($APP.$cljs$core$truth_$$($internal_editing_QMARK_$$)){var $value__$1$jscomp$40$$=$APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$9$$));$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$46$$)&&($on_change$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$46$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$40$$):$on_change$jscomp$46$$($value__$1$jscomp$40$$));
return $stop_edition$$.$cljs$core$IFn$_invoke$arity$0$?$stop_edition$$.$cljs$core$IFn$_invoke$arity$0$():$stop_edition$$()}return null}),$cancel_edition$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stop_edition$$),$APP.$rumext$v2$adapt$$($on_cancel$jscomp$7$$)],function(){$stop_edition$$.$cljs$core$IFn$_invoke$arity$0$?$stop_edition$$.$cljs$core$IFn$_invoke$arity$0$():$stop_edition$$();return $APP.$cljs$core$fn_QMARK_$$($on_cancel$jscomp$7$$)?$on_cancel$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$?
$on_cancel$jscomp$7$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$jscomp$7$$():null}),$on_key_up$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cancel_edition$$),$APP.$rumext$v2$adapt$$($accept_edition$$)],function($event$jscomp$437$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$437$$))?$cancel_edition$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_edition$$.$cljs$core$IFn$_invoke$arity$0$():$cancel_edition$$():$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$437$$))?
$accept_edition$$.$cljs$core$IFn$_invoke$arity$0$?$accept_edition$$.$cljs$core$IFn$_invoke$arity$0$():$accept_edition$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$$),$APP.$rumext$v2$adapt$$($internal_editing_QMARK_$$),$APP.$rumext$v2$adapt$$($start_edition$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_editing$$)?$APP.$cljs$core$not$$($internal_editing_QMARK_$$):$is_editing$$)?$start_edition$$.$cljs$core$IFn$_invoke$arity$0$?
$start_edition$$.$cljs$core$IFn$_invoke$arity$0$():$start_edition$$():null});return $internal_editing_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("input",{ref:$input_ref$jscomp$9$$,defaultValue:$value$jscomp$809$$,onKeyUp:$on_key_up$$,maxLength:255,onBlur:$accept_edition$$,className:"main_ui_components_editable_label__editable-label-input "+($class_input$$??"")}):(0,$APP.$rumext$v2$jsx$$)("span",{title:$tooltip$$,className:"main_ui_components_editable_label__editable-label-text "+($class_label$$??""),children:$display_value_props_78705$$})};
$app$main$ui$workspace$sidebar$assets$components$get_component_root_and_container$$=function($file_id$jscomp$391_root_shape$jscomp$10$$,$component$jscomp$124_container$jscomp$86$$){var $data$jscomp$477$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$refs$files$$),$file_id$jscomp$391_root_shape$jscomp$10$$),$APP.$cljs$cst$142$data$$);$file_id$jscomp$391_root_shape$jscomp$10$$=$APP.$app$common$types$file$get_component_root$$($data$jscomp$477$$,
$component$jscomp$124_container$jscomp$86$$);$component$jscomp$124_container$jscomp$86$$=$APP.$app$common$types$file$get_component_page$$($data$jscomp$477$$,$component$jscomp$124_container$jscomp$86$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_id$jscomp$391_root_shape$jscomp$10$$,$component$jscomp$124_container$jscomp$86$$],null)};
$app$main$ui$workspace$sidebar$assets$components$components_item_STAR_$$=function($dragging_QMARK_$jscomp$7_props_78713$$){var $selected_paths$jscomp$6$$=$dragging_QMARK_$jscomp$7_props_78713$$.selectedPaths,$on_asset_click$jscomp$3$$=$dragging_QMARK_$jscomp$7_props_78713$$.onAssetClick,$selected_full$jscomp$5$$=$dragging_QMARK_$jscomp$7_props_78713$$.selectedFull,$selected$jscomp$159$$=$dragging_QMARK_$jscomp$7_props_78713$$.selected,$file_id$jscomp$392$$=$dragging_QMARK_$jscomp$7_props_78713$$.fileId,
$cancel_rename$$=$dragging_QMARK_$jscomp$7_props_78713$$.cancelRename,$is_listing_thumbs$$=$dragging_QMARK_$jscomp$7_props_78713$$.isListingThumbs,$num_variants$$=$dragging_QMARK_$jscomp$7_props_78713$$.numVariants,$on_context_menu$jscomp$4_on_context_menu__$1$$=$dragging_QMARK_$jscomp$7_props_78713$$.onContextMenu,$renaming_root_shape$jscomp$11$$=$dragging_QMARK_$jscomp$7_props_78713$$.renaming,$component$jscomp$125$$=$dragging_QMARK_$jscomp$7_props_78713$$.component,$do_rename$jscomp$2$$=$dragging_QMARK_$jscomp$7_props_78713$$.doRename,
$is_local$jscomp$3$$=$dragging_QMARK_$jscomp$7_props_78713$$.isLocal,$on_drag_start$jscomp$2$$=$dragging_QMARK_$jscomp$7_props_78713$$.onDragStart,$item_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(),$dragging_STAR_$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$dragging_QMARK_$jscomp$7_props_78713$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$7$$);var $read_only_QMARK_$jscomp$15$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),
$component_id$jscomp$92$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$),$visible_QMARK_$jscomp$3$$=$APP.$app$main$ui$hooks$use_visible$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($item_ref$jscomp$4$$),$renaming_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($renaming_root_shape$jscomp$11$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$)),$container$jscomp$87_vec__78721$$=$app$main$ui$workspace$sidebar$assets$components$get_component_root_and_container$$($file_id$jscomp$392$$,
$component$jscomp$125$$);$renaming_root_shape$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($container$jscomp$87_vec__78721$$,0,null);$container$jscomp$87_vec__78721$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($container$jscomp$87_vec__78721$$,1,null);var $on_component_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component_id$jscomp$92$$),$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$3$$)],function($event$jscomp$438$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$438$$);
return $APP.$cljs$core$truth_$$($on_asset_click$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$on_asset_click$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$438$$,$component_id$jscomp$92$$):$on_asset_click$jscomp$3$$($event$jscomp$438$$,$component_id$jscomp$92$$))?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}),$on_component_double_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$392$$),
$APP.$rumext$v2$adapt$$($component$jscomp$125$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$),$APP.$rumext$v2$adapt$$($renaming_QMARK_$$)],function($event$jscomp$439$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$439$$);return $renaming_QMARK_$$?null:$APP.$cljs$core$truth_$$($is_local$jscomp$3$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,
$component_id$jscomp$92$$]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($file_id$jscomp$392$$,$component$jscomp$125$$,!1))}),$on_drop$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component$jscomp$125$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$7$$),$APP.$rumext$v2$adapt$$($selected$jscomp$159$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$5$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$6$$),
$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$440$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$3$$)?$APP.$cljs$cst$2585$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$3$$)?$app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$($event$jscomp$440$$,
$component$jscomp$125$$,$dragging_STAR_$jscomp$7$$,$selected$jscomp$159$$,$selected_full$jscomp$5$$,$selected_paths$jscomp$6$$,$APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$):null}),$on_drag_enter$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component$jscomp$125$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$7$$),$APP.$rumext$v2$adapt$$($selected$jscomp$159$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$6$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$),
$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$441$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$3$$)?$APP.$cljs$cst$2585$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$3$$)?$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$($event$jscomp$441$$,$component$jscomp$125$$,$dragging_STAR_$jscomp$7$$,
$selected$jscomp$159$$,$selected_paths$jscomp$6$$):null}),$on_drag_leave$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$7$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$442$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$3$$)?$APP.$cljs$cst$2585$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):
$is_local$jscomp$3$$)?$app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$442$$,$dragging_STAR_$jscomp$7$$):null}),$on_component_drag_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$392$$),$APP.$rumext$v2$adapt$$($component$jscomp$125$$),$APP.$rumext$v2$adapt$$($selected$jscomp$159$$),$APP.$rumext$v2$adapt$$($item_ref$jscomp$4$$),$APP.$rumext$v2$adapt$$($on_drag_start$jscomp$2$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$15$$),
$APP.$rumext$v2$adapt$$($renaming_QMARK_$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$3$$)],function($event$jscomp$443$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$15$$)?$read_only_QMARK_$jscomp$15$$:$renaming_QMARK_$$)?$APP.$app$util$dom$prevent_default$$($event$jscomp$443$$):$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$($event$jscomp$443$$,$file_id$jscomp$392$$,$component$jscomp$125$$,$selected$jscomp$159$$,$item_ref$jscomp$4$$,$APP.$cljs$cst$1643$components$$,
$on_drag_start$jscomp$2$$)});$on_context_menu$jscomp$4_on_context_menu__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_context_menu$jscomp$4_on_context_menu__$1$$),$APP.$rumext$v2$adapt$$($component_id$jscomp$92$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_context_menu$jscomp$4_on_context_menu__$1$$,$component_id$jscomp$92$$));return(0,$APP.$rumext$v2$jsx$$)("div",{onDoubleClick:$on_component_double_click$$,onDragEnter:$on_drag_enter$jscomp$4$$,
onDragLeave:$on_drag_leave$jscomp$4$$,className:"main_ui_workspace_sidebar_assets_components__component-item "+($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-grid":"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list":"")+" "+($APP.$cljs$core$contains_QMARK_$$($selected$jscomp$159$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$))?"main_ui_workspace_sidebar_assets_components__component-item-selected":
""),children:$renaming_root_shape$jscomp$11$$!=null&&$container$jscomp$87_vec__78721$$!=null?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-grid-name":"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list-name":
"")+" "+($renaming_QMARK_$$?"main_ui_workspace_sidebar_assets_components__component-item-editing":""),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$editable_label$editable_label_STAR_$$,{classInput:($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-grid-input":"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list-input":""),classLabel:($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?
"main_ui_workspace_sidebar_assets_components__component-item-grid-label":"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list-label":""),value:$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$)),tooltip:$APP.$app$common$path_names$merge_path_item$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$),
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$)),displayValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$),isEditing:$renaming_QMARK_$$,onChange:$do_rename$jscomp$2$$,onCancel:$cancel_rename$$})}),$dragging_QMARK_$jscomp$7_props_78713$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_components__component-item-dragging"}):null]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$component_item_thumbnail_STAR_$$,
{fileId:$file_id$jscomp$392$$,className:"main_ui_workspace_sidebar_assets_components__component-item-thumbnail "+($APP.$cljs$core$not$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-list-thumbnail":""),rootShape:$renaming_root_shape$jscomp$11$$,component:$component$jscomp$125$$,container:$container$jscomp$87_vec__78721$$,isHidden:$APP.$cljs$core$not$$($visible_QMARK_$jscomp$3$$)}),$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$125$$)?(0,$APP.$rumext$v2$jsx$$)("span",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.assets.components.num-variants",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$num_variants$$])),className:"main_ui_workspace_sidebar_assets_components__component-item-variant-mark "+($APP.$cljs$core$truth_$$($is_listing_thumbs$$)?"main_ui_workspace_sidebar_assets_components__component-item-grid-variant-mark":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"variant",size:"s"})}):null]}):null,id:"component-shape-id-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$125$$)??""),onContextMenu:$on_context_menu$jscomp$4_on_context_menu__$1$$,onDrop:$on_drop$jscomp$7$$,onDragOver:$APP.$app$util$dom$prevent_default$$,draggable:$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$15$$)&&!$renaming_QMARK_$$,onClick:$on_component_click$$,ref:$item_ref$jscomp$4$$,onDragStart:$on_component_drag_start$$})};
$app$main$ui$workspace$sidebar$assets$components$components_section_STAR_$$=function($props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$){var $on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.onAssetClick,$is_open$jscomp$5$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.isOpen,$open_status_ref$jscomp$1$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.openStatusRef,$on_assets_delete$jscomp$3$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.onAssetsDelete,
$any_variant_QMARK_$jscomp$2_selected$jscomp$161$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.selected,$file_id$jscomp$394$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.fileId,$is_listing_thumbs$jscomp$2$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.isListingThumbs,$count_variants$jscomp$1$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.countVariants,$is_force_open$jscomp$2$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.isForceOpen,
$is_local$jscomp$5$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.isLocal,$on_clear_selection$jscomp$4$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.onClearSelection,$components$jscomp$14$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.components,$is_reverse_sort$jscomp$1$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.isReverseSort,$delete_component$$=$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$.deleteComponent,$input_ref$jscomp$10$$=
(0,$APP.$rumext$v2$use_ref$$)(null),$state_STAR_$jscomp$10$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$10$$);var $current_component_id$$=$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$);$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$=$cljs$cst$5745$renaming$$.$cljs$core$IFn$_invoke$arity$1$($props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$);
var $open_groups$jscomp$5_open_groups_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_status_ref$jscomp$1$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4449$groups$$,$APP.$cljs$cst$1643$components$$],null)),$open_status_ref$jscomp$1$$)});$open_groups$jscomp$5_open_groups_ref$jscomp$1$$=
$APP.$rumext$v2$deref$$($open_groups$jscomp$5_open_groups_ref$jscomp$1$$);var $menu_state$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$),$read_only_QMARK_$jscomp$16$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$toggle_list_style$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($app$main$ui$workspace$sidebar$assets$common$assets_toggle_list_style$$),$selected__$1$jscomp$16$$=
$APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($any_variant_QMARK_$jscomp$2_selected$jscomp$161$$),$selected_full$jscomp$7$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78745_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$16$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78745_SHARP_$$))}),$components$jscomp$14$$),$multi_components_QMARK_$$=
$APP.$cljs$core$count$$($selected__$1$jscomp$16$$)>1,$multi_assets_QMARK_$jscomp$2$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$2483$graphics$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$16$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$16$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$16$$)),$selected_and_current$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$),
$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($current_component_id$$)],function(){return $APP.$cljs$core$set$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($selected__$1$jscomp$16$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$current_component_id$$))}),$selected_and_current_full$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_and_current$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78746_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected_and_current$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78746_SHARP_$$))},$components$jscomp$14$$)});$any_variant_QMARK_$jscomp$2_selected$jscomp$161$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_and_current$$)],function(){return $APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$selected_and_current_full$$)});var $all_same_page_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_and_current$$)],
function(){var $page$jscomp$165$$=$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_and_current_full$$));return $APP.$cljs$core$every_QMARK_$$(function($p1__78747_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$165$$,$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($p1__78747_SHARP_$$))},$selected_and_current_full$$)}),$groups$jscomp$11$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),
$APP.$rumext$v2$adapt$$($is_reverse_sort$jscomp$1$$)],function(){return $app$main$ui$workspace$sidebar$assets$groups$group_assets$$($components$jscomp$14$$,$is_reverse_sort$jscomp$1$$)}),$add_component$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$394$$,$APP.$cljs$cst$1643$components$$,!0));return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$10$$))}),
$on_file_selected$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$394$$)],function($blobs$jscomp$2_params$jscomp$419$$){$blobs$jscomp$2_params$jscomp$419$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$394$$,$APP.$cljs$cst$3748$blobs$$,$APP.$cljs$core$seq$$($blobs$jscomp$2_params$jscomp$419$$)],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$media$upload_media_components$$($blobs$jscomp$2_params$jscomp$419$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-asset-to-library",$APP.$cljs$cst$2556$asset_type$$,"components"],null))]))}),$on_duplicate$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$)],function(){if($APP.$cljs$core$empty_QMARK_$$($selected__$1$jscomp$16$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$394$$,
$current_component_id$$));var $undo_id$jscomp$96$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$96$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$data$workspace$libraries$duplicate_component$$,$file_id$jscomp$394$$),$selected__$1$jscomp$16$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$96$$))}),
$on_delete$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$394$$),$APP.$rumext$v2$adapt$$($multi_components_QMARK_$$),$APP.$rumext$v2$adapt$$($multi_assets_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_assets_delete$jscomp$3$$)],function(){var $undo_id$jscomp$97$$=Symbol();return $multi_components_QMARK_$$||$multi_assets_QMARK_$jscomp$2$$?$on_assets_delete$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?
$on_assets_delete$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$on_assets_delete$jscomp$3$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$97$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$delete_component$$.$cljs$core$IFn$_invoke$arity$1$?$delete_component$$.$cljs$core$IFn$_invoke$arity$1$($current_component_id$$):$delete_component$$($current_component_id$$),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$394$$,
$file_id$jscomp$394$$,$APP.$cljs$cst$1643$components$$,$current_component_id$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$97$$)]))}),$on_close_menu$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_state$jscomp$2$$,$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$)}),$on_rename$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$10$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5745$renaming$$,!0)}),$cancel_rename$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($state_STAR_$jscomp$10$$,$APP.$cljs$core$dissoc$$,$cljs$cst$5745$renaming$$)}),$do_rename$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$)],function($new_name$jscomp$36$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($state_STAR_$jscomp$10$$,
$APP.$cljs$core$dissoc$$,$cljs$cst$5745$renaming$$);return $APP.$cuerdas$core$blank_QMARK_$$($new_name$jscomp$36$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($current_component_id$$,$new_name$jscomp$36$$))}),$on_context_menu$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$),
$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$16$$)],function($component_id$jscomp$93$$,$event$jscomp$447_pos$jscomp$137$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$447_pos$jscomp$137$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$447_pos$jscomp$137$$);$event$jscomp$447_pos$jscomp$137$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$447_pos$jscomp$137$$);return $APP.$cljs$core$not$$($read_only_QMARK_$jscomp$16$$)?($APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$16$$,
$component_id$jscomp$93$$)||($on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$4$$()),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$10$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1632$component_id$$,$component_id$jscomp$93$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($menu_state$jscomp$2$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,
$event$jscomp$447_pos$jscomp$137$$)):null}),$create_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$),$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function($group_name$jscomp$4$$){$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$4$$();
var $undo_id$jscomp$98$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$98$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78753_SHARP_$$){return $APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78753_SHARP_$$),$app$main$ui$workspace$sidebar$assets$common$add_group$$($p1__78753_SHARP_$$,
$group_name$jscomp$4$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78752_SHARP_$$){return $multi_components_QMARK_$$?$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$16$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78752_SHARP_$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_component_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78752_SHARP_$$))},$components$jscomp$14$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$98$$))}),
$rename_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function($path$jscomp$270$$,$last_path$jscomp$5$$){$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$4$$();var $undo_id$jscomp$99$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$99$$));
$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78758_SHARP_$$){return $APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78758_SHARP_$$),$app$main$ui$workspace$sidebar$assets$common$rename_group$$($p1__78758_SHARP_$$,$path$jscomp$270$$,$last_path$jscomp$5$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78757_SHARP_$$){return $app$common$path_names$inside_path_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78757_SHARP_$$),
$path$jscomp$270$$)},$components$jscomp$14$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$99$$))}),$on_group$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$16$$),$APP.$rumext$v2$adapt$$($create_group$jscomp$1$$)],function($event$jscomp$448$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$448$$);
return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5697$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$924$accept$$,$create_group$jscomp$1$$],null))}),$on_rename_group$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$)],function($event$jscomp$449$$,$path$jscomp$271$$,$last_path$jscomp$6$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$449$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5697$name_group_dialog$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$296$path$$,$path$jscomp$271$$,$cljs$cst$5700$last_path$$,$last_path$jscomp$6$$,$APP.$cljs$cst$924$accept$$,$rename_group$jscomp$1$$],null))}),$on_ungroup$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function($path$jscomp$272$$){$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():
$on_clear_selection$jscomp$4$$();var $undo_id$jscomp$100$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$100$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78760_SHARP_$$){return $APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78760_SHARP_$$),
$app$main$ui$workspace$sidebar$assets$common$ungroup$$($p1__78760_SHARP_$$,$path$jscomp$272$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78759_SHARP_$$){return $app$common$path_names$inside_path_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78759_SHARP_$$),$path$jscomp$272$$)},$components$jscomp$14$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$100$$))}),
$on_delete_group$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3767$assets$$,$components$jscomp$14$$,$cljs$cst$5694$on_clear_selection$$,$on_clear_selection$jscomp$4$$,$cljs$cst$5696$path_filter$$,$app$common$path_names$inside_path_QMARK_$$,
$cljs$cst$5695$delete_events$$,function($map__78777_matching$jscomp$1_variant_containers_variants$jscomp$9$$){$map__78777_matching$jscomp$1_variant_containers_variants$jscomp$9$$=$APP.$cljs$core$group_by$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$boolean$0$$,$APP.$app$common$types$component$is_variant_QMARK_$$),$map__78777_matching$jscomp$1_variant_containers_variants$jscomp$9$$);var $map__78777__$1_non_variants$$=$APP.$cljs$core$__destructure_map$$($map__78777_matching$jscomp$1_variant_containers_variants$jscomp$9$$);
$map__78777_matching$jscomp$1_variant_containers_variants$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78777__$1_non_variants$$,!0);$map__78777__$1_non_variants$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78777__$1_non_variants$$,!1);$map__78777_matching$jscomp$1_variant_containers_variants$jscomp$9$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($comps_p__78779$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($comps_p__78779$$,
0,null);$comps_p__78779$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($comps_p__78779$$,1,null);return $APP.$cljs$core$first$$($comps_p__78779$$)},$APP.$cljs$core$group_by$$($APP.$cljs$cst$2016$variant_id$$,$map__78777_matching$jscomp$1_variant_containers_variants$jscomp$9$$));return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78761_SHARP_$$){return $app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($p1__78761_SHARP_$$),
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78761_SHARP_$$)]))},$map__78777_matching$jscomp$1_variant_containers_variants$jscomp$9$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78762_SHARP_$$){return $APP.$app$main$data$workspace$libraries$delete_component$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78762_SHARP_$$)],
null))},$map__78777__$1_non_variants$$))}],null))}),$on_group_combine_variants$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$14$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$4$$)],function($path$jscomp$273$$){$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$4$$();var $comps$jscomp$1_page_id$jscomp$426$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78763_SHARP_$$){return $app$common$path_names$inside_path_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78763_SHARP_$$),
$path$jscomp$273$$)},$components$jscomp$14$$),$ids$jscomp$280$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2070$main_instance_id$$,$comps$jscomp$1_page_id$jscomp$426$$));$comps$jscomp$1_page_id$jscomp$426$$=$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($comps$jscomp$1_page_id$jscomp$426$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$combine_as_variants$$($ids$jscomp$280$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2051$page_id$$,$comps$jscomp$1_page_id$jscomp$426$$,$APP.$cljs$cst$4491$trigger$$,"workspace:context-menu-assets-group"],null)))}),$on_drag_start$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$394$$)],function($component$jscomp$127$$,$event$jscomp$450$$){var $file_data$jscomp$116_shape_main$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$refs$files$$),
$file_id$jscomp$394$$),$APP.$cljs$cst$142$data$$);$file_data$jscomp$116_shape_main$jscomp$12$$=$APP.$app$common$types$file$get_component_root$$($file_data$jscomp$116_shape_main$jscomp$12$$,$component$jscomp$127$$);$APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$394$$,$APP.$cljs$cst$1630$component$$,$component$jscomp$127$$,$APP.$cljs$cst$1817$shape$$,$file_data$jscomp$116_shape_main$jscomp$12$$,
$APP.$cljs$cst$2585$is_local$$,$is_local$jscomp$5$$],null));$APP.$app$util$dom$dnd$set_data_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$450$$,"penpot/component",!0);$APP.$app$util$dom$dnd$set_drag_image_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($event$jscomp$450$$);return $APP.$app$util$dom$dnd$set_allowed_effect_BANG_$$($event$jscomp$450$$)}),$on_show_main$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_component_id$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$394$$),
$APP.$rumext$v2$adapt$$($is_local$jscomp$5$$)],function($component$jscomp$128_event$jscomp$451$$){$APP.$app$util$dom$stop_propagation$$($component$jscomp$128_event$jscomp$451$$);if($APP.$cljs$core$truth_$$($is_local$jscomp$5$$))return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,$current_component_id$$])));
$component$jscomp$128_event$jscomp$451$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78764_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78764_SHARP_$$),$current_component_id$$)},$components$jscomp$14$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($file_id$jscomp$394$$,$component$jscomp$128_event$jscomp$451$$,
!1))});$on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$11$$),$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$,$groups$jscomp$11$$));var $on_combine_as_variants$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_and_current_full$$)],
function($event$jscomp$452_page_id$jscomp$427$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$452_page_id$jscomp$427$$);$event$jscomp$452_page_id$jscomp$427$$=$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_and_current_full$$));var $ids$jscomp$281$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2070$main_instance_id$$,
$selected_full$jscomp$7$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$combine_as_variants$$($ids$jscomp$281$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2051$page_id$$,$event$jscomp$452_page_id$jscomp$427$$,$APP.$cljs$cst$4491$trigger$$,"workspace:context-menu-assets"],null)))});return(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$,{fileId:$file_id$jscomp$394$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components"),section:$APP.$cljs$cst$1643$components$$,assetsCount:$APP.$cljs$core$count$$($components$jscomp$14$$),isOpen:$is_open$jscomp$5$$,children:[(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$cljs$cst$5693$title_button$$,children:[$is_open$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,
{selected:$APP.$cljs$core$truth_$$($is_listing_thumbs$jscomp$2$$)?"grid":"list","on-change":$toggle_list_style$jscomp$1$$,name:"listing-style",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"view-as-list",value:"list",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.list-view"),id:"opt-list"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"flex-grid",value:"grid",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.grid-view"),
id:"opt-grid"})]})}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$794$$=$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$16$$);return $and__5023__auto__$jscomp$794$$?$is_local$jscomp$5$$:$and__5023__auto__$jscomp$794$$}())?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components.add-component"),onClick:$add_component$jscomp$1$$,icon:"add",
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{accept:$APP.$app$main$data$workspace$media$accept_image_types$$,multi:!0,ref:$input_ref$jscomp$10$$,"on-selected":$on_file_selected$jscomp$2$$})}):null]}),(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$APP.$cljs$cst$1642$content$$,children:[$is_open$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$components$components_group_STAR_$$,
{isLocal:$is_local$jscomp$5$$,selected:$selected__$1$jscomp$16$$,onRenameGroup:$on_rename_group$jscomp$3$$,onGroup:$on_group$jscomp$4$$,onAssetClick:$on_asset_click$jscomp$5_on_asset_click__$1$jscomp$1$$,prefix:"",isForceOpen:$is_force_open$jscomp$2$$,doRename:$do_rename$jscomp$4$$,countVariants:$count_variants$jscomp$1$$,cancelRename:$cancel_rename$jscomp$2$$,onContextMenu:$on_context_menu$jscomp$6$$,isListingThumbs:$is_listing_thumbs$jscomp$2$$,onUngroup:$on_ungroup$jscomp$4$$,onGroupCombineVariants:$on_group_combine_variants$jscomp$2$$,
openGroups:$open_groups$jscomp$5_open_groups_ref$jscomp$1$$,onDeleteGroup:$on_delete_group$jscomp$4$$,renaming:$props_78765_renaming_QMARK_$jscomp$1_state$jscomp$1195$$?$current_component_id$$:null,onDragStart:$on_drag_start$jscomp$4$$,fileId:$file_id$jscomp$394$$,groups:$groups$jscomp$11$$,selectedFull:$selected_full$jscomp$7$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,{onClose:$on_close_menu$jscomp$3$$,state:$APP.$cljs$core$_deref$$($menu_state$jscomp$2$$),
options:new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$5$$)?$APP.$cljs$core$not$$($multi_components_QMARK_$$?$multi_components_QMARK_$$:$multi_assets_QMARK_$jscomp$2$$?$multi_assets_QMARK_$jscomp$2$$:$read_only_QMARK_$jscomp$16$$):$is_local$jscomp$5$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),
$APP.$cljs$cst$266$id$$,"assets-rename-component",$APP.$cljs$cst$2413$handler$$,$on_rename$jscomp$1$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$5$$)?$APP.$cljs$core$not$$($multi_assets_QMARK_$jscomp$2$$?$multi_assets_QMARK_$jscomp$2$$:$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$16$$)?$read_only_QMARK_$jscomp$16$$:$any_variant_QMARK_$jscomp$2_selected$jscomp$161$$):$is_local$jscomp$5$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate-main"),$APP.$cljs$cst$266$id$$,"assets-duplicate-component",$APP.$cljs$cst$2413$handler$$,$on_duplicate$jscomp$1$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$5$$)?$APP.$cljs$core$not$$($multi_assets_QMARK_$jscomp$2$$?$multi_assets_QMARK_$jscomp$2$$:$read_only_QMARK_$jscomp$16$$):$is_local$jscomp$5$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.group"),
$APP.$cljs$cst$266$id$$,"assets-group-component",$APP.$cljs$cst$2413$handler$$,$on_group$jscomp$4$$],null):null,$multi_assets_QMARK_$jscomp$2$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show-main"),$APP.$cljs$cst$266$id$$,"assets-show-main-component",$APP.$cljs$cst$2413$handler$$,$on_show_main$$],null),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$5$$)?$multi_components_QMARK_$$&&
$APP.$cljs$core$not$$($any_variant_QMARK_$jscomp$2_selected$jscomp$161$$):$is_local$jscomp$5$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants"),$APP.$cljs$cst$266$id$$,"assets-combine-as-variants",$APP.$cljs$cst$939$title$$,$APP.$cljs$core$truth_$$($all_same_page_QMARK_$$)?null:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants-error"),
$APP.$cljs$cst$2959$disabled$$,$APP.$cljs$core$not$$($all_same_page_QMARK_$$),$APP.$cljs$cst$2413$handler$$,$on_combine_as_variants$$],null):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$5$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$16$$):$is_local$jscomp$5$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),$APP.$cljs$cst$266$id$$,"assets-delete-component",
$APP.$cljs$cst$2413$handler$$,$on_delete$jscomp$9$$],null):null],null)})]})]})};
$app$main$ui$components$editable_select$editable_select$$=function($aria_label$jscomp$9_map__78734_props_78732$$){function $handle_change_input$$($event$jscomp$455_value__$1$jscomp$44$$){$event$jscomp$455_value__$1$jscomp$44$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$455_value__$1$jscomp$44$$));var $or__5025__auto__$jscomp$inline_8969$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$455_value__$1$jscomp$44$$);return $set_value$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8969$$)?
$or__5025__auto__$jscomp$inline_8969$$:$event$jscomp$455_value__$1$jscomp$44$$)}function $set_value$$($value__$1$jscomp$43$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4633$current_value$$,$value__$1$jscomp$43$$);return $APP.$cljs$core$truth_$$($on_change$jscomp$47$$)?$on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$43$$):$on_change$jscomp$47$$($value__$1$jscomp$43$$):
null}function $as_key_value$$($item$jscomp$130$$){return $APP.$cljs$core$map_QMARK_$$($item$jscomp$130$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$130$$),$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$130$$)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$item$jscomp$130$$,$item$jscomp$130$$],
null)}$aria_label$jscomp$9_map__78734_props_78732$$=$APP.$rumext$v2$util$wrap_props$$($aria_label$jscomp$9_map__78734_props_78732$$);var $map__78734__$1_toggle_dropdown$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($aria_label$jscomp$9_map__78734_props_78732$$),$options$jscomp$611$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$873$options$$);$aria_label$jscomp$9_map__78734_props_78732$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,
$APP.$cljs$cst$4634$aria_label$$);var $on_change$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$4224$on_change$$),$placeholder$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$4846$placeholder$$),$value$jscomp$810$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$260$value$$),$on_blur$jscomp$12$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$4854$on_blur$$),$type$jscomp$618$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$139$type$$),$input_class$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,$cljs$cst$5746$input_class$$),$class$$jscomp$66$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,
$APP.$cljs$cst$1296$class$$),$state_STAR_$jscomp$11$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),$APP.$cljs$cst$4630$is_open_QMARK_$$,!1,$APP.$cljs$cst$4633$current_value$$,$value$jscomp$810$$,$APP.$cljs$cst$1567$top$$,null,$APP.$cljs$cst$257$left$$,null,$APP.$cljs$cst$1568$bottom$$,null],null)),$handle_key_down$jscomp$7_state$jscomp$1196$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$11$$),
$is_open_QMARK_$jscomp$1$$=$APP.$cljs$cst$4630$is_open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($handle_key_down$jscomp$7_state$jscomp$1196$$),$current_value$jscomp$6$$=$APP.$cljs$cst$4633$current_value$$.$cljs$core$IFn$_invoke$arity$1$($handle_key_down$jscomp$7_state$jscomp$1196$$),$element_id$jscomp$4$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($handle_key_down$jscomp$7_state$jscomp$1196$$),$min_val$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,
$APP.$cljs$cst$338$min$$),$max_val$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78734__$1_toggle_dropdown$jscomp$3$$,$APP.$cljs$cst$339$max$$),$emit_blur_QMARK_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$font_size_wrapper_ref$$=(0,$APP.$rumext$v2$use_ref$$)();$map__78734__$1_toggle_dropdown$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_key_down$jscomp$7_state$jscomp$1196$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$11$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$4630$is_open_QMARK_$$,$APP.$cljs$core$not$$)});var $select_item$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$47$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$12$$)],function($event$jscomp$454_value__$1$jscomp$41$$){$event$jscomp$454_value__$1$jscomp$41$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$454_value__$1$jscomp$41$$),
"value"));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4633$current_value$$,$event$jscomp$454_value__$1$jscomp$41$$);$APP.$cljs$core$truth_$$($on_change$jscomp$47$$)&&($on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$47$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$454_value__$1$jscomp$41$$):$on_change$jscomp$47$$($event$jscomp$454_value__$1$jscomp$41$$));return $APP.$cljs$core$truth_$$($on_blur$jscomp$12$$)?
$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$12$$():null}),$labels_map$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($as_key_value$$),$options$jscomp$611$$);$handle_key_down$jscomp$7_state$jscomp$1196$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set_value$$)],function($event$jscomp$456$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$618$$,
"number")){var $up_QMARK_$jscomp$3$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$456$$),$down_QMARK_$jscomp$3$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$456$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($up_QMARK_$jscomp$3$$)?$up_QMARK_$jscomp$3$$:$down_QMARK_$jscomp$3$$)){$APP.$app$util$dom$prevent_default$$($event$jscomp$456$$);var $value__$1$jscomp$45$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$456$$)),$new_value$jscomp$20$$=
function(){var $or__5025__auto__$jscomp$1176$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$45$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1176$$)?$or__5025__auto__$jscomp$1176$$:$value__$1$jscomp$45$$}()+($event$jscomp$456$$.shiftKey?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$3$$)?10:-10:$event$jscomp$456$$.altKey?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$3$$)?.1:-.1:$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$3$$)?1:-1);return $set_value$$($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$800$$=
$APP.$app$common$math$finite_QMARK_$$($min_val$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$800$$)?$new_value$jscomp$20$$<$min_val$jscomp$2$$:$and__5023__auto__$jscomp$800$$}())?$min_val$jscomp$2$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$801$$=$APP.$app$common$math$finite_QMARK_$$($max_val$jscomp$3$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$801$$)?$new_value$jscomp$20$$>$max_val$jscomp$3$$:$and__5023__auto__$jscomp$801$$}())?$max_val$jscomp$3$$:
$new_value$jscomp$20$$)}}return null});var $handle_focus$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($emit_blur_QMARK_$$,!1)}),$handle_blur$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($emit_blur_QMARK_$$,!0);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(200,function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($on_blur$jscomp$12$$)?
$APP.$rumext$v2$ref_val$$($emit_blur_QMARK_$$):$on_blur$jscomp$12$$)?$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$12$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$12$$():null})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$810$$),$APP.$rumext$v2$adapt$$($current_value$jscomp$6$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$810$$),
$current_value$jscomp$6$$)?$APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$11$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4633$current_value$$,$value$jscomp$810$$],null)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$1$$)],function(){var $nodes_78768_wrapper_node_78766$$=$APP.$rumext$v2$ref_val$$($font_size_wrapper_ref$$),$G__78739_78772__$1_node_78767$$=$APP.$goog$dom$getElementByClass$$("checked-element is-selected",
$nodes_78768_wrapper_node_78766$$);$nodes_78768_wrapper_node_78766$$=$goog$dom$getElementsByClass$$("checked-element-value",$nodes_78768_wrapper_node_78766$$);var $closest_value_78770$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(function($a$jscomp$427$$,$b$jscomp$361$$){return $APP.$cljs$core$first$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78730_SHARP_$$){return $APP.$app$common$math$abs$$($p1__78730_SHARP_$$-$b$jscomp$361$$)},$a$jscomp$427$$))}($options$jscomp$611$$,
$value$jscomp$810$$));$APP.$cljs$core$truth_$$($is_open_QMARK_$jscomp$1$$)&&($G__78739_78772__$1_node_78767$$!=null?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78739_78772__$1_node_78767$$,!1):($G__78739_78772__$1_node_78767$$=$nodes_78768_wrapper_node_78766$$==null?null:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78731_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($closest_value_78770$$,$p1__78731_SHARP_$$!=
null?$p1__78731_SHARP_$$.innerText:null)},$nodes_78768_wrapper_node_78766$$),$G__78739_78772__$1_node_78767$$!=null&&$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78739_78772__$1_node_78767$$,!1)));return $APP.$rumext$v2$set_ref_val_BANG_$$($emit_blur_QMARK_$$,$APP.$cljs$core$not$$($is_open_QMARK_$jscomp$1$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:function($node$jscomp$411$$){return $APP.$cljs$core$truth_$$($node$jscomp$411$$)?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $left$jscomp$34_temp__5825__auto__$jscomp$369$$=
$APP.$cljs$core$truth_$$($node$jscomp$411$$)?$APP.$app$util$dom$get_bounding_rect$$($node$jscomp$411$$):null;if($APP.$cljs$core$truth_$$($left$jscomp$34_temp__5825__auto__$jscomp$369$$)){var $map__78735__$1_window_height$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($APP.$app$util$dom$get_window_size$$());$map__78735__$1_window_height$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78735__$1_window_height$jscomp$2$$,$APP.$cljs$cst$1527$height$$);var $height$jscomp$166_map__78736__$1$$=
$APP.$cljs$core$__destructure_map$$($left$jscomp$34_temp__5825__auto__$jscomp$369$$);$left$jscomp$34_temp__5825__auto__$jscomp$369$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$166_map__78736__$1$$,$APP.$cljs$cst$257$left$$);var $top$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$166_map__78736__$1$$,$APP.$cljs$cst$1567$top$$);$height$jscomp$166_map__78736__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$166_map__78736__$1$$,
$APP.$cljs$cst$1527$height$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$257$left$$,$left$jscomp$34_temp__5825__auto__$jscomp$369$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1567$top$$,$map__78735__$1_window_height$jscomp$2$$-$top$jscomp$16$$>=300?$top$jscomp$16$$+$height$jscomp$166_map__78736__$1$$:null,$APP.$cljs$cst$1568$bottom$$,$map__78735__$1_window_height$jscomp$2$$-
$top$jscomp$16$$<300?$map__78735__$1_window_height$jscomp$2$$-$top$jscomp$16$$:null]))}return null}):null},className:""+($class$$jscomp$66$$??"")+" main_ui_components_editable_select__editable-select",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$618$$,"number")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{value:function(){var $or__5025__auto__$jscomp$1177$$=$current_value$jscomp$6$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($labels_map$$,
$current_value$jscomp$6$$,$current_value$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1177$$)?$or__5025__auto__$jscomp$1177$$:""}(),className:$input_class$$,onChange:$set_value$$,onFocus:$handle_focus$jscomp$3$$,onBlur:$handle_blur$jscomp$4$$,"aria-label":$aria_label$jscomp$9_map__78734_props_78732$$,placeholder:$placeholder$jscomp$4$$}):(0,$APP.$rumext$v2$jsx$$)("input",{onChange:$handle_change_input$$,"aria-label":$aria_label$jscomp$9_map__78734_props_78732$$,className:$input_class$$,
placeholder:$placeholder$jscomp$4$$,value:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$810$$,$APP.$cljs$cst$1621$multiple$$)?null:function(){var $or__5025__auto__$jscomp$1178$$=$current_value$jscomp$6$$==null?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($labels_map$$,$current_value$jscomp$6$$,$current_value$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1178$$)?$or__5025__auto__$jscomp$1178$$:""}(),onFocus:$handle_focus$jscomp$3$$,onBlur:$handle_blur$jscomp$4$$,
type:$type$jscomp$618$$,onKeyDown:$handle_key_down$jscomp$7_state$jscomp$1196$$}),(0,$APP.$rumext$v2$jsx$$)("span",{onClick:$map__78734__$1_toggle_dropdown$jscomp$3$$,className:"main_ui_components_editable_select__dropdown-button",children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$truth_$$($is_open_QMARK_$jscomp$1$$)?$is_open_QMARK_$jscomp$1$$:!1,"on-close":function($event$jscomp$453$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$453$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$11$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4630$is_open_QMARK_$$,!1)},children:(0,$APP.$rumext$v2$jsx$$)("ul",{ref:$font_size_wrapper_ref$$,className:"main_ui_components_editable_select__custom-select-dropdown",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$150$$,$JSCompiler_temp_const$jscomp$1786_p__78748$$){var $JSCompiler_temp$jscomp$1788_index$jscomp$478$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1786_p__78748$$,0,null),$item$jscomp$131_value__$1$jscomp$inline_8972$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1786_p__78748$$,1,null);$JSCompiler_temp_const$jscomp$1786_p__78748$$=$out_arr__44092__auto__$jscomp$150$$.push;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1477$separator$$,$item$jscomp$131_value__$1$jscomp$inline_8972$$))$JSCompiler_temp$jscomp$1788_index$jscomp$478$$=
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_components_editable_select__separator"},""+($element_id$jscomp$4$$??"")+"-"+($JSCompiler_temp$jscomp$1788_index$jscomp$478$$??""));else{var $label$jscomp$inline_8973_vec__78754$jscomp$inline_8971$$=$as_key_value$$($item$jscomp$131_value__$1$jscomp$inline_8972$$);$item$jscomp$131_value__$1$jscomp$inline_8972$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($label$jscomp$inline_8973_vec__78754$jscomp$inline_8971$$,0,null);$label$jscomp$inline_8973_vec__78754$jscomp$inline_8971$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($label$jscomp$inline_8973_vec__78754$jscomp$inline_8971$$,1,null);$JSCompiler_temp$jscomp$1788_index$jscomp$478$$=(0,$APP.$rumext$v2$jsxs$$)("li",{"data-value":$item$jscomp$131_value__$1$jscomp$inline_8972$$,onClick:$select_item$jscomp$1$$,className:"main_ui_components_editable_select__dropdown-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(""+($item$jscomp$131_value__$1$jscomp$inline_8972$$??""),$current_value$jscomp$6$$)?
"main_ui_components_editable_select__is-selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_editable_select__label",children:$label$jscomp$inline_8973_vec__78754$jscomp$inline_8971$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_components_editable_select__check-icon",children:$APP.$app$main$ui$icons$tick$$})]},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($element_id$jscomp$4$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1788_index$jscomp$478$$)].join(""))}$JSCompiler_temp_const$jscomp$1786_p__78748$$.call($out_arr__44092__auto__$jscomp$150$$,
$JSCompiler_temp$jscomp$1788_index$jscomp$478$$);return $out_arr__44092__auto__$jscomp$150$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$options$jscomp$611$$))})})]})};
$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$=function($value$jscomp$811$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$811$$,$APP.$cljs$cst$1621$multiple$$)?"":$APP.$app$util$strings$format_precision$$($value$jscomp$811$$,2)};
$app$main$ui$workspace$sidebar$options$menus$typography$get_next_font$$=function($index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$,$fonts$jscomp$30$$){$index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$);var $id$jscomp$944$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$,$APP.$cljs$cst$266$id$$);if($APP.$cljs$core$seq$$($fonts$jscomp$30$$)){$index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$=
$APP.$app$common$data$index_of_pred$$($fonts$jscomp$30$$,function($p1__78773_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78773_SHARP_$$),$id$jscomp$944$$)});$index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$=$APP.$cljs$core$truth_$$($index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$)?$index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$:-1;try{var $or__5025__auto__$jscomp$1180$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($fonts$jscomp$30$$,$index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$+1)}catch($e78776$jscomp$inline_8975$$){$or__5025__auto__$jscomp$1180$$=null}return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1180$$)?$or__5025__auto__$jscomp$1180$$:$APP.$cljs$core$first$$($fonts$jscomp$30$$)}return $index$jscomp$479_index__$1$jscomp$23_map__78775__$1_p__78774$$};
$app$main$ui$workspace$sidebar$options$menus$typography$get_prev_font$$=function($index$jscomp$480_map__78781__$1_p__78780$$,$fonts$jscomp$31$$){$index$jscomp$480_map__78781__$1_p__78780$$=$APP.$cljs$core$__destructure_map$$($index$jscomp$480_map__78781__$1_p__78780$$);var $id$jscomp$945$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$480_map__78781__$1_p__78780$$,$APP.$cljs$cst$266$id$$);if($APP.$cljs$core$seq$$($fonts$jscomp$31$$)){$index$jscomp$480_map__78781__$1_p__78780$$=
$APP.$app$common$data$index_of_pred$$($fonts$jscomp$31$$,function($p1__78778_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78778_SHARP_$$),$id$jscomp$945$$)});try{var $or__5025__auto__$jscomp$1182$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($fonts$jscomp$31$$,$index$jscomp$480_map__78781__$1_p__78780$$-1)}catch($e78785$jscomp$inline_8977$$){$or__5025__auto__$jscomp$1182$$=null}return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1182$$)?
$or__5025__auto__$jscomp$1182$$:$APP.$cljs$core$peek$$($fonts$jscomp$31$$)}return $index$jscomp$480_map__78781__$1_p__78780$$};
$app$main$ui$workspace$sidebar$options$menus$typography$filter_fonts$$=function($map__78790__$1_p__78789_xform$jscomp$40$$,$fonts$jscomp$32$$){$map__78790__$1_p__78789_xform$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($map__78790__$1_p__78789_xform$jscomp$40$$);var $term$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78790__$1_p__78789_xform$jscomp$40$$,$APP.$cljs$cst$2524$term$$),$backends$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78790__$1_p__78789_xform$jscomp$40$$,
$cljs$cst$5747$backends$$),$term__$1$jscomp$1$$=$APP.$cuerdas$core$lower$$($term$jscomp$8$$);$map__78790__$1_p__78789_xform$jscomp$40$$=function(){var $G__78791_G__78791__$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$identity$$);$G__78791_G__78791__$1$$=$APP.$cljs$core$seq$$($term__$1$jscomp$1$$)?$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($G__78791_G__78791__$1$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78787_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78787_SHARP_$$)),
$term__$1$jscomp$1$$)})):$G__78791_G__78791__$1$$;return $APP.$cljs$core$seq$$($backends$$)?$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($G__78791_G__78791__$1$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78788_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($backends$$,$APP.$cljs$cst$2595$backend$$.$cljs$core$IFn$_invoke$arity$1$($p1__78788_SHARP_$$))})):$G__78791_G__78791__$1$$}();return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$map__78790__$1_p__78789_xform$jscomp$40$$,$fonts$jscomp$32$$)};
$app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$=function($props_78794_recent_fonts__$1$$){var $current_font$jscomp$1$$=$props_78794_recent_fonts__$1$$.currentFont,$on_close$jscomp$27$$=$props_78794_recent_fonts__$1$$.onClose,$show_recent$$=$props_78794_recent_fonts__$1$$.showRecent,$full_size_full_size_QMARK_$$=$props_78794_recent_fonts__$1$$.fullSize,$on_select$jscomp$2$$=$props_78794_recent_fonts__$1$$.onSelect,$selected$jscomp$162$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($current_font$jscomp$1$$),
$state_STAR_$jscomp$12$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2524$term$$,"",$cljs$cst$5747$backends$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$],null)}),$state$jscomp$1197$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$12$$),$flist$$=(0,$APP.$rumext$v2$use_ref$$)(),$input$jscomp$71$$=(0,$APP.$rumext$v2$use_ref$$)(),$fonts$jscomp$33$$=$APP.$rumext$v2$deref$$($APP.$app$main$fonts$fonts$$),$fonts__$1$jscomp$3$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1197$$),$APP.$rumext$v2$adapt$$($fonts$jscomp$33$$)],function(){return $app$main$ui$workspace$sidebar$options$menus$typography$filter_fonts$$($state$jscomp$1197$$,$fonts$jscomp$33$$)}),$recent_fonts$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$recent_fonts$$);$props_78794_recent_fonts__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1197$$),
$APP.$rumext$v2$adapt$$($recent_fonts$jscomp$1$$)],function(){return $app$main$ui$workspace$sidebar$options$menus$typography$filter_fonts$$($state$jscomp$1197$$,$recent_fonts$jscomp$1$$)});$full_size_full_size_QMARK_$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$truth_$$($full_size_full_size_QMARK_$$)?$show_recent$$:$full_size_full_size_QMARK_$$);var $select_next$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts__$1$jscomp$3$$)],function($event$jscomp$457$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$457$$);
$APP.$app$util$dom$prevent_default$$($event$jscomp$457$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$162$$,$app$main$ui$workspace$sidebar$options$menus$typography$get_next_font$$,$fonts__$1$jscomp$3$$)}),$select_prev$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts__$1$jscomp$3$$)],function($event$jscomp$458$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$458$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$458$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($selected$jscomp$162$$,$app$main$ui$workspace$sidebar$options$menus$typography$get_prev_font$$,$fonts__$1$jscomp$3$$)}),$on_key_down$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts__$1$jscomp$3$$)],function($event$jscomp$459$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$459$$))?$select_prev$$.$cljs$core$IFn$_invoke$arity$1$?$select_prev$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$459$$):
$select_prev$$($event$jscomp$459$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$459$$))?$select_next$$.$cljs$core$IFn$_invoke$arity$1$?$select_next$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$459$$):$select_next$$($event$jscomp$459$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$459$$))?$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$27$$():
$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$459$$))?$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$27$$():$APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($input$jscomp$71$$))}),$on_filter_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$460$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$12$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2524$term$$,$event$jscomp$460$$)}),$on_select_and_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_close$jscomp$27$$)],function($font$jscomp$45$$){$on_select$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$45$$):$on_select$jscomp$2$$($font$jscomp$45$$);return $on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$?
$on_close$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$27$$()});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts__$1$jscomp$3$$)],function(){var $key$jscomp$414$$=$APP.$goog$events$listen$$(document,"keydown",$on_key_down$jscomp$14$$);return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$414$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($selected$jscomp$162$$))],
function(){var $temp__5825__auto__$jscomp$370$$=$APP.$rumext$v2$ref_val$$($flist$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$370$$)){var $temp__5825__auto____$1$jscomp$21$$=$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($selected$jscomp$162$$));return $APP.$cljs$core$truth_$$($temp__5825__auto____$1$jscomp$21$$)?$temp__5825__auto__$jscomp$370$$.scrollToRow($temp__5825__auto____$1$jscomp$21$$):null}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($selected$jscomp$162$$))],
function(){var $G__78795$$=$APP.$cljs$core$_deref$$($selected$jscomp$162$$);return $on_select$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78795$$):$on_select$jscomp$2$$($G__78795$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($APP.$cljs$cst$1997$typography$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$));
return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($APP.$cljs$cst$1997$typography$$))}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $index$jscomp$482$$=$APP.$app$common$data$index_of_pred$$($fonts__$1$jscomp$3$$,function($p1__78792_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78792_SHARP_$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_font$jscomp$1$$))}),$inst$jscomp$6$$=$APP.$rumext$v2$ref_val$$($flist$$);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $offset$jscomp$211$$=$inst$jscomp$6$$.getOffsetForRow({alignment:"center",index:$index$jscomp$482$$});return $inst$jscomp$6$$.scrollToPosition($offset$jscomp$211$$)})});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-selector "+
($full_size_full_size_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_typography__fonts-on-modal"),children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-selector-dropdown "+($full_size_full_size_QMARK_$$?"main_ui_workspace_sidebar_options_menus_typography__font-selector-dropdown-full-size":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__header",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,
{onChange:$on_filter_change$$,value:$APP.$cljs$cst$2524$term$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1197$$),autoFocus:!0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.search-font")}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_78794_recent_fonts__$1$$)?$show_recent$$:$props_78794_recent_fonts__$1$$)?(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_workspace_sidebar_options_menus_typography__show-recent",children:[(0,$APP.$rumext$v2$jsx$$)("p",
{className:"main_ui_workspace_sidebar_options_menus_typography__header-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.recent-fonts")}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$151$$,$font$jscomp$46_p__78796$$){var $idx$jscomp$119$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$46_p__78796$$,0,null);$font$jscomp$46_p__78796$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($font$jscomp$46_p__78796$$,
1,null);$out_arr__44092__auto__$jscomp$151$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_item_STAR_$$,{font:$font$jscomp$46_p__78796$$,style:{},onClick:$on_select_and_close$$,isCurrent:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$46_p__78796$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($selected$jscomp$162$$)))},"font-"+($idx$jscomp$119$$??
"")));return $out_arr__44092__auto__$jscomp$151$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($props_78794_recent_fonts__$1$$))]}):null]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__fonts-list "+($full_size_full_size_QMARK_$$?"main_ui_workspace_sidebar_options_menus_typography__fonts-list-full-size":""),children:(0,$APP.$rumext$v2$jsx$$)($shadow$js$shim$module$0react_virtualized$$.AutoSizer,{children:function($props$jscomp$308$$){return(0,$APP.$rumext$v2$create_element$$)($shadow$js$shim$module$0react_virtualized$$.List,
{height:$props$jscomp$308$$.height,ref:$flist$$,width:$props$jscomp$308$$.width,rowCount:$APP.$cljs$core$count$$($fonts__$1$jscomp$3$$),rowHeight:36,rowRenderer:function($p1__78793_SHARP_$$){var $G__78801$$=$APP.$cljs$core$_deref$$($selected$jscomp$162$$);return $app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$.$cljs$core$IFn$_invoke$arity$4$?$app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$.$cljs$core$IFn$_invoke$arity$4$($fonts__$1$jscomp$3$$,$G__78801$$,
$on_select_and_close$$,$p1__78793_SHARP_$$):$app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$($fonts__$1$jscomp$3$$,$G__78801$$,$on_select_and_close$$,$p1__78793_SHARP_$$)}})}})})]})})};
$app$main$ui$workspace$sidebar$options$menus$typography$row_renderer$$=function($font$jscomp$47_fonts$jscomp$34$$,$selected$jscomp$163$$,$on_select$jscomp$3$$,$props$jscomp$309$$){var $key$jscomp$415$$=$props$jscomp$309$$.key,$style$jscomp$73$$=$props$jscomp$309$$.style;$font$jscomp$47_fonts$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($font$jscomp$47_fonts$jscomp$34$$,$props$jscomp$309$$.index);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_item_STAR_$$,
{font:$font$jscomp$47_fonts$jscomp$34$$,style:$style$jscomp$73$$,onClick:$on_select$jscomp$3$$,isCurrent:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$47_fonts$jscomp$34$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$163$$))},$key$jscomp$415$$)};
$app$main$ui$workspace$sidebar$options$menus$typography$font_options_STAR_$$=function($font_size$jscomp$12_on_font_select_props_78805$$){var $on_change$jscomp$48$$=$font_size$jscomp$12_on_font_select_props_78805$$.onChange,$full_size_selector$$=$font_size$jscomp$12_on_font_select_props_78805$$.fullSizeSelector,$on_blur$jscomp$13$$=$font_size$jscomp$12_on_font_select_props_78805$$.onBlur,$show_recent$jscomp$1$$=$font_size$jscomp$12_on_font_select_props_78805$$.showRecent,$font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$=
$APP.$cljs$core$__destructure_map$$($font_size$jscomp$12_on_font_select_props_78805$$.values),$font_id$jscomp$36_font_id__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$,$APP.$cljs$cst$1763$font_id$$);$font_size$jscomp$12_on_font_select_props_78805$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$,$APP.$cljs$cst$1766$font_size$$);$font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$,$APP.$cljs$cst$1765$font_variant_id$$);$font_id$jscomp$36_font_id__$1$$=$APP.$cljs$core$truth_$$($font_id$jscomp$36_font_id__$1$$)?$font_id$jscomp$36_font_id__$1$$:$APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$);var $font_size__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($font_size$jscomp$12_on_font_select_props_78805$$)?
$font_size$jscomp$12_on_font_select_props_78805$$:$APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$),$font_variant_id__$1$jscomp$1$$=$APP.$cljs$core$truth_$$($font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$)?$font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$:$APP.$cljs$cst$1765$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$text$default_typography$$),$fonts$jscomp$35$$=$APP.$rumext$v2$deref$$($APP.$app$main$fonts$fontsdb$$),
$font$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fonts$jscomp$35$$,$font_id$jscomp$36_font_id__$1$$),$last_font$$=(0,$APP.$rumext$v2$use_ref$$)(null),$open_selector_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$change_font$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$48$$),$APP.$rumext$v2$adapt$$($fonts$jscomp$35$$)],function($G__78809_78832_new_font_id$$){var $map__78807_map__78807__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fonts$jscomp$35$$,$G__78809_78832_new_font_id$$);$map__78807_map__78807__$1$$=$APP.$cljs$core$__destructure_map$$($map__78807_map__78807__$1$$);var $family$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78807_map__78807__$1$$,$APP.$cljs$cst$2686$family$$),$id$jscomp$946_map__78808$$=$APP.$app$main$fonts$get_default_variant$$($map__78807_map__78807__$1$$),$map__78808__$1_style$jscomp$74$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$946_map__78808$$);
$id$jscomp$946_map__78808$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78808__$1_style$jscomp$74$$,$APP.$cljs$cst$266$id$$);var $name$jscomp$453$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78808__$1_style$jscomp$74$$,$APP.$cljs$cst$725$name$$),$weight$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78808__$1_style$jscomp$74$$,$APP.$cljs$cst$2012$weight$$);$map__78808__$1_style$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78808__$1_style$jscomp$74$$,
$APP.$cljs$cst$1921$style$$);$G__78809_78832_new_font_id$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1763$font_id$$,$G__78809_78832_new_font_id$$,$APP.$cljs$cst$1764$font_family$$,$family$jscomp$7$$,$APP.$cljs$cst$1765$font_variant_id$$,$APP.$cljs$core$truth_$$($id$jscomp$946_map__78808$$)?$id$jscomp$946_map__78808$$:$name$jscomp$453$$,$APP.$cljs$cst$1767$font_weight$$,$weight$jscomp$9$$,$APP.$cljs$cst$1768$font_style$$,$map__78808__$1_style$jscomp$74$$],null);$on_change$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($G__78809_78832_new_font_id$$):$on_change$jscomp$48$$($G__78809_78832_new_font_id$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($last_font$$,$map__78807_map__78807__$1$$)}),$on_font_size_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$48$$)],function($G__78810_new_font_size$$){if($APP.$cuerdas$core$empty_QMARK_$$($G__78810_new_font_size$$))return null;$G__78810_new_font_size$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1766$font_size$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78810_new_font_size$$)],null);return $on_change$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($G__78810_new_font_size$$):$on_change$jscomp$48$$($G__78810_new_font_size$$)}),$on_font_variant_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font$jscomp$48$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$48$$)],function($new_variant_id$jscomp$2$$){var $G__78811_78834_variant$jscomp$23$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78804_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_variant_id$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78804_SHARP_$$))},$APP.$cljs$cst$2687$variants$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$));$G__78811_78834_variant$jscomp$23$$!=null&&($G__78811_78834_variant$jscomp$23$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1763$font_id$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$),$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$2686$family$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$),$APP.$cljs$cst$1765$font_variant_id$$,$new_variant_id$jscomp$2$$,$APP.$cljs$cst$1767$font_weight$$,$APP.$cljs$cst$2012$weight$$.$cljs$core$IFn$_invoke$arity$1$($G__78811_78834_variant$jscomp$23$$),$APP.$cljs$cst$1768$font_style$$,$APP.$cljs$cst$1921$style$$.$cljs$core$IFn$_invoke$arity$1$($G__78811_78834_variant$jscomp$23$$)],
null),$on_change$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($G__78811_78834_variant$jscomp$23$$):$on_change$jscomp$48$$($G__78811_78834_variant$jscomp$23$$));return $on_blur$jscomp$13$$!=null?$on_blur$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$13$$():null});$font_size$jscomp$12_on_font_select_props_78805$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_font$$)],
function($G__78812_78835_font_STAR_$$){$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font$jscomp$48$$,$G__78812_78835_font_STAR_$$)&&($G__78812_78835_font_STAR_$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__78812_78835_font_STAR_$$),$change_font$$.$cljs$core$IFn$_invoke$arity$1$?$change_font$$.$cljs$core$IFn$_invoke$arity$1$($G__78812_78835_font_STAR_$$):$change_font$$($G__78812_78835_font_STAR_$$));return $on_blur$jscomp$13$$!=null?$on_blur$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$?
$on_blur$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$13$$():null});$font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($open_selector_QMARK_$$,!1);$on_blur$jscomp$13$$!=null&&($on_blur$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$13$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$13$$());return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($last_font$$))?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$fonts$add_recent_font$$($APP.$rumext$v2$ref_val$$($last_font$$))):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($open_selector_QMARK_$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$,{currentFont:$font$jscomp$48$$,onClose:$font_variant_id$jscomp$18_map__78806__$1_on_font_selector_close$$,
onSelect:$font_size$jscomp$12_on_font_select_props_78805$$,fullSize:$full_size_selector$$,origin:"right-sidebar",showRecent:$show_recent$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.font-family"),onClick:function(){return $APP.$cljs$core$reset_BANG_$$($open_selector_QMARK_$$,!0)},className:"main_ui_workspace_sidebar_options_menus_typography__font-option",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$font_id$jscomp$36_font_id__$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("mixed",$font_id$jscomp$36_font_id__$1$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__font-option-name main_ui_workspace_sidebar_options_menus_typography__font-family-mixed",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.mixed-font-family")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-down",className:"main_ui_workspace_sidebar_options_menus_typography__dropdown-icon",size:"s"})]}):$font$jscomp$48$$!=null?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__font-option-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-down",className:"main_ui_workspace_sidebar_options_menus_typography__dropdown-icon",size:"s"})]}):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.fonts.deleted-placeholder")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-modifiers",children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.font-size"),className:"main_ui_workspace_sidebar_options_menus_typography__font-size-options",
children:function(){var $size_options$jscomp$1_size_options__$1$$=new $APP.$cljs$core$PersistentVector$$(null,12,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[8,9,10,11,12,14,16,18,24,36,48,72],null);$size_options$jscomp$1_size_options__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_size__$1$jscomp$1$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[""],null),$size_options$jscomp$1_size_options__$1$$):$size_options$jscomp$1_size_options__$1$$;return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$editable_select$editable_select$$,{min:3,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),value:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_size__$1$jscomp$1$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$cst$1621$multiple$$:$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$($font_size__$1$jscomp$1$$),
"on-blur":$on_blur$jscomp$13$$,type:"number","input-class":"main_ui_workspace_sidebar_options_menus_typography__numeric-input",max:1E3,"class":"main_ui_workspace_sidebar_options_menus_typography__font-size-select",options:$size_options$jscomp$1_size_options__$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.font-size"),"on-change":$on_font_size_change$$})}()}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.font-style"),
className:"main_ui_workspace_sidebar_options_menus_typography__font-variant-options",children:function(){var $basic_variant_options_variant_options$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($variant$jscomp$24$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$24$$),$APP.$cljs$cst$302$key$$,$APP.$cljs$core$pr_str$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$variant$jscomp$24$$])),
$APP.$cljs$cst$2296$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($variant$jscomp$24$$)],null)},$APP.$cljs$cst$2687$variants$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$48$$));$basic_variant_options_variant_options$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id__$1$jscomp$1$$,$APP.$cljs$cst$1621$multiple$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_id__$1$jscomp$1$$,"mixed")?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($basic_variant_options_variant_options$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$302$key$$,$cljs$cst$5748$multiple_variants$$,$APP.$cljs$cst$2296$label$$,"--"],null)):$basic_variant_options_variant_options$$;var $font_variant_value_font_variant_value__$1$$=$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$($font_variant_id__$1$jscomp$1$$);$font_variant_value_font_variant_value__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($font_variant_value_font_variant_value__$1$$,
"mixed")?"":$font_variant_value_font_variant_value__$1$$;return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_menus_typography__font-variant-select","default-value":$font_variant_value_font_variant_value__$1$$,options:$basic_variant_options_variant_options$$,"on-change":$on_font_variant_change$$,"on-blur":$on_blur$jscomp$13$$})}()})]})]})};
$app$main$ui$workspace$sidebar$options$menus$typography$spacing_options_STAR_$$=function($line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$){function $handle_change$jscomp$4$$($G__78817_value$jscomp$812$$,$attr$jscomp$64$$){$G__78817_value$jscomp$812$$=$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$attr$jscomp$64$$,$APP.$app$util$strings$format_precision$$($G__78817_value$jscomp$812$$,2)]);return $on_change$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$49$$.$cljs$core$IFn$_invoke$arity$1$($G__78817_value$jscomp$812$$):
$on_change$jscomp$49$$($G__78817_value$jscomp$812$$)}var $on_change$jscomp$49$$=$line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$.onChange,$on_blur$jscomp$14$$=$line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$.onBlur,$letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$=$APP.$cljs$core$__destructure_map$$($line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$.values);$line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$,
$APP.$cljs$cst$1771$line_height$$);$letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$,$APP.$cljs$cst$1772$letter_spacing$$);$line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$=$APP.$cljs$core$truth_$$($line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$)?$line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$:"1.2";$letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$=
$APP.$cljs$core$truth_$$($letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$)?$letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$:"0";return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__spacing-options",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.line-height"),className:"main_ui_workspace_sidebar_options_menus_typography__line-height",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.line-height"),className:"main_ui_workspace_sidebar_options_menus_typography__icon",children:$APP.$app$main$ui$icons$text_lineheight$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:-200,onChange:function($p1__78813_SHARP_$$){return $handle_change$jscomp$4$$($p1__78813_SHARP_$$,$APP.$cljs$cst$1771$line_height$$)},"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.line-height"),
className:"main_ui_workspace_sidebar_options_menus_typography__line-height-input",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",max:200,value:$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$($line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$),onBlur:$on_blur$jscomp$14$$,
nillable:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$line_height$jscomp$20_line_height__$1$jscomp$5_props_78815$$),defaultValue:"1.2",step:.1})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.letter-spacing"),className:"main_ui_workspace_sidebar_options_menus_typography__letter-spacing",children:[(0,$APP.$rumext$v2$jsx$$)("span",{alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.letter-spacing"),
className:"main_ui_workspace_sidebar_options_menus_typography__icon",children:$APP.$app$main$ui$icons$text_letterspacing$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:-200,onChange:function($p1__78814_SHARP_$$){return $handle_change$jscomp$4$$($p1__78814_SHARP_$$,$APP.$cljs$cst$1772$letter_spacing$$)},"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.letter-spacing"),className:"main_ui_workspace_sidebar_options_menus_typography__letter-spacing-input",
placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",max:200,value:$app$main$ui$workspace$sidebar$options$menus$typography$attr__GT_string$$($letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$),onBlur:$on_blur$jscomp$14$$,nillable:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$letter_spacing$jscomp$7_letter_spacing__$1_map__78816__$1$$),defaultValue:"0",step:.1})]})]})};
$app$main$ui$workspace$sidebar$options$menus$typography$text_transform_options_STAR_$$=function($props_78818$$){var $on_change$jscomp$50$$=$props_78818$$.onChange,$on_blur$jscomp$15$$=$props_78818$$.onBlur,$values$jscomp$78$$=$props_78818$$.values,$text_transform$jscomp$7$$=function(){var $or__5025__auto__$jscomp$1189$$=$APP.$cljs$cst$1775$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$78$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1189$$)?$or__5025__auto__$jscomp$1189$$:
"none"}(),$unset_value$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?"none":"unset";return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__text-transform",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$text_transform$jscomp$7$$,"on-change":function($G__78819_78842_G__78820_78843_type$jscomp$619$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($text_transform$jscomp$7$$,
$G__78819_78842_G__78820_78843_type$jscomp$619$$)?($G__78819_78842_G__78820_78843_type$jscomp$619$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1775$text_transform$$,$unset_value$$],null),$on_change$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$($G__78819_78842_G__78820_78843_type$jscomp$619$$):$on_change$jscomp$50$$($G__78819_78842_G__78820_78843_type$jscomp$619$$)):($G__78819_78842_G__78820_78843_type$jscomp$619$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1775$text_transform$$,$G__78819_78842_G__78820_78843_type$jscomp$619$$],null),$on_change$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$($G__78819_78842_G__78820_78843_type$jscomp$619$$):$on_change$jscomp$50$$($G__78819_78842_G__78820_78843_type$jscomp$619$$));return $on_blur$jscomp$15$$!=null?$on_blur$jscomp$15$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$15$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$15$$():null},
name:"text-transform",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"text-uppercase",type:"checkbox",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.text-transform.uppercase"),value:"uppercase",id:"text-transform-uppercase"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"text-mixed",type:"checkbox",value:"capitalize",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.text-transform.capitalize"),
id:"text-transform-capitalize"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"text-lowercase",type:"checkbox",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.typography.text-transform.lowercase"),value:"lowercase",id:"text-transform-lowercase"})]})})};
$app$main$ui$workspace$sidebar$options$menus$typography$text_options_STAR_$$=function($full_size_selector_QMARK__props_78821$$){var $on_change$jscomp$51_opts$jscomp$312$$=$full_size_selector_QMARK__props_78821$$.onChange,$on_blur$jscomp$16$$=$full_size_selector_QMARK__props_78821$$.onBlur,$show_recent$jscomp$2$$=$full_size_selector_QMARK__props_78821$$.showRecent,$ids$jscomp$282$$=$full_size_selector_QMARK__props_78821$$.ids,$values$jscomp$79$$=$full_size_selector_QMARK__props_78821$$.values,$editor$jscomp$7$$=
$full_size_selector_QMARK__props_78821$$.editor;$full_size_selector_QMARK__props_78821$$=$APP.$cljs$core$truth_$$($show_recent$jscomp$2$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$((0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$sidebar$$),$APP.$cljs$cst$258$right$$):$show_recent$jscomp$2$$;$on_change$jscomp$51_opts$jscomp$312$$={editor:$editor$jscomp$7$$,ids:$ids$jscomp$282$$,values:$values$jscomp$79$$,onChange:$on_change$jscomp$51_opts$jscomp$312$$,onBlur:$on_blur$jscomp$16$$,
showRecent:$show_recent$jscomp$2$$,fullSizeSelector:$full_size_selector_QMARK__props_78821$$};return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__text-options "+($APP.$cljs$core$truth_$$($full_size_selector_QMARK__props_78821$$)?"main_ui_workspace_sidebar_options_menus_typography__text-options-full-size":""),children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_options_STAR_$$,$on_change$jscomp$51_opts$jscomp$312$$),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__typography-variations",children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$typography$spacing_options_STAR_$$,$on_change$jscomp$51_opts$jscomp$312$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$typography$text_transform_options_STAR_$$,$on_change$jscomp$51_opts$jscomp$312$$)]})]})};
$app$main$ui$workspace$sidebar$options$menus$typography$typography_entry_STAR_$$=function($on_detach$jscomp$1_props_78824$$){var $on_change$jscomp$53$$=$on_detach$jscomp$1_props_78824$$.onChange,$is_asset_QMARK_$jscomp$1$$=$on_detach$jscomp$1_props_78824$$.isAsset,$file_id$jscomp$396$$=$on_detach$jscomp$1_props_78824$$.fileId,$is_renaming$$=$on_detach$jscomp$1_props_78824$$.isRenaming,$external_open_STAR_$$=$on_detach$jscomp$1_props_78824$$.externalOpen,$is_focus_name$$=$on_detach$jscomp$1_props_78824$$.isFocusName,
$is_selected$jscomp$6$$=$on_detach$jscomp$1_props_78824$$.isSelected,$on_context_menu$jscomp$7$$=$on_detach$jscomp$1_props_78824$$.onContextMenu,$on_click$jscomp$43$$=$on_detach$jscomp$1_props_78824$$.onClick,$is_local$jscomp$7$$=$on_detach$jscomp$1_props_78824$$.isLocal,$is_editing$jscomp$1$$=$on_detach$jscomp$1_props_78824$$.isEditing,$typography$jscomp$33$$=$on_detach$jscomp$1_props_78824$$.typography;$on_detach$jscomp$1_props_78824$$=$on_detach$jscomp$1_props_78824$$.onDetach;var $name_input_ref$jscomp$1$$=
(0,$APP.$rumext$v2$use_ref$$)(),$editable_QMARK_$jscomp$8_read_only_QMARK_$jscomp$17$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);$editable_QMARK_$jscomp$8_read_only_QMARK_$jscomp$17$$=$APP.$cljs$core$truth_$$($is_local$jscomp$7$$)?$APP.$cljs$core$not$$($editable_QMARK_$jscomp$8_read_only_QMARK_$jscomp$17$$):$is_local$jscomp$7$$;var $open_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($is_editing$jscomp$1$$),$open_QMARK_$jscomp$11$$=
$APP.$cljs$core$_deref$$($open_STAR_$jscomp$4$$),$font_data$jscomp$13$$=$APP.$app$main$fonts$get_font_data$$($APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)),$name_only_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$13$$)),$on_name_blur$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$53$$)],
function($G__78825_78856_event$jscomp$461_name$jscomp$454$$){$G__78825_78856_event$jscomp$461_name$jscomp$454$$=(0,$APP.$app$util$dom$get_target_val$$)($G__78825_78856_event$jscomp$461_name$jscomp$454$$);if($APP.$cuerdas$core$blank_QMARK_$$($G__78825_78856_event$jscomp$461_name$jscomp$454$$))return null;$G__78825_78856_event$jscomp$461_name$jscomp$454$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$G__78825_78856_event$jscomp$461_name$jscomp$454$$],null);$on_change$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$53$$.$cljs$core$IFn$_invoke$arity$1$($G__78825_78856_event$jscomp$461_name$jscomp$454$$):$on_change$jscomp$53$$($G__78825_78856_event$jscomp$461_name$jscomp$454$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78823_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__78823_SHARP_$$,$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$core$dissoc$$,$cljs$cst$5749$rename_typography$$)})}),$on_open$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$4$$,
!0)}),$on_close$jscomp$29$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$4$$,!1)}),$navigate_to_library$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$396$$)],function(){return $APP.$cljs$core$truth_$$($file_id$jscomp$396$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,
$file_id$jscomp$396$$]))):null}),$on_key_down$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$462_input_node$jscomp$7$$){var $enter_QMARK_$jscomp$2$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$462_input_node$jscomp$7$$),$esc_QMARK_$jscomp$3$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$462_input_node$jscomp$7$$);$event$jscomp$462_input_node$jscomp$7$$=$APP.$app$util$dom$get_target$$($event$jscomp$462_input_node$jscomp$7$$);$enter_QMARK_$jscomp$2$$&&
$APP.$app$util$dom$blur_BANG_$$($event$jscomp$462_input_node$jscomp$7$$);return $esc_QMARK_$jscomp$3$$?$APP.$app$util$dom$blur_BANG_$$($event$jscomp$462_input_node$jscomp$7$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($is_editing$jscomp$1$$)?$APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$4$$,$is_editing$jscomp$1$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_QMARK_$jscomp$11$$)],
function(){return $external_open_STAR_$$!=null?$APP.$cljs$core$reset_BANG_$$($external_open_STAR_$$,$open_QMARK_$jscomp$11$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_focus_name$$)],function(){return $APP.$cljs$core$truth_$$($is_focus_name$$)?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$372$$=$APP.$rumext$v2$ref_val$$($name_input_ref$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$372$$)?
($APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$372$$),$APP.$app$util$dom$select_text_BANG_$$($temp__5825__auto__$jscomp$372$$)):null}):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{style:{display:$open_QMARK_$jscomp$11$$?"none":null},className:"main_ui_workspace_sidebar_options_menus_typography__typography-entry "+($is_selected$jscomp$6$$?"main_ui_workspace_sidebar_options_menus_typography__selected":""),children:[$APP.$cljs$core$truth_$$($is_renaming$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),fontWeight:$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),fontStyle:$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)},className:"main_ui_workspace_sidebar_options_menus_typography__typography-sample-input",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$name_input_ref$jscomp$1$$,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),maxLength:255,onKeyDown:$on_key_down$jscomp$16$$,onBlur:$on_name_blur$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_typography__adv-typography-name"})]}):(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$on_click$jscomp$43$$,
onContextMenu:$on_context_menu$jscomp$7$$,className:"main_ui_workspace_sidebar_options_menus_typography__typography-selection-wrapper "+($on_click$jscomp$43$$?"main_ui_workspace_sidebar_options_menus_typography__is-selectable":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),fontWeight:$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),fontStyle:$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)},
className:"main_ui_workspace_sidebar_options_menus_typography__typography-sample",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$name_only_QMARK_$$?$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$):""+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)??"")+" ("+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$13$$)??
"")+")",className:"main_ui_workspace_sidebar_options_menus_typography__name-block",children:$name_only_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__typography-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$)}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$33$$),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_menus_typography__typography-name main_ui_workspace_sidebar_options_menus_typography__typography-font",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$13$$)})]})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__element-set-actions",children:[$on_detach$jscomp$1_props_78824$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.detach"),onClick:$on_detach$jscomp$1_props_78824$$,icon:"detach"}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.open"),onClick:$on_open$jscomp$2$$,icon:"menu"})]})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$typography_advanced_options_STAR_$$,
{isLocal:$is_local$jscomp$7$$,onClose:$on_close$jscomp$29$$,onChange:$on_change$jscomp$53$$,isAsset:$is_asset_QMARK_$jscomp$1$$,navigateToLibrary:$navigate_to_library$jscomp$1$$,onNameBlur:$on_name_blur$jscomp$1$$,isEditable:$editable_QMARK_$jscomp$8_read_only_QMARK_$jscomp$17$$,nameInputRef:$name_input_ref$jscomp$1$$,typography:$typography$jscomp$33$$,isVisible:$open_QMARK_$jscomp$11$$,onKeyDown:$on_key_down$jscomp$16$$,fileId:$file_id$jscomp$396$$})]})};
$app$main$ui$workspace$sidebar$assets$typographies$typography_item$$=function($props_78829_typography_id$jscomp$9$$){var $selected_paths$jscomp$8$$=$props_78829_typography_id$jscomp$9$$["selected-paths"],$move_typography$$=$props_78829_typography_id$jscomp$9$$["move-typography"],$on_asset_click$jscomp$6$$=$props_78829_typography_id$jscomp$9$$["on-asset-click"],$selected_full$jscomp$8$$=$props_78829_typography_id$jscomp$9$$["selected-full"],$handle_change$jscomp$6_handle_change__$1$$=$props_78829_typography_id$jscomp$9$$["handle-change"],
$selected$jscomp$164$$=$props_78829_typography_id$jscomp$9$$.selected,$rename_QMARK_$jscomp$3$$=$props_78829_typography_id$jscomp$9$$["rename?"],$file_id$jscomp$397$$=$props_78829_typography_id$jscomp$9$$["file-id"],$local_QMARK_$jscomp$6$$=$props_78829_typography_id$jscomp$9$$["local?"],$on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$=$props_78829_typography_id$jscomp$9$$["on-context-menu"],$editing_QMARK_$jscomp$6_editing_id$jscomp$1$$=$props_78829_typography_id$jscomp$9$$["editing-id"],
$typography$jscomp$34$$=$props_78829_typography_id$jscomp$9$$.typography,$open_STAR_$jscomp$5_renaming_id$$=$props_78829_typography_id$jscomp$9$$["renaming-id"],$item_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)();$props_78829_typography_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$34$$);var $dragging_STAR_$jscomp$9$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$9$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$9$$),
$read_only_QMARK_$jscomp$18$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);$editing_QMARK_$jscomp$6_editing_id$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing_QMARK_$jscomp$6_editing_id$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$34$$));var $renaming_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$5_renaming_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$34$$));
$open_STAR_$jscomp$5_renaming_id$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($editing_QMARK_$jscomp$6_editing_id$jscomp$1$$);var $open_QMARK_$jscomp$12$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$5_renaming_id$$),$on_drop$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$9$$),$APP.$rumext$v2$adapt$$($selected$jscomp$164$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$8$$),
$APP.$rumext$v2$adapt$$($selected_paths$jscomp$8$$),$APP.$rumext$v2$adapt$$($move_typography$$)],function($event$jscomp$463$$){return $app$main$ui$workspace$sidebar$assets$common$on_drop_asset$$($event$jscomp$463$$,$typography$jscomp$34$$,$dragging_STAR_$jscomp$9$$,$selected$jscomp$164$$,$selected_full$jscomp$8$$,$selected_paths$jscomp$8$$,$move_typography$$)}),$on_drag_enter$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$),$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$9$$),
$APP.$rumext$v2$adapt$$($selected$jscomp$164$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$8$$)],function($event$jscomp$464$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset$$($event$jscomp$464$$,$typography$jscomp$34$$,$dragging_STAR_$jscomp$9$$,$selected$jscomp$164$$,$selected_paths$jscomp$8$$)}),$on_drag_leave$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$9$$)],function($event$jscomp$465$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$465$$,
$dragging_STAR_$jscomp$9$$)}),$on_typography_drag_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$397$$),$APP.$rumext$v2$adapt$$($selected$jscomp$164$$),$APP.$rumext$v2$adapt$$($item_ref$jscomp$6$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$18$$),$APP.$rumext$v2$adapt$$($renaming_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($open_QMARK_$jscomp$12$$)],function($event$jscomp$466$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$18$$)?
$read_only_QMARK_$jscomp$18$$:$renaming_QMARK_$jscomp$2$$?$renaming_QMARK_$jscomp$2$$:$open_QMARK_$jscomp$12$$)?$APP.$app$util$dom$prevent_default$$($event$jscomp$466$$):$app$main$ui$workspace$sidebar$assets$common$on_asset_drag_start$$($event$jscomp$466$$,$file_id$jscomp$397$$,$typography$jscomp$34$$,$selected$jscomp$164$$,$item_ref$jscomp$6$$,$APP.$cljs$cst$2223$typographies$$,$APP.$cljs$core$identity$$)});$on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$),
$APP.$rumext$v2$adapt$$($props_78829_typography_id$jscomp$9$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$,$props_78829_typography_id$jscomp$9$$));$handle_change$jscomp$6_handle_change__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_change$jscomp$6_handle_change__$1$$,$typography$jscomp$34$$));
var $on_asset_click__$1$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$34$$),$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$6$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$18$$),$APP.$rumext$v2$adapt$$($local_QMARK_$jscomp$6$$)],function($JSCompiler_inline_result$jscomp$1789_event$jscomp$467$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$18$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-typography",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"sidebar",$APP.$cljs$cst$4001$external_library$$,$APP.$cljs$core$not$$($local_QMARK_$jscomp$6$$)],null)));var $G__78831$jscomp$inline_8979$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$34$$);$JSCompiler_inline_result$jscomp$1789_event$jscomp$467$$=$on_asset_click$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$on_asset_click$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1789_event$jscomp$467$$,
$G__78831$jscomp$inline_8979$$):$on_asset_click$jscomp$6$$($JSCompiler_inline_result$jscomp$1789_event$jscomp$467$$,$G__78831$jscomp$inline_8979$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1789_event$jscomp$467$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$apply_typography$cljs$0core$0IFn$0_invoke$0arity$03$$(null,$typography$jscomp$34$$,$file_id$jscomp$397$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$6$$,
onDragLeave:$on_drag_leave$jscomp$6$$,className:"main_ui_workspace_sidebar_assets_typographies__typography-item",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$typography_entry_STAR_$$,{isLocal:$local_QMARK_$jscomp$6$$,onChange:$handle_change$jscomp$6_handle_change__$1$$,isAsset:!0,isFocusName:$rename_QMARK_$jscomp$3$$,isRenaming:$renaming_QMARK_$jscomp$2$$,onContextMenu:$on_context_menu$jscomp$8_on_context_menu__$1$jscomp$1$$,externalOpen:$open_STAR_$jscomp$5_renaming_id$$,
onClick:$on_asset_click__$1$jscomp$2$$,typography:$typography$jscomp$34$$,isSelected:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$164$$,$props_78829_typography_id$jscomp$9$$),isEditing:$editing_QMARK_$jscomp$6_editing_id$jscomp$1$$,fileId:$file_id$jscomp$397$$}),$dragging_QMARK_$jscomp$9$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_typographies__dragging"}):null],onDrop:$on_drop$jscomp$9$$,onDragOver:$APP.$app$util$dom$prevent_default$$,draggable:$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$18$$)&&
$APP.$cljs$core$not$$($open_QMARK_$jscomp$12$$),ref:$item_ref$jscomp$6$$,onDragStart:$on_typography_drag_start$$})};
$app$main$ui$workspace$sidebar$assets$typographies$typographies_section_STAR_$$=function($groups$jscomp$13_props_78855$$){function $handle_edit_typography_clicked$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78853_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__78853_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$cst$3983$edit_typography$$],null),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1198$$)))})}function $handle_rename_typography_clicked$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78852_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__78852_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2196$workspace_global$$,$cljs$cst$5749$rename_typography$$],null),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1198$$)))})}
var $on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$=$groups$jscomp$13_props_78855$$.onAssetClick,$is_open$jscomp$6$$=$groups$jscomp$13_props_78855$$.isOpen,$open_status_ref$jscomp$2$$=$groups$jscomp$13_props_78855$$.openStatusRef,$on_assets_delete$jscomp$4$$=$groups$jscomp$13_props_78855$$.onAssetsDelete,$selected$jscomp$166_selected_full$jscomp$10$$=$groups$jscomp$13_props_78855$$.selected,$file_id$jscomp$399$$=$groups$jscomp$13_props_78855$$.fileId,$is_force_open$jscomp$3$$=$groups$jscomp$13_props_78855$$.isForceOpen,
$file$jscomp$166$$=$groups$jscomp$13_props_78855$$.file,$typographies$jscomp$8$$=$groups$jscomp$13_props_78855$$.typographies,$is_local$jscomp$8$$=$groups$jscomp$13_props_78855$$.isLocal,$on_clear_selection$jscomp$5$$=$groups$jscomp$13_props_78855$$.onClearSelection,$is_reverse_sort$jscomp$2$$=$groups$jscomp$13_props_78855$$.isReverseSort,$state$jscomp$1198$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5750$detail_open_QMARK_$$,
!1,$APP.$cljs$cst$266$id$$,null],null)),$local_data$jscomp$1$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$assets$typographies$lens_COLON_typography_section_state$$),$read_only_QMARK_$jscomp$19$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$menu_state$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$),$typographies__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies$jscomp$8$$)],
function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$libraries$extract_path_if_missing$$,$typographies$jscomp$8$$)});$groups$jscomp$13_props_78855$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($is_reverse_sort$jscomp$2$$)],function(){return $app$main$ui$workspace$sidebar$assets$groups$group_assets$$($typographies__$1$jscomp$1$$,$is_reverse_sort$jscomp$2$$)});
var $selected__$1$jscomp$17$$=$APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$166_selected_full$jscomp$10$$);$selected$jscomp$166_selected_full$jscomp$10$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78844_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$17$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78844_SHARP_$$))}),$typographies__$1$jscomp$1$$)});var $multi_typographies_QMARK_$$=$APP.$cljs$core$count$$($selected__$1$jscomp$17$$)>1,$multi_assets_QMARK_$jscomp$3$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$17$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2483$graphics$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$17$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($selected__$1$jscomp$17$$)),
$open_groups$jscomp$7_open_groups_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($open_status_ref$jscomp$2$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4449$groups$$,$APP.$cljs$cst$2223$typographies$$],null)),$open_status_ref$jscomp$2$$)});$open_groups$jscomp$7_open_groups_ref$jscomp$2$$=
$APP.$rumext$v2$deref$$($open_groups$jscomp$7_open_groups_ref$jscomp$2$$);var $add_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$399$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$399$$,$APP.$cljs$cst$2223$typographies$$,!0));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$399$$,
null))}),$handle_change$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$399$$)],function($typography$jscomp$36$$,$changes$jscomp$332$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$typography$jscomp$36$$,$changes$jscomp$332$$])),
$file_id$jscomp$399$$))}),$create_group$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$5$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$399$$),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1198$$)))],function($group_name$jscomp$5$$){$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?
$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$5$$();var $undo_id$jscomp$102$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$102$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78846_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_typography$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78846_SHARP_$$,
$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$add_group$$($p1__78846_SHARP_$$,$group_name$jscomp$5$$)),$file_id$jscomp$399$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78845_SHARP_$$){return $multi_typographies_QMARK_$$?$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$17$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78845_SHARP_$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1198$$)),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78845_SHARP_$$))},$typographies__$1$jscomp$1$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$102$$))}),$rename_group$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$)],function($path$jscomp$274$$,$last_path$jscomp$7$$){$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?
$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$5$$();var $undo_id$jscomp$103$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$103$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78848_SHARP_$$){return $APP.$app$main$data$workspace$libraries$update_typography$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__78848_SHARP_$$,
$APP.$cljs$cst$725$name$$,$app$main$ui$workspace$sidebar$assets$common$rename_group$$($p1__78848_SHARP_$$,$path$jscomp$274$$,$last_path$jscomp$7$$)),$file_id$jscomp$399$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78847_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78847_SHARP_$$),$path$jscomp$274$$)},$typographies__$1$jscomp$1$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$103$$))}),
$on_group$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($selected__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($create_group$jscomp$2$$)],function($event$jscomp$471$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$471$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5697$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$924$accept$$,
$create_group$jscomp$2$$],null))}),$on_rename_group$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$)],function($event$jscomp$472$$,$path$jscomp$275$$,$last_path$jscomp$8$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$472$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5697$name_group_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$296$path$$,$path$jscomp$275$$,
$cljs$cst$5700$last_path$$,$last_path$jscomp$8$$,$APP.$cljs$cst$924$accept$$,$rename_group$jscomp$2$$],null))}),$on_ungroup$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$)],function($path$jscomp$276$$){$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$5$$();var $undo_id$jscomp$104$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$104$$));
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78850_SHARP_$$){return $APP.$app$main$data$workspace$libraries$rename_typography$$($file_id$jscomp$399$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78850_SHARP_$$),$app$main$ui$workspace$sidebar$assets$common$ungroup$$($p1__78850_SHARP_$$,$path$jscomp$276$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78849_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__78849_SHARP_$$),
$path$jscomp$276$$)},$typographies__$1$jscomp$1$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$104$$))}),$on_delete_group$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typographies__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$5$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$make_delete_asset_group_fn$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$3767$assets$$,$typographies__$1$jscomp$1$$,$cljs$cst$5694$on_clear_selection$$,$on_clear_selection$jscomp$5$$,$cljs$cst$5695$delete_events$$,function($p1__78851_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($t$jscomp$99$$){return $APP.$app$main$data$workspace$libraries$delete_typography$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($t$jscomp$99$$))},$p1__78851_SHARP_$$)}],null))}),$on_context_menu$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected__$1$jscomp$17$$),
$APP.$rumext$v2$adapt$$($on_clear_selection$jscomp$5$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$19$$)],function($id$jscomp$948$$,$event$jscomp$473_pos$jscomp$138$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$473_pos$jscomp$138$$);$event$jscomp$473_pos$jscomp$138$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$473_pos$jscomp$138$$);return $APP.$cljs$core$not$$($read_only_QMARK_$jscomp$19$$)?($APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$17$$,$id$jscomp$948$$)||($on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?
$on_clear_selection$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_selection$jscomp$5$$()),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1198$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$266$id$$,$id$jscomp$948$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($menu_state$jscomp$3$$,$app$main$ui$workspace$sidebar$assets$common$open_context_menu$$,$event$jscomp$473_pos$jscomp$138$$)):null}),$on_close_menu$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_state$jscomp$3$$,
$app$main$ui$workspace$sidebar$assets$common$close_context_menu$$)}),$handle_delete_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($state$jscomp$1198$$)),$APP.$rumext$v2$adapt$$($multi_typographies_QMARK_$$),$APP.$rumext$v2$adapt$$($multi_assets_QMARK_$jscomp$3$$)],function(){var $undo_id$jscomp$105$$=Symbol();return $multi_typographies_QMARK_$$||$multi_assets_QMARK_$jscomp$3$$?$on_assets_delete$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$on_assets_delete$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$on_assets_delete$jscomp$4$$():$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$105$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$delete_typography$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1198$$))),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$399$$,
$file_id$jscomp$399$$,$APP.$cljs$cst$2223$typographies$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1198$$))),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$105$$)]))}),$handle_duplicate_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$399$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($state$jscomp$1198$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$duplicate_typography$$($file_id$jscomp$399$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1198$$))))}),$editing_id$jscomp$3$$=$APP.$cljs$cst$3983$edit_typography$$.$cljs$core$IFn$_invoke$arity$1$($local_data$jscomp$1$$),$renaming_id$jscomp$2$$=$cljs$cst$5749$rename_typography$$.$cljs$core$IFn$_invoke$arity$1$($local_data$jscomp$1$$);$on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$13_props_78855$$),
$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$,$groups$jscomp$13_props_78855$$));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($local_data$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$3983$edit_typography$$.$cljs$core$IFn$_invoke$arity$1$($local_data$jscomp$1$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78854_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__78854_SHARP_$$,
$APP.$cljs$cst$2196$workspace_global$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$3983$edit_typography$$)}):null});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_STAR_$$,{fileId:$file_id$jscomp$399$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography"),section:$APP.$cljs$cst$2223$typographies$$,assetsCount:$APP.$cljs$core$count$$($typographies__$1$jscomp$1$$),
isOpen:$is_open$jscomp$6$$,children:[$APP.$cljs$core$truth_$$($is_local$jscomp$8$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$cljs$cst$5693$title_button$$,children:$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$19$$)?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.add-typography"),
onClick:$add_typography$$,icon:"add"})}):null,(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$assets$common$asset_section_block_STAR_$$,{role:$APP.$cljs$cst$1642$content$$,children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$typographies$typographies_group$$,{"selected-full":$selected$jscomp$166_selected_full$jscomp$10$$,"force-open?":$is_force_open$jscomp$3$$,"handle-change":$handle_change$jscomp$8$$,selected:$selected__$1$jscomp$17$$,"file-id":$file_id$jscomp$399$$,
"is-read-only":$read_only_QMARK_$jscomp$19$$,"on-ungroup":$on_ungroup$jscomp$6$$,file:$file$jscomp$166$$,"local?":$is_local$jscomp$8$$,"on-context-menu":$on_context_menu$jscomp$10$$,state:$state$jscomp$1198$$,"local-data":$local_data$jscomp$1$$,"open-groups":$open_groups$jscomp$7_open_groups_ref$jscomp$2$$,prefix:"","editing-id":$editing_id$jscomp$3$$,"renaming-id":$renaming_id$jscomp$2$$,"on-delete-group":$on_delete_group$jscomp$6$$,groups:$groups$jscomp$13_props_78855$$,"on-asset-click":$on_asset_click$jscomp$8_on_asset_click__$1$jscomp$3$$,
"on-rename-group":$on_rename_group$jscomp$5$$}),$APP.$cljs$core$truth_$$($is_local$jscomp$8$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,{onClose:$on_close_menu$jscomp$4$$,state:$APP.$cljs$core$_deref$$($menu_state$jscomp$3$$),options:new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$multi_typographies_QMARK_$$||$multi_assets_QMARK_$jscomp$3$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,
[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.rename"),$APP.$cljs$cst$266$id$$,"assets-rename-typography",$APP.$cljs$cst$2413$handler$$,$handle_rename_typography_clicked$$],null),$multi_typographies_QMARK_$$||$multi_assets_QMARK_$jscomp$3$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.edit"),$APP.$cljs$cst$266$id$$,"assets-edit-typography",
$APP.$cljs$cst$2413$handler$$,$handle_edit_typography_clicked$$],null),$multi_typographies_QMARK_$$||$multi_assets_QMARK_$jscomp$3$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate"),$APP.$cljs$cst$266$id$$,"assets-duplicate-typography",$APP.$cljs$cst$2413$handler$$,$handle_duplicate_typography$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),
$APP.$cljs$cst$266$id$$,"assets-delete-typography",$APP.$cljs$cst$2413$handler$$,$handle_delete_typography$$],null),$multi_assets_QMARK_$jscomp$3$$?null:new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.group"),$APP.$cljs$cst$266$id$$,"assets-group-typography",$APP.$cljs$cst$2413$handler$$,$on_group$jscomp$5$$],null)],null)}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$assets_context_menu_STAR_$$,
{onClose:$on_close_menu$jscomp$4$$,state:$APP.$cljs$core$_deref$$($menu_state$jscomp$3$$),options:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"show info",$APP.$cljs$cst$266$id$$,"assets-rename-typography",$APP.$cljs$cst$2413$handler$$,$handle_edit_typography_clicked$$],null)],null)})]})]})})};
$app$main$ui$workspace$sidebar$assets$file_library$create_file_ref$$=function($library_id$jscomp$63$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1199$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1199$$,$APP.$cljs$cst$1933$files$$),$library_id$jscomp$63$$),$APP.$cljs$cst$142$data$$)},$APP.$app$main$store$state$$)};
$app$main$ui$workspace$sidebar$assets$file_library$use_library_ref$$=function($file_id$jscomp$400$$){var $library_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$400$$)],function(){return $app$main$ui$workspace$sidebar$assets$file_library$create_file_ref$$($file_id$jscomp$400$$)});return $APP.$rumext$v2$deref$$($library_ref$$)};
$app$main$ui$workspace$sidebar$assets$file_library$use_selected$$=function($file_id$jscomp$401$$){var $selected_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$401$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($file_id$jscomp$401$$),$app$main$ui$workspace$sidebar$assets$file_library$ref_COLON_selected$$)});return $APP.$rumext$v2$deref$$($selected_ref$$)};
$app$main$ui$workspace$sidebar$assets$file_library$file_library_title_STAR_$$=function($file_name$jscomp$9_props_78857$$){var $is_open$jscomp$7$$=$file_name$jscomp$9_props_78857$$.isOpen,$file_id$jscomp$402$$=$file_name$jscomp$9_props_78857$$.fileId,$is_local$jscomp$9$$=$file_name$jscomp$9_props_78857$$.isLocal,$page_id$jscomp$428_url$jscomp$102$$=$file_name$jscomp$9_props_78857$$.pageId;$file_name$jscomp$9_props_78857$$=$file_name$jscomp$9_props_78857$$.fileName;var $router$jscomp$7_toggle_open$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$router$$),$on_click$jscomp$44_team_id$jscomp$163$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_team_id$$);$page_id$jscomp$428_url$jscomp$102$$=$APP.$app$main$router$resolve$cljs$0core$0IFn$0_invoke$0arity$03$$($router$jscomp$7_toggle_open$$,$APP.$cljs$cst$2543$workspace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1944$team_id$$,$on_click$jscomp$44_team_id$jscomp$163$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$402$$,
$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$428_url$jscomp$102$$],null));$router$jscomp$7_toggle_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$402$$),$APP.$rumext$v2$adapt$$($is_open$jscomp$7$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$402$$,$APP.$cljs$cst$3585$library$$,$APP.$cljs$core$not$$($is_open$jscomp$7$$)))});$on_click$jscomp$44_team_id$jscomp$163$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($ev$jscomp$11$$){$APP.$app$util$dom$stop_propagation$$($ev$jscomp$11$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"navigate-to-library-file"],null)))});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_file_library__library-title "+
($APP.$cljs$core$truth_$$($is_open$jscomp$7$$)?"main_ui_workspace_sidebar_assets_file_library__open":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($is_open$jscomp$7$$),onCollapsed:$router$jscomp$7_toggle_open$$,title:$APP.$cljs$core$truth_$$($is_local$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_file_library__special-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.local-library")}):
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_file_library__special-title",children:$file_name$jscomp$9_props_78857$$}),children:$is_local$jscomp$9$$?null:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.open-library"),children:(0,$APP.$rumext$v2$jsx$$)("a",{href:["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$428_url$jscomp$102$$)].join(""),target:"_blank",onClick:$on_click$jscomp$44_team_id$jscomp$163$$,
className:"main_ui_workspace_sidebar_assets_file_library__file-link",children:$APP.$app$main$ui$icons$open_link$$})})})})};
$app$main$ui$workspace$sidebar$assets$file_library$extend_selected$$=function($first_index_ids$jscomp$283_selected$jscomp$167$$,$type$jscomp$620$$,$asset_groups_click_index$$,$asset_id$jscomp$19$$,$file_id$jscomp$403$$){var $selected_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_index_ids$jscomp$283_selected$jscomp$167$$,$type$jscomp$620$$);if($APP.$cljs$core$count$$($selected_SINGLEQUOTE_$jscomp$1$$)===0)$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$select_single_asset$$($file_id$jscomp$403$$,
$asset_id$jscomp$19$$,$type$jscomp$620$$));else{var $all_assets$$=function $app$main$ui$workspace$sidebar$assets$file_library$extend_selected_$_flatten_groups$$($groups$jscomp$14$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$concat$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$14$$,"",$APP.$cljs$core$PersistentVector$EMPTY$$),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$ui$workspace$sidebar$assets$file_library$extend_selected_$_flatten_groups$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78858_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$core$first$$($p1__78858_SHARP_$$))},$groups$jscomp$14$$))])))],null))}($asset_groups_click_index$$);
$asset_groups_click_index$$=$APP.$app$common$data$index_of_pred$$($all_assets$$,function($p1__78859_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78859_SHARP_$$),$asset_id$jscomp$19$$)});$first_index_ids$jscomp$283_selected$jscomp$167$$=$APP.$cljs$core$first$$($APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($asset$jscomp$11$$){return $APP.$app$common$data$index_of_pred$$($all_assets$$,
function($p1__78860_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78860_SHARP_$$),$asset$jscomp$11$$)})},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_index_ids$jscomp$283_selected$jscomp$167$$,$type$jscomp$620$$))));var $min_index$$=$first_index_ids$jscomp$283_selected$jscomp$167$$<$asset_groups_click_index$$?$first_index_ids$jscomp$283_selected$jscomp$167$$:$asset_groups_click_index$$,$max_index$jscomp$1$$=
$first_index_ids$jscomp$283_selected$jscomp$167$$>$asset_groups_click_index$$?$first_index_ids$jscomp$283_selected$jscomp$167$$:$asset_groups_click_index$$;$first_index_ids$jscomp$283_selected$jscomp$167$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78861_SHARP_$$){return $min_index$$<=$APP.$cljs$core$first$$($p1__78861_SHARP_$$)&&
$APP.$cljs$core$first$$($p1__78861_SHARP_$$)<=$max_index$jscomp$1$$}),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$second$$))),$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($all_assets$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$select_assets$$($file_id$jscomp$403$$,$first_index_ids$jscomp$283_selected$jscomp$167$$,$type$jscomp$620$$))}};
$app$main$ui$workspace$sidebar$assets$file_library$file_library_content_STAR_$$=function($open_status_props_78869$$){var $open_status_ref$jscomp$3$$=$open_status_props_78869$$.openStatusRef,$filters$jscomp$7_listing_thumbs_QMARK_$$=$open_status_props_78869$$.filters,$count_variants$jscomp$2$$=$open_status_props_78869$$.countVariants,$file$jscomp$167$$=$open_status_props_78869$$.file,$colors$jscomp$23$$=$open_status_props_78869$$.colors,$is_loaded$$=$open_status_props_78869$$.isLoaded,$typographies$jscomp$9$$=
$open_status_props_78869$$.typographies,$is_local$jscomp$10$$=$open_status_props_78869$$.isLocal,$on_clear_selection$jscomp$6$$=$open_status_props_78869$$.onClearSelection,$components$jscomp$15$$=$open_status_props_78869$$.components;$open_status_props_78869$$=$APP.$rumext$v2$deref$$($open_status_ref$jscomp$3$$);var $file_id$jscomp$404$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$167$$),$filters_section_show_typography_QMARK_$$=$APP.$cljs$cst$1371$section$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$7_listing_thumbs_QMARK_$$),
$force_open_typographies_QMARK__has_filters_term_QMARK_$$=!$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$2524$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$7_listing_thumbs_QMARK_$$)),$reverse_sort_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2709$desc$$,$cljs$cst$5692$ordering$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$7_listing_thumbs_QMARK_$$));$filters$jscomp$7_listing_thumbs_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5733$thumbs$$,
$APP.$cljs$cst$5751$list_style$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$7_listing_thumbs_QMARK_$$));var $selected$jscomp$168$$=$app$main$ui$workspace$sidebar$assets$file_library$use_selected$$($file_id$jscomp$404$$),$show_components_QMARK_$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"all")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"components"))&&($APP.$cljs$core$count$$($components$jscomp$15$$)>
0||!$force_open_typographies_QMARK__has_filters_term_QMARK_$$),$show_colors_QMARK_$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"all")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"colors"))&&($APP.$cljs$core$count$$($colors$jscomp$23$$)>0||!$force_open_typographies_QMARK__has_filters_term_QMARK_$$);$filters_section_show_typography_QMARK_$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,
"all")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($filters_section_show_typography_QMARK_$$,"typographies"))&&($APP.$cljs$core$count$$($typographies$jscomp$9$$)>0||!$force_open_typographies_QMARK__has_filters_term_QMARK_$$);var $force_open_components_QMARK_$$=$force_open_typographies_QMARK__has_filters_term_QMARK_$$?60>$APP.$cljs$core$count$$($components$jscomp$15$$):null,$force_open_colors_QMARK_$$=$force_open_typographies_QMARK__has_filters_term_QMARK_$$?60>$APP.$cljs$core$count$$($colors$jscomp$23$$):
null;$force_open_typographies_QMARK__has_filters_term_QMARK_$$=$force_open_typographies_QMARK__has_filters_term_QMARK_$$?60>$APP.$cljs$core$count$$($typographies$jscomp$9$$):null;var $on_asset_click$jscomp$9_on_typography_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$404$$),$APP.$rumext$v2$adapt$$($selected$jscomp$168$$)],function($asset_type$jscomp$17$$,$asset_groups$jscomp$1$$,$event$jscomp$474$$,$asset_id$jscomp$20$$){return $APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$474$$)?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$474$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$toggle_selected_assets$$($file_id$jscomp$404$$,$asset_id$jscomp$20$$,$asset_type$jscomp$17$$)),!0):$event$jscomp$474$$.shiftKey?($APP.$app$util$dom$stop_propagation$$($event$jscomp$474$$),$app$main$ui$workspace$sidebar$assets$file_library$extend_selected$$($selected$jscomp$168$$,$asset_type$jscomp$17$$,$asset_groups$jscomp$1$$,$asset_id$jscomp$20$$,
$file_id$jscomp$404$$),!0):null}),$on_component_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$9_on_typography_click$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$9_on_typography_click$$,$APP.$cljs$cst$1643$components$$)),$on_colors_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$9_on_typography_click$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$9_on_typography_click$$,
$APP.$cljs$cst$2220$colors$$));$on_asset_click$jscomp$9_on_typography_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_asset_click$jscomp$9_on_typography_click$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_asset_click$jscomp$9_on_typography_click$$,$APP.$cljs$cst$2223$typographies$$));var $delete_component$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$15$$)],
function($component_id$jscomp$94$$){var $component$jscomp$129$$=$APP.$cljs$core$some$$(function($p1__78865_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78865_SHARP_$$),$component_id$jscomp$94$$)?$p1__78865_SHARP_$$:null},$components$jscomp$15$$);return $APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$129$$)?$app$main$data$workspace$shapes$delete_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$129$$),
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$129$$)])):$APP.$app$main$data$workspace$libraries$delete_component$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$component_id$jscomp$94$$],null))}),$on_assets_delete$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$168$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$404$$)],
function(){var $undo_id$jscomp$106$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$106$$));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($delete_component$jscomp$1$$,$APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$168$$)));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78866_SHARP_$$){return $app$main$data$workspace$libraries$delete_media$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$266$id$$,$p1__78866_SHARP_$$],null))},$APP.$cljs$cst$2483$graphics$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$168$$)));$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78867_SHARP_$$){return $APP.$app$main$data$workspace$libraries$delete_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$266$id$$,$p1__78867_SHARP_$$],null))},$APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$168$$)));
$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78868_SHARP_$$){return $APP.$app$main$data$workspace$libraries$delete_typography$$($p1__78868_SHARP_$$)},$APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$168$$)));($APP.$cljs$core$seq$$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$168$$))||$APP.$cljs$core$seq$$($APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$168$$))||
$APP.$cljs$core$seq$$($APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$168$$)))&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$404$$,$file_id$jscomp$404$$,null,null));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$106$$))});return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_assets_file_library__library-content",children:$APP.$cljs$core$not$$($is_loaded$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_file_library__loading",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading")}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$show_components_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$components$components_section_STAR_$$,
{isLocal:$is_local$jscomp$10$$,selected:$selected$jscomp$168$$,onAssetClick:$on_component_click$jscomp$1$$,onAssetsDelete:$on_assets_delete$jscomp$5$$,isForceOpen:$force_open_components_QMARK_$$,countVariants:$count_variants$jscomp$2$$,deleteComponent:$delete_component$jscomp$1$$,isListingThumbs:$filters$jscomp$7_listing_thumbs_QMARK_$$,onClearSelection:$on_clear_selection$jscomp$6$$,components:$components$jscomp$15$$,isOpen:$force_open_components_QMARK_$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_status_props_78869$$,
$APP.$cljs$cst$1643$components$$,!1),fileId:$file_id$jscomp$404$$,isReverseSort:$reverse_sort_QMARK_$jscomp$2$$,openStatusRef:$open_status_ref$jscomp$3$$}):null,$show_colors_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$colors$colors_section_STAR_$$,{isLocal:$is_local$jscomp$10$$,selected:$selected$jscomp$168$$,onAssetClick:$on_colors_click$$,onAssetsDelete:$on_assets_delete$jscomp$5$$,isForceOpen:$force_open_colors_QMARK_$$,onClearSelection:$on_clear_selection$jscomp$6$$,
isOpen:$force_open_colors_QMARK_$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_status_props_78869$$,$APP.$cljs$cst$2220$colors$$,!1),colors:$colors$jscomp$23$$,fileId:$file_id$jscomp$404$$,isReverseSort:$reverse_sort_QMARK_$jscomp$2$$,openStatusRef:$open_status_ref$jscomp$3$$}):null,$filters_section_show_typography_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$typographies$typographies_section_STAR_$$,{isLocal:$is_local$jscomp$10$$,selected:$selected$jscomp$168$$,
onAssetClick:$on_asset_click$jscomp$9_on_typography_click$$,onAssetsDelete:$on_assets_delete$jscomp$5$$,isForceOpen:$force_open_typographies_QMARK__has_filters_term_QMARK_$$,onClearSelection:$on_clear_selection$jscomp$6$$,typographies:$typographies$jscomp$9$$,file:$file$jscomp$167$$,isOpen:$force_open_typographies_QMARK__has_filters_term_QMARK_$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_status_props_78869$$,$APP.$cljs$cst$2223$typographies$$,!1),fileId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$167$$),
isReverseSort:$reverse_sort_QMARK_$jscomp$2$$,openStatusRef:$open_status_ref$jscomp$3$$}):null,$show_components_QMARK_$$||$show_colors_QMARK_$$||$filters_section_show_typography_QMARK_$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets_file_library__asset-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_file_library__no-found-icon",children:$APP.$app$main$ui$icons$search$$}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_assets_file_library__no-found-text",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.not-found")})]})]})})};
$app$main$ui$workspace$sidebar$assets$file_library$file_library_STAR_$$=function($is_local$jscomp$11_props_78893$$){var $is_default_open_open_QMARK_$jscomp$13$$=$is_local$jscomp$11_props_78893$$.isDefaultOpen,$filters$jscomp$8$$=$is_local$jscomp$11_props_78893$$.filters,$file$jscomp$168$$=$is_local$jscomp$11_props_78893$$.file;$is_local$jscomp$11_props_78893$$=$is_local$jscomp$11_props_78893$$.isLocal;var $file_id$jscomp$405$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$168$$),
$file_name$jscomp$10$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$168$$),$page_id$jscomp$429$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$168$$,$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2236$pages$$),0),$library$jscomp$40$$=$app$main$ui$workspace$sidebar$assets$file_library$use_library_ref$$($file_id$jscomp$405$$),$colors$jscomp$24$$=$APP.$cljs$cst$2220$colors$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$40$$),
$typographies$jscomp$10$$=$APP.$cljs$cst$2223$typographies$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$40$$),$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$=$APP.$cljs$cst$2524$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$8$$),$is_loaded$jscomp$1$$=$library$jscomp$40$$!=null,$filtered_colors$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filters$jscomp$8$$),$APP.$rumext$v2$adapt$$($colors$jscomp$24$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$apply_filters$$($APP.$cljs$core$vals$$($colors$jscomp$24$$),
$filters$jscomp$8$$)}),$filtered_components$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filters$jscomp$8$$),$APP.$rumext$v2$adapt$$($library$jscomp$40$$)],function(){var $$$jscomp$32_$__$1$jscomp$25$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$app$common$types$components_list$components_seq$$($library$jscomp$40$$));$$$jscomp$32_$__$1$jscomp$25$$=$app$main$ui$workspace$sidebar$assets$common$apply_filters$$($$$jscomp$32_$__$1$jscomp$25$$,
$filters$jscomp$8$$);return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78891_SHARP_$$){return $APP.$app$common$files$variant$is_secondary_variant_QMARK_$$($p1__78891_SHARP_$$,$library$jscomp$40$$)},$$$jscomp$32_$__$1$jscomp$25$$)}),$filtered_typographies$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filters$jscomp$8$$),$APP.$rumext$v2$adapt$$($typographies$jscomp$10$$)],function(){return $app$main$ui$workspace$sidebar$assets$common$apply_filters$$($APP.$cljs$core$vals$$($typographies$jscomp$10$$),
$filters$jscomp$8$$)}),$open_status_ref$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$405$$)],function(){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($file_id$jscomp$405$$),$app$main$ui$workspace$sidebar$assets$file_library$ref_COLON_open_status$$)}),$open_status$jscomp$1_unselect_all$$=$APP.$rumext$v2$deref$$($open_status_ref$jscomp$4$$);$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$=
!$APP.$cuerdas$core$blank_QMARK_$$($count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$)&&(60>$APP.$cljs$core$count$$($filtered_colors$jscomp$1$$)||60>$APP.$cljs$core$count$$($filtered_components$$)||60>$APP.$cljs$core$count$$($filtered_typographies$$));$is_default_open_open_QMARK_$jscomp$13$$=$APP.$cljs$cst$3585$library$$.$cljs$core$IFn$_invoke$arity$1$($open_status$jscomp$1_unselect_all$$)===!1?!1:$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$?$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$:
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3585$library$$.$cljs$core$IFn$_invoke$arity$1$($open_status$jscomp$1_unselect_all$$),$is_default_open_open_QMARK_$jscomp$13$$);$open_status$jscomp$1_unselect_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$405$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$unselect_all_assets$cljs$0core$0IFn$0_invoke$0arity$01$$($file_id$jscomp$405$$))});
var $variants_counter$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($library$jscomp$40$$)],function(){return $APP.$cljs$core$update_vals$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$2016$variant_id$$,$APP.$app$common$types$components_list$components_seq$$($library$jscomp$40$$)),$APP.$cljs$core$count$$)});$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variants_counter$$)],
function($variant_id$jscomp$51$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($variants_counter$$,$variant_id$jscomp$51$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{onContextMenu:$APP.$app$util$dom$prevent_default$$,onClick:$open_status$jscomp$1_unselect_all$$,className:"main_ui_workspace_sidebar_assets_file_library__tool-window",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$file_library$file_library_title_STAR_$$,{fileId:$file_id$jscomp$405$$,pageId:$page_id$jscomp$429$$,
fileName:$file_name$jscomp$10$$,isOpen:$is_default_open_open_QMARK_$jscomp$13$$,isLocal:$is_local$jscomp$11_props_78893$$}),$is_default_open_open_QMARK_$jscomp$13$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$file_library$file_library_content_STAR_$$,{isLocal:$is_local$jscomp$11_props_78893$$,isLoaded:$is_loaded$jscomp$1$$,countVariants:$count_variants$jscomp$3_filters_term_force_lib_open_QMARK_$$,filters:$filters$jscomp$8$$,onClearSelection:$open_status$jscomp$1_unselect_all$$,
typographies:$filtered_typographies$$,file:$file$jscomp$168$$,components:$filtered_components$$,colors:$filtered_colors$jscomp$1$$,openStatusRef:$open_status_ref$jscomp$4$$}):null]})};
$app$main$ui$workspace$sidebar$assets$assets_local_library_STAR_$$=function($filters$jscomp$10_props_78924$$){$filters$jscomp$10_props_78924$$=$filters$jscomp$10_props_78924$$.filters;var $file$jscomp$172$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$assets$ref_COLON_local_library$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$file_library$file_library_STAR_$$,{file:$file$jscomp$172$$,isLocal:!0,isDefaultOpen:!0,filters:$filters$jscomp$10_props_78924$$})};
$app$main$ui$workspace$sidebar$debug$debug_panel_STAR_$$=function($class$$jscomp$67_props_78828$$){$class$$jscomp$67_props_78828$$=$class$$jscomp$67_props_78828$$.className;var $on_toggle_enabled$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$477$$,$option$jscomp$17$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$477$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$477$$);$APP.$app$util$debug$enabled_QMARK_$$($option$jscomp$17$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$debug$state$$,
$APP.$cljs$core$disj$$,$option$jscomp$17$$):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$util$debug$state$$,$APP.$cljs$core$conj$$,$option$jscomp$17$$);return $APP.$app$main$reinit$$(!0)}),$handle_close$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($cljs$cst$5753$debug_panel$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:""+($class$$jscomp$67_props_78828$$??"")+" main_ui_workspace_sidebar_debug__debug-panel",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$panel_title$panel_title_STAR_$$,{className:"main_ui_workspace_sidebar_debug__debug-panel-title",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.debug.title"),onClose:$handle_close$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug__debug-panel-inner",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$155$$,
$option$jscomp$18$$){$out_arr__44092__auto__$jscomp$155$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug__checkbox-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{onClick:function($p1__78826_SHARP_$$){return $on_toggle_enabled$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_toggle_enabled$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__78826_SHARP_$$,$option$jscomp$18$$):$on_toggle_enabled$jscomp$1$$($p1__78826_SHARP_$$,$option$jscomp$18$$)},className:"main_ui_workspace_sidebar_debug__checkbox-icon "+
($APP.$app$util$debug$enabled_QMARK_$$($option$jscomp$18$$)?"checked":""),children:$APP.$app$util$debug$enabled_QMARK_$$($option$jscomp$18$$)?$APP.$app$main$ui$icons$status_tick$$:null}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:$APP.$app$common$data$name$$($option$jscomp$18$$),onChange:function($p1__78827_SHARP_$$){return $on_toggle_enabled$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_toggle_enabled$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__78827_SHARP_$$,$option$jscomp$18$$):
$on_toggle_enabled$jscomp$1$$($p1__78827_SHARP_$$,$option$jscomp$18$$)},checked:$APP.$app$util$debug$enabled_QMARK_$$($option$jscomp$18$$)},$APP.$app$common$data$name$$($option$jscomp$18$$)),(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:$APP.$app$common$data$name$$($option$jscomp$18$$),children:$APP.$app$common$data$name$$($option$jscomp$18$$)})]},$APP.$app$common$data$name$$($option$jscomp$18$$)));return $out_arr__44092__auto__$jscomp$155$$},[],$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$,
$APP.$app$util$debug$options$$))})]})};
$app$main$ui$workspace$sidebar$debug_shape_info$get_attrs$$=function($shape$jscomp$993$$){var $shape_attrs$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$name$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$debug_shape_info$remove_attrs$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($app$main$ui$workspace$sidebar$debug_shape_info$display_attrs$$),$APP.$cljs$core$keys$$($shape$jscomp$993$$)))),$$__$1$jscomp$26$$=
$APP.$app$common$data$removev$$(function($p1__78862_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$993$$,$p1__78862_SHARP_$$)==null},$app$main$ui$workspace$sidebar$debug_shape_info$display_attrs$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($$__$1$jscomp$26$$,$shape_attrs$$)};
$app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$=function($map__78864_map__78864__$1_objects$jscomp$783_props_78863$$){$map__78864_map__78864__$1_objects$jscomp$783_props_78863$$=$APP.$rumext$v2$util$wrap_props$$($map__78864_map__78864__$1_objects$jscomp$783_props_78863$$);$map__78864_map__78864__$1_objects$jscomp$783_props_78863$$=$APP.$cljs$core$__destructure_map$$($map__78864_map__78864__$1_objects$jscomp$783_props_78863$$);var $id$jscomp$949$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78864_map__78864__$1_objects$jscomp$783_props_78863$$,
$APP.$cljs$cst$266$id$$);$map__78864_map__78864__$1_objects$jscomp$783_props_78863$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78864_map__78864__$1_objects$jscomp$783_props_78863$$,$APP.$cljs$cst$1636$objects$$);return(0,$APP.$rumext$v2$jsx$$)("a",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$949$$))},className:"main_ui_workspace_sidebar_debug_shape_info__shape-link",
children:""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78864_map__78864__$1_objects$jscomp$783_props_78863$$,$id$jscomp$949$$),$APP.$cljs$cst$725$name$$)??"")+" #"+($id$jscomp$949$$??"")})};
$app$main$ui$workspace$sidebar$debug_shape_info$cells_render$$=function($map__78871_map__78871__$1_props_78870$$){$map__78871_map__78871__$1_props_78870$$=$APP.$rumext$v2$util$wrap_props$$($map__78871_map__78871__$1_props_78870$$);$map__78871_map__78871__$1_props_78870$$=$APP.$cljs$core$__destructure_map$$($map__78871_map__78871__$1_props_78870$$);var $cells$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78871_map__78871__$1_props_78870$$,$APP.$cljs$cst$4580$cells$$),$objects$jscomp$784$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78871_map__78871__$1_props_78870$$,$APP.$cljs$cst$1636$objects$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__cells-render",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$156$$,$cell$jscomp$45_p__78872$$){var $id$jscomp$950$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$45_p__78872$$,0,null);$cell$jscomp$45_p__78872$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cell$jscomp$45_p__78872$$,1,null);$out_arr__44092__auto__$jscomp$156$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__cell-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__cell-position",children:"("+($APP.$cljs$cst$1661$row$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78872$$)??"")+", "+($APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78872$$)??
"")+") -\x3e ("+($APP.$cljs$cst$1661$row$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78872$$)+($APP.$cljs$cst$1662$row_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78872$$)-1)??"")+", "+($APP.$cljs$cst$216$column$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78872$$)+($APP.$cljs$cst$1663$column_span$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78872$$)-1)??"")+")"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__cell-shape",
children:$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78872$$))?(0,$APP.$rumext$v2$jsx$$)("div",{children:"\x3cempty\x3e"}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$,{id:$APP.$cljs$core$first$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$45_p__78872$$)),objects:$objects$jscomp$784$$})})]},"cell-"+($id$jscomp$950$$??"")));return $out_arr__44092__auto__$jscomp$156$$},
[],$cells$jscomp$30$$)})};
$app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_attr$$=function($map__78877_props_78876_value$jscomp$814$$){$map__78877_props_78876_value$jscomp$814$$=$APP.$rumext$v2$util$wrap_props$$($map__78877_props_78876_value$jscomp$814$$);var $G__78878_map__78877__$1$$=$APP.$cljs$core$__destructure_map$$($map__78877_props_78876_value$jscomp$814$$),$attr$jscomp$65$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78878_map__78877__$1$$,$APP.$cljs$cst$2610$attr$$);$map__78877_props_78876_value$jscomp$814$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78878_map__78877__$1$$,$APP.$cljs$cst$260$value$$);var $objects$jscomp$785$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78878_map__78877__$1$$,$APP.$cljs$cst$1636$objects$$);$G__78878_map__78877__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$debug_shape_info$custom_renderer$$,$attr$jscomp$65$$);switch($G__78878_map__78877__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__78878_map__78877__$1$$.$fqn$:
null){case "shape-link":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$,{id:$map__78877_props_78876_value$jscomp$814$$,objects:$objects$jscomp$785$$});case "shape-list":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$157$$,$id$jscomp$951$$){$out_arr__44092__auto__$jscomp$157$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$shape_link$$,
{id:$id$jscomp$951$$,objects:$objects$jscomp$785$$},"child-"+($id$jscomp$951$$??"")));return $out_arr__44092__auto__$jscomp$157$$},[],$map__78877_props_78876_value$jscomp$814$$)});case "matrix-render":return(0,$APP.$rumext$v2$jsx$$)("div",{children:""+($APP.$app$common$geom$matrix$format_precision$$($map__78877_props_78876_value$jscomp$814$$,2)??"")});case "rect-render":return(0,$APP.$rumext$v2$jsx$$)("div",{children:"X:"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($map__78877_props_78876_value$jscomp$814$$)??
"")+" Y:"+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($map__78877_props_78876_value$jscomp$814$$)??"")+" W:"+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__78877_props_78876_value$jscomp$814$$)??"")+" H:"+($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($map__78877_props_78876_value$jscomp$814$$)??"")});case "points-render":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__point-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$158$$,
$p__78879_point$jscomp$79$$){var $idx$jscomp$120$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78879_point$jscomp$79$$,0,null);$p__78879_point$jscomp$79$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78879_point$jscomp$79$$,1,null);$out_arr__44092__auto__$jscomp$158$$.push((0,$APP.$rumext$v2$jsx$$)("div",{children:"("+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p__78879_point$jscomp$79$$)??"")+", "+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p__78879_point$jscomp$79$$)??
"")+")"},"point-"+($idx$jscomp$120$$??"")));return $out_arr__44092__auto__$jscomp$158$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($map__78877_props_78876_value$jscomp$814$$))});case "cells-render":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$cells_render$$,{cells:$map__78877_props_78876_value$jscomp$814$$,objects:$objects$jscomp$785$$});default:return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container-value",
children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__78877_props_78876_value$jscomp$814$$)})}};
$app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_info_STAR_$$=function(){var $objects$jscomp$786$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$selected$jscomp$169$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$786$$),$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$));return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-info",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$panel_title$panel_title_STAR_$$,
{className:"main_ui_workspace_sidebar_debug_shape_info__shape-info-title",text:"Debug",onClose:function(){return $APP.$debug$disable_BANG_$$($APP.$cljs$cst$3095$shape_panel$$)}}),$APP.$cljs$core$empty_QMARK_$$($selected$jscomp$169$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container",children:"No shapes selected"}):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$159$$,$p__78884$$){var $idx$jscomp$121$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78884$$,0,null),$current$jscomp$57$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78884$$,1,null);$out_arr__44092__auto__$jscomp$159$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-name",
children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$57$$)}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$debug$dump_object$$(""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$57$$)??""))},children:"object"}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$debug$dump_subtree$$.$cljs$core$IFn$_invoke$arity$2$(""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current$jscomp$57$$)??""),!0)},
children:"tree"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__shape-attrs",children:function(){var $attrs$jscomp$175$$=$app$main$ui$workspace$sidebar$debug_shape_info$get_attrs$$($current$jscomp$57$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$19$$,$JSCompiler_inline_result$jscomp$1795_attr$jscomp$66$$){var $JSCompiler_temp_const$jscomp$1793$$=$out_arr__44092__auto____$1$jscomp$19$$.push,
$temp__5825__auto__$jscomp$inline_8995$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$57$$,$JSCompiler_inline_result$jscomp$1795_attr$jscomp$66$$);$JSCompiler_inline_result$jscomp$1795_attr$jscomp$66$$=$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_8995$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container-attr "+($APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$JSCompiler_inline_result$jscomp$1795_attr$jscomp$66$$)?
"main_ui_workspace_sidebar_debug_shape_info__vertical-layout":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_debug_shape_info__attrs-container-name",children:$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$1795_attr$jscomp$66$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_attr$$,{attr:$JSCompiler_inline_result$jscomp$1795_attr$jscomp$66$$,value:$temp__5825__auto__$jscomp$inline_8995$$,objects:$objects$jscomp$786$$})]},
"att-"+($idx$jscomp$121$$??"")+"-"+($JSCompiler_inline_result$jscomp$1795_attr$jscomp$66$$??"")):null;$JSCompiler_temp_const$jscomp$1793$$.call($out_arr__44092__auto____$1$jscomp$19$$,$JSCompiler_inline_result$jscomp$1795_attr$jscomp$66$$);return $out_arr__44092__auto____$1$jscomp$19$$},[],$attrs$jscomp$175$$)}()})]},"shape"+($idx$jscomp$121$$??"")));return $out_arr__44092__auto__$jscomp$159$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($selected$jscomp$169$$))]})};
$app$main$ui$workspace$sidebar$history$get_object$$=function($id$jscomp$952$$,$entries$jscomp$35$$,$objects$jscomp$787_or__5025__auto__$jscomp$1194$$){function $search_deleted_shape$$($id__$1$jscomp$18$$,$entries__$1$jscomp$4_map__78885_map__78885__$1$$){function $search_delete_entry$$($or__5025__auto__$jscomp$1195_p__78889_undo_changes$jscomp$10$$){var $map__78890__$1_redo_changes$jscomp$15$$=$APP.$cljs$core$__destructure_map$$($or__5025__auto__$jscomp$1195_p__78889_undo_changes$jscomp$10$$);$or__5025__auto__$jscomp$1195_p__78889_undo_changes$jscomp$10$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78890__$1_redo_changes$jscomp$15$$,$APP.$cljs$cst$3161$undo_changes$$);$map__78890__$1_redo_changes$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78890__$1_redo_changes$jscomp$15$$,$APP.$cljs$cst$3157$redo_changes$$);$or__5025__auto__$jscomp$1195_p__78889_undo_changes$jscomp$10$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($search_obj$$,$or__5025__auto__$jscomp$1195_p__78889_undo_changes$jscomp$10$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1195_p__78889_undo_changes$jscomp$10$$)?$or__5025__auto__$jscomp$1195_p__78889_undo_changes$jscomp$10$$:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($search_obj$$,$map__78890__$1_redo_changes$jscomp$15$$)}function $search_obj$$($obj$jscomp$219$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$219$$),$APP.$cljs$cst$2621$add_obj$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$219$$),
$id__$1$jscomp$18$$)}$entries__$1$jscomp$4_map__78885_map__78885__$1$$=$search_delete_entry$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($search_delete_entry$$,$entries__$1$jscomp$4_map__78885_map__78885__$1$$));$entries__$1$jscomp$4_map__78885_map__78885__$1$$=$APP.$cljs$core$__destructure_map$$($entries__$1$jscomp$4_map__78885_map__78885__$1$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($entries__$1$jscomp$4_map__78885_map__78885__$1$$,$APP.$cljs$cst$2622$obj$$)}
$objects$jscomp$787_or__5025__auto__$jscomp$1194$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$787_or__5025__auto__$jscomp$1194$$,$id$jscomp$952$$);return $APP.$cljs$core$truth_$$($objects$jscomp$787_or__5025__auto__$jscomp$1194$$)?$objects$jscomp$787_or__5025__auto__$jscomp$1194$$:$search_deleted_shape$$($id$jscomp$952$$,$entries$jscomp$35$$)};
$app$main$ui$workspace$sidebar$history$extract_operation$$=function($G__78892_change$jscomp$34$$){$G__78892_change$jscomp$34$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__78892_change$jscomp$34$$);switch($G__78892_change$jscomp$34$$ instanceof $APP.$cljs$core$Keyword$$?$G__78892_change$jscomp$34$$.$fqn$:null){case "add-obj":case "add-page":case "add-color":case "add-media":case "add-component":case "add-typography":return $APP.$cljs$cst$4068$new$$;case "mod-obj":case "mod-page":case "mod-color":case "mod-media":case "mod-component":case "mod-typography":return $cljs$cst$5760$modify$$;
case "del-obj":case "del-page":case "del-color":case "del-media":case "del-component":case "del-typography":return $APP.$cljs$cst$4945$delete$$;case "mov-objects":return $APP.$cljs$cst$1804$move$$;default:return null}};
$app$main$ui$workspace$sidebar$history$parse_change$$=function($change$jscomp$35$$){function $r$jscomp$140$$($type$jscomp$621$$,$id$jscomp$953$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$type$jscomp$621$$,$cljs$cst$5761$operation$$,$app$main$ui$workspace$sidebar$history$extract_operation$$($change$jscomp$35$$),$APP.$cljs$cst$5446$detail$$,$APP.$cljs$cst$2624$operations$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$),$APP.$cljs$cst$266$id$$,$APP.$cljs$core$coll_QMARK_$$($id$jscomp$953$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($id$jscomp$953$$))?$APP.$cljs$core$first$$($id$jscomp$953$$):$APP.$cljs$core$coll_QMARK_$$($id$jscomp$953$$)?$APP.$cljs$cst$1621$multiple$$:$id$jscomp$953$$],null)}var $G__78894$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$);switch($G__78894$$ instanceof $APP.$cljs$core$Keyword$$?$G__78894$$.$fqn$:null){case "set-option":return $r$jscomp$140$$($APP.$cljs$cst$1629$page$$,$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));
case "add-obj":case "mod-obj":case "del-obj":return $r$jscomp$140$$($APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));case "reg-objects":return null;case "mov-objects":return $r$jscomp$140$$($APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));case "add-page":case "mod-page":case "del-page":case "mov-page":return $r$jscomp$140$$($APP.$cljs$cst$1629$page$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));
case "add-color":case "mod-color":return $r$jscomp$140$$($APP.$cljs$cst$1303$color$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($change$jscomp$35$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$266$id$$],null)));case "del-color":return $r$jscomp$140$$($APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));case "add-recent-color":return null;case "add-media":case "mod-media":return $r$jscomp$140$$($APP.$cljs$cst$1644$media$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($change$jscomp$35$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2206$object$$,$APP.$cljs$cst$266$id$$],null)));case "del-media":return $r$jscomp$140$$($APP.$cljs$cst$1644$media$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));case "add-component":case "mod-component":case "del-component":return $r$jscomp$140$$($APP.$cljs$cst$1630$component$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));
case "add-typography":case "mod-typography":return $r$jscomp$140$$($APP.$cljs$cst$1997$typography$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($change$jscomp$35$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1997$typography$$,$APP.$cljs$cst$266$id$$],null)));case "del-typography":return $r$jscomp$140$$($APP.$cljs$cst$1997$typography$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$35$$));default:return null}};
$app$main$ui$workspace$sidebar$history$resolve_shape_types$$=function($entries$jscomp$36$$,$objects$jscomp$788$$){function $map_fn$$($JSCompiler_temp$jscomp$1796_entry$jscomp$72$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1796_entry$jscomp$72$$),$APP.$cljs$cst$1817$shape$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1796_entry$jscomp$72$$),
$APP.$cljs$cst$1621$multiple$$)){var $JSCompiler_temp_const$jscomp$1798$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1797$$=$APP.$cljs$cst$139$type$$,$id$jscomp$inline_9000_map__78896__$1$jscomp$inline_8998$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$1796_entry$jscomp$72$$);var $JSCompiler_inline_result$jscomp$1800_type$jscomp$inline_8999$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_9000_map__78896__$1$jscomp$inline_8998$$,
$APP.$cljs$cst$139$type$$);$id$jscomp$inline_9000_map__78896__$1$jscomp$inline_8998$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_9000_map__78896__$1$jscomp$inline_8998$$,$APP.$cljs$cst$266$id$$);$JSCompiler_inline_result$jscomp$1800_type$jscomp$inline_8999$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1800_type$jscomp$inline_8999$$,$APP.$cljs$cst$1817$shape$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$inline_9000_map__78896__$1$jscomp$inline_8998$$,
$APP.$cljs$cst$1621$multiple$$)?$JSCompiler_inline_result$jscomp$1800_type$jscomp$inline_8999$$:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$history$get_object$$($id$jscomp$inline_9000_map__78896__$1$jscomp$inline_8998$$,$entries$jscomp$36$$,$objects$jscomp$788$$));$JSCompiler_temp$jscomp$1796_entry$jscomp$72$$=$JSCompiler_temp_const$jscomp$1798$$.call($APP.$cljs$core$assoc$$,$JSCompiler_temp$jscomp$1796_entry$jscomp$72$$,$JSCompiler_temp_const$jscomp$1797$$,
$JSCompiler_inline_result$jscomp$1800_type$jscomp$inline_8999$$)}return $JSCompiler_temp$jscomp$1796_entry$jscomp$72$$}return function($entries__$1$jscomp$5$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($map_fn$$,$entries__$1$jscomp$5$$)}};
$app$main$ui$workspace$sidebar$history$entry__GT_message$$=function($G__78897_entry$jscomp$73$$){var $attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__78897_entry$jscomp$73$$);var $arity$jscomp$inline_13806_multiple_QMARK_$jscomp$inline_13805$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__78897_entry$jscomp$73$$));
$arity$jscomp$inline_13806_multiple_QMARK_$jscomp$inline_13805$$=$APP.$cljs$core$truth_$$($arity$jscomp$inline_13806_multiple_QMARK_$jscomp$inline_13805$$)?"multiple":"single";$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$=$APP.$cljs$core$name$$($APP.$cljs$core$truth_$$($attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$)?$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$:$APP.$cljs$cst$1621$multiple$$);$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$format$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.%s.%s",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$arity$jscomp$inline_13806_multiple_QMARK_$jscomp$inline_13805$$,$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$])));$G__78897_entry$jscomp$73$$=$cljs$cst$5761$operation$$.$cljs$core$IFn$_invoke$arity$1$($G__78897_entry$jscomp$73$$);switch($G__78897_entry$jscomp$73$$ instanceof
$APP.$cljs$core$Keyword$$?$G__78897_entry$jscomp$73$$.$fqn$:null){case "new":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.new",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$]));case "modify":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.modify",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$]));
case "delete":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.delete",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$]));case "move":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.move",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$]));
default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.unknown",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$attribute$jscomp$inline_13807_type$jscomp$inline_13804_value$jscomp$816$$]))}};
$app$main$ui$workspace$sidebar$history$entry__GT_icon$$=function($G__78900_map__78899__$1_p__78898$$){$G__78900_map__78899__$1_p__78898$$=$APP.$cljs$core$__destructure_map$$($G__78900_map__78899__$1_p__78898$$);$G__78900_map__78899__$1_p__78898$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78900_map__78899__$1_p__78898$$,$APP.$cljs$cst$139$type$$);switch($G__78900_map__78899__$1_p__78898$$ instanceof $APP.$cljs$core$Keyword$$?$G__78900_map__78899__$1_p__78898$$.$fqn$:null){case "page":return $APP.$app$main$ui$icons$document$$;
case "shape":return $APP.$app$main$ui$icons$svg$$;case "rect":return $APP.$app$main$ui$icons$rectangle$$;case "circle":return $APP.$app$main$ui$icons$ellipse$$;case "text":return $APP.$app$main$ui$icons$text$$;case "path":return $APP.$app$main$ui$icons$path$$;case "frame":return $APP.$app$main$ui$icons$board$$;case "group":return $APP.$app$main$ui$icons$group$$;case "color":return $APP.$app$main$ui$icons$drop_icon$$;case "typography":return $APP.$app$main$ui$icons$text_palette$$;case "component":return $APP.$app$main$ui$icons$component$$;
case "media":return $APP.$app$main$ui$icons$img$$;case "image":return $APP.$app$main$ui$icons$img$$;default:return $APP.$app$main$ui$icons$svg$$}};
$app$main$ui$workspace$sidebar$history$is_shape_QMARK_$$=function($type$jscomp$625$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$1613$group$$,null,$APP.$cljs$cst$1611$frame$$,null,$APP.$cljs$cst$1422$circle$$,null,$APP.$cljs$cst$1817$shape$$,null,$APP.$cljs$cst$1616$rect$$,null,$APP.$cljs$cst$1593$text$$,null],null),null),$type$jscomp$625$$)};
$app$main$ui$workspace$sidebar$history$short_id$$=function($JSCompiler_temp_const$jscomp$1806_entry$jscomp$74_temp__5825__auto__$jscomp$374$$){$JSCompiler_temp_const$jscomp$1806_entry$jscomp$74_temp__5825__auto__$jscomp$374$$=$APP.$cljs$cst$3162$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$1806_entry$jscomp$74_temp__5825__auto__$jscomp$374$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$1806_entry$jscomp$74_temp__5825__auto__$jscomp$374$$)){var $s$jscomp$589_y__5114__auto__$jscomp$inline_9002$$=
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$1806_entry$jscomp$74_temp__5825__auto__$jscomp$374$$);$JSCompiler_temp_const$jscomp$1806_entry$jscomp$74_temp__5825__auto__$jscomp$374$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$;var $JSCompiler_temp_const$jscomp$1805$$=$APP.$cuerdas$core$replace$$($s$jscomp$589_y__5114__auto__$jscomp$inline_9002$$,/[^0-9a-f]/,"");$s$jscomp$589_y__5114__auto__$jscomp$inline_9002$$=$s$jscomp$589_y__5114__auto__$jscomp$inline_9002$$.length;
return $JSCompiler_temp_const$jscomp$1806_entry$jscomp$74_temp__5825__auto__$jscomp$374$$.call($APP.$cljs$core$subs$$,$JSCompiler_temp_const$jscomp$1805$$,0,7<$s$jscomp$589_y__5114__auto__$jscomp$inline_9002$$?7:$s$jscomp$589_y__5114__auto__$jscomp$inline_9002$$)}return null};$app$main$ui$workspace$sidebar$history$safe_name$$=function($maybe_keyword$jscomp$1$$){return $maybe_keyword$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$APP.$cljs$core$name$$($maybe_keyword$jscomp$1$$):$maybe_keyword$jscomp$1$$};
$app$main$ui$workspace$sidebar$history$select_entry$$=function($candidates$jscomp$1$$){function $single_QMARK_$jscomp$13$$($coll$jscomp$1102$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($coll$jscomp$1102$$),1)}var $detail$jscomp$9_entries$jscomp$37$$=$APP.$cljs$core$group_by$$(function($p1__78904_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__78904_SHARP_$$),
$cljs$cst$5761$operation$$.$cljs$core$IFn$_invoke$arity$1$($p1__78904_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78904_SHARP_$$)],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$candidates$jscomp$1$$)),$types$jscomp$13$$=$APP.$cljs$core$group_by$$($APP.$cljs$core$first$$,$APP.$cljs$core$keys$$($detail$jscomp$9_entries$jscomp$37$$)),$operations$jscomp$11$$=$APP.$cljs$core$group_by$$($APP.$cljs$core$second$$,$APP.$cljs$core$keys$$($detail$jscomp$9_entries$jscomp$37$$)),
$selected_entry$$=$single_QMARK_$jscomp$13$$($detail$jscomp$9_entries$jscomp$37$$)?$APP.$cljs$core$last$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($detail$jscomp$9_entries$jscomp$37$$,$APP.$cljs$core$first$$($APP.$cljs$core$keys$$($detail$jscomp$9_entries$jscomp$37$$)))):$single_QMARK_$jscomp$13$$($APP.$cljs$cst$4068$new$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$))?$APP.$cljs$core$last$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($detail$jscomp$9_entries$jscomp$37$$,
$APP.$cljs$core$first$$($APP.$cljs$cst$4068$new$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$)))):$single_QMARK_$jscomp$13$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78905_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$group$$,$APP.$cljs$core$first$$($p1__78905_SHARP_$$))},$APP.$cljs$cst$4945$delete$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$)))?$APP.$cljs$core$last$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($detail$jscomp$9_entries$jscomp$37$$,
$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78906_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$group$$,$APP.$cljs$core$first$$($p1__78906_SHARP_$$))},$APP.$cljs$cst$4945$delete$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$))))):$single_QMARK_$jscomp$13$$($APP.$cljs$cst$1804$move$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$))?$APP.$cljs$core$last$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($detail$jscomp$9_entries$jscomp$37$$,
$APP.$cljs$core$first$$($APP.$cljs$cst$1804$move$$.$cljs$core$IFn$_invoke$arity$1$($operations$jscomp$11$$)))):$single_QMARK_$jscomp$13$$($operations$jscomp$11$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$core$every_QMARK_$$($app$main$ui$workspace$sidebar$history$is_shape_QMARK_$$,$APP.$cljs$core$keys$$($types$jscomp$13$$))?$APP.$cljs$cst$1817$shape$$:$APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1621$multiple$$,$cljs$cst$5761$operation$$,
$APP.$cljs$core$first$$($APP.$cljs$core$keys$$($operations$jscomp$11$$))],null):new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1621$multiple$$,$cljs$cst$5761$operation$$,$APP.$cljs$cst$1621$multiple$$],null);$detail$jscomp$9_entries$jscomp$37$$=function(){var $G__78909$$=$cljs$cst$5761$operation$$.$cljs$core$IFn$_invoke$arity$1$($selected_entry$$);switch($G__78909$$ instanceof $APP.$cljs$core$Keyword$$?
$G__78909$$.$fqn$:null){case "new":return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($selected_entry$$);case "modify":return $APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($_$jscomp$3043$$,$v$jscomp$671$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$history$safe_name$$,
$APP.$cljs$cst$2610$attr$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$5446$detail$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$v$jscomp$671$$])))))},$APP.$cljs$core$group_by$$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78907_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5760$modify$$,$cljs$cst$5761$operation$$.$cljs$core$IFn$_invoke$arity$1$($p1__78907_SHARP_$$))},
$candidates$jscomp$1$$)));case "delete":return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78908_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4945$delete$$,$cljs$cst$5761$operation$$.$cljs$core$IFn$_invoke$arity$1$($p1__78908_SHARP_$$))},$candidates$jscomp$1$$));default:return $candidates$jscomp$1$$}}();return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($selected_entry$$,
$APP.$cljs$cst$5446$detail$$,$detail$jscomp$9_entries$jscomp$37$$)};
$app$main$ui$workspace$sidebar$history$parse_entries$$=function($entries$jscomp$38$$,$objects$jscomp$789$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($raw_entry$$){var $JSCompiler_temp_const$jscomp$1802$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp_const$jscomp$1801$$=$app$main$ui$workspace$sidebar$history$resolve_shape_types$$($entries$jscomp$38$$,$objects$jscomp$789$$);var $JSCompiler_inline_result$jscomp$1804_map__78903__$1$jscomp$inline_9005_redo_changes$jscomp$inline_9006$$=
$APP.$cljs$core$__destructure_map$$($raw_entry$$);$JSCompiler_inline_result$jscomp$1804_map__78903__$1$jscomp$inline_9005_redo_changes$jscomp$inline_9006$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1804_map__78903__$1$jscomp$inline_9005_redo_changes$jscomp$inline_9006$$,$APP.$cljs$cst$3157$redo_changes$$);$JSCompiler_inline_result$jscomp$1804_map__78903__$1$jscomp$inline_9005_redo_changes$jscomp$inline_9006$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$history$parse_change$$,
$JSCompiler_inline_result$jscomp$1804_map__78903__$1$jscomp$inline_9005_redo_changes$jscomp$inline_9006$$);return $JSCompiler_temp_const$jscomp$1802$$.call($APP.$cljs$core$assoc$$,$app$main$ui$workspace$sidebar$history$select_entry$$($JSCompiler_temp_const$jscomp$1801$$($JSCompiler_inline_result$jscomp$1804_map__78903__$1$jscomp$inline_9005_redo_changes$jscomp$inline_9006$$)),$APP.$cljs$cst$2345$timestamp$$,$APP.$cljs$cst$2345$timestamp$$.$cljs$core$IFn$_invoke$arity$1$($raw_entry$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3162$undo_group$$,
$APP.$cljs$cst$3162$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($raw_entry$$),$APP.$cljs$cst$2878$by$$,$APP.$cljs$cst$2878$by$$.$cljs$core$IFn$_invoke$arity$1$($raw_entry$$)]))},$entries$jscomp$38$$)};
$app$main$ui$workspace$sidebar$history$history_entry_details_STAR_$$=function($map__78912_map__78912__$1_props_78911$$){var $entry$jscomp$75$$=$map__78912_map__78912__$1_props_78911$$.entry;$map__78912_map__78912__$1_props_78911$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$history$workspace_undo$$);$map__78912_map__78912__$1_props_78911$$=$APP.$cljs$core$__destructure_map$$($map__78912_map__78912__$1_props_78911$$);var $entries$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78912_map__78912__$1_props_78911$$,
$APP.$cljs$cst$1844$items$$),$objects$jscomp$790$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-detail",children:function(){var $G__78913$$=$cljs$cst$5761$operation$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$75$$);switch($G__78913$$ instanceof $APP.$cljs$core$Keyword$$?$G__78913$$.$fqn$:null){case "new":return $APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$history$get_object$$($APP.$cljs$cst$5446$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$75$$),
$entries$jscomp$39$$,$objects$jscomp$790$$));case "delete":return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_history__history-entry-details-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$160$$,$JSCompiler_inline_result$jscomp$1811_id$jscomp$955$$){var $JSCompiler_temp_const$jscomp$1809$$=$out_arr__44092__auto__$jscomp$160$$.push,$shape_name$jscomp$inline_9008$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$history$get_object$$($JSCompiler_inline_result$jscomp$1811_id$jscomp$955$$,
$entries$jscomp$39$$,$objects$jscomp$790$$));$JSCompiler_inline_result$jscomp$1811_id$jscomp$955$$=(0,$APP.$rumext$v2$jsx$$)("li",{children:$shape_name$jscomp$inline_9008$$},$JSCompiler_inline_result$jscomp$1811_id$jscomp$955$$);$JSCompiler_temp_const$jscomp$1809$$.call($out_arr__44092__auto__$jscomp$160$$,$JSCompiler_inline_result$jscomp$1811_id$jscomp$955$$);return $out_arr__44092__auto__$jscomp$160$$},[],$APP.$cljs$cst$5446$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$75$$))});case "modify":return(0,$APP.$rumext$v2$jsx$$)("ul",
{className:"main_ui_workspace_sidebar_history__history-entry-details-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$161$$,$JSCompiler_temp_const$jscomp$1812_p__78916$$){var $JSCompiler_inline_result$jscomp$1814_id$jscomp$956$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1812_p__78916$$,0,null),$attributes$jscomp$78$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1812_p__78916$$,
1,null);$JSCompiler_temp_const$jscomp$1812_p__78916$$=$out_arr__44092__auto__$jscomp$161$$.push;var $shape_name$jscomp$inline_9010$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$history$get_object$$($JSCompiler_inline_result$jscomp$1814_id$jscomp$956$$,$entries$jscomp$39$$,$objects$jscomp$790$$));$JSCompiler_inline_result$jscomp$1814_id$jscomp$956$$=(0,$APP.$rumext$v2$jsxs$$)("li",{children:[(0,$APP.$rumext$v2$jsx$$)("div",{children:$shape_name$jscomp$inline_9010$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$attributes$jscomp$78$$)})]},$JSCompiler_inline_result$jscomp$1814_id$jscomp$956$$);$JSCompiler_temp_const$jscomp$1812_p__78916$$.call($out_arr__44092__auto__$jscomp$161$$,$JSCompiler_inline_result$jscomp$1814_id$jscomp$956$$);return $out_arr__44092__auto__$jscomp$161$$},[],$APP.$cljs$cst$5446$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$75$$))});default:return null}}()})};
$app$main$ui$workspace$sidebar$history$history_entry_STAR_$$=function($entry$jscomp$76_props_78922$$){var $is_disabled$jscomp$1$$=$entry$jscomp$76_props_78922$$.isDisabled,$is_current$jscomp$1$$=$entry$jscomp$76_props_78922$$.isCurrent,$idx_entry$$=$entry$jscomp$76_props_78922$$.idxEntry;$entry$jscomp$76_props_78922$$=$entry$jscomp$76_props_78922$$.entry;var $hover_QMARK_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_detail_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$relative_time$$=$APP.$app$common$time$timeago$$($APP.$cljs$cst$2345$timestamp$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76_props_78922$$)),$label$jscomp$43$$=$app$main$ui$workspace$sidebar$history$short_id$$($entry$jscomp$76_props_78922$$),$author$$=$APP.$cljs$cst$2878$by$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76_props_78922$$),$toggle_show_detail$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$478$$){var $has_entry_QMARK_$$=$APP.$cljs$core$parse_boolean$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$478$$),
"has-entry"));$APP.$app$util$dom$stop_propagation$$($event$jscomp$478$$);return $APP.$cljs$core$truth_$$($has_entry_QMARK_$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_detail_QMARK_$$,$APP.$cljs$core$not$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{onPointerEnter:function(){return $APP.$cljs$core$reset_BANG_$$($hover_QMARK_$jscomp$6$$,!0)},onPointerLeave:function(){return $APP.$cljs$core$reset_BANG_$$($hover_QMARK_$jscomp$6$$,!1)},onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$undo_to_index$$($idx_entry$$))},
className:"main_ui_workspace_sidebar_history__history-entry "+($APP.$cljs$core$truth_$$($is_disabled$jscomp$1$$)?"main_ui_workspace_sidebar_history__disabled":"")+" "+($APP.$cljs$core$truth_$$($is_current$jscomp$1$$)?"main_ui_workspace_sidebar_history__current":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover_QMARK_$jscomp$6$$))?"main_ui_workspace_sidebar_history__hover":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_detail_QMARK_$$))?"main_ui_workspace_sidebar_history__show-detail":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-summary",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-summary-icon",children:$app$main$ui$workspace$sidebar$history$entry__GT_icon$$($entry$jscomp$76_props_78922$$)}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-summary-text",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-title",
children:$app$main$ui$workspace$sidebar$history$entry__GT_message$$($entry$jscomp$76_props_78922$$)}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($label$jscomp$43$$)?$label$jscomp$43$$:$APP.$cljs$core$truth_$$($relative_time$$)?$relative_time$$:$author$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_history__history-entry-meta",children:[$APP.$cljs$core$truth_$$($label$jscomp$43$$)?(0,$APP.$rumext$v2$jsx$$)("span",{title:""+($APP.$cljs$cst$3162$undo_group$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76_props_78922$$)??
""),className:"main_ui_workspace_sidebar_history__history-entry-hash",children:$label$jscomp$43$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($label$jscomp$43$$)?$relative_time$$:$label$jscomp$43$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_history__history-entry-meta-sep",children:" · "}):null,$APP.$cljs$core$truth_$$($relative_time$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_history__history-entry-time",children:$relative_time$$}):
null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$810$$=$APP.$cljs$core$truth_$$($label$jscomp$43$$)?$label$jscomp$43$$:$relative_time$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$810$$)?$author$$:$and__5023__auto__$jscomp$810$$}())?" ":null,$APP.$cljs$core$truth_$$($author$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_history__history-entry-author",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.undo.entry.by",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$author$$]))}):null]}):null]}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$5446$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76_props_78922$$))?(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$toggle_show_detail$$,"data-has-entry":""+($APP.$cljs$cst$5446$detail$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$76_props_78922$$)!=null),className:"main_ui_workspace_sidebar_history__history-entry-summary-button "+($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_detail_QMARK_$$))?
"main_ui_workspace_sidebar_history__button-opened":""),children:$APP.$app$main$ui$icons$arrow$$}):null]}),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($show_detail_QMARK_$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history$history_entry_details_STAR_$$,{entry:$entry$jscomp$76_props_78922$$}):null]})};
$app$main$ui$workspace$sidebar$history$history_toolbox_STAR_$$=function(){var $entries$jscomp$40_objects$jscomp$791$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$map__78932_map__78932__$1$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$history$workspace_undo$$);$map__78932_map__78932__$1$$=$APP.$cljs$core$__destructure_map$$($map__78932_map__78932__$1$$);var $items$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78932_map__78932__$1$$,$APP.$cljs$cst$1844$items$$),
$index$jscomp$484$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78932_map__78932__$1$$,$APP.$cljs$cst$1801$index$$);$entries$jscomp$40_objects$jscomp$791$$=$app$main$ui$workspace$sidebar$history$parse_entries$$($items$jscomp$62$$,$entries$jscomp$40_objects$jscomp$791$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_history__history-toolbox",children:$APP.$cljs$core$empty_QMARK_$$($entries$jscomp$40_objects$jscomp$791$$)?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_history__history-entry-empty",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"history",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.undo.empty")})}):(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_history__history-entries",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$162$$,$entry$jscomp$77_p__78934$$){var $idx_entry$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entry$jscomp$77_p__78934$$,0,null);$entry$jscomp$77_p__78934$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entry$jscomp$77_p__78934$$,1,null);$out_arr__44092__auto__$jscomp$162$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history$history_entry_STAR_$$,{entry:$entry$jscomp$77_p__78934$$,idxEntry:$idx_entry$jscomp$1$$,isCurrent:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx_entry$jscomp$1$$,$index$jscomp$484$$),
isDisabled:$idx_entry$jscomp$1$$>$index$jscomp$484$$},["entry-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($idx_entry$jscomp$1$$)].join("")));return $out_arr__44092__auto__$jscomp$162$$},[],$APP.$cljs$core$reverse$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$entries$jscomp$40_objects$jscomp$791$$)))})})};
$app$main$ui$workspace$sidebar$layers$use_selected_shapes$$=function(){var $selected$jscomp$170$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$);return $APP.$app$main$ui$hooks$use_equal_memo$$($selected$jscomp$170$$)};
$app$main$ui$workspace$sidebar$layers$frame_wrapper_STAR_$$=function($props_78910_props__$1$jscomp$75$$){var $selected$jscomp$171$$=$props_78910_props__$1$jscomp$75$$.selected,$pending_selected_ref$$=(0,$APP.$rumext$v2$use_ref$$)($selected$jscomp$171$$),$current_selected$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($selected$jscomp$171$$);$props_78910_props__$1$jscomp$75$$={...$props_78910_props__$1$jscomp$75$$,selected:$APP.$cljs$core$_deref$$($current_selected$$)};var $set_selected$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$rxops$throttle_fn$$(function(){var $temp__5825__auto__$jscomp$375$$=$APP.$rumext$v2$ref_val$$($pending_selected_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$375$$)?$APP.$cljs$core$reset_BANG_$$($current_selected$$,$temp__5825__auto__$jscomp$375$$):null})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$171$$),$APP.$rumext$v2$adapt$$($set_selected$$)],
function(){$APP.$rumext$v2$set_ref_val_BANG_$$($pending_selected_ref$$,$selected$jscomp$171$$);$set_selected$$();return function(){$APP.$rumext$v2$set_ref_val_BANG_$$($pending_selected_ref$$,null);return $APP.$beicon$v2$core$_dispose$$($set_selected$$)}});return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$,$props_78910_props__$1$jscomp$75$$)};
$app$main$ui$workspace$sidebar$layers$layers_tree_wrapper_STAR_$$=function($props_78923_props__$1$jscomp$76$$){var $objects$jscomp$793$$=$props_78923_props__$1$jscomp$76$$.objects,$state_tmp$$=(0,$APP.$rumext$v2$useState$$)($objects$jscomp$793$$),$objects_SINGLEQUOTE_$jscomp$2$$=$state_tmp$$[0],$set_objects$$=$state_tmp$$[1],$subject_s$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$subject$$()}),$changes_s$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($subject_s$$)],
function(){return $APP.$beicon$v2$core$debounce$$(500,$subject_s$$)});$props_78923_props__$1$jscomp$76$$={...$props_78923_props__$1$jscomp$76$$,objects:$objects_SINGLEQUOTE_$jscomp$2$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$793$$),$APP.$rumext$v2$adapt$$($subject_s$$)],function(){return $subject_s$$.next($objects$jscomp$793$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($changes_s$jscomp$1$$)],
function(){var $sub$jscomp$26$$=$APP.$beicon$v2$core$subscribe$cljs$0core$0IFn$0_invoke$0arity$02$$($changes_s$jscomp$1$$,$set_objects$$);return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$26$$)}});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$layers$layers_tree_STAR_$$,$props_78923_props__$1$jscomp$76$$)};
$app$main$ui$workspace$sidebar$layers$calc_reparented_objects$$=function($objects$jscomp$795_reparented_objects$$){$objects$jscomp$795_reparented_objects$$=$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($_$jscomp$3044$$,$val$jscomp$207$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($val$jscomp$207$$,$APP.$cljs$cst$1624$parent_id$$,$APP.$app$common$uuid$zero$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1619$shapes$$,
null]))},$objects$jscomp$795_reparented_objects$$);var $reparented_shapes$$=$APP.$cljs$core$vec$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78938_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$p1__78938_SHARP_$$)},$APP.$cljs$core$keys$$($objects$jscomp$795_reparented_objects$$)));return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($objects$jscomp$795_reparented_objects$$,$APP.$app$common$uuid$zero$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1619$shapes$$,$reparented_shapes$$)};
$app$main$ui$workspace$sidebar$layers$match_filters_QMARK_$$=function($filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$,$p__78939$$){var $id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78939$$,0,null),$shape$jscomp$994$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78939$$,1,null),$search$jscomp$8$$=
$cljs$cst$5762$search_text$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$),$scope$jscomp$11$$=$cljs$cst$5763$search_scope$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$);$filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$=$cljs$cst$5764$filters$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$);var $filters__$1$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$,
$APP.$cljs$cst$1817$shape$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$variadic$($filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$,$APP.$cljs$cst$1616$rect$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1422$circle$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1615$bool$$])):$filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$;$filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$=function(){switch($scope$jscomp$11$$ instanceof $APP.$cljs$core$Keyword$$?
$scope$jscomp$11$$.$fqn$:null){case "canvas":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$))&&$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$)!=null&&$app$common$types$text$content_has_text_QMARK_$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$),$search$jscomp$8$$);default:var $and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$=
$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$)),$APP.$cuerdas$core$lower$$($search$jscomp$8$$));if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$))return $and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$;$and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$=
$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$2018$variant_name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$)),$APP.$cuerdas$core$lower$$($search$jscomp$8$$));if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$))return $and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$;$and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$=
$APP.$cljs$core$_STAR_assert_STAR_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$)?$APP.$cuerdas$core$includes_QMARK_$$(""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$)??""),$APP.$cuerdas$core$lower$$($search$jscomp$8$$)):$and__5023__auto__$jscomp$812_or__5025__auto__$jscomp$1200_or__5025__auto____$1$jscomp$131$$}}();return($id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$))?$id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$:$APP.$cljs$core$truth_$$($filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$)?
($id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$=$APP.$cljs$core$empty_QMARK_$$($filters__$1$jscomp$1$$))||($id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$=$APP.$cljs$core$contains_QMARK_$$($filters__$1$jscomp$1$$,$APP.$cljs$cst$1630$component$$)&&$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$994$$,
$APP.$cljs$cst$1632$component_id$$))||($id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$=$APP.$cljs$core$contains_QMARK_$$($filters__$1$jscomp$1$$,$APP.$cljs$cst$1617$image$$)&&$APP.$app$common$types$shape$has_images_QMARK_$$($shape$jscomp$994$$)!=null)?$id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$:
($id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$=function(){var $direct_filters$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$1611$frame$$,
null,$APP.$cljs$cst$1422$circle$$,null,$APP.$cljs$cst$1615$bool$$,null,$APP.$cljs$cst$1616$rect$$,null,$APP.$cljs$cst$1593$text$$,null],null),null)),$filters__$1$jscomp$1$$);return $APP.$cljs$core$contains_QMARK_$$($direct_filters$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$))}())?$id$jscomp$959_or__5025__auto__$jscomp$1199_or__5025__auto____$1$jscomp$130_or__5025__auto____$2$jscomp$32_or__5025__auto____$3$jscomp$9_or__5025__auto____$4$jscomp$6$$:$APP.$cljs$core$contains_QMARK_$$($filters__$1$jscomp$1$$,
$APP.$cljs$cst$1613$group$$)&&$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$)&&!$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$994$$,$APP.$cljs$cst$1632$component_id$$)&&(!$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$994$$,$APP.$cljs$cst$1614$masked_group$$)||$APP.$cljs$cst$1614$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$)===!1)||$APP.$cljs$core$contains_QMARK_$$($filters__$1$jscomp$1$$,$APP.$cljs$cst$2700$mask$$)&&
$APP.$cljs$cst$1614$masked_group$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$994$$)===!0:$filters$jscomp$12_state$jscomp$1200_text_match_QMARK_$$};
$app$main$ui$workspace$sidebar$layers$radio_button_STAR_$$=function($checked_props_78949$$){var $on_change$jscomp$54$$=$checked_props_78949$$.onChange,$text$jscomp$142$$=$checked_props_78949$$.text,$name$jscomp$455$$=$checked_props_78949$$.name;$checked_props_78949$$=$checked_props_78949$$.checked;return(0,$APP.$rumext$v2$jsxs$$)("label",{className:"main_ui_workspace_sidebar_layers__radio-label "+($APP.$cljs$core$truth_$$($checked_props_78949$$)?"main_ui_workspace_sidebar_layers__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_layers__radio-icon "+($APP.$cljs$core$truth_$$($checked_props_78949$$)?"main_ui_workspace_sidebar_layers__checked":"")}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"radio",name:$name$jscomp$455$$,checked:$checked_props_78949$$,onChange:$on_change$jscomp$54$$,className:"main_ui_workspace_sidebar_layers__radio-input"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__radio-text",children:$text$jscomp$142$$})]})};
$app$main$ui$workspace$sidebar$layers$use_search$$=function($page$jscomp$166$$,$objects$jscomp$796$$){var $state_STAR_$jscomp$13$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5764$filters$$,$cljs$cst$5765$show_search$$,$cljs$cst$5766$num_items$$,$cljs$cst$5763$search_scope$$,$cljs$cst$5767$replace_text$$,$cljs$cst$5727$show_menu$$,$APP.$cljs$cst$4603$find_replace_mode_QMARK_$$,$cljs$cst$5762$search_text$$,
$cljs$cst$5768$current_match_idx$$],[$APP.$cljs$core$PersistentHashSet$EMPTY$$,!1,100,$APP.$cljs$cst$3777$layers$$,"",!1,!1,"",0])}),$layers_search$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$layers$ref_COLON_layers_search$$),$state$jscomp$1201$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$13$$),$current_filters$$=$cljs$cst$5764$filters$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),$current_items$$=$cljs$cst$5766$num_items$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),
$current_search$$=$cljs$cst$5762$search_text$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),$replace_text$$=$cljs$cst$5767$replace_text$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),$show_menu_QMARK_$jscomp$2$$=$cljs$cst$5727$show_menu$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),$show_search_QMARK_$$=$cljs$cst$5765$show_search$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),$find_replace_mode_QMARK_$$=$APP.$cljs$cst$4603$find_replace_mode_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),
$search_scope$$=$cljs$cst$5763$search_scope$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),$current_match_idx_filtered_objects$$=$cljs$cst$5768$current_match_idx$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1201$$),$search_input_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$clear_search_text$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$13$$,$APP.$cljs$core$assoc$$,
$cljs$cst$5762$search_text$$,"",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5766$num_items$$,100,$cljs$cst$5768$current_match_idx$$,0]))}),$toggle_filters$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$update$$,$cljs$cst$5727$show_menu$$,$APP.$cljs$core$not$$)}),$on_toggle_filters_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$479$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$479$$);
return $toggle_filters$$.$cljs$core$IFn$_invoke$arity$0$?$toggle_filters$$.$cljs$core$IFn$_invoke$arity$0$():$toggle_filters$$()}),$hide_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$assoc$$,$cljs$cst$5727$show_menu$$,!1)}),$on_key_down$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$480$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$480$$))?
$hide_menu$$.$cljs$core$IFn$_invoke$arity$0$?$hide_menu$$.$cljs$core$IFn$_invoke$arity$0$():$hide_menu$$():null}),$update_search_text$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$817$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$13$$,$APP.$cljs$core$assoc$$,$cljs$cst$5762$search_text$$,$value$jscomp$817$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5766$num_items$$,100,$cljs$cst$5768$current_match_idx$$,
0]))}),$update_replace_text$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$481_value$jscomp$818$$){$event$jscomp$481_value$jscomp$818$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$481_value$jscomp$818$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$assoc$$,$cljs$cst$5767$replace_text$$,$event$jscomp$481_value$jscomp$818$$)}),$f_key_QMARK_$$=$APP.$app$util$keyboard$is_key_ignore_case_QMARK_$$("f"),
$h_key_QMARK_$$=$APP.$app$util$keyboard$is_key_ignore_case_QMARK_$$("h"),$handle_find_shortcut_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$482$$){if($APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$482$$)){if($APP.$cljs$core$truth_$$($f_key_QMARK_$$($event$jscomp$482$$)))return $APP.$app$util$dom$prevent_default$$($event$jscomp$482$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$482$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4905$find$$,
null));if($APP.$cljs$core$truth_$$($h_key_QMARK_$$($event$jscomp$482$$)))return $APP.$app$util$dom$prevent_default$$($event$jscomp$482$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$482$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4602$find_and_replace$$,null))}return null}),$set_search_scope$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($scope$jscomp$12$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$13$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5763$search_scope$$,$scope$jscomp$12$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5766$num_items$$,100,$cljs$cst$5768$current_match_idx$$,0]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_layers_search_scope$$($scope$jscomp$12$$))}),$toggle_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($find_replace_mode_QMARK_$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($find_replace_mode_QMARK_$$)?
$APP.$cljs$cst$4905$find$$:$APP.$cljs$cst$4602$find_and_replace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3784$force_QMARK_$$,!0],null)))}),$toggle_search$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_search_QMARK_$$)],function($event$jscomp$483$$){$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_current_target$$($event$jscomp$483$$));return $APP.$cljs$core$truth_$$($show_search_QMARK_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$close_layers_search$$):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4905$find$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3784$force_QMARK_$$,!0],null)))}),$remove_filter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$484$$){var $fkey$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$484$$),
"filter"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$13$$,function($state__$1$jscomp$55$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$55$$,$cljs$cst$5764$filters$$,$APP.$cljs$core$disj$$,$fkey$$),$cljs$cst$5766$num_items$$,100)})}),$add_filter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$485$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$485$$);
var $key$jscomp$416$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$485$$),"filter"));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$13$$,function($state__$1$jscomp$56$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($state__$1$jscomp$56$$,
$cljs$cst$5764$filters$$,$APP.$cljs$core$conj$$,$key$jscomp$416$$),$cljs$cst$5727$show_menu$$,$APP.$cljs$core$not$$),$cljs$cst$5766$num_items$$,100)})}),$active_QMARK_$jscomp$5$$=$show_search_QMARK_$$&&($APP.$app$common$data$not_empty_QMARK_$$($current_search$$)||$APP.$app$common$data$not_empty_QMARK_$$($current_filters$$)),$filtered_objects_all$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_QMARK_$jscomp$5$$),$APP.$rumext$v2$adapt$$($objects$jscomp$796$$),
$APP.$rumext$v2$adapt$$($state$jscomp$1201$$)],function(){return $active_QMARK_$jscomp$5$$?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$sidebar$layers$match_filters_QMARK_$$,$state$jscomp$1201$$)),$objects$jscomp$796$$):null}),$filtered_objects_total$$=$APP.$cljs$core$count$$($filtered_objects_all$$),$canvas_match_ids_handle_show_more$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$796$$),$APP.$rumext$v2$adapt$$($current_search$$),$APP.$rumext$v2$adapt$$($search_scope$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3103$canvas$$,$search_scope$$)&&$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)?$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$160$$,$id$jscomp$960$$,$shape$jscomp$995$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$995$$))&&$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$995$$)!=null&&$app$common$types$text$content_has_text_QMARK_$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$995$$),$current_search$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$160$$,$id$jscomp$960$$):$acc$jscomp$160$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$objects$jscomp$796$$):null}),
$layer_match_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$796$$),$APP.$rumext$v2$adapt$$($current_search$$),$APP.$rumext$v2$adapt$$($search_scope$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3777$layers$$,$search_scope$$)&&$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)?$APP.$cljs$core$reduce_kv$$(function($acc$jscomp$161$$,$id$jscomp$961$$,$shape$jscomp$996$$){return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$996$$)),
$APP.$cuerdas$core$lower$$($current_search$$)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$161$$,$id$jscomp$961$$):$acc$jscomp$161$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$objects$jscomp$796$$):null}),$text_match_ids$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3103$canvas$$,$search_scope$$)?$canvas_match_ids_handle_show_more$$:$layer_match_ids$$,$text_match_count$$=$APP.$cljs$core$count$$($text_match_ids$$),$safe_match_idx$$=$text_match_count$$>
0?$APP.$cljs$core$mod$$($current_match_idx_filtered_objects$$,$text_match_count$$):0,$navigate_next$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_match_count$$)],function(){return $text_match_count$$>0?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$update$$,$cljs$cst$5768$current_match_idx$$,function($idx$jscomp$122$$){return $APP.$cljs$core$mod$$($idx$jscomp$122$$+1,$text_match_count$$)}):null}),
$navigate_prev$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_match_count$$)],function(){return $text_match_count$$>0?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,$APP.$cljs$core$update$$,$cljs$cst$5768$current_match_idx$$,function($idx$jscomp$123$$){return $APP.$cljs$core$mod$$($idx$jscomp$123$$-1+$text_match_count$$,$text_match_count$$)}):null}),$handle_replace$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_match_ids$$),
$APP.$rumext$v2$adapt$$($safe_match_idx$$),$APP.$rumext$v2$adapt$$($replace_text$$),$APP.$rumext$v2$adapt$$($current_search$$),$APP.$rumext$v2$adapt$$($search_scope$$)],function(){if($text_match_count$$>0&&$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)){var $id$jscomp$962$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($text_match_ids$$,$safe_match_idx$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3103$canvas$$,$search_scope$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$replace_text_in_shapes$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$962$$],null),$current_search$$,$replace_text$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$replace_layer_names_in_shapes$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$962$$],null),$current_search$$,$replace_text$$))}return null}),$handle_replace_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_match_ids$$),
$APP.$rumext$v2$adapt$$($replace_text$$),$APP.$rumext$v2$adapt$$($current_search$$),$APP.$rumext$v2$adapt$$($search_scope$$)],function(){return $text_match_count$$>0&&$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3103$canvas$$,$search_scope$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$replace_text_in_shapes$$($text_match_ids$$,$current_search$$,$replace_text$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$replace_layer_names_in_shapes$$($text_match_ids$$,$current_search$$,$replace_text$$)):null}),$on_replace_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_replace$$)],function($event$jscomp$486$$){var $JSCompiler_inline_result$jscomp$1818_or__5025__auto__$jscomp$inline_9016$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$486$$);$JSCompiler_inline_result$jscomp$1818_or__5025__auto__$jscomp$inline_9016$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1818_or__5025__auto__$jscomp$inline_9016$$)?$JSCompiler_inline_result$jscomp$1818_or__5025__auto__$jscomp$inline_9016$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($event$jscomp$486$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1818_or__5025__auto__$jscomp$inline_9016$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$486$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$486$$),$handle_replace$$.$cljs$core$IFn$_invoke$arity$1$?
$handle_replace$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$486$$):$handle_replace$$($event$jscomp$486$$)):null}),$on_replace_all_keydown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_replace_all$$)],function($event$jscomp$487$$){var $JSCompiler_inline_result$jscomp$1819_or__5025__auto__$jscomp$inline_9018$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$487$$);$JSCompiler_inline_result$jscomp$1819_or__5025__auto__$jscomp$inline_9018$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1819_or__5025__auto__$jscomp$inline_9018$$)?$JSCompiler_inline_result$jscomp$1819_or__5025__auto__$jscomp$inline_9018$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($event$jscomp$487$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1819_or__5025__auto__$jscomp$inline_9018$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$487$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$487$$),$handle_replace_all$$.$cljs$core$IFn$_invoke$arity$1$?
$handle_replace_all$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$487$$):$handle_replace_all$$($event$jscomp$487$$)):null});$current_match_idx_filtered_objects$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_QMARK_$jscomp$5$$),$APP.$rumext$v2$adapt$$($filtered_objects_all$$),$APP.$rumext$v2$adapt$$($current_items$$)],function(){return $active_QMARK_$jscomp$5$$?$app$main$ui$workspace$sidebar$layers$calc_reparented_objects$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$($current_items$$),$filtered_objects_all$$)):null});$canvas_match_ids_handle_show_more$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filtered_objects_total$$),$APP.$rumext$v2$adapt$$($current_items$$)],function(){return $current_items$$<=$filtered_objects_total$$?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$13$$,$APP.$cljs$core$update$$,$cljs$cst$5766$num_items$$,
$APP.$cljs$core$_PLUS_$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([100])):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key1$jscomp$8$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keydown",$on_key_down$jscomp$17$$),$key2$jscomp$6$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"click",$hide_menu$$);return function(){$APP.$goog$events$unlistenByKey$$($key1$jscomp$8$$);return $APP.$goog$events$unlistenByKey$$($key2$jscomp$6$$)}});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layers_search$$)],function(){if($APP.$cljs$core$truth_$$($layers_search$$)){var $map__78955__$1$$=$APP.$cljs$core$__destructure_map$$($layers_search$$),$open_QMARK_$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78955__$1$$,$APP.$cljs$cst$4601$open_QMARK_$$),$find_replace_mode_QMARK___$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78955__$1$$,$APP.$cljs$cst$4603$find_replace_mode_QMARK_$$),
$scope$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78955__$1$$,$APP.$cljs$cst$571$scope$$);return $APP.$cljs$core$truth_$$($open_QMARK_$jscomp$14$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$13$$,function($G__78956_s$jscomp$590$$){var $mode_changed_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4603$find_replace_mode_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__78956_s$jscomp$590$$),$find_replace_mode_QMARK___$1$$),
$opening_QMARK_$$=$APP.$cljs$core$not$$($cljs$cst$5765$show_search$$.$cljs$core$IFn$_invoke$arity$1$($G__78956_s$jscomp$590$$));$G__78956_s$jscomp$590$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__78956_s$jscomp$590$$,$cljs$cst$5765$show_search$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4603$find_replace_mode_QMARK_$$,$find_replace_mode_QMARK___$1$$,$cljs$cst$5763$search_scope$$,$scope$jscomp$13$$]));return $opening_QMARK_$$||$mode_changed_QMARK_$$?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__78956_s$jscomp$590$$,$cljs$cst$5762$search_text$$,"",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5767$replace_text$$,"",$cljs$cst$5768$current_match_idx$$,0])):$G__78956_s$jscomp$590$$}):null}return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$13$$,function($state__$1$jscomp$57$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($state__$1$jscomp$57$$,
$cljs$cst$5762$search_text$$,"",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5767$replace_text$$,"",$cljs$cst$5764$filters$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$])),$cljs$cst$5727$show_menu$$,!1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4603$find_replace_mode_QMARK_$$,!1])),$cljs$cst$5763$search_scope$$,$APP.$cljs$cst$3777$layers$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5766$num_items$$,100,$cljs$cst$5768$current_match_idx$$,
0])),$cljs$cst$5765$show_search$$,!1)})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($layers_search$$,$APP.$cljs$cst$571$scope$$))],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($layers_search$$)?$APP.$cljs$cst$4601$open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layers_search$$):$layers_search$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$13$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5763$search_scope$$,$APP.$cljs$cst$571$scope$$.$cljs$core$IFn$_invoke$arity$1$($layers_search$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layers_search$$),$APP.$rumext$v2$adapt$$($show_search_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($layers_search$$)){var $and__5023__auto____$1$jscomp$138$$=$APP.$cljs$cst$4601$open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($layers_search$$);
return $APP.$cljs$core$truth_$$($and__5023__auto____$1$jscomp$138$$)?$show_search_QMARK_$$:$and__5023__auto____$1$jscomp$138$$}return $layers_search$$}())?(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $temp__5825__auto__$jscomp$377$$=$APP.$rumext$v2$ref_val$$($search_input_ref$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$377$$)?$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$377$$):null}):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($find_replace_mode_QMARK_$$),
$APP.$rumext$v2$adapt$$($show_search_QMARK_$$),$APP.$rumext$v2$adapt$$($safe_match_idx$$),$APP.$rumext$v2$adapt$$($text_match_ids$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($find_replace_mode_QMARK_$$)?$APP.$cljs$core$truth_$$($show_search_QMARK_$$)?$APP.$cljs$core$seq$$($text_match_ids$$):$show_search_QMARK_$$:$find_replace_mode_QMARK_$$)){var $current_id_78973$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($text_match_ids$$,$safe_match_idx$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$highlight$set_search_match_highlight$$($current_id_78973$$,
$text_match_ids$$))}return function(){return $APP.$cljs$core$seq$$($text_match_ids$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$highlight$clear_search_match_highlight$$($text_match_ids$$)):null}});return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_match_idx_filtered_objects$$,$canvas_match_ids_handle_show_more$$,function(){return $APP.$cljs$core$truth_$$($show_search_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__tool-window-bar",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{inputRef:$search_input_ref$jscomp$1$$,className:"main_ui_workspace_sidebar_layers__search-item",onChange:$update_search_text$$,value:$current_search$$,onClear:$clear_search_text$$,onKeyDown:$handle_find_shortcut_keydown$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.search"),
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_layers__filter-button","aria-pressed":$show_menu_QMARK_$jscomp$2$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.filter"),onClick:$on_toggle_filters_click$$,icon:"filter"})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-pressed":$find_replace_mode_QMARK_$$,
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.search-and-replace"),onClick:$toggle_mode$$,icon:"menu"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$toggle_search$$,icon:"close"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-wrapper",children:[$find_replace_mode_QMARK_$$?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-row",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{type:"text",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.replace-placeholder"),onKeyDown:$handle_find_shortcut_keydown$$,onChange:$update_replace_text$$}),$APP.$app$common$data$not_empty_QMARK_$$($current_search$$)?$text_match_count$$>0?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-match-navigation",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__replace-match-count",children:""+($safe_match_idx$$+1??"")+" / "+($text_match_count$$??"")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.previous"),onClick:$navigate_prev$$,icon:"arrow-up"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.next"),onClick:$navigate_next$$,icon:"arrow-down"})]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-match-count",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.no-matches")}):null]}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-scope-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$radio_button_STAR_$$,
{name:"search-scope",checked:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3103$canvas$$,$search_scope$$),text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.search-scope-canvas"),onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($set_search_scope$$,$APP.$cljs$cst$3103$canvas$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$radio_button_STAR_$$,{name:"search-scope",checked:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3777$layers$$,
$search_scope$$),text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.search-scope-layers"),onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($set_search_scope$$,$APP.$cljs$cst$3777$layers$$)})]}),$find_replace_mode_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__replace-actions-row",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_layers__replace-actions-button",
onClick:$handle_replace$$,onKeyDown:$on_replace_keydown$$,disabled:$text_match_count$$===0||$APP.$cuerdas$core$empty_QMARK_$$($current_search$$),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.replace")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_layers__replace-actions-button",onClick:$handle_replace_all$$,onKeyDown:$on_replace_all_keydown$$,disabled:$text_match_count$$===
0||$APP.$cuerdas$core$empty_QMARK_$$($current_search$$),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.replace-all")})]}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__active-filters",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$165$$,$fkey$jscomp$1$$){$out_arr__44092__auto__$jscomp$165$$.push(function(){var $fname$jscomp$3$$=$APP.$app$common$data$name$$($fkey$jscomp$1$$),
$name$jscomp$456$$=function(){switch($fkey$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$fkey$jscomp$1$$.$fqn$:null){case "frame":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.frames");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.groups");case "mask":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.masks");case "component":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.components");
case "text":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.texts");case "image":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.images");case "shape":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.shapes");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($fkey$jscomp$1$$)}}(),$filter_icon$$=$app$util$shape_icon$get_shape_icon_by_type$$($fkey$jscomp$1$$);
return(0,$APP.$rumext$v2$jsxs$$)("button",{"data-filter":$fname$jscomp$3$$,onClick:$remove_filter$$,className:"main_ui_workspace_sidebar_layers__layer-filter",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$filter_icon$$,size:"s",className:"main_ui_workspace_sidebar_layers__layer-filter-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__layer-filter-name",children:$name$jscomp$456$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"close-small",className:"main_ui_workspace_sidebar_layers__layer-filter-close"})]},$fname$jscomp$3$$)}());return $out_arr__44092__auto__$jscomp$165$$},[],$current_filters$$)}),$show_menu_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_sidebar_layers__filters-container",children:[(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"frame",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,
$APP.$cljs$cst$1611$frame$$)?"main_ui_workspace_sidebar_layers__selected":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"board",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.frames")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1611$frame$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"group",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1613$group$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"group",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.groups")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1613$group$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"mask",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$2700$mask$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"mask",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.masks")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$2700$mask$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"component",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1630$component$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"component",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.components")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1630$component$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"text",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1593$text$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"text",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.texts")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1593$text$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"image",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1617$image$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"img",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.images")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1617$image$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("li",{"data-filter":"shape",onClick:$add_filter$$,className:"main_ui_workspace_sidebar_layers__filter-menu-item "+($APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1817$shape$$)?"main_ui_workspace_sidebar_layers__selected":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"path",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-icon"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__filter-menu-item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers.shapes")})]}),
$APP.$cljs$core$contains_QMARK_$$($current_filters$$,$APP.$cljs$cst$1817$shape$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_sidebar_layers__filter-menu-item-tick"}):null]})]}):null]})]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__tool-window-bar",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,className:"main_ui_workspace_sidebar_layers__tool-window-bar-title",
title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$166$$),onBtnClick:$toggle_search$$,btnIcon:"search",btnTitle:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.search")})})}],null)};
$app$main$ui$workspace$sidebar$layers$on_scroll$$=function($event$jscomp$488_frames$jscomp$27$$){var $children$jscomp$299_is_children_shown_QMARK_$$=$goog$dom$getElementsByClass$$("sticky-children");if($children$jscomp$299_is_children_shown_QMARK_$$.length>0){var $target_top$$=$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($event$jscomp$488_frames$jscomp$27$$)));$event$jscomp$488_frames$jscomp$27$$=$goog$dom$getElementsByClass$$("root-board");
var $last_hidden_frame$$=$APP.$cljs$core$last$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78958_SHARP_$$){return $APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($p1__78958_SHARP_$$))-$target_top$$<=0},$event$jscomp$488_frames$jscomp$27$$)),$frame_id$jscomp$145_sticky_QMARK_$$=$APP.$app$util$dom$get_attribute$$($last_hidden_frame$$,"id"),$children_frame_id_last_hidden_children$$=$APP.$cljs$core$last$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78959_SHARP_$$){return $APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($p1__78959_SHARP_$$))-
$target_top$$<0},$children$jscomp$299_is_children_shown_QMARK_$$));$children$jscomp$299_is_children_shown_QMARK_$$=$APP.$cljs$core$truth_$$($children_frame_id_last_hidden_children$$)?$APP.$cljs$cst$1568$bottom$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($children_frame_id_last_hidden_children$$))-$target_top$$>0:$children_frame_id_last_hidden_children$$;$children_frame_id_last_hidden_children$$=$APP.$app$util$dom$get_attribute$$($children_frame_id_last_hidden_children$$,
"data-id");$frame_id$jscomp$145_sticky_QMARK_$$=$APP.$cljs$core$truth_$$($last_hidden_frame$$)?$APP.$cljs$core$truth_$$($children$jscomp$299_is_children_shown_QMARK_$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$145_sticky_QMARK_$$,$children_frame_id_last_hidden_children$$):$children$jscomp$299_is_children_shown_QMARK_$$:$last_hidden_frame$$;$APP.$cljs$core$run_BANG_$$(function($p1__78960_SHARP_$$){return $p1__78960_SHARP_$$!=null?$p1__78960_SHARP_$$.classList.remove("sticky"):
null},$event$jscomp$488_frames$jscomp$27$$);return $APP.$cljs$core$truth_$$($frame_id$jscomp$145_sticky_QMARK_$$)?$APP.$app$util$dom$add_class_BANG_$$($last_hidden_frame$$,"sticky"):null}return null};
$app$main$ui$workspace$sidebar$options$common$advanced_options_STAR_$$=function($props_78952$$){var $children$jscomp$300$$=$props_78952$$.children,$class$$jscomp$68$$=$props_78952$$.className,$is_visible$jscomp$1$$=$props_78952$$.isVisible,$ref$jscomp$52$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_visible$jscomp$1$$)],function(){var $temp__5825__auto__$jscomp$379$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$52$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$379$$)?
$APP.$cljs$core$truth_$$($is_visible$jscomp$1$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$379$$,!1):null:null});return $APP.$cljs$core$truth_$$($is_visible$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{ref:$ref$jscomp$52$$,className:($class$$jscomp$68$$??"")+" main_ui_workspace_sidebar_options_common__advanced-options-wrapper",children:$children$jscomp$300$$}):null};
$app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$=function($value$jscomp$819$$,$emit_value_fn$$,$ids$jscomp$284$$,$attrs$jscomp$176$$){return typeof $value$jscomp$819$$==="string"||typeof $value$jscomp$819$$==="number"||$value$jscomp$819$$==null?$emit_value_fn$$.$cljs$core$IFn$_invoke$arity$1$?$emit_value_fn$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$819$$):$emit_value_fn$$($value$jscomp$819$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$toggle_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$819$$),$APP.$cljs$cst$2656$attrs$$,$attrs$jscomp$176$$,$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$284$$],null)))};
$app$main$ui$ds$controls$utilities$token_field$token_field_STAR_$$=function($on_token_key_down_props_78965$$){var $is_open$jscomp$8$$=$on_token_key_down_props_78965$$.isOpen,$detach_token$jscomp$2$$=$on_token_key_down_props_78965$$.detachToken,$disabled$jscomp$15$$=$on_token_key_down_props_78965$$.disabled,$property$jscomp$81$$=$on_token_key_down_props_78965$$.property,$on_focus$jscomp$9$$=$on_token_key_down_props_78965$$.onFocus,$value$jscomp$820$$=$on_token_key_down_props_78965$$.value,$token_has_errors$$=
$on_token_key_down_props_78965$$.tokenHasErrors,$tooltip_placement$jscomp$1$$=$on_token_key_down_props_78965$$.tooltipPlacement,$on_blur$jscomp$17$$=$on_token_key_down_props_78965$$.onBlur,$token_detach_btn_ref$$=$on_token_key_down_props_78965$$.tokenDetachBtnRef,$on_click$jscomp$45$$=$on_token_key_down_props_78965$$.onClick,$content$jscomp$249_label$jscomp$44$$=$on_token_key_down_props_78965$$.label,$id$jscomp$963_id__$1$jscomp$19$$=$on_token_key_down_props_78965$$.id,$class$$jscomp$69$$=$on_token_key_down_props_78965$$.className,
$token_wrapper_ref$$=$on_token_key_down_props_78965$$.tokenWrapperRef,$slot_start$jscomp$1$$=$on_token_key_down_props_78965$$.slotStart;$on_token_key_down_props_78965$$=$on_token_key_down_props_78965$$.onTokenKeyDown;var $broken_state$jscomp$1_set_active_QMARK_$$=$id$jscomp$963_id__$1$jscomp$19$$!=null,$all_tokens_map$jscomp$1_default_id$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_map$$),$token_exists_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($all_tokens_map$jscomp$1_default_id$$,
$content$jscomp$249_label$jscomp$44$$),$token_not_active$$=$token_exists_QMARK_$jscomp$1$$&&!$broken_state$jscomp$1_set_active_QMARK_$$;$content$jscomp$249_label$jscomp$44$$=$token_exists_QMARK_$jscomp$1$$?$token_exists_QMARK_$jscomp$1$$&&!$broken_state$jscomp$1_set_active_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("ds.inputs.token-field.no-active-token-option",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$content$jscomp$249_label$jscomp$44$$])):$APP.$cljs$core$truth_$$($token_exists_QMARK_$jscomp$1$$?
$token_has_errors$$:$token_exists_QMARK_$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.ref-not-valid",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$content$jscomp$249_label$jscomp$44$$])):$content$jscomp$249_label$jscomp$44$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("options.deleted-token-with-name",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$content$jscomp$249_label$jscomp$44$$]));$broken_state$jscomp$1_set_active_QMARK_$$=
function(){var $or__5025__auto__$jscomp$1204$$=!$token_exists_QMARK_$jscomp$1$$;return $or__5025__auto__$jscomp$1204$$?$or__5025__auto__$jscomp$1204$$:$APP.$cljs$core$truth_$$($token_has_errors$$)?$token_has_errors$$:$token_not_active$$}();$all_tokens_map$jscomp$1_default_id$$=(0,$APP.$rumext$v2$use_id$$)();$id$jscomp$963_id__$1$jscomp$19$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$963_id__$1$jscomp$19$$,$all_tokens_map$jscomp$1_default_id$$);var $pill_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$focus_wrapper$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled$jscomp$15$$)],function($event$jscomp$489$$){if($disabled$jscomp$15$$)return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$489$$);return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($token_wrapper_ref$$))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$property$jscomp$81$$,className:"main_ui_ds_controls_utilities_token_field__token-field-wrapper",
triggerRef:$token_wrapper_ref$$,id:""+($all_tokens_map$jscomp$1_default_id$$??"")+"-input",children:(0,$APP.$rumext$v2$jsxs$$)("div",{"aria-labelledby":""+($all_tokens_map$jscomp$1_default_id$$??"")+"-input",tabIndex:$APP.$cljs$core$truth_$$($disabled$jscomp$15$$)?-1:0,className:($class$$jscomp$69$$??"")+" main_ui_ds_controls_utilities_token_field__token-field "+(($slot_start$jscomp$1$$!=null?"main_ui_ds_controls_utilities_token_field__with-icon":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$15$$)?
"main_ui_ds_controls_utilities_token_field__token-field-disabled":"")),children:[$slot_start$jscomp$1$$!=null?$slot_start$jscomp$1$$:null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_utilities_token_field__content-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$content$jscomp$249_label$jscomp$44$$,triggerRef:$pill_ref$$,id:""+($id$jscomp$963_id__$1$jscomp$19$$??"")+"-pill",children:(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_click$jscomp$45$$,
ref:$pill_ref$$,disabled:$disabled$jscomp$15$$,"aria-labelledby":""+($id$jscomp$963_id__$1$jscomp$19$$??"")+"-pill",onKeyDown:$on_token_key_down_props_78965$$,className:"main_ui_ds_controls_utilities_token_field__pill "+($APP.$cljs$core$truth_$$($broken_state$jscomp$1_set_active_QMARK_$$)?"main_ui_ds_controls_utilities_token_field__no-set-pill":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$15$$)?"main_ui_ds_controls_utilities_token_field__pill-disabled":""),children:[$value$jscomp$820$$,$APP.$cljs$core$truth_$$($broken_state$jscomp$1_set_active_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_utilities_token_field__pill-dot"}):null]})})}),$disabled$jscomp$15$$?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_ds_controls_utilities_token_field__invisible-button "+($APP.$cljs$core$truth_$$($is_open$jscomp$8$$)?"main_ui_ds_controls_utilities_token_field__invisible-btn-dropdown-open":""),tooltipClass:"main_ui_ds_controls_utilities_token_field__button-tooltip",
tooltipPlacement:$tooltip_placement$jscomp$1$$,icon:"broken-link",ref:$token_detach_btn_ref$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("token-actions.detach-token"),onClick:$detach_token$jscomp$2$$})],onFocus:$on_focus$jscomp$9$$,onBlur:$on_blur$jscomp$17$$,onClick:$focus_wrapper$$,ref:$token_wrapper_ref$$,onKeyDown:$on_token_key_down_props_78965$$,disabled:$disabled$jscomp$15$$})})};
$app$main$ui$ds$controls$numeric_input$parse_value$$=function($G__78976$jscomp$inline_13809_raw_value$$,$last_value_new_value$jscomp$23$$,$G__78975_min_value$jscomp$3$$,$max_value$jscomp$5$$,$nillable$$){$last_value_new_value$jscomp$23$$=$app$util$simple_math$expr_eval$$($APP.$cuerdas$core$strip_suffix$$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78976$jscomp$inline_13809_raw_value$$),"."),$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($last_value_new_value$jscomp$23$$));
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nillable$$)?$G__78976$jscomp$inline_13809_raw_value$$==null:$nillable$$)?null:$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($last_value_new_value$jscomp$23$$))?($G__78976$jscomp$inline_13809_raw_value$$=Math.min(Math.max($last_value_new_value$jscomp$23$$,-1073741824),1.0737418235E9),$G__78975_min_value$jscomp$3$$=$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($G__78975_min_value$jscomp$3$$))?Math.max($G__78976$jscomp$inline_13809_raw_value$$,
$G__78975_min_value$jscomp$3$$):$G__78976$jscomp$inline_13809_raw_value$$,$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($max_value$jscomp$5$$))?Math.min($G__78975_min_value$jscomp$3$$,$max_value$jscomp$5$$):$G__78975_min_value$jscomp$3$$):null};
$app$main$ui$ds$controls$numeric_input$get_option_by_name$$=function($options$jscomp$613_options__$1$jscomp$81$$,$name$jscomp$457$$){$options$jscomp$613_options__$1$jscomp$81$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$613_options__$1$jscomp$81$$)?$APP.$cljs$core$_deref$$($options$jscomp$613_options__$1$jscomp$81$$):$options$jscomp$613_options__$1$jscomp$81$$;return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78977_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1136$token$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__78977_SHARP_$$,$APP.$cljs$cst$139$type$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$457$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__78977_SHARP_$$,$APP.$cljs$cst$725$name$$))},$options$jscomp$613_options__$1$jscomp$81$$)};
$app$main$ui$ds$controls$numeric_input$get_token_op$$=function($tokens$jscomp$49_tokens__$1$jscomp$2$$,$name$jscomp$458$$){$tokens$jscomp$49_tokens__$1$jscomp$2$$=$APP.$cljs$core$delay_QMARK_$$($tokens$jscomp$49_tokens__$1$jscomp$2$$)?$APP.$cljs$core$_deref$$($tokens$jscomp$49_tokens__$1$jscomp$2$$):$tokens$jscomp$49_tokens__$1$jscomp$2$$;var $xform$jscomp$41$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__78978_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78978_SHARP_$$),
$name$jscomp$458$$)});return $APP.$cljs$core$reduce_kv$$(function($result$jscomp$373$$,$_$jscomp$3050$$,$tokens__$2$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$373$$,$xform$jscomp$41$$,$tokens__$2$$)},$APP.$cljs$core$PersistentVector$EMPTY$$,$tokens$jscomp$49_tokens__$1$jscomp$2$$)};
$app$main$ui$ds$controls$numeric_input$clean_token_name$$=function($G__78979__$1_s$jscomp$591$$){$G__78979__$1_s$jscomp$591$$=$G__78979__$1_s$jscomp$591$$==null?null:$APP.$cuerdas$core$replace$$($G__78979__$1_s$jscomp$591$$,/^\{/,"");return $G__78979__$1_s$jscomp$591$$==null?null:$APP.$cuerdas$core$replace$$($G__78979__$1_s$jscomp$591$$,/\}$/,"")};
$app$main$ui$ds$controls$numeric_input$focusable_option_QMARK_$$=function($option$jscomp$19$$){var $and__5023__auto__$jscomp$821$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$19$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$821$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$group$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$19$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1477$separator$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$19$$)):$and__5023__auto__$jscomp$821$$};$app$main$ui$ds$controls$numeric_input$first_focusable_id$$=function($options$jscomp$614$$){return $APP.$cljs$core$some$$(function($p1__78980_SHARP_$$){return $APP.$cljs$core$truth_$$($app$main$ui$ds$controls$numeric_input$focusable_option_QMARK_$$($p1__78980_SHARP_$$))?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78980_SHARP_$$):null},$options$jscomp$614$$)};
$app$main$ui$ds$controls$numeric_input$next_focus_index$$=function($indices$jscomp$1_options$jscomp$615$$,$focused_id$jscomp$2$$,$direction$jscomp$25$$){var $options__$1$jscomp$82$$=$APP.$cljs$core$delay_QMARK_$$($indices$jscomp$1_options$jscomp$615$$)?$APP.$cljs$core$_deref$$($indices$jscomp$1_options$jscomp$615$$):$indices$jscomp$1_options$jscomp$615$$,$len$jscomp$78$$=$APP.$cljs$core$count$$($options__$1$jscomp$82$$),$start_index$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1205$$=$APP.$app$common$data$index_of_pred$$($options__$1$jscomp$82$$,
function($p1__78981_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($focused_id$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78981_SHARP_$$))});return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1205$$)?$or__5025__auto__$jscomp$1205$$:-1}();$indices$jscomp$1_options$jscomp$615$$=function(){var $G__78982__$1$$=$direction$jscomp$25$$ instanceof $APP.$cljs$core$Keyword$$?$direction$jscomp$25$$.$fqn$:null;switch($G__78982__$1$$){case "down":return $APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$($start_index$jscomp$4$$+
1,$len$jscomp$78$$+$start_index$jscomp$4$$);case "up":return $APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$($start_index$jscomp$4$$-1,$start_index$jscomp$4$$-$len$jscomp$78$$,-1);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78982__$1$$)].join(""));}}();return $APP.$cljs$core$some$$(function($i$jscomp$528_j$jscomp$121$$){$i$jscomp$528_j$jscomp$121$$=$APP.$cljs$core$mod$$($i$jscomp$528_j$jscomp$121$$,$len$jscomp$78$$);return $APP.$cljs$core$truth_$$($app$main$ui$ds$controls$numeric_input$focusable_option_QMARK_$$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($options__$1$jscomp$82$$,
$i$jscomp$528_j$jscomp$121$$)))?$i$jscomp$528_j$jscomp$121$$:null},$indices$jscomp$1_options$jscomp$615$$)};
$app$main$ui$ds$controls$numeric_input$find_token_by_name$$=function($data$jscomp$478$$,$name$jscomp$459$$){return $APP.$cljs$core$some$$(function($tokens_data$$){return $APP.$cljs$core$some$$(function($p1__78983_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78983_SHARP_$$),$name$jscomp$459$$)?$p1__78983_SHARP_$$:null},$tokens_data$$)},$APP.$cljs$core$vals$$($data$jscomp$478$$))};
$app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$=function($props_78985$$){var $on_change$jscomp$55$$=void 0,$step$jscomp$33$$=void 0,$inner_class$$=void 0,$align$jscomp$3$$=void 0,$min$jscomp$68$$=void 0,$max_length$jscomp$6$$=void 0,$on_change_end$$=void 0,$placeholder$jscomp$5$$=void 0,$applied_token_name$jscomp$1$$=void 0,$disabled$jscomp$16$$=void 0,$ref$jscomp$53$$=void 0,$property$jscomp$82$$=void 0,$default$$jscomp$93$$=void 0,$on_change_start$$=void 0,$on_focus$jscomp$10$$=void 0,
$value$jscomp$821$$=void 0,$name$jscomp$460$$=void 0,$tooltip_placement$jscomp$2$$=void 0,$on_blur$jscomp$18$$=void 0,$icon$jscomp$21$$=void 0,$empty_to_end$jscomp$3$$=void 0,$text_icon$jscomp$1$$=void 0,$id$jscomp$964$$=void 0,$class$$jscomp$70$$=void 0,$max$jscomp$81$$=void 0,$on_detach$jscomp$2$$=void 0,$tokens$jscomp$50$$=void 0,$nillable$jscomp$1$$=void 0,$is_selected_on_focus$$=void 0,$props$jscomp$313$$=void 0;({onChange:$on_change$jscomp$55$$,step:$step$jscomp$33$$,innerClass:$inner_class$$,
align:$align$jscomp$3$$,min:$min$jscomp$68$$,maxLength:$max_length$jscomp$6$$,onChangeEnd:$on_change_end$$,placeholder:$placeholder$jscomp$5$$,appliedTokenName:$applied_token_name$jscomp$1$$,disabled:$disabled$jscomp$16$$,ref:$ref$jscomp$53$$,property:$property$jscomp$82$$,"default":$default$$jscomp$93$$,onChangeStart:$on_change_start$$,onFocus:$on_focus$jscomp$10$$,value:$value$jscomp$821$$,name:$name$jscomp$460$$,tooltipPlacement:$tooltip_placement$jscomp$2$$,onBlur:$on_blur$jscomp$18$$,icon:$icon$jscomp$21$$,
emptyToEnd:$empty_to_end$jscomp$3$$,textIcon:$text_icon$jscomp$1$$,id:$id$jscomp$964$$,className:$class$$jscomp$70$$,max:$max$jscomp$81$$,onDetach:$on_detach$jscomp$2$$,tokens:$tokens$jscomp$50$$,nillable:$nillable$jscomp$1$$,isSelectedOnFocus:$is_selected_on_focus$$,...$props$jscomp$313$$}=$props_78985$$);var $tokens__$1$jscomp$3$$=$APP.$cljs$core$object_QMARK_$$($tokens$jscomp$50$$)?$APP.$rumext$v2$util$bean$$($tokens$jscomp$50$$):$tokens$jscomp$50$$,$value__$1$jscomp$47$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$applied_token_name$jscomp$1$$)?$APP.$cljs$cst$1621$multiple$$:$value$jscomp$821$$,$token_applied$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$1$$)],function(){return $app$main$ui$ds$controls$numeric_input$find_token_by_name$$($tokens__$1$jscomp$3$$,$applied_token_name$jscomp$1$$)}),$token_has_errors_QMARK_$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($token_applied$$))),
$is_multiple_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$value__$1$jscomp$47$$),$value__$2$jscomp$7$$=$is_multiple_QMARK_$$?null:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$822$$=$nillable$jscomp$1$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$822$$)?$value__$1$jscomp$47$$==null:$and__5023__auto__$jscomp$822$$}())?null:$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($value__$1$jscomp$47$$,
$default$$jscomp$93$$),$nillable__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($nillable$jscomp$1$$,!1),$disabled__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($disabled$jscomp$16$$,!1),$select_on_focus$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($is_selected_on_focus$$,!0),$default$__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default$$jscomp$93$$),$APP.$rumext$v2$adapt$$($nillable__$1$$)],
function(){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($default$$jscomp$93$$,$APP.$cljs$core$truth_$$($nillable__$1$$)?null:0)}),$step__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($step$jscomp$33$$)],function(){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($step$jscomp$33$$,1)}),$min__$1$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min$jscomp$68$$)],
function(){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($min$jscomp$68$$,-2147483648)}),$max__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max$jscomp$81$$)],function(){return $APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($max$jscomp$81$$,2147483647)}),$max_length__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($max_length$jscomp$6$$,255),$empty_to_end__$1$jscomp$2$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($empty_to_end$jscomp$3$$,!1),$internal_id$jscomp$3$$=(0,$APP.$rumext$v2$use_id$$)(),$id__$1$jscomp$20$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$964$$,$internal_id$jscomp$3$$),$listbox_id$jscomp$2$$=(0,$APP.$rumext$v2$use_id$$)(),$align__$1$jscomp$2$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$3$$,$APP.$cljs$cst$257$left$$),$is_open_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$is_open$jscomp$9$$=$APP.$cljs$core$_deref$$($is_open_STAR_$jscomp$2$$),$token_applied_name_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($applied_token_name$jscomp$1$$),$token_applied_name$$=$APP.$cljs$core$_deref$$($token_applied_name_STAR_$$),$is_token_applied_QMARK_$$=$token_applied_name$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$token_applied_name$$),$focused_id_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$focused_id$jscomp$3$$=$APP.$cljs$core$_deref$$($focused_id_STAR_$jscomp$2$$),$filter_id_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$filter_id$jscomp$10$$=$APP.$cljs$core$_deref$$($filter_id_STAR_$jscomp$1$$),$raw_value_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$last_value_STAR_$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$token_selection_in_progress_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$wrapper_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$nodes_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$options_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$token_wrapper_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$internal_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$ref__$1$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1206$$=$ref$jscomp$53$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1206$$)?$or__5025__auto__$jscomp$1206$$:$internal_ref$$}(),$dirty_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$open_dropdown_ref$$=
(0,$APP.$rumext$v2$use_ref$$)(null),$token_detach_btn_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$drag_state_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)($cljs$cst$5779$idle$$),$drag_start_x_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(0),$drag_start_val_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(0),$undo_transaction_id_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dropdown_options$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($filter_id$jscomp$10$$)],
function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$($tokens__$1$jscomp$3$$,$filter_id$jscomp$10$$)}),$selected_id_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$truth_$$($applied_token_name$jscomp$1$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$ds$controls$numeric_input$get_option_by_name$$($dropdown_options$jscomp$1$$,$applied_token_name$jscomp$1$$)):
null}),$selected_id$jscomp$7$$=$APP.$cljs$core$_deref$$($selected_id_STAR_$jscomp$2$$),$set_option_ref$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$417$$){var $state__$1$jscomp$58_state__$2$jscomp$8$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$),{}),$id__$2$jscomp$1$$=$APP.$app$util$dom$get_data$$($node$jscomp$417$$,"id");$state__$1$jscomp$58_state__$2$jscomp$8$$=$APP.$app$util$object$set_BANG_$$($state__$1$jscomp$58_state__$2$jscomp$8$$,
$id__$2$jscomp$1$$,$node$jscomp$417$$);$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$3$$,$state__$1$jscomp$58_state__$2$jscomp$8$$);return function(){var $state__$4$jscomp$3_state__$5$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$),{}),$id__$3$$=$APP.$app$util$dom$get_data$$($node$jscomp$417$$,"id");$state__$4$jscomp$3_state__$5$jscomp$3$$=$APP.$app$util$object$unset_BANG_$$($state__$4$jscomp$3_state__$5$jscomp$3$$,$id__$3$$);
return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$3$$,$state__$4$jscomp$3_state__$5$jscomp$3$$)}}),$update_input$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($new_value$jscomp$24$$){var $temp__5825__auto__$jscomp$380$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$380$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$380$$,$new_value$jscomp$24$$):null}),$apply_value$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$55$$),
$APP.$rumext$v2$adapt$$($update_input$jscomp$2$$),$APP.$rumext$v2$adapt$$($value__$2$jscomp$7$$),$APP.$rumext$v2$adapt$$($nillable__$1$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$)],function($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$){$G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$));
var $G__78987_79006_temp__5823__auto__$jscomp$232$$=$app$main$ui$ds$controls$numeric_input$parse_value$$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$,$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);if($APP.$cljs$core$truth_$$($G__78987_79006_temp__5823__auto__$jscomp$232$$))return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78987_79006_temp__5823__auto__$jscomp$232$$,
$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$))||($APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,$G__78987_79006_temp__5823__auto__$jscomp$232$$),$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,null),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$55$$)&&($on_change$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$($G__78987_79006_temp__5823__auto__$jscomp$232$$):$on_change$jscomp$55$$($G__78987_79006_temp__5823__auto__$jscomp$232$$))),
$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78987_79006_temp__5823__auto__$jscomp$232$$)),$G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78987_79006_temp__5823__auto__$jscomp$232$$),$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$):
$update_input$jscomp$2$$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nillable__$1$$)?$APP.$cljs$core$empty_QMARK_$$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$):$nillable__$1$$))return $APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,null),$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,""),$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,
null),$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$(""):$update_input$jscomp$2$$(""),$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$55$$)?$on_change$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$(null):$on_change$jscomp$55$$(null):null;$G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$=$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$);
$G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$=$APP.$cljs$core$truth_$$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$)?$G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$:$default$__$1$jscomp$1$$;$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,$G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$);$APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,
$G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$);$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,null);$G__78987_79006_temp__5823__auto__$jscomp$232$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$);$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78987_79006_temp__5823__auto__$jscomp$232$$):
$update_input$jscomp$2$$($G__78987_79006_temp__5823__auto__$jscomp$232$$);return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$55$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value__$2$jscomp$7$$))?$on_change$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$):
$on_change$jscomp$55$$($G__78986_fallback_value_or__5025__auto__$jscomp$inline_13811_raw_value$jscomp$1_raw_value__$1$$):null}),$apply_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($nillable__$1$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$55$$),$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$3$$)],function($parsed$jscomp$6_value__$3$$,$G__78988_name__$1$jscomp$18$$){$parsed$jscomp$6_value__$3$$=
$app$main$ui$ds$controls$numeric_input$parse_value$$($parsed$jscomp$6_value__$3$$,$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($parsed$jscomp$6_value__$3$$,$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$)))return null;$APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,$parsed$jscomp$6_value__$3$$);return $APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$55$$)?
($G__78988_name__$1$jscomp$18$$=$app$main$ui$ds$controls$numeric_input$get_token_op$$($tokens__$1$jscomp$3$$,$G__78988_name__$1$jscomp$18$$),$on_change$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$($G__78988_name__$1$jscomp$18$$):$on_change$jscomp$55$$($G__78988_name__$1$jscomp$18$$)):null}),$store_raw_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$490_text$jscomp$143$$){$event$jscomp$490_text$jscomp$143$$=
(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$490_text$jscomp$143$$);$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,$event$jscomp$490_text$jscomp$143$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!0);return $APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,$event$jscomp$490_text$jscomp$143$$)}),$on_token_apply$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_token$$)],function($id__$2$jscomp$2$$,$value__$3$jscomp$1$$,
$name__$1$jscomp$19$$){$APP.$rumext$v2$set_ref_val_BANG_$$($token_selection_in_progress_STAR_$$,!0);$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!1);$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,$id__$2$jscomp$2$$);$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$2$$,null);$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!1);$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,$name__$1$jscomp$19$$);$apply_token$$.$cljs$core$IFn$_invoke$arity$2$?$apply_token$$.$cljs$core$IFn$_invoke$arity$2$($value__$3$jscomp$1$$,
$name__$1$jscomp$19$$):$apply_token$$($value__$3$jscomp$1$$,$name__$1$jscomp$19$$);return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$rumext$v2$set_ref_val_BANG_$$($token_selection_in_progress_STAR_$$,!1);return $APP.$cljs$core$truth_$$($token_wrapper_ref$jscomp$1$$)?$APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($token_wrapper_ref$jscomp$1$$)):null})}),$on_option_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_token_apply$$)],
function($event$jscomp$491_id__$2$jscomp$3$$){$event$jscomp$491_id__$2$jscomp$3$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$491_id__$2$jscomp$3$$),"id");var $options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$2$$);$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$)?$APP.$cljs$core$_deref$$($options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$):
$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$;var $name__$1$jscomp$20_option$jscomp$20$$=$APP.$app$main$ui$ds$controls$select$get_option$$($options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$,$event$jscomp$491_id__$2$jscomp$3$$);$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$20_option$jscomp$20$$,$APP.$cljs$cst$4686$resolved_value$$);$name__$1$jscomp$20_option$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$20_option$jscomp$20$$,
$APP.$cljs$cst$725$name$$);$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$491_id__$2$jscomp$3$$,$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$,$name__$1$jscomp$20_option$jscomp$20$$):$on_token_apply$$($event$jscomp$491_id__$2$jscomp$3$$,$options$jscomp$616_options__$1$jscomp$83_value__$3$jscomp$2$$,$name__$1$jscomp$20_option$jscomp$20$$);return $APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,"")}),$on_option_enter$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_token_apply$$)],function(){var $options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$2$$);$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$)?$APP.$cljs$core$_deref$$($options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$):
$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$;var $name__$1$jscomp$21_option$jscomp$21$$=$APP.$app$main$ui$ds$controls$select$get_option$$($options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$,$focused_id$jscomp$3$$);$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$21_option$jscomp$21$$,$APP.$cljs$cst$4686$resolved_value$$);$name__$1$jscomp$21_option$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$21_option$jscomp$21$$,
$APP.$cljs$cst$725$name$$);$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$($focused_id$jscomp$3$$,$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$,$name__$1$jscomp$21_option$jscomp$21$$):$on_token_apply$$($focused_id$jscomp$3$$,$options$jscomp$617_options__$1$jscomp$84_value__$3$jscomp$3$$,$name__$1$jscomp$21_option$jscomp$21$$);return $APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,"")}),$handle_blur$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$),
$APP.$rumext$v2$adapt$$($on_blur$jscomp$18$$)],function($event$jscomp$492$$){$APP.$cljs$core$truth_$$($APP.$app$util$dom$is_child_QMARK_$$($APP.$rumext$v2$ref_val$$($wrapper_ref$jscomp$3$$),$event$jscomp$492$$!=null?$event$jscomp$492$$.relatedTarget:null))||($APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,""),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$2$$,null),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!1));if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dirty_ref$jscomp$2$$))){var $G__78989_79009$$=
$APP.$rumext$v2$ref_val$$($raw_value_STAR_$$);$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78989_79009$$):$apply_value$jscomp$2$$($G__78989_79009$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!1)}$APP.$cljs$core$fn_QMARK_$$($on_blur$jscomp$18$$)&&($on_blur$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$18$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$492$$):$on_blur$jscomp$18$$($event$jscomp$492$$));
return $APP.$app$util$dom$blur_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$))}),$commit_pending_on_unmount$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$)],function(){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dirty_ref$jscomp$2$$))){var $G__78990_79010$$=$APP.$rumext$v2$ref_val$$($raw_value_STAR_$$);$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78990_79010$$):
$apply_value$jscomp$2$$($G__78990_79010$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!1)}return null}),$handle_unmount$jscomp$1$$=$app$main$ui$hooks$use_ref_callback$$($commit_pending_on_unmount$$),$on_key_down$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$9$$),$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$2$$),$APP.$rumext$v2$adapt$$($is_open$jscomp$9$$),$APP.$rumext$v2$adapt$$($focused_id$jscomp$3$$),
$APP.$rumext$v2$adapt$$($APP.$app$main$ui$ds$controls$select$handle_focus_change$$)],function($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!0);var $name__$1$jscomp$22_option$jscomp$22_up_QMARK_$jscomp$4$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$),$down_QMARK_$jscomp$4$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$),
$enter_QMARK_$jscomp$3$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$),$esc_QMARK_$jscomp$4$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$),$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$),$open_tokens$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$.key,
"{"),$close_tokens$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$.key,"}"),$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$2$$);$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=$APP.$cljs$core$delay_QMARK_$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$)?
$APP.$cljs$core$_deref$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$):$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$;if($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$!=null&&$open_tokens$$)return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,
!0);if($close_tokens$$)return $eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$=$app$main$ui$ds$controls$numeric_input$clean_token_name$$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=$app$main$ui$ds$controls$numeric_input$get_option_by_name$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,
$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$),$APP.$cljs$core$truth_$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$)?($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=$APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$),
$apply_token$$.$cljs$core$IFn$_invoke$arity$2$?$apply_token$$.$cljs$core$IFn$_invoke$arity$2$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$):$apply_token$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$),
$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$2$$,!1),$APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,""),$handle_blur$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$handle_blur$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):$handle_blur$jscomp$5$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$)):($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$=
$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):$apply_value$jscomp$2$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$)),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!1);if($APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$3$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$9$$)){$APP.$app$util$dom$prevent_default$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$);
if($APP.$cljs$core$truth_$$($focused_id$jscomp$3$$))return $on_option_enter$$.$cljs$core$IFn$_invoke$arity$1$?$on_option_enter$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):$on_option_enter$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$);$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$=$app$main$ui$ds$controls$numeric_input$first_focusable_id$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$);
$name__$1$jscomp$22_option$jscomp$22_up_QMARK_$jscomp$4$$=$APP.$app$main$ui$ds$controls$select$get_option$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$);$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$22_option$jscomp$22_up_QMARK_$jscomp$4$$,
$APP.$cljs$cst$4686$resolved_value$$);$name__$1$jscomp$22_option$jscomp$22_up_QMARK_$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($name__$1$jscomp$22_option$jscomp$22_up_QMARK_$jscomp$4$$,$APP.$cljs$cst$725$name$$);$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_apply$$.$cljs$core$IFn$_invoke$arity$3$($eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$,$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,
$name__$1$jscomp$22_option$jscomp$22_up_QMARK_$jscomp$4$$):$on_token_apply$$($eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$,$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,$name__$1$jscomp$22_option$jscomp$22_up_QMARK_$jscomp$4$$);$APP.$cljs$core$reset_BANG_$$($filter_id_STAR_$jscomp$1$$,"")}return $handle_blur$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$handle_blur$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):
$handle_blur$jscomp$5$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$)}if($APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$4$$))return $G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$)),$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):
$update_input$jscomp$2$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!1),$APP.$app$util$dom$blur_BANG_$$($eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$home_QMARK_$$)($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$)))return $APP.$app$main$ui$ds$controls$select$handle_focus_change$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,
$focused_id_STAR_$jscomp$2$$,0,$APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$));if($APP.$cljs$core$truth_$$($name__$1$jscomp$22_option$jscomp$22_up_QMARK_$jscomp$4$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$9$$))return $eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$=$app$main$ui$ds$controls$numeric_input$next_focus_index$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,$focused_id$jscomp$3$$,
$APP.$cljs$cst$1970$up$$),$APP.$app$util$dom$prevent_default$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,$focused_id_STAR_$jscomp$2$$,$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$,$APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$));
var $parsed$jscomp$7$$=$app$main$ui$ds$controls$numeric_input$parse_value$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1208$$=$parsed$jscomp$7$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1208$$)?
$or__5025__auto__$jscomp$1208$$:$default$__$1$jscomp$1$$}();$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$=$G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$.shiftKey?$step__$1$$*10:$G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$.altKey?$step__$1$$*.1:$step__$1$$;$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=
$APP.$app$common$math$clamp$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$+$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$,$min__$1$jscomp$2$$,$max__$1$jscomp$1$$);$APP.$app$util$dom$prevent_default$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$);$G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$=
$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$);$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):$update_input$jscomp$2$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$);
$G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$=""+($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$??"");return $apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):$apply_value$jscomp$2$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$)}if($APP.$cljs$core$truth_$$($down_QMARK_$jscomp$4$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$9$$))return $eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$=
$app$main$ui$ds$controls$numeric_input$next_focus_index$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,$focused_id$jscomp$3$$,$APP.$cljs$cst$1969$down$$),$APP.$app$util$dom$prevent_default$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$,
$focused_id_STAR_$jscomp$2$$,$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$,$APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$3$$));$parsed$jscomp$7$$=$app$main$ui$ds$controls$numeric_input$parse_value$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=
function(){var $or__5025__auto__$jscomp$1209$$=$parsed$jscomp$7$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1209$$)?$or__5025__auto__$jscomp$1209$$:$default$__$1$jscomp$1$$}();$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$=$G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$.shiftKey?$step__$1$$*10:$G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$.altKey?$step__$1$$*
.1:$step__$1$$;$G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$=$APP.$app$common$math$clamp$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$-$eff_step_name_79019__$1_new_index$jscomp$9_node$jscomp$420_option_id$$,$min__$1$jscomp$2$$,$max__$1$jscomp$1$$);$APP.$app$util$dom$prevent_default$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$);
$G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$);$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):
$update_input$jscomp$2$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$);$G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$=""+($G__78991_79021_current_value$jscomp$7_new_val$jscomp$6_options$jscomp$618_options__$1$jscomp$85_token_79020_value__$3$jscomp$4$$??"");return $apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$):
$apply_value$jscomp$2$$($G__78993_79023_G__78994_79024_G__78995_79026_G__78996_G__78997_79027_G__78998_event$jscomp$493$$)}return null}),$on_focus__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$10$$),$APP.$rumext$v2$adapt$$($select_on_focus$jscomp$3$$)],function($event$jscomp$494_target$jscomp$148$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5780$dragging$$,$APP.$rumext$v2$ref_val$$($drag_state_STAR_$$)))return null;
$APP.$cljs$core$fn_QMARK_$$($on_focus$jscomp$10$$)&&($on_focus$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$494_target$jscomp$148$$):$on_focus$jscomp$10$$($event$jscomp$494_target$jscomp$148$$));$event$jscomp$494_target$jscomp$148$$=$APP.$app$util$dom$get_target$$($event$jscomp$494_target$jscomp$148$$);return $APP.$cljs$core$truth_$$($select_on_focus$jscomp$3$$)?($APP.$app$util$dom$select_text_BANG_$$($event$jscomp$494_target$jscomp$148$$),
$event$jscomp$494_target$jscomp$148$$.addEventListener("mouseup",$APP.$app$util$dom$prevent_default$$,{once:!0})):null}),$on_mouse_wheel$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$),$APP.$rumext$v2$adapt$$($app$main$ui$ds$controls$numeric_input$parse_value$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($nillable__$1$$),$APP.$rumext$v2$adapt$$($ref__$1$jscomp$2$$),
$APP.$rumext$v2$adapt$$($default$__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($step__$1$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$)],function($G__78999_event$jscomp$495$$){var $inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$381$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);if($APP.$cljs$core$truth_$$($inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$381$$)&&$APP.$cljs$core$truth_$$($app$util$dom$active_QMARK_$$($inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$381$$))){$inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$381$$=
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($app$util$dom$get_delta_position$$($G__78999_event$jscomp$495$$))<0;var $current_value$jscomp$8_parsed$jscomp$8$$=$app$main$ui$ds$controls$numeric_input$parse_value$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);$current_value$jscomp$8_parsed$jscomp$8$$=$APP.$cljs$core$truth_$$($current_value$jscomp$8_parsed$jscomp$8$$)?
$current_value$jscomp$8_parsed$jscomp$8$$:$default$__$1$jscomp$1$$;$inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$381$$=$inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$381$$?$APP.$app$common$math$clamp$$($current_value$jscomp$8_parsed$jscomp$8$$+$step__$1$$,$min__$1$jscomp$2$$,$max__$1$jscomp$1$$):$APP.$app$common$math$clamp$$($current_value$jscomp$8_parsed$jscomp$8$$-$step__$1$$,$min__$1$jscomp$2$$,$max__$1$jscomp$1$$);$APP.$app$util$dom$prevent_default$$($G__78999_event$jscomp$495$$);
$APP.$app$util$dom$stop_propagation$$($G__78999_event$jscomp$495$$);$G__78999_event$jscomp$495$$=""+($inc_QMARK__new_val$jscomp$7_temp__5825__auto__$jscomp$381$$??"");return $apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__78999_event$jscomp$495$$):$apply_value$jscomp$2$$($G__78999_event$jscomp$495$$)}return null}),$on_scrub_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled__$1$$),
$APP.$rumext$v2$adapt$$($is_open$jscomp$9$$),$APP.$rumext$v2$adapt$$($is_multiple_QMARK_$$),$APP.$rumext$v2$adapt$$($ref__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($nillable__$1$$),$APP.$rumext$v2$adapt$$($default$__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($is_token_applied_QMARK_$$)],function($event$jscomp$496$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($disabled__$1$$)?$disabled__$1$$:$APP.$cljs$core$truth_$$($is_open$jscomp$9$$)?
$is_open$jscomp$9$$:$is_multiple_QMARK_$$||$is_token_applied_QMARK_$$))return null;var $client_x_is_focused_node$jscomp$422$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$),$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$=$client_x_is_focused_node$jscomp$422$$!=null;$client_x_is_focused_node$jscomp$422$$=$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$?$app$util$dom$active_QMARK_$$($client_x_is_focused_node$jscomp$422$$):$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$;
$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$=$APP.$cljs$core$_deref$$($token_applied_name_STAR_$$)!=null;if($APP.$cljs$core$truth_$$($client_x_is_focused_node$jscomp$422$$)?$client_x_is_focused_node$jscomp$422$$:$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$)return null;$client_x_is_focused_node$jscomp$422$$=$event$jscomp$496$$.clientX;$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$=
$app$main$ui$ds$controls$numeric_input$parse_value$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$rumext$v2$ref_val$$($raw_value_STAR_$$)),$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$,$nillable__$1$$);$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$)?$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$:
$APP.$cljs$core$truth_$$($default$__$1$jscomp$1$$)?$default$__$1$jscomp$1$$:0;$APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5781$maybe_dragging$$);$APP.$rumext$v2$set_ref_val_BANG_$$($drag_start_x_STAR_$$,$client_x_is_focused_node$jscomp$422$$);$APP.$rumext$v2$set_ref_val_BANG_$$($drag_start_val_STAR_$$,$and__5023__auto__$jscomp$inline_13813_has_token$jscomp$1_parsed$jscomp$9_start_val$$);return $APP.$app$util$dom$capture_pointer$$($event$jscomp$496$$)}),$on_scrub_pointer_move$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$2$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$2$$),$APP.$rumext$v2$adapt$$($step__$1$$),$APP.$rumext$v2$adapt$$($min__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($max__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_change_start$$),$APP.$rumext$v2$adapt$$($is_token_applied_QMARK_$$)],function($G__79001_event$jscomp$497_new_val$jscomp$8$$){if($is_token_applied_QMARK_$$)return null;var $state$jscomp$1203_undo_id_79028$$=
$APP.$rumext$v2$ref_val$$($drag_state_STAR_$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1203_undo_id_79028$$,$cljs$cst$5781$maybe_dragging$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1203_undo_id_79028$$,$cljs$cst$5780$dragging$$)){var $G__79000_79029_delta_x$jscomp$4$$=$G__79001_event$jscomp$497_new_val$jscomp$8$$.clientX-$APP.$rumext$v2$ref_val$$($drag_start_x_STAR_$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1203_undo_id_79028$$,
$cljs$cst$5781$maybe_dragging$$)&&Math.abs($G__79000_79029_delta_x$jscomp$4$$)>=3&&($state$jscomp$1203_undo_id_79028$$=Symbol(),$APP.$rumext$v2$set_ref_val_BANG_$$($undo_transaction_id_STAR_$$,$state$jscomp$1203_undo_id_79028$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($state$jscomp$1203_undo_id_79028$$)),$APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5780$dragging$$),$APP.$cljs$core$fn_QMARK_$$($on_change_start$$)&&
($on_change_start$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_start$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_start$$()));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($drag_state_STAR_$$),$cljs$cst$5780$dragging$$))return $G__79001_event$jscomp$497_new_val$jscomp$8$$=$APP.$app$common$math$clamp$$($APP.$rumext$v2$ref_val$$($drag_start_val_STAR_$$)+Math.round($G__79000_79029_delta_x$jscomp$4$$/1)*($APP.$cljs$core$truth_$$($G__79001_event$jscomp$497_new_val$jscomp$8$$.shiftKey)?
$step__$1$$*10:$APP.$cljs$core$truth_$$($G__79001_event$jscomp$497_new_val$jscomp$8$$.ctrlKey)?$step__$1$$*.1:$step__$1$$),$min__$1$jscomp$2$$,$max__$1$jscomp$1$$),$G__79000_79029_delta_x$jscomp$4$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($G__79001_event$jscomp$497_new_val$jscomp$8$$),$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__79000_79029_delta_x$jscomp$4$$):$update_input$jscomp$2$$($G__79000_79029_delta_x$jscomp$4$$),
$G__79001_event$jscomp$497_new_val$jscomp$8$$=""+($G__79001_event$jscomp$497_new_val$jscomp$8$$??""),$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$apply_value$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__79001_event$jscomp$497_new_val$jscomp$8$$):$apply_value$jscomp$2$$($G__79001_event$jscomp$497_new_val$jscomp$8$$)}return null}),$on_scrub_pointer_up$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ref__$1$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_change_end$$),
$APP.$rumext$v2$adapt$$($is_token_applied_QMARK_$$)],function($event$jscomp$498_temp__5825__auto___79033$$){if($is_token_applied_QMARK_$$)return null;var $state$jscomp$1204$$=$APP.$rumext$v2$ref_val$$($drag_state_STAR_$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1204$$,$cljs$cst$5781$maybe_dragging$$)){$APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5779$idle$$);$APP.$app$util$dom$release_pointer$$($event$jscomp$498_temp__5825__auto___79033$$);var $temp__5825__auto___79030$$=
$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);$APP.$cljs$core$truth_$$($temp__5825__auto___79030$$)&&$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto___79030$$)}return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1204$$,$cljs$cst$5780$dragging$$)?($APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5779$idle$$),$APP.$app$util$dom$release_pointer$$($event$jscomp$498_temp__5825__auto___79033$$),$event$jscomp$498_temp__5825__auto___79033$$=$APP.$rumext$v2$ref_val$$($undo_transaction_id_STAR_$$),
$APP.$cljs$core$truth_$$($event$jscomp$498_temp__5825__auto___79033$$)&&($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($event$jscomp$498_temp__5825__auto___79033$$)),$APP.$rumext$v2$set_ref_val_BANG_$$($undo_transaction_id_STAR_$$,null)),$APP.$cljs$core$fn_QMARK_$$($on_change_end$$)?$on_change_end$$.$cljs$core$IFn$_invoke$arity$0$?$on_change_end$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_end$$():null):null}),$on_scrub_lost_pointer_capture$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_end$$),$APP.$rumext$v2$adapt$$($is_token_applied_QMARK_$$)],function(){if($is_token_applied_QMARK_$$)return null;var $temp__5825__auto___79035_was_dragging$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5780$dragging$$,$APP.$rumext$v2$ref_val$$($drag_state_STAR_$$));$APP.$rumext$v2$set_ref_val_BANG_$$($drag_state_STAR_$$,$cljs$cst$5779$idle$$);return $temp__5825__auto___79035_was_dragging$$?
($temp__5825__auto___79035_was_dragging$$=$APP.$rumext$v2$ref_val$$($undo_transaction_id_STAR_$$),$APP.$cljs$core$truth_$$($temp__5825__auto___79035_was_dragging$$)&&($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($temp__5825__auto___79035_was_dragging$$)),$APP.$rumext$v2$set_ref_val_BANG_$$($undo_transaction_id_STAR_$$,null)),$APP.$cljs$core$fn_QMARK_$$($on_change_end$$)?$on_change_end$$.$cljs$core$IFn$_invoke$arity$0$?
$on_change_end$$.$cljs$core$IFn$_invoke$arity$0$():$on_change_end$$():null):null}),$open_dropdown$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled__$1$$),$APP.$rumext$v2$adapt$$($ref__$1$jscomp$2$$)],function($event$jscomp$499$$){if($APP.$cljs$core$truth_$$($disabled__$1$$))return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$499$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($is_open_STAR_$jscomp$2$$,$APP.$cljs$core$not$$);
return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$))}),$open_dropdown_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($disabled__$1$$),$APP.$rumext$v2$adapt$$($token_wrapper_ref$jscomp$1$$)],function($event$jscomp$500$$){if($APP.$cljs$core$truth_$$($disabled__$1$$))return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$500$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($is_open_STAR_$jscomp$2$$,
$APP.$cljs$core$not$$);return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($token_wrapper_ref$jscomp$1$$))}),$detach_token$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach$jscomp$2$$),$APP.$rumext$v2$adapt$$($tokens__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($disabled__$1$$),$APP.$rumext$v2$adapt$$($token_applied_name$$)],function($event$jscomp$501$$){if($APP.$cljs$core$truth_$$($disabled__$1$$))return null;$APP.$app$util$dom$prevent_default$$($event$jscomp$501$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$501$$);$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,null);$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,null);$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$2$$,null);$APP.$cljs$core$truth_$$($on_detach$jscomp$2$$)&&($on_detach$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_detach$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($token_applied_name$$):$on_detach$jscomp$2$$($token_applied_name$$));return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$))})}),
$on_token_key_down$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($detach_token$jscomp$3$$),$APP.$rumext$v2$adapt$$($is_open$jscomp$9$$)],function($event$jscomp$502$$){var $esc_QMARK_$jscomp$5_new_index$jscomp$10$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$502$$),$delete_QMARK_$$=(0,$APP.$app$util$keyboard$delete_QMARK_$$)($event$jscomp$502$$),$backspace_QMARK_$$=(0,$APP.$app$util$keyboard$backspace_QMARK_$$)($event$jscomp$502$$),$enter_QMARK_$jscomp$4$$=
(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$502$$),$up_QMARK_$jscomp$5$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$502$$),$down_QMARK_$jscomp$5$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$502$$),$options$jscomp$619_options__$1$jscomp$86$$=$APP.$rumext$v2$ref_val$$($options_ref$jscomp$2$$);$options$jscomp$619_options__$1$jscomp$86$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$619_options__$1$jscomp$86$$)?$APP.$cljs$core$_deref$$($options$jscomp$619_options__$1$jscomp$86$$):
$options$jscomp$619_options__$1$jscomp$86$$;var $detach_btn$$=$APP.$rumext$v2$ref_val$$($token_detach_btn_ref$jscomp$1$$),$target$jscomp$149$$=$APP.$app$util$dom$get_target$$($event$jscomp$502$$);if($APP.$cljs$core$truth_$$($disabled__$1$$))return null;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($delete_QMARK_$$)?$delete_QMARK_$$:$backspace_QMARK_$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$502$$),$detach_token$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$detach_token$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$502$$):
$detach_token$jscomp$3$$($event$jscomp$502$$),$APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$));if($APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$4$$))return $APP.$cljs$core$truth_$$($is_open$jscomp$9$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$502$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$502$$),$on_option_enter$$.$cljs$core$IFn$_invoke$arity$1$?$on_option_enter$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$502$$):$on_option_enter$$($event$jscomp$502$$)):
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($target$jscomp$149$$,$detach_btn$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$502$$),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$2$$,!0)):null;if($APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$5_new_index$jscomp$10$$))return $APP.$app$util$dom$blur_BANG_$$($APP.$rumext$v2$ref_val$$($token_wrapper_ref$jscomp$1$$));if($APP.$cljs$core$truth_$$($up_QMARK_$jscomp$5$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$9$$))return $esc_QMARK_$jscomp$5_new_index$jscomp$10$$=
$app$main$ui$ds$controls$numeric_input$next_focus_index$$($options$jscomp$619_options__$1$jscomp$86$$,$focused_id$jscomp$3$$,$APP.$cljs$cst$1970$up$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$502$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options$jscomp$619_options__$1$jscomp$86$$,$focused_id_STAR_$jscomp$2$$,$esc_QMARK_$jscomp$5_new_index$jscomp$10$$,$nodes_ref$jscomp$3$$)}else if($APP.$cljs$core$truth_$$($down_QMARK_$jscomp$5$$)&&$APP.$cljs$core$truth_$$($is_open$jscomp$9$$))return $esc_QMARK_$jscomp$5_new_index$jscomp$10$$=
$app$main$ui$ds$controls$numeric_input$next_focus_index$$($options$jscomp$619_options__$1$jscomp$86$$,$focused_id$jscomp$3$$,$APP.$cljs$cst$1969$down$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$502$$),$APP.$app$main$ui$ds$controls$select$handle_focus_change$$($options$jscomp$619_options__$1$jscomp$86$$,$focused_id_STAR_$jscomp$2$$,$esc_QMARK_$jscomp$5_new_index$jscomp$10$$,$nodes_ref$jscomp$3$$);return null}),$input_props$$={...$props$jscomp$313$$,onChange:$store_raw_value$$,"aria-label":$property$jscomp$82$$,
className:$inner_class$$,placeholder:$is_multiple_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.mixed-values"):$placeholder$jscomp$5$$,id:$id__$1$jscomp$20$$,maxLength:$max_length__$1$jscomp$1$$,slotStart:$APP.$cljs$core$truth_$$($text_icon$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_numeric_input__text-icon",children:$text_icon$jscomp$1$$}):null,onFocus:$on_focus__$1$$,onBlur:$handle_blur$jscomp$5$$,type:"text",ref:$ref__$1$jscomp$2$$,slotEnd:$APP.$cljs$core$truth_$$($disabled__$1$$)?
null:$tokens__$1$jscomp$3$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",icon:"tokens",tooltipClass:"main_ui_ds_controls_numeric_input__button-tooltip",className:"main_ui_ds_controls_numeric_input__invisible-button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.open-token-list-dropdown"),ref:$open_dropdown_ref$$,tooltipPlacement:$tooltip_placement$jscomp$2$$,onClick:$open_dropdown$jscomp$4$$}):
null,defaultValue:function(){var $or__5025__auto__$jscomp$1215$$=$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1215$$)?$or__5025__auto__$jscomp$1215$$:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value__$2$jscomp$7$$)}(),onKeyDown:$on_key_down$jscomp$18$$,disabled:$disabled__$1$$,variant:"comfortable",icon:$icon$jscomp$21$$},$token_props$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($token_applied_name$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$token_applied_name$$):$token_applied_name$$)?function(){var $token$jscomp$132$$=$app$main$ui$ds$controls$numeric_input$get_option_by_name$$($dropdown_options$jscomp$1$$,$token_applied_name$$),$id__$2$jscomp$4$$=function(){var $G__79002_or__5025__auto__$jscomp$1216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$132$$,$APP.$cljs$cst$266$id$$);if($APP.$cljs$core$truth_$$($G__79002_or__5025__auto__$jscomp$1216$$))return $G__79002_or__5025__auto__$jscomp$1216$$;
$G__79002_or__5025__auto__$jscomp$1216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token_applied$$,$APP.$cljs$cst$266$id$$);return $G__79002_or__5025__auto__$jscomp$1216$$==null?null:""+($G__79002_or__5025__auto__$jscomp$1216$$??"")}(),$label$jscomp$45$$=function(){var $or__5025__auto__$jscomp$1217$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$132$$,$APP.$cljs$cst$725$name$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1217$$)?$or__5025__auto__$jscomp$1217$$:
$applied_token_name$jscomp$1$$}(),$token_value$jscomp$6_token_value__$1$$=function(){var $or__5025__auto__$jscomp$1218_or__5025__auto____$1$jscomp$135$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$132$$,$APP.$cljs$cst$4686$resolved_value$$);if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1218_or__5025__auto____$1$jscomp$135$$))return $or__5025__auto__$jscomp$1218_or__5025__auto____$1$jscomp$135$$;$or__5025__auto__$jscomp$1218_or__5025__auto____$1$jscomp$135$$=$APP.$rumext$v2$ref_val$$($last_value_STAR_$jscomp$1$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1218_or__5025__auto____$1$jscomp$135$$)?$or__5025__auto__$jscomp$1218_or__5025__auto____$1$jscomp$135$$:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value__$2$jscomp$7$$)}();$token_value$jscomp$6_token_value__$1$$=$id__$2$jscomp$4$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$460$$,$APP.$cljs$cst$1740$opacity$$)?100*$token_value$jscomp$6_token_value__$1$$:$token_value$jscomp$6_token_value__$1$$;
return{...$props$jscomp$313$$,onTokenKeyDown:$on_token_key_down$jscomp$1$$,detachToken:$detach_token$jscomp$3$$,tokenDetachBtnRef:$token_detach_btn_ref$jscomp$1$$,tooltipPlacement:$tooltip_placement$jscomp$2$$,className:$inner_class$$,label:$label$jscomp$45$$,id:$id__$2$jscomp$4$$,value:$token_value$jscomp$6_token_value__$1$$,slotStart:$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1219$$=$icon$jscomp$21$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1219$$)?$or__5025__auto__$jscomp$1219$$:
$text_icon$jscomp$1$$}())?$APP.$cljs$core$truth_$$($icon$jscomp$21$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$21$$,size:"s",className:"main_ui_ds_controls_numeric_input__icon"}):$APP.$cljs$core$truth_$$($text_icon$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_numeric_input__text-icon",children:$text_icon$jscomp$1$$}):null:null,tokenHasErrors:$token_has_errors_QMARK_$$,onFocus:$on_focus__$1$$,property:$property$jscomp$82$$,
onBlur:$handle_blur$jscomp$5$$,onClick:$open_dropdown_token$$,isOpen:$is_open$jscomp$9$$,tokenWrapperRef:$token_wrapper_ref$jscomp$1$$,disabled:$disabled__$1$$}}():null;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value__$2$jscomp$7$$),$APP.$rumext$v2$adapt$$($default$__$1$jscomp$1$$),$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$1$$)],function(){var $value_SINGLEQUOTE_$jscomp$2$$=$is_multiple_QMARK_$$?"":$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nillable__$1$$)?
$value__$2$jscomp$7$$==null:$nillable__$1$$)?"":$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($value__$2$jscomp$7$$,$default$__$1$jscomp$1$$));$APP.$rumext$v2$set_ref_val_BANG_$$($raw_value_STAR_$$,$value_SINGLEQUOTE_$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($last_value_STAR_$jscomp$1$$,$value_SINGLEQUOTE_$jscomp$2$$);if(!$APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($token_selection_in_progress_STAR_$$)))if($APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,
$applied_token_name$jscomp$1$$),$APP.$cljs$core$truth_$$($applied_token_name$jscomp$1$$)){var $temp__5825__auto__$jscomp$382_token_id_79039$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$ds$controls$numeric_input$get_option_by_name$$($dropdown_options$jscomp$1$$,$applied_token_name$jscomp$1$$));$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,$temp__5825__auto__$jscomp$382_token_id_79039$$)}else $APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,null);$temp__5825__auto__$jscomp$382_token_id_79039$$=
$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$382_token_id_79039$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$382_token_id_79039$$,$value_SINGLEQUOTE_$jscomp$2$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$1$$)],function(){if($applied_token_name$jscomp$1$$==null){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($token_selection_in_progress_STAR_$$)))return null;
$APP.$cljs$core$reset_BANG_$$($token_applied_name_STAR_$$,null);return $APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$2$$,null)}return null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_mouse_wheel$jscomp$1$$)],function(){var $temp__5825__auto__$jscomp$383$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$2$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$383$$)){var $key$jscomp$417$$=$APP.$goog$events$listen$$($temp__5825__auto__$jscomp$383$$,
"wheel",$on_mouse_wheel$jscomp$1$$,{passive:!1});return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$417$$)}}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dropdown_options$jscomp$1$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($options_ref$jscomp$2$$,$dropdown_options$jscomp$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_unmount$jscomp$1$$)],function(){return $handle_unmount$jscomp$1$$});
return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$wrapper_ref$jscomp$3$$,onPointerDown:$on_scrub_pointer_down$$,onPointerMove:$on_scrub_pointer_move$$,onPointerUp:$on_scrub_pointer_up$$,onLostPointerCapture:$on_scrub_lost_pointer_capture$$,className:($class$$jscomp$70$$??"")+" main_ui_ds_controls_numeric_input__input-wrapper "+($is_token_applied_QMARK_$$?"":"main_ui_ds_controls_numeric_input__resizable"),children:[$is_token_applied_QMARK_$$?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$ds$controls$utilities$token_field$token_field_STAR_$$,
$token_props$$):(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$utilities$input_field$input_field_STAR_$$,$input_props$$),$is_open$jscomp$9$$?function(){var $options$jscomp$620$$=$APP.$cljs$core$delay_QMARK_$$($dropdown_options$jscomp$1$$)?$APP.$cljs$core$_deref$$($dropdown_options$jscomp$1$$):$dropdown_options$jscomp$1$$;return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$,{onClick:$on_option_click$jscomp$2$$,id:$listbox_id$jscomp$2$$,
options:$options$jscomp$620$$,selected:$selected_id$jscomp$7$$,focused:$focused_id$jscomp$3$$,align:$align__$1$jscomp$2$$,emptyToEnd:$empty_to_end__$1$jscomp$2$$,ref:$set_option_ref$jscomp$2$$})}():null]})};
$app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$=function($props_79004_tokens__$1$jscomp$4$$){var $attr$jscomp$67$$=void 0,$align$jscomp$4_props__$1$jscomp$77$$=void 0,$placeholder$jscomp$6$$=void 0,$value$jscomp$822$$=void 0,$applied_token$jscomp$5$$=void 0,$input_type$jscomp$2$$=void 0,$class$$jscomp$71$$=void 0,$on_detach$jscomp$3$$=void 0,$props$jscomp$314$$=void 0;({value:$value$jscomp$822$$,attr:$attr$jscomp$67$$,appliedToken:$applied_token$jscomp$5$$,
align:$align$jscomp$4_props__$1$jscomp$77$$,onDetach:$on_detach$jscomp$3$$,placeholder:$placeholder$jscomp$6$$,inputType:$input_type$jscomp$2$$,className:$class$$jscomp$71$$,...$props$jscomp$314$$}=$props_79004_tokens__$1$jscomp$4$$);var $tokens$jscomp$51$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$active_tokens_by_type$$);$props_79004_tokens__$1$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$51$$),$APP.$rumext$v2$adapt$$($input_type$jscomp$2$$),
$APP.$rumext$v2$adapt$$($attr$jscomp$67$$)],function(){var $or__5025__auto__$jscomp$inline_9022$$=$input_type$jscomp$2$$;return $app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$($tokens$jscomp$51$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9022$$)?$or__5025__auto__$jscomp$inline_9022$$:$attr$jscomp$67$$)});var $on_detach_attr$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach$jscomp$3$$),$APP.$rumext$v2$adapt$$($attr$jscomp$67$$)],
function($p1__79003_SHARP_$$){return $on_detach$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach$jscomp$3$$.$cljs$core$IFn$_invoke$arity$2$($p1__79003_SHARP_$$,$attr$jscomp$67$$):$on_detach$jscomp$3$$($p1__79003_SHARP_$$,$attr$jscomp$67$$)});$align$jscomp$4_props__$1$jscomp$77$$={...$props$jscomp$314$$,placeholder:function(){var $or__5025__auto__$jscomp$1221$$=$placeholder$jscomp$6$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1221$$)?$or__5025__auto__$jscomp$1221$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$value$jscomp$822$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--"}(),className:($class$$jscomp$71$$??"")+" main_ui_workspace_sidebar_options_menus_input_wrapper_tokens__numeric-input-wrapper",appliedTokenName:$applied_token$jscomp$5$$,tokens:$APP.$cljs$core$delay_QMARK_$$($props_79004_tokens__$1$jscomp$4$$)?$APP.$cljs$core$_deref$$($props_79004_tokens__$1$jscomp$4$$):$props_79004_tokens__$1$jscomp$4$$,align:$align$jscomp$4_props__$1$jscomp$77$$,onDetach:$on_detach_attr$$,
name:$attr$jscomp$67$$,value:$value$jscomp$822$$};return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,$align$jscomp$4_props__$1$jscomp$77$$)};
$app$main$ui$workspace$sidebar$options$menus$border_radius$all_equal_QMARK_$$=function($shape$jscomp$997$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$997$$),$APP.$cljs$cst$1652$r2$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$997$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1653$r3$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$997$$),$APP.$cljs$cst$1654$r4$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$997$$)]))};
$app$main$ui$workspace$sidebar$options$menus$measures$type__GT_options$$=function($G__79040__$1_type$jscomp$626$$){$G__79040__$1_type$jscomp$626$$=$G__79040__$1_type$jscomp$626$$ instanceof $APP.$cljs$core$Keyword$$?$G__79040__$1_type$jscomp$626$$.$fqn$:null;switch($G__79040__$1_type$jscomp$626$$){case "bool":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "circle":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "frame":return $app$main$ui$workspace$sidebar$options$menus$measures$frame_options$$;
case "group":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "path":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "rect":return $app$main$ui$workspace$sidebar$options$menus$measures$rect_options$$;case "svg-raw":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;case "text":return $app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79040__$1_type$jscomp$626$$)].join(""));
}};
$app$main$ui$workspace$sidebar$options$menus$measures$select_measure_keys$$=function($shape$jscomp$1002_shape__$1$jscomp$105$$){var $flip_x$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1002_shape__$1$jscomp$105$$,$APP.$cljs$cst$1887$flip_x$$),$flip_y$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1002_shape__$1$jscomp$105$$,$APP.$cljs$cst$1888$flip_y$$);$shape$jscomp$1002_shape__$1$jscomp$105$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($flip_x$jscomp$8$$)?$flip_y$jscomp$8$$:
$flip_x$jscomp$8$$)?$APP.$clojure$set$rename_keys$$($shape$jscomp$1002_shape__$1$jscomp$105$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1652$r2$$],null)):$APP.$cljs$core$truth_$$($flip_x$jscomp$8$$)?$APP.$clojure$set$rename_keys$$($shape$jscomp$1002_shape__$1$jscomp$105$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1653$r3$$],null)):$APP.$cljs$core$truth_$$($flip_y$jscomp$8$$)?$APP.$clojure$set$rename_keys$$($shape$jscomp$1002_shape__$1$jscomp$105$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1653$r3$$,
$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1651$r1$$],null)):$shape$jscomp$1002_shape__$1$jscomp$105$$;return $APP.$cljs$core$select_keys$$($shape$jscomp$1002_shape__$1$jscomp$105$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$)};
$app$main$ui$workspace$sidebar$options$menus$measures$fixed_decimal_value$cljs$0core$0IFn$0_invoke$0arity$02$$=function($value$jscomp$826$$,$decimals$jscomp$1$$){return typeof $value$jscomp$826$$==="string"?$app$main$ui$workspace$sidebar$options$menus$measures$fixed_decimal_value$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$parse_double$$($value$jscomp$826$$),$decimals$jscomp$1$$):typeof $value$jscomp$826$$==="number"?$APP.$cljs$core$parse_double$$($value$jscomp$826$$.toFixed($decimals$jscomp$1$$)):
null};
$app$main$ui$workspace$sidebar$options$menus$measures$filter_size_presets$$=function($G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$){function $matches_QMARK_$jscomp$3$$($p$jscomp$252$$){var $and__5023__auto__$jscomp$828$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$252$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$828$$)?$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$252$$)),$lterm$$):
$and__5023__auto__$jscomp$828$$}if($APP.$cuerdas$core$blank_QMARK_$$($G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$))return $APP.$app$main$constants$size_presets$$;var $lterm$$=$APP.$cuerdas$core$lower$$($G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$);$G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$=$APP.$app$main$constants$size_presets$$;for(var $acc$jscomp$162$$=$APP.$cljs$core$PersistentVector$EMPTY$$;;){var $G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$=
$APP.$cljs$core$first$$($G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$);if($APP.$cljs$core$truth_$$($G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$)){var $head$jscomp$28$$=$G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$;if($APP.$cljs$core$truth_$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($head$jscomp$28$$)))$G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$=$APP.$cljs$core$rest$$($G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$),
$acc$jscomp$162$$=$G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$=function(){var $G__79048$$=$acc$jscomp$162$$;return $APP.$cljs$core$truth_$$($matches_QMARK_$jscomp$3$$($head$jscomp$28$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__79048$$,$head$jscomp$28$$):$G__79048$$}();else{$G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$=$APP.$cljs$core$split_with$$($APP.$cljs$cst$290$width$$,$APP.$cljs$core$rest$$($G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$));
$G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$,0,null);$G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$,1,null);$G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($matches_QMARK_$jscomp$3$$,$G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$);var $G__79068$$=$APP.$cljs$core$seq$$($G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$162$$,$head$jscomp$28$$),$G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$):
$acc$jscomp$162$$;$G__79065_items$jscomp$63_matching_items_remaining$jscomp$2_term$jscomp$10$$=$G__79066_G__79067_tail$jscomp$10_temp__5823__auto__$jscomp$233_vec__79049$$;$acc$jscomp$162$$=$G__79068$$}}else return $acc$jscomp$162$$}};
$app$main$ui$workspace$sidebar$options$drawing$frame$options_STAR_$$=function($props_79064_show_QMARK_$jscomp$5$$){var $drawing_state$jscomp$1$$=$props_79064_show_QMARK_$jscomp$5$$.drawingState,$show_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$props_79064_show_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($show_STAR_$$);var $selected_preset_name_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$selected_preset_name$$=$APP.$cljs$core$_deref$$($selected_preset_name_STAR_$$),
$search_term_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$search_term$jscomp$5$$=$APP.$cljs$core$_deref$$($search_term_STAR_$jscomp$2$$),$container_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$on_toggle$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_STAR_$$,$APP.$cljs$core$not$$);return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$2$$,"")}),
$on_close$jscomp$30$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($show_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$2$$,"")}),$on_search_change$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$833$$){return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$2$$,$value$jscomp$833$$)}),$filtered_presets$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($search_term$jscomp$5$$)],
function(){return $app$main$ui$workspace$sidebar$options$menus$measures$filter_size_presets$$($search_term$jscomp$5$$)}),$on_preset_selected$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$506_name$jscomp$461$$){var $height$jscomp$169_target$jscomp$150$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$506_name$jscomp$461$$);$event$jscomp$506_name$jscomp$461$$=$APP.$app$util$dom$get_data$$($height$jscomp$169_target$jscomp$150$$,"name");var $width$jscomp$198$$=
$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($height$jscomp$169_target$jscomp$150$$,"width"));$height$jscomp$169_target$jscomp$150$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($height$jscomp$169_target$jscomp$150$$,"height"));$APP.$cljs$core$reset_BANG_$$($selected_preset_name_STAR_$$,$event$jscomp$506_name$jscomp$461$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$drawing$set_default_size$$($width$jscomp$198$$,
$height$jscomp$169_target$jscomp$150$$));$APP.$cljs$core$reset_BANG_$$($show_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$2$$,"")}),$orientation$jscomp$8$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$))?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$)>$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$)?$APP.$cljs$cst$1926$horizontal$$:
$APP.$cljs$cst$1927$vertical$$:null,$on_orientation_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($orientation__$1$jscomp$1_orientation__$2$$){$orientation__$1$jscomp$1_orientation__$2$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($orientation__$1$jscomp$1_orientation__$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$drawing$change_orientation$$($orientation__$1$jscomp$1_orientation__$2$$))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_drawing_frame__presets",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$container_ref$jscomp$2$$,onClick:$on_toggle$jscomp$1$$,className:"main_ui_workspace_sidebar_options_drawing_frame__presets-wrapper "+($APP.$cljs$core$truth_$$($props_79064_show_QMARK_$jscomp$5$$)?"main_ui_workspace_sidebar_options_drawing_frame__opened":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__select-name",
children:$APP.$cljs$core$truth_$$($selected_preset_name$$)?$selected_preset_name$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size-presets")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__collapsed-icon",children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$props_79064_show_QMARK_$jscomp$5$$,"on-close":$on_close$jscomp$30$$,container:$container_ref$jscomp$2$$,
children:(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$APP.$app$util$dom$stop_propagation$$,className:"main_ui_workspace_sidebar_options_drawing_frame__custom-select-dropdown",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-search",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_search_change$jscomp$2$$,value:$search_term$jscomp$5$$,autoFocus:!0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.search-size-preset")})}),
(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-list",children:$APP.$cljs$core$empty_QMARK_$$($filtered_presets$$)?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_sidebar_options_drawing_frame__dropdown-element main_ui_workspace_sidebar_options_drawing_frame__disabled",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.no-size-preset-results")})}):
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$167$$,$JSCompiler_temp$jscomp$1827_preset$$){var $JSCompiler_temp_const$jscomp$1825$$=$out_arr__44092__auto__$jscomp$167$$.push;if($APP.$cljs$core$not$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$)))$JSCompiler_temp$jscomp$1827_preset$$=(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_sidebar_options_drawing_frame__dropdown-element main_ui_workspace_sidebar_options_drawing_frame__disabled",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$)})},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$));else{var $preset_match$jscomp$inline_9029$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$),
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$),$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$1$$));$JSCompiler_temp$jscomp$1827_preset$$=(0,$APP.$rumext$v2$jsxs$$)("li",{"data-width":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$)),
"data-height":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$)),"data-name":$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$),onClick:$on_preset_selected$jscomp$1$$,className:"main_ui_workspace_sidebar_options_drawing_frame__dropdown-element "+($preset_match$jscomp$inline_9029$$?"main_ui_workspace_sidebar_options_drawing_frame__match":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_drawing_frame__name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$)}),(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__preset-size",children:[$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$),
" x ",$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$)]})]}),$preset_match$jscomp$inline_9029$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_drawing_frame__check-icon",children:$APP.$app$main$ui$icons$tick$$}):null]},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1827_preset$$))}$JSCompiler_temp_const$jscomp$1825$$.call($out_arr__44092__auto__$jscomp$167$$,$JSCompiler_temp$jscomp$1827_preset$$);
return $out_arr__44092__auto__$jscomp$167$$},[],$filtered_presets$$)})]})})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:function(){var $or__5025__auto__$jscomp$1228$$=$APP.$app$common$data$name$$($orientation$jscomp$8$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1228$$)?$or__5025__auto__$jscomp$1228$$:""}(),"on-change":$on_orientation_change$jscomp$1$$,name:"frame-orientation",wide:!0,"class":"main_ui_workspace_sidebar_options_drawing_frame__radio-buttons",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"size-vertical",value:"vertical",id:"size-vertical"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"size-horizontal",value:"horizontal",id:"size-horizontal"})]})]})};
$app$main$ui$workspace$sidebar$options$menus$align$align_options_STAR_$$=function($disabled_align_props_79047$$){var $disabled_distribute_shapes$jscomp$206$$=$disabled_align_props_79047$$.shapes;$disabled_align_props_79047$$=!$APP.$app$main$data$workspace$can_align_QMARK_$$($disabled_distribute_shapes$jscomp$206$$,$disabled_align_props_79047$$.objects);$disabled_distribute_shapes$jscomp$206$$=!$APP.$app$main$data$workspace$can_distribute_QMARK_$$($disabled_distribute_shapes$jscomp$206$$);var $align_objects$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$507_value$jscomp$834$$){$event$jscomp$507_value$jscomp$834$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$507_value$jscomp$834$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$align_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($event$jscomp$507_value$jscomp$834$$,
null))}),$distribute_objects$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$508_value$jscomp$835$$){$event$jscomp$508_value$jscomp$835$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$508_value$jscomp$835$$),"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$distribute_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($event$jscomp$508_value$jscomp$835$$,
null))});return $disabled_align_props_79047$$&&$disabled_distribute_shapes$jscomp$206$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_align__align-options",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_align__align-group-horizontal",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_79047$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.hleft",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4926$align_left$$)])),"data-value":"hleft",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_79047$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_left$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_79047$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.hcenter",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4977$align_hcenter$$)])),"data-value":"hcenter",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_79047$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_horizontal_center$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_79047$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.hright",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4976$align_right$$)])),"data-value":"hright",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_79047$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_right$$}),
(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_distribute_shapes$jscomp$206$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.hdistribute",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4922$h_distribute$$)])),"data-value":"horizontal",onClick:$distribute_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_distribute_shapes$jscomp$206$$?
"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$distribute_horizontally$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_align__align-group-vertical",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_79047$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.vtop",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4987$align_top$$)])),
"data-value":"vtop",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_79047$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_top$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_79047$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.vcenter",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4994$align_vcenter$$)])),
"data-value":"vcenter",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_79047$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_vertical_center$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$disabled_align_props_79047$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.vbottom",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4990$align_bottom$$)])),
"data-value":"vbottom",onClick:$align_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_align_props_79047$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$align_bottom$$}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.align.vdistribute",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4930$v_distribute$$)])),
disabled:$disabled_distribute_shapes$jscomp$206$$,"data-value":"vertical",onClick:$distribute_objects$$,className:"main_ui_workspace_sidebar_options_menus_align__align-button "+($disabled_distribute_shapes$jscomp$206$$?"main_ui_workspace_sidebar_options_menus_align__disabled":""),children:$APP.$app$main$ui$icons$distribute_vertical_spacing$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$bool$bool_options_STAR_$$=function($disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$){var $disabled_bool_btns_shapes_with_children$$=$disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$.shapesWithChildren,$total_selected$$=$disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$.totalSelected;$disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$=
$APP.$cljs$core$first$$($disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$.shapes);var $head_id$$=$disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$,$APP.$cljs$cst$266$id$$),$is_group_QMARK_$jscomp$3$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$),
$is_bool_QMARK_$jscomp$2$$=$APP.$app$common$files$helpers$bool_shape_QMARK_$$($disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$),$head_bool_type$$=$is_bool_QMARK_$jscomp$2$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$,$APP.$cljs$cst$1896$bool_type$$):$is_bool_QMARK_$jscomp$2$$;$disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$=$APP.$app$main$features$use_feature$$("render-wasm/v1");
var $has_invalid_shapes_QMARK_$$=$APP.$cljs$core$some$$($disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$?$APP.$app$common$files$helpers$frame_shape_QMARK_$$:function($p1__79069_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__79069_SHARP_$$)||$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__79069_SHARP_$$)},$disabled_bool_btns_shapes_with_children$$),$head_not_group_like_QMARK_$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$total_selected$$)&&!$is_group_QMARK_$jscomp$3$$&&!$is_bool_QMARK_$jscomp$2$$;$disabled_bool_btns_shapes_with_children$$=function(){var $or__5025__auto__$jscomp$1229$$=$total_selected$$===0;return $or__5025__auto__$jscomp$1229$$?$or__5025__auto__$jscomp$1229$$:$APP.$cljs$core$truth_$$($has_invalid_shapes_QMARK_$$)?$has_invalid_shapes_QMARK_$$:$head_not_group_like_QMARK_$$}();$disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$=
function(){var $or__5025__auto__$jscomp$1230$$=$total_selected$$===0;return $or__5025__auto__$jscomp$1230$$?$or__5025__auto__$jscomp$1230$$:$has_invalid_shapes_QMARK_$$}();var $on_change$jscomp$56$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($total_selected$$),$APP.$rumext$v2$adapt$$($is_group_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($is_bool_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($head_id$$),$APP.$rumext$v2$adapt$$($head_bool_type$$)],function($bool_type$jscomp$10_bool_type__$1$$){$bool_type$jscomp$10_bool_type__$1$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($bool_type$jscomp$10_bool_type__$1$$);return $total_selected$$>1?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$bool$create_bool$$($bool_type$jscomp$10_bool_type__$1$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($total_selected$$,1)&&$is_group_QMARK_$jscomp$3$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$bool$group_to_bool$$($head_id$$,
$bool_type$jscomp$10_bool_type__$1$$)):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($total_selected$$,1)&&$is_bool_QMARK_$jscomp$2$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($head_bool_type$$,$bool_type$jscomp$10_bool_type__$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$bool$bool_to_group$$($head_id$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$bool$change_bool_type$$($head_id$$,
$bool_type$jscomp$10_bool_type__$1$$)):null}),$flatten_objects$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$shapes_to_path$convert_selected_to_path$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});return $APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($disabled_bool_btns_shapes_with_children$$)?$disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$:
$disabled_bool_btns_shapes_with_children$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_bool__boolean-options",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_bool__bool-group",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($head_bool_type$$),"class":"main_ui_workspace_sidebar_options_menus_bool__boolean-radio-btn","on-change":$on_change$jscomp$56$$,
name:"bool-options",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"boolean-union",value:"union",disabled:$disabled_bool_btns_shapes_with_children$$,title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.union"))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4941$bool_union$$)),")"].join(""),
id:"bool-opt-union"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"boolean-difference",value:"difference",disabled:$disabled_bool_btns_shapes_with_children$$,title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.difference"))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4943$bool_difference$$)),
")"].join(""),id:"bool-opt-differente"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"boolean-intersection",value:"intersection",disabled:$disabled_bool_btns_shapes_with_children$$,title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.intersection"))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4907$bool_intersection$$)),
")"].join(""),id:"bool-opt-intersection"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"boolean-exclude",value:"exclude",disabled:$disabled_bool_btns_shapes_with_children$$,title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.exclude"))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4962$bool_exclude$$)),
")"].join(""),id:"bool-opt-exclude"})]})}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.flatten"),disabled:$disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$,onClick:$flatten_objects$$,className:"main_ui_workspace_sidebar_options_menus_bool__flatten-button "+($APP.$cljs$core$truth_$$($disabled_flatten_head$jscomp$29_props_79070_render_wasm_enabled_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_options_menus_bool__disabled":
""),children:$app$main$ui$workspace$sidebar$options$menus$bool$flatten_icon$$})]}):null};
$app$main$ui$ds$product$input_with_meta$input_with_meta_STAR_$$=function($props_79071_title$jscomp$40$$){var $max_length$jscomp$7_props__$1$jscomp$78$$=void 0,$meta$jscomp$88$$=void 0,$value$jscomp$836$$=void 0,$on_blur$jscomp$19$$=void 0,$editing_QMARK_$jscomp$7_is_editing$jscomp$2$$=void 0,$props$jscomp$316$$=void 0;({value:$value$jscomp$836$$,meta:$meta$jscomp$88$$,maxLength:$max_length$jscomp$7_props__$1$jscomp$78$$,isEditing:$editing_QMARK_$jscomp$7_is_editing$jscomp$2$$,onBlur:$on_blur$jscomp$19$$,
...$props$jscomp$316$$}=$props_79071_title$jscomp$40$$);$props_79071_title$jscomp$40$$=$APP.$cljs$core$truth_$$($meta$jscomp$88$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$836$$),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($meta$jscomp$88$$)].join(""):$value$jscomp$836$$;var $editing_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($editing_QMARK_$jscomp$7_is_editing$jscomp$2$$,
!1));$editing_QMARK_$jscomp$7_is_editing$jscomp$2$$=$APP.$cljs$core$_deref$$($editing_STAR_$jscomp$3$$);var $input_ref$jscomp$11$$=(0,$APP.$rumext$v2$use_ref$$)(),$last_node_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$ref_cb$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$425$$){$APP.$rumext$v2$set_ref_val_BANG_$$($input_ref$jscomp$11$$,$node$jscomp$425$$);return $APP.$cljs$core$truth_$$($node$jscomp$425$$)?$APP.$rumext$v2$set_ref_val_BANG_$$($last_node_STAR_$$,
$node$jscomp$425$$):null}),$on_edit$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$509$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$509$$);$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$3$$,!0);return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$11$$))}),$on_stop_edit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_blur$jscomp$19$$)],function($event$jscomp$510$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$510$$);
$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$3$$,!1);return $APP.$cljs$core$truth_$$($on_blur$jscomp$19$$)?$on_blur$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$510$$):$on_blur$jscomp$19$$($event$jscomp$510$$):null}),$on_focus$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$511$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$511$$);return $APP.$app$util$dom$select_text_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$511$$))}),
$handle_key_down$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$512_node$jscomp$426$$){var $enter_QMARK_$jscomp$5$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$512_node$jscomp$426$$),$esc_QMARK_$jscomp$6$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$512_node$jscomp$426$$);$event$jscomp$512_node$jscomp$426$$=$APP.$app$util$dom$get_target$$($event$jscomp$512_node$jscomp$426$$);$enter_QMARK_$jscomp$5$$&&$APP.$app$util$dom$blur_BANG_$$($event$jscomp$512_node$jscomp$426$$);
return $esc_QMARK_$jscomp$6$$?$APP.$app$util$dom$blur_BANG_$$($event$jscomp$512_node$jscomp$426$$):null});$max_length$jscomp$7_props__$1$jscomp$78$$={...$props$jscomp$316$$,ref:$ref_cb$$,defaultValue:$value$jscomp$836$$,maxLength:$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($max_length$jscomp$7_props__$1$jscomp$78$$,255),autoFocus:!0,onFocus:$on_focus$jscomp$11$$,onBlur:$on_stop_edit$jscomp$1$$,onKeyDown:$handle_key_down$jscomp$8$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_blur$jscomp$19$$),
$APP.$rumext$v2$adapt$$($last_node_STAR_$$)],function(){return function(){var $input$jscomp$72$$=$APP.$rumext$v2$ref_val$$($last_node_STAR_$$),$fake_blur_event$$={type:"blur",target:$input$jscomp$72$$,currentTarget:$input$jscomp$72$$,stopPropagation:function(){return null},preventDefault:function(){return null}};return $APP.$cljs$core$truth_$$($input$jscomp$72$$)?$on_blur$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($fake_blur_event$$):$on_blur$jscomp$19$$($fake_blur_event$$):
null}});return $APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$7_is_editing$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_input_with_meta__input-with-meta-edit-container",children:(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$max_length$jscomp$7_props__$1$jscomp$78$$)}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$props_79071_title$jscomp$40$$,onClick:$on_edit$jscomp$6$$,className:"main_ui_ds_product_input_with_meta__input-with-meta-container",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_product_input_with_meta__input-with-meta-value",children:$value$jscomp$836$$}),$APP.$cljs$core$truth_$$($meta$jscomp$88$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_product_input_with_meta__input-with-meta-data",children:$meta$jscomp$88$$}):null]})};
$app$main$ui$workspace$sidebar$options$menus$variants_help_modal$variants_help_modal$$=function(){var $on_close$jscomp$31$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()}),$close_dialog_outside$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$513$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$dom$get_target$$($event$jscomp$513$$),$APP.$app$util$dom$get_current_target$$($event$jscomp$513$$))?
$APP.$app$main$data$modal$hide_BANG_$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$close_dialog_outside$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$on_close$jscomp$31$$,className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-close-btn",
icon:"close",variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.title")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__help-text",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{typography:"body-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.intro")}),(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-list",children:[(0,$APP.$rumext$v2$jsxs$$)("li",
{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"text-mixed",size:"m","aria-hidden":!0})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-text",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-large",className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule1")})})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-icon",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"img",size:"m","aria-hidden":!0})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{typography:"body-large",className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-text",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule2")}),
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule2.detail")]})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"folder",size:"m","aria-hidden":!0})}),
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-text",typography:"body-large",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__rule-item-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule3")}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.rule3.detail")]})]})]}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{typography:"body-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.outro")})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__help-image",children:(0,$APP.$rumext$v2$jsx$$)("img",{src:"images/help-variant-connection.png",alt:""})})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__button-row",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_workspace_sidebar_options_menus_variants_help_modal__modal-accept-btn",onClick:$on_close$jscomp$31$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-ok")})})]})})};
$app$main$ui$workspace$sidebar$options$menus$component$component_annotation_STAR_$$=function($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$){var $component$jscomp$130_shape_id$jscomp$161$$=$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$.component,$rerender_fn$jscomp$4$$=$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$.rerenderFn,$id$jscomp$965_on_toggle_expand$$=$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$.id;$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$=
$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$.shape;var $main_instance_QMARK_$jscomp$4$$=$APP.$cljs$cst$2053$main_instance$$.$cljs$core$IFn$_invoke$arity$1$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$),$component_id$jscomp$95$$=$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$),$annotation$jscomp$6$$=$APP.$cljs$cst$2553$annotation$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$130_shape_id$jscomp$161$$);
$component$jscomp$130_shape_id$jscomp$161$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$);var $editing_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$=$APP.$cljs$core$_deref$$($editing_STAR_$jscomp$4$$);var $invalid_text_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cuerdas$core$blank_QMARK_$$($annotation$jscomp$6$$)}),
$invalid_text_QMARK_$$=$APP.$cljs$core$_deref$$($invalid_text_STAR_$$),$size_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$count$$($annotation$jscomp$6$$)}),$size$jscomp$158$$=$APP.$cljs$core$_deref$$($size_STAR_$$),$textarea_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$state$jscomp$1205$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$menus$component$ref_COLON_annotations_state$$),$expanded_QMARK_$jscomp$1$$=$APP.$cljs$cst$3600$expanded$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1205$$),
$create_id$$=$APP.$cljs$cst$4596$id_for_create$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1205$$),$creating_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$965_on_toggle_expand$$,$create_id$$),$adjust_textarea_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$384$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$384$$)){var $text$jscomp$144$$=$APP.$app$util$dom$get_value$$($temp__5825__auto__$jscomp$384$$);
$APP.$cljs$core$reset_BANG_$$($invalid_text_STAR_$$,$APP.$cuerdas$core$blank_QMARK_$$($text$jscomp$144$$));$APP.$cljs$core$reset_BANG_$$($size_STAR_$$,$APP.$cljs$core$count$$($text$jscomp$144$$));return $temp__5825__auto__$jscomp$384$$.parentNode.dataset.replicatedValue=$text$jscomp$144$$}return null});$id$jscomp$965_on_toggle_expand$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($expanded_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$),
$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_expanded$$($APP.$cljs$core$not$$($expanded_QMARK_$jscomp$1$$)))});var $on_discard$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($adjust_textarea_size$$),$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function($event$jscomp$514_temp__5825__auto__$jscomp$385$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$514_temp__5825__auto__$jscomp$385$$);
$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$();$event$jscomp$514_temp__5825__auto__$jscomp$385$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$);return $APP.$cljs$core$truth_$$($event$jscomp$514_temp__5825__auto__$jscomp$385$$)?($app$util$dom$set_value_BANG_$$($event$jscomp$514_temp__5825__auto__$jscomp$385$$,$annotation$jscomp$6$$),$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$4$$,!1),$creating_QMARK_$$&&
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$(null)),$adjust_textarea_size$$.$cljs$core$IFn$_invoke$arity$0$?$adjust_textarea_size$$.$cljs$core$IFn$_invoke$arity$0$():$adjust_textarea_size$$(),$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$()):null}),$on_edit$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$515_temp__5825__auto__$jscomp$386$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$515_temp__5825__auto__$jscomp$386$$);
$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$();return $main_instance_QMARK_$jscomp$4$$&&($event$jscomp$515_temp__5825__auto__$jscomp$386$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$),$APP.$cljs$core$truth_$$($event$jscomp$515_temp__5825__auto__$jscomp$386$$))?($APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$4$$,!0),$APP.$app$util$dom$focus_BANG_$$($event$jscomp$515_temp__5825__auto__$jscomp$386$$),$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$()):null}),$on_save$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function($event$jscomp$516_temp__5825__auto__$jscomp$387_text$jscomp$145$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$516_temp__5825__auto__$jscomp$387_text$jscomp$145$$);$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():
$rerender_fn$jscomp$4$$();$event$jscomp$516_temp__5825__auto__$jscomp$387_text$jscomp$145$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$);if($APP.$cljs$core$truth_$$($event$jscomp$516_temp__5825__auto__$jscomp$387_text$jscomp$145$$)){$event$jscomp$516_temp__5825__auto__$jscomp$387_text$jscomp$145$$=$APP.$app$util$dom$get_value$$($event$jscomp$516_temp__5825__auto__$jscomp$387_text$jscomp$145$$);if($APP.$cuerdas$core$blank_QMARK_$$($event$jscomp$516_temp__5825__auto__$jscomp$387_text$jscomp$145$$))return null;
$APP.$cljs$core$reset_BANG_$$($editing_STAR_$jscomp$4$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_component_annotation$$($component_id$jscomp$95$$,$event$jscomp$516_temp__5825__auto__$jscomp$387_text$jscomp$145$$));$creating_QMARK_$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$(null));return $rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():
$rerender_fn$jscomp$4$$()}return null}),$on_delete_annotation$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component$jscomp$130_shape_id$jscomp$161$$),$APP.$rumext$v2$adapt$$($component_id$jscomp$95$$),$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function($event$jscomp$517$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$517$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-component-annotation.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-component-annotation.message"),$APP.$cljs$cst$2487$accept_label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.confirm-ok"),$APP.$cljs$cst$2490$on_accept$$,function(){$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?
$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():$rerender_fn$jscomp$4$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($creating_QMARK_$$?$app$main$data$workspace$set_annotations_id_for_create$$(null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$update_component_annotation$$($component_id$jscomp$95$$,null),$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$?$rerender_fn$jscomp$4$$.$cljs$core$IFn$_invoke$arity$0$():
$rerender_fn$jscomp$4$$()]))}],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component$jscomp$130_shape_id$jscomp$161$$),$APP.$rumext$v2$adapt$$($state$jscomp$1205$$),$APP.$rumext$v2$adapt$$($create_id$$),$APP.$rumext$v2$adapt$$($creating_QMARK_$$)],function(){var $temp__5825__auto___79152$$=$APP.$rumext$v2$ref_val$$($textarea_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto___79152$$)&&($app$util$dom$set_value_BANG_$$($temp__5825__auto___79152$$,
$annotation$jscomp$6$$),$adjust_textarea_size$$.$cljs$core$IFn$_invoke$arity$0$?$adjust_textarea_size$$.$cljs$core$IFn$_invoke$arity$0$():$adjust_textarea_size$$());$creating_QMARK_$$||$create_id$$==null||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$(null));return function(){return $creating_QMARK_$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_annotations_id_for_create$$(null)):
null}});return $APP.$cljs$core$truth_$$($creating_QMARK_$$?$creating_QMARK_$$:$annotation$jscomp$6$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__annotation "+($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$)?"main_ui_workspace_sidebar_options_menus_component__editing":"")+" "+($creating_QMARK_$$?"main_ui_workspace_sidebar_options_menus_component__creating":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$id$jscomp$965_on_toggle_expand$$,
className:"main_ui_workspace_sidebar_options_menus_component__annotation-title "+($APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$)?$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$:$creating_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_component__expandeable":"")+" "+($APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_options_menus_component__expanded":""),children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$)?
$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$:$creating_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-name",children:$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.edit-annotation"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.create-annotation")}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$1$$)?"arrow-down":"arrow-right",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-arrow",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.annotation")})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-actions",children:$main_instance_QMARK_$jscomp$4$$&&$expanded_QMARK_$jscomp$1$$?$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$||$creating_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$creating_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.create"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.save"),
onClick:$on_save$$,className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-ok "+($APP.$cljs$core$truth_$$($invalid_text_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_component__disabled":"")})}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.discard"),
onClick:$on_discard$$,className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"close",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-nok"})})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.edit"),onClick:$on_edit$jscomp$7$$,
className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"curve",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-ok"})}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),onClick:$on_delete_annotation$$,className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-action",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"delete",className:"main_ui_workspace_sidebar_options_menus_component__annotation-title-icon-nok"})})]}):null})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:$APP.$cljs$core$not$$($expanded_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_options_menus_component__annotation-body-hidden":"",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-body",
children:(0,$APP.$rumext$v2$jsx$$)("textarea",{"data-debug":$annotation$jscomp$6$$,onInput:$adjust_textarea_size$$,className:"main_ui_workspace_sidebar_options_menus_component__annotation-textarea",id:"annotation-textarea",maxLength:300,readOnly:$APP.$cljs$core$not$$($creating_QMARK_$$?$creating_QMARK_$$:$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$),ref:$textarea_ref$$,defaultValue:$annotation$jscomp$6$$,autoFocus:$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$)?
$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$:$creating_QMARK_$$})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$)?$editing_QMARK_$jscomp$8_props_79077_shape$jscomp$1004$$:$creating_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__annotation-counter",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($size$jscomp$158$$),"/300"].join("")}):null]})]}):null};
$app$main$ui$workspace$sidebar$options$menus$component$get_variant_malformed_warning_message$$=function($JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$),1)&&$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$)!=
null)$JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.single.one");else if($APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$)&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$some_QMARK_$$,$JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$))$JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.single.all");else{var $and__5023__auto__$jscomp$inline_9031$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$);$JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$=$and__5023__auto__$jscomp$inline_9031$$?$APP.$cljs$core$some$$($APP.$cljs$core$some_QMARK_$$,
$JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$):$and__5023__auto__$jscomp$inline_9031$$;$JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.single.some"):
null}return $JSCompiler_inline_result$jscomp$1830_JSCompiler_temp$jscomp$1828_JSCompiler_temp$jscomp$1829_malformed_list$$};
$app$main$ui$workspace$sidebar$options$menus$component$get_variant_duplicated_warning_message$$=function($JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$),1)&&$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$)!=
null)$JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.single.one");else if($APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$)&&$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$some_QMARK_$$,$JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$))$JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.single.all");else{var $and__5023__auto__$jscomp$inline_9033$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$);$JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$=$and__5023__auto__$jscomp$inline_9033$$?$APP.$cljs$core$some$$($APP.$cljs$core$some_QMARK_$$,
$JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$):$and__5023__auto__$jscomp$inline_9033$$;$JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.single.some"):
null}return $JSCompiler_inline_result$jscomp$1833_JSCompiler_temp$jscomp$1831_JSCompiler_temp$jscomp$1832_duplicated_list$$};
$app$main$ui$workspace$sidebar$options$menus$component$get_components_with_duplicated_variant_props_and_values$$=function($components$jscomp$17$$){var $duplicated_props$$=$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79078_SHARP_$$){return $APP.$cljs$core$_val$$($p1__79078_SHARP_$$)>1},$APP.$cljs$core$frequencies$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2017$variant_properties$$,$components$jscomp$17$$)))));
return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($G__79080_p1__79079_SHARP_$$){$G__79080_p1__79079_SHARP_$$=$APP.$cljs$cst$2017$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($G__79080_p1__79079_SHARP_$$);return $duplicated_props$$.$cljs$core$IFn$_invoke$arity$1$?$duplicated_props$$.$cljs$core$IFn$_invoke$arity$1$($G__79080_p1__79079_SHARP_$$):$duplicated_props$$($G__79080_p1__79079_SHARP_$$)},$components$jscomp$17$$)};
$app$main$ui$workspace$sidebar$options$menus$component$get_main_ids_with_duplicated_variant_props_and_values$$=function($components$jscomp$18$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2070$main_instance_id$$,$app$main$ui$workspace$sidebar$options$menus$component$get_components_with_duplicated_variant_props_and_values$$($components$jscomp$18$$))};
$app$main$ui$workspace$sidebar$options$menus$component$get_variant_options$$=function($prop_name$jscomp$1$$,$prop_vals$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($val$jscomp$210$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$266$id$$,$val$jscomp$210$$,$APP.$cljs$cst$2296$label$$,$APP.$cuerdas$core$blank_QMARK_$$($val$jscomp$210$$)?["(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.empty")),
")"].join(""):$val$jscomp$210$$],null)},$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79081_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__79081_SHARP_$$),$prop_name$jscomp$1$$)},$prop_vals$$))))};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_property_STAR_$$=function($dprops$jscomp$3_on_drop$jscomp$11_props_79082$$){var $options$jscomp$622$$=$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$.options,$on_prop_value_change$$=$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$.onPropValueChange,$pos$jscomp$139$$=$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$.pos,$on_reorder$jscomp$1$$=$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$.onReorder,$on_prop_name_blur$$=$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$.onPropNameBlur,
$prop$jscomp$32$$=$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$.prop;$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$,$data$jscomp$479_from_pos$jscomp$11$$){$data$jscomp$479_from_pos$jscomp$11$$=$cljs$cst$5788$from_pos$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$479_from_pos$jscomp$11$$);$relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$,
$APP.$cljs$cst$2963$bot$$)?$pos$jscomp$139$$+1:$pos$jscomp$139$$;return $on_reorder$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$479_from_pos$jscomp$11$$,$relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$):$on_reorder$jscomp$1$$($data$jscomp$479_from_pos$jscomp$11$$,$relative_pos$jscomp$1_to_space_between_pos$jscomp$11$$)});var $on_prop_value_change__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_prop_value_change$$),
$APP.$rumext$v2$adapt$$($pos$jscomp$139$$)],function($value$jscomp$837$$){return $on_prop_value_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_prop_value_change$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$139$$,$value$jscomp$837$$):$on_prop_value_change$$($pos$jscomp$139$$,$value$jscomp$837$$)}),$dref$jscomp$3_vec__79083$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,
"penpot/variant-property",$APP.$cljs$cst$2966$on_drop$$,$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$,$APP.$cljs$cst$2970$draggable_QMARK_$$,!0,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5788$from_pos$$,$pos$jscomp$139$$],null)]));$dprops$jscomp$3_on_drop$jscomp$11_props_79082$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$3_vec__79083$$,0,null);$dref$jscomp$3_vec__79083$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$3_vec__79083$$,
1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$3_on_drop$jscomp$11_props_79082$$),$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_sidebar_options_menus_component__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$3_on_drop$jscomp$11_props_79082$$),
$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_sidebar_options_menus_component__dnd-over-bot":""),children:[$on_reorder$jscomp$1$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$3_vec__79083$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-name-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$input_with_meta$input_with_meta_STAR_$$,{value:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$32$$),isEditing:$APP.$cljs$cst$3571$editing_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($prop$jscomp$32$$)),maxLength:60,"data-position":$pos$jscomp$139$$,onBlur:$on_prop_name_blur$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-value-wrapper",
children:function(){var $mixed_value_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$32$$),!1);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$combobox$combobox_STAR_$$,{id:["variant-prop-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$139$$)].join(""),placeholder:$mixed_value_QMARK_$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",defaultSelected:$mixed_value_QMARK_$$?
"":$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$32$$),options:$options$jscomp$622$$,emptyToEnd:!0,maxLength:60,onChange:$on_prop_value_change__$1$$})}()})]})]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_STAR_$$=function($component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$){var $data$jscomp$480$$=$component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$.data,$malformed_list$jscomp$1_malformed_msg_shapes$jscomp$208$$=$component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$.shapes,$components$jscomp$19$$=$component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$.components;
$component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$=$APP.$cljs$core$first$$($components$jscomp$19$$);var $variant_id$jscomp$52$$=$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$),$objects$jscomp$800$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$480$$,$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$)),
$APP.$cljs$cst$1636$objects$$);$component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2017$variant_properties$$,$components$jscomp$19$$);var $component_ids$jscomp$9$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($components$jscomp$19$$)],function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$components$jscomp$19$$)});$component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$=
$APP.$cljs$core$count$$($component_ids$jscomp$9$$)>1?$app$common$types$variant$compare_properties$cljs$0core$0IFn$0_invoke$0arity$02$$($component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$):$APP.$cljs$core$first$$($component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$);$malformed_list$jscomp$1_malformed_msg_shapes$jscomp$208$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2019$variant_error$$,$malformed_list$jscomp$1_malformed_msg_shapes$jscomp$208$$);
$malformed_list$jscomp$1_malformed_msg_shapes$jscomp$208$$=$app$main$ui$workspace$sidebar$options$menus$component$get_variant_malformed_warning_message$$($malformed_list$jscomp$1_malformed_msg_shapes$jscomp$208$$);var $duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$=$APP.$cljs$core$set$$($app$main$ui$workspace$sidebar$options$menus$component$get_main_ids_with_duplicated_variant_props_and_values$$($APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$480$$,
$objects$jscomp$800$$,$variant_id$jscomp$52$$)));$duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2070$main_instance_id$$,$components$jscomp$19$$));$duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$=$app$main$ui$workspace$sidebar$options$menus$component$get_variant_duplicated_warning_message$$($duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$);
var $prop_vals$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$480$$),$APP.$rumext$v2$adapt$$($objects$jscomp$800$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$52$$)],function(){return $APP.$app$common$files$variant$extract_properties_values$$($data$jscomp$480$$,$objects$jscomp$800$$,$variant_id$jscomp$52$$)}),$get_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($prop_vals$jscomp$1$$)],function($prop_name$jscomp$2$$){return $app$main$ui$workspace$sidebar$options$menus$component$get_variant_options$$($prop_name$jscomp$2$$,
$prop_vals$jscomp$1$$)}),$update_property_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component_ids$jscomp$9$$)],function($pos$jscomp$140$$,$value$jscomp$838_value__$1$jscomp$49$$){$value$jscomp$838_value__$1$jscomp$49$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$838_value__$1$jscomp$49$$),"");for(var $c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$=
$APP.$cljs$core$seq$$($component_ids$jscomp$9$$),$G__79163_chunk__79088_seq__79087__$1$$=null,$G__79162_count__79089$$=0,$i__79090$$=0;;)if($i__79090$$<$G__79162_count__79089$$){var $G__79164_id$jscomp$966$$=$G__79163_chunk__79088_seq__79087__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__79090$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"variant-edit-property-value",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:combo-design-tab"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$update_property_value$$($G__79164_id$jscomp$966$$,$pos$jscomp$140$$,$value$jscomp$838_value__$1$jscomp$49$$)]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_error$cljs$0core$0IFn$0_invoke$0arity$02$$($G__79164_id$jscomp$966$$,
null));$i__79090$$+=1}else if($c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$))$G__79163_chunk__79088_seq__79087__$1$$=$c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__79163_chunk__79088_seq__79087__$1$$)?($c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$=$APP.$cljs$core$_chunked_first$$($G__79163_chunk__79088_seq__79087__$1$$),
$G__79162_count__79089$$=$APP.$cljs$core$_chunked_rest$$($G__79163_chunk__79088_seq__79087__$1$$),$G__79163_chunk__79088_seq__79087__$1$$=$c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$,$G__79164_id$jscomp$966$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$),$c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$=$G__79162_count__79089$$,$G__79162_count__79089$$=$G__79164_id$jscomp$966$$):($G__79164_id$jscomp$966$$=
$APP.$cljs$core$first$$($G__79163_chunk__79088_seq__79087__$1$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"variant-edit-property-value",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:combo-design-tab"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$update_property_value$$($G__79164_id$jscomp$966$$,
$pos$jscomp$140$$,$value$jscomp$838_value__$1$jscomp$49$$)])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_error$cljs$0core$0IFn$0_invoke$0arity$02$$($G__79164_id$jscomp$966$$,null)),$c__5548__auto__$jscomp$46_seq__79087_temp__5825__auto__$jscomp$388$$=$APP.$cljs$core$next$$($G__79163_chunk__79088_seq__79087__$1$$),$G__79163_chunk__79088_seq__79087__$1$$=null,$G__79162_count__79089$$=0),$i__79090$$=0;else return null}),$update_property_name$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$52$$)],function($event$jscomp$518_pos$jscomp$141$$){var $value$jscomp$839$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$518_pos$jscomp$141$$));$event$jscomp$518_pos$jscomp$141$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$518_pos$jscomp$141$$),"position")|0;return $APP.$cljs$core$seq$$($value$jscomp$839$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_property_name$$($variant_id$jscomp$52$$,$event$jscomp$518_pos$jscomp$141$$,$value$jscomp$839$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4491$trigger$$,"workspace:design-tab-variant"],null))):null}),$reorder_properties$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$52$$)],function($from_pos$jscomp$12$$,$to_space_between_pos$jscomp$12$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$variants$reorder_variant_poperties$$($variant_id$jscomp$52$$,
$from_pos$jscomp$12$$,$to_space_between_pos$jscomp$12$$))});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$168$$,$p__79091_prop$jscomp$33$$){var $pos$jscomp$142$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79091_prop$jscomp$33$$,
0,null);$p__79091_prop$jscomp$33$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79091_prop$jscomp$33$$,1,null);var $JSCompiler_temp_const$jscomp$1834$$=$out_arr__44092__auto__$jscomp$168$$.push;var $G__79095$jscomp$inline_9035_JSCompiler_inline_result$jscomp$1836$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p__79091_prop$jscomp$33$$);$G__79095$jscomp$inline_9035_JSCompiler_inline_result$jscomp$1836$$=$get_options$$.$cljs$core$IFn$_invoke$arity$1$?$get_options$$.$cljs$core$IFn$_invoke$arity$1$($G__79095$jscomp$inline_9035_JSCompiler_inline_result$jscomp$1836$$):
$get_options$$($G__79095$jscomp$inline_9035_JSCompiler_inline_result$jscomp$1836$$);$JSCompiler_temp_const$jscomp$1834$$.call($out_arr__44092__auto__$jscomp$168$$,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_property_STAR_$$,{pos:$pos$jscomp$142$$,prop:$p__79091_prop$jscomp$33$$,options:$G__79095$jscomp$inline_9035_JSCompiler_inline_result$jscomp$1836$$,onPropNameBlur:$update_property_name$$,onPropValueChange:$update_property_value$$,onReorder:$reorder_properties$$},
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($variant_id$jscomp$52$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$142$$)].join("")));return $out_arr__44092__auto__$jscomp$168$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$component$jscomp$131_properties$jscomp$106_props_79086_props_list$jscomp$2$$))})}),$APP.$cljs$core$truth_$$($malformed_list$jscomp$1_malformed_msg_shapes$jscomp$208$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($malformed_list$jscomp$1_malformed_msg_shapes$jscomp$208$$),
" ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.structure.title"))].join("")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.structure.example")})]}):$APP.$cljs$core$truth_$$($duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($duplicated_ids$jscomp$1_duplicated_list$jscomp$1_duplicated_msg$$)})]}):
null]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_copy_STAR_$$=function($component$jscomp$132_props_79099_select_duplicated_comps$$){var $shapes$jscomp$209$$=$component$jscomp$132_props_79099_select_duplicated_comps$$.shapes,$component_file_data$jscomp$1$$=$component$jscomp$132_props_79099_select_duplicated_comps$$.componentFileData,$components$jscomp$20_props_first$$=$component$jscomp$132_props_79099_select_duplicated_comps$$.components,$current_file_id$jscomp$19$$=$component$jscomp$132_props_79099_select_duplicated_comps$$.currentFileId;
$component$jscomp$132_props_79099_select_duplicated_comps$$=$APP.$cljs$core$first$$($components$jscomp$20_props_first$$);var $shape$jscomp$1005$$=$APP.$cljs$core$first$$($shapes$jscomp$209$$),$properties$jscomp$107$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2017$variant_properties$$,$components$jscomp$20_props_first$$);$components$jscomp$20_props_first$$=$APP.$cljs$cst$2017$variant_properties$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$132_props_79099_select_duplicated_comps$$);
var $variant_id$jscomp$53$$=$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$132_props_79099_select_duplicated_comps$$),$component_page_objects$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($component_file_data$jscomp$1$$,$APP.$cljs$cst$2071$main_instance_page$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$132_props_79099_select_duplicated_comps$$)),$APP.$cljs$cst$1636$objects$$),$variant_comps$jscomp$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component_file_data$jscomp$1$$),$APP.$rumext$v2$adapt$$($component_page_objects$jscomp$1$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$53$$)],function(){return $APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($component_file_data$jscomp$1$$,$component_page_objects$jscomp$1$$,$variant_id$jscomp$53$$)}),$duplicated_comps$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_comps$jscomp$1$$)],
function(){return $app$main$ui$workspace$sidebar$options$menus$component$get_components_with_duplicated_variant_props_and_values$$($variant_comps$jscomp$1$$)}),$malformed_comps$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_comps$jscomp$1$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79096_SHARP_$$){return $APP.$cljs$cst$2019$variant_error$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($component_page_objects$jscomp$1$$,
$APP.$cljs$cst$2070$main_instance_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79096_SHARP_$$)))},$variant_comps$jscomp$1$$)}),$prop_vals$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($component_file_data$jscomp$1$$),$APP.$rumext$v2$adapt$$($component_page_objects$jscomp$1$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$53$$)],function(){return $APP.$app$common$files$variant$extract_properties_values$$($component_file_data$jscomp$1$$,$component_page_objects$jscomp$1$$,
$variant_id$jscomp$53$$)}),$get_options$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($prop_vals$jscomp$2$$)],function($prop_name$jscomp$3$$){return $app$main$ui$workspace$sidebar$options$menus$component$get_variant_options$$($prop_name$jscomp$3$$,$prop_vals$jscomp$2$$)});$component$jscomp$132_props_79099_select_duplicated_comps$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_file_id$jscomp$19$$),$APP.$rumext$v2$adapt$$($shape$jscomp$1005$$),
$APP.$rumext$v2$adapt$$($duplicated_comps$$)],function(){var $ids$jscomp$287$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$duplicated_comps$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_file_id$jscomp$19$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1005$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$first$$($ids$jscomp$287$$),$APP.$cljs$cst$4007$additional_ids$$,$APP.$cljs$core$rest$$($ids$jscomp$287$$)],null)]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1005$$),$APP.$cljs$core$first$$($duplicated_comps$$),!1))});var $select_malformed_comps$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_file_id$jscomp$19$$),
$APP.$rumext$v2$adapt$$($shape$jscomp$1005$$),$APP.$rumext$v2$adapt$$($malformed_comps$$)],function(){var $ids$jscomp$288$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$malformed_comps$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_file_id$jscomp$19$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1005$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$go_to_local_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$266$id$$,
$APP.$cljs$core$first$$($ids$jscomp$288$$),$APP.$cljs$cst$4007$additional_ids$$,$APP.$cljs$core$rest$$($ids$jscomp$288$$)]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$go_to_component_file$$($APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1005$$),$APP.$cljs$core$first$$($malformed_comps$$),!1))}),$key_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$uuid$next$$()),$key$jscomp$418$$=
$APP.$cljs$core$_deref$$($key_STAR_$$),$mixed_label$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),$switch_component$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$209$$)],function($pos$jscomp$143$$,$val$jscomp$211$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val$jscomp$211$$,$mixed_label$$))return $APP.$cljs$core$reset_BANG_$$($key_STAR_$$,$APP.$app$common$uuid$next$$());var $error_msg$$=$APP.$cljs$core$count$$($shapes$jscomp$209$$)>
1?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.component.switch.loop-error-multi"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.component.swap.loop-error");return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$variants_switch$$($APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1619$shapes$$,$shapes$jscomp$209$$,$APP.$cljs$cst$1411$pos$$,$pos$jscomp$143$$,
$APP.$cljs$cst$108$val$$,$val$jscomp$211$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1300$on_error$$,function(){$APP.$cljs$core$reset_BANG_$$($key_STAR_$$,$APP.$app$common$uuid$next$$());return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$warn$cljs$0core$0IFn$0_invoke$0arity$02$$($error_msg$$))}],null))))}),$switch_component_toggle$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$209$$)],
function($pos$jscomp$144$$,$boolean_pair_inverted_boolean_pair$$,$val$jscomp$212_val__$1$jscomp$16$$){$boolean_pair_inverted_boolean_pair$$=$app$common$data$invert_map$$($boolean_pair_inverted_boolean_pair$$);$val$jscomp$212_val__$1$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($boolean_pair_inverted_boolean_pair$$,$val$jscomp$212_val__$1$jscomp$16$$);return $switch_component$$.$cljs$core$IFn$_invoke$arity$2$?$switch_component$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$144$$,
$val$jscomp$212_val__$1$jscomp$16$$):$switch_component$$($pos$jscomp$144$$,$val$jscomp$212_val__$1$jscomp$16$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$169$$,$p__79111$$){var $pos$jscomp$145$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79111$$,
0,null),$prop$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79111$$,1,null);$out_arr__44092__auto__$jscomp$169$$.push(function(){var $mixed_value_QMARK_$jscomp$1$$=$cljs$core$not_every_QMARK_$$(function($p1__79098_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$),$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__79098_SHARP_$$,
$pos$jscomp$145$$)))},$properties$jscomp$107$$),$options$jscomp$623_options__$1$jscomp$87$$=function(){var $G__79116$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$);return $get_options$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$get_options$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__79116$$):$get_options$jscomp$1$$($G__79116$$)}(),$boolean_pair$jscomp$1$$=$app$common$types$variant$find_boolean_pair$$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$options$jscomp$623_options__$1$jscomp$87$$));$options$jscomp$623_options__$1$jscomp$87$$=$mixed_value_QMARK_$jscomp$1$$?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($options$jscomp$623_options__$1$jscomp$87$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$mixed_label$$,$APP.$cljs$cst$2296$label$$,$mixed_label$$,$APP.$cljs$cst$4825$dimmed$$,!0],null)):$options$jscomp$623_options__$1$jscomp$87$$;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-container",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$),className:"main_ui_workspace_sidebar_options_menus_component__variant-property-name-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$)})}),$APP.$cljs$core$truth_$$($boolean_pair$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-value-switch-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$,{defaultChecked:$mixed_value_QMARK_$jscomp$1$$?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($boolean_pair$jscomp$1$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$)),onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($switch_component_toggle$$,$pos$jscomp$145$$,
$boolean_pair$jscomp$1$$)},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$418$$)].join(""))}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-value-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{defaultSelected:$mixed_value_QMARK_$jscomp$1$$?
$mixed_label$$:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$),options:$options$jscomp$623_options__$1$jscomp$87$$,emptyToEnd:!0,onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($switch_component$$,$pos$jscomp$145$$)},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prop$jscomp$34$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$418$$)].join(""))})]},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$145$$),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($mixed_value_QMARK_$jscomp$1$$)].join(""))}());return $out_arr__44092__auto__$jscomp$169$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$components$jscomp$20_props_first$$))}),$APP.$cljs$core$seq$$($malformed_comps$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.copy")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$select_malformed_comps$$,className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-button",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.locate")})]}):$APP.$cljs$core$seq$$($duplicated_comps$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.copy.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$component$jscomp$132_props_79099_select_duplicated_comps$$,className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.copy.locate")})]}):
null]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_swap_item_STAR_$$=function($component_id$jscomp$96_props_79118$$){var $is_search$$=$component_id$jscomp$96_props_79118$$.isSearch,$shapes$jscomp$210$$=$component_id$jscomp$96_props_79118$$.shapes,$listing_thumbs$$=$component_id$jscomp$96_props_79118$$.listingThumbs,$file_id$jscomp$408$$=$component_id$jscomp$96_props_79118$$.fileId,$root_shape$jscomp$12$$=$component_id$jscomp$96_props_79118$$.rootShape,$num_variants$jscomp$1$$=$component_id$jscomp$96_props_79118$$.numVariants,
$item$jscomp$132$$=$component_id$jscomp$96_props_79118$$.item,$loop$$=$component_id$jscomp$96_props_79118$$.loop,$container$jscomp$88$$=$component_id$jscomp$96_props_79118$$.container;$component_id$jscomp$96_props_79118$$=$component_id$jscomp$96_props_79118$$.componentId;var $on_select$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$210$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$408$$),$APP.$rumext$v2$adapt$$($item$jscomp$132$$)],function(){return $APP.$cljs$core$truth_$$($loop$$)?
null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$libraries$component_multi_swap$$($shapes$jscomp$210$$,$file_id$jscomp$408$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$132$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$specialized_panel$clear_specialized_panel$$()]))}),$item_ref$jscomp$7$$=(0,$APP.$rumext$v2$use_ref$$)(),$visible_QMARK_$jscomp$4$$=$APP.$app$main$ui$hooks$use_visible$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($item_ref$jscomp$7$$);
return(0,$APP.$rumext$v2$jsxs$$)("button",{ref:$item_ref$jscomp$7$$,onClick:$on_select$jscomp$4$$,disabled:$loop$$,className:($APP.$cljs$core$not$$($listing_thumbs$$)?"main_ui_workspace_sidebar_options_menus_component__swap-item-list":"")+" "+($APP.$cljs$core$truth_$$($listing_thumbs$$)?"main_ui_workspace_sidebar_options_menus_component__swap-item-grid":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$132$$),$component_id$jscomp$96_props_79118$$)?
"main_ui_workspace_sidebar_options_menus_component__selected":""),children:[$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$common$component_item_thumbnail_STAR_$$,{fileId:$file_id$jscomp$408$$,className:"main_ui_workspace_sidebar_options_menus_component__swap-item-thumbnail",rootShape:$root_shape$jscomp$12$$,component:$item$jscomp$132$$,container:$container$jscomp$88$$}):null,(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$cljs$core$truth_$$($is_search$$)?
$cljs$cst$5789$full_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$132$$):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$132$$),className:"main_ui_workspace_sidebar_options_menus_component__swap-item-name",children:$APP.$cljs$core$truth_$$($is_search$$)?$cljs$cst$5789$full_name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$132$$):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$132$$)}),$APP.$app$common$types$component$is_variant_QMARK_$$($item$jscomp$132$$)?
(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.assets.components.num-variants",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$num_variants$jscomp$1$$])),className:"main_ui_workspace_sidebar_options_menus_component__swap-item-variant-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"variant",size:"s"})}):null]},["swap-item-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$132$$))].join(""))};
$app$main$ui$workspace$sidebar$options$menus$component$component_swap_group_title_STAR_$$=function($props_79122$$){var $on_enter_group$$=$props_79122$$.onEnterGroup,$group_name$jscomp$6$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($props_79122$$.item);return(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:function(){return $on_enter_group$$.$cljs$core$IFn$_invoke$arity$1$?$on_enter_group$$.$cljs$core$IFn$_invoke$arity$1$($group_name$jscomp$6$$):$on_enter_group$$($group_name$jscomp$6$$)},title:$group_name$jscomp$6$$,
className:"main_ui_workspace_sidebar_options_menus_component__swap-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__swap-group-name",children:$APP.$cljs$core$last$$($APP.$app$common$path_names$split_path$$($group_name$jscomp$6$$))}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_component__swap-group-icon",variant:"ghost",iconId:"arrow-right",size:"s"})]})};
$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$01$$=function($components$jscomp$21_paths$jscomp$7$$){$components$jscomp$21_paths$jscomp$7$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$path_names$split_path$$,$APP.$cljs$cst$296$path$$),$components$jscomp$21_paths$jscomp$7$$);return $app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$03$$($components$jscomp$21_paths$jscomp$7$$,
$APP.$cljs$core$PersistentVector$EMPTY$$,0)};
$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$03$$=function($paths$jscomp$8$$,$path$jscomp$277$$,$n$jscomp$305$$){var $current$jscomp$58$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$first$$($paths$jscomp$8$$),$n$jscomp$305$$,null);return $current$jscomp$58$$!=null&&$APP.$cljs$core$every_QMARK_$$(function($p1__79123_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current$jscomp$58$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p1__79123_SHARP_$$,
$n$jscomp$305$$,null))},$paths$jscomp$8$$)?$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$03$$($paths$jscomp$8$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$277$$,$current$jscomp$58$$),$n$jscomp$305$$+1):$path$jscomp$277$$};
$app$main$ui$workspace$sidebar$options$menus$component$same_component_file_QMARK_$$=function($shape_a$$,$shape_b$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_a$$),$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape_b$$))};
$app$main$ui$workspace$sidebar$options$menus$component$same_component_QMARK_$$=function($shape_a$jscomp$1$$,$shape_b$jscomp$1$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_a$jscomp$1$$),$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($shape_b$jscomp$1$$))};
$app$main$ui$workspace$sidebar$options$menus$component$component_swap_STAR_$$=function($current_file_id$jscomp$20_current_lib_name_props_79135$$){var $shapes$jscomp$211$$=$current_file_id$jscomp$20_current_lib_name_props_79135$$.shapes,$groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($shapes$jscomp$211$$)),$file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$=$APP.$cljs$core$first$$($shapes$jscomp$211$$);
$current_file_id$jscomp$20_current_lib_name_props_79135$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);var $libraries$jscomp$149$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$),$objects$jscomp$801$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$sidebar$options$menus$component$same_component_file_QMARK_$$,
$file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$),$shapes$jscomp$211$$),$component_id$jscomp$97$$=$APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$sidebar$options$menus$component$same_component_QMARK_$$,$file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$),$shapes$jscomp$211$$)?$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$):
null;$file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$=$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$?$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$):$current_file_id$jscomp$20_current_lib_name_props_79135$$;var $components$jscomp$22_on_library_change$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79126_SHARP_$$){return $APP.$app$common$types$file$get_component$$($libraries$jscomp$149$$,
$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($p1__79126_SHARP_$$),$APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79126_SHARP_$$))},$shapes$jscomp$211$$);$groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$=$groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$?$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($components$jscomp$22_on_library_change$jscomp$1$$)):$APP.$app$common$path_names$join_path$$($components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$?
$app$main$ui$workspace$sidebar$options$menus$component$find_common_path$cljs$0core$0IFn$0_invoke$0arity$01$$($components$jscomp$22_on_library_change$jscomp$1$$):"");var $filters_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2524$term$$,"",$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$,$APP.$cljs$cst$296$path$$,$APP.$cljs$core$truth_$$($groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$)?
$groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$:"",$cljs$cst$5790$listing_thumbs_QMARK_$$,!1],null)),$filters$jscomp$13$$=$APP.$cljs$core$_deref$$($filters_STAR_$jscomp$1$$),$search_QMARK_$$=!$APP.$cuerdas$core$blank_QMARK_$$($APP.$cljs$cst$2524$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$)),$current_library_id$$=$APP.$cljs$core$contains_QMARK_$$($libraries$jscomp$149$$,$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?
$APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$):$current_file_id$jscomp$20_current_lib_name_props_79135$$;$current_file_id$jscomp$20_current_lib_name_props_79135$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_library_id$$,$current_file_id$jscomp$20_current_lib_name_props_79135$$)?$APP.$cuerdas$core$upper$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.local-library")):$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$149$$,
$current_library_id$$),$APP.$cljs$cst$725$name$$);var $current_lib_data$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($libraries$jscomp$149$$),$APP.$rumext$v2$adapt$$($current_library_id$$)],function(){return $APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$149$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_library_id$$,$APP.$cljs$cst$142$data$$],null))}),$current_lib_counts$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_lib_data$$)],function(){return $APP.$cljs$core$update_vals$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$2016$variant_id$$,$APP.$app$common$types$components_list$components_seq$$($current_lib_data$$)),$APP.$cljs$core$count$$)});$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79129_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79129_SHARP_$$,
$cljs$cst$5789$full_name$$,$app$common$path_names$merge_path_item_with_dot$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__79129_SHARP_$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__79129_SHARP_$$)))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79128_SHARP_$$){return $APP.$app$common$files$variant$is_secondary_variant_QMARK_$$($p1__79128_SHARP_$$,$current_lib_data$$)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79127_SHARP_$$){return $APP.$cljs$cst$2552$deleted$$.$cljs$core$IFn$_invoke$arity$1$($p1__79127_SHARP_$$)===
!0},$APP.$cljs$core$vals$$($APP.$cljs$cst$1643$components$$.$cljs$core$IFn$_invoke$arity$1$($current_lib_data$$)))));$groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($path__$1$jscomp$10_split_path$jscomp$1$$){$path__$1$jscomp$10_split_path$jscomp$1$$=$APP.$app$common$path_names$split_path$$($path__$1$jscomp$10_split_path$jscomp$1$$);
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$163$$,$dir$jscomp$6$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$163$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($acc$jscomp$163$$))," / ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($dir$jscomp$6$$)].join(""))},new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($path__$1$jscomp$10_split_path$jscomp$1$$)],
null),$APP.$cljs$core$rest$$($path__$1$jscomp$10_split_path$jscomp$1$$))}),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$empty_QMARK_$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nil_QMARK_$$),$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__79130_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($app$common$path_names$butlast_path$$($p1__79130_SHARP_$$),
$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))})]));$groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$=$search_QMARK_$$?null:$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($name$jscomp$462$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$name$jscomp$462$$],null)},$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$,
$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$)));$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$=$search_QMARK_$$?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79131_SHARP_$$){return $APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($cljs$cst$5789$full_name$$.$cljs$core$IFn$_invoke$arity$1$($p1__79131_SHARP_$$)),$APP.$cuerdas$core$lower$$($APP.$cljs$cst$2524$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$)))},
$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$):$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79132_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($p1__79132_SHARP_$$),$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))},$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$);$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$=
$APP.$cljs$core$truth_$$($search_QMARK_$$?$search_QMARK_$$:$cljs$cst$5790$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5789$full_name$$,$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$):$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$,
$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$));$file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$801$$)],function($shape__$1$jscomp$107$$){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1632$component_id$$,$APP.$app$common$files$helpers$get_parents$$($objects$jscomp$801$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$107$$))))});var $parent_components$jscomp$1$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shapes$jscomp$211$$]));$file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($library$jscomp$41$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$41$$),$APP.$cljs$cst$2296$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($library$jscomp$41$$)],null)},$APP.$cljs$core$vals$$($libraries$jscomp$149$$));$components$jscomp$22_on_library_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$967$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($filters_STAR_$jscomp$1$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1649$file_id$$,$id$jscomp$967$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2524$term$$,"",$APP.$cljs$cst$296$path$$,""]))});var $on_search_term_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($term$jscomp$11$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2524$term$$,$term$jscomp$11$$)}),$on_search_clear_click$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2524$term$$,"")}),$on_go_back$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$296$path$$,$app$common$path_names$butlast_path$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$)))}),$on_enter_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79133_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$296$path$$,$p1__79133_SHARP_$$)}),$toggle_list_style$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($style$jscomp$75$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$jscomp$1$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5790$listing_thumbs_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($style$jscomp$75$$,"grid"))}),$filter_path_with_dots$$=$app$common$path_names$join_path_with_dot$$($APP.$app$common$path_names$split_path$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$)));return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-title",
children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.swap")})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-filters",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{id:"swap-component-search-filter",
iconId:"search",value:$APP.$cljs$cst$2524$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$),placeholder:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.search"))," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$149$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$current_library_id$$,
$APP.$cljs$cst$725$name$$],null)))].join(""),onChange:$on_search_term_change$jscomp$1$$,onClear:$on_search_clear_click$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$current_library_id$$,options:$file_id$jscomp$409_find_parent_components_libraries_options_shape$jscomp$1006$$,"on-change":$components$jscomp$22_on_library_change$jscomp$1$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-library",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__swap-library-title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-library-name",children:$current_file_id$jscomp$20_current_lib_name_props_79135$$}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$cljs$core$truth_$$($cljs$cst$5790$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?"grid":"list",
"on-change":$toggle_list_style$jscomp$3$$,name:"swap-listing-style",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"view-as-list",value:"list",id:"swap-opt-list"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"flex-grid",value:"grid",id:"swap-opt-grid"})]})]}),$search_QMARK_$$||$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?null:(0,$APP.$rumext$v2$jsxs$$)("button",
{onClick:$on_go_back$$,title:$filter_path_with_dots$$,className:"main_ui_workspace_sidebar_options_menus_component__swap-library-back",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-left",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__swap-library-back-name",children:$filter_path_with_dots$$})]}),$APP.$cljs$core$empty_QMARK_$$($components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__swap-library-empty",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.swap.empty")}):null,$APP.$cljs$core$truth_$$($cljs$cst$5790$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$170$$,$item$jscomp$134$$){$out_arr__44092__auto__$jscomp$170$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_swap_group_title_STAR_$$,
{item:$item$jscomp$134$$,onEnterGroup:$on_enter_group$jscomp$1$$}));return $out_arr__44092__auto__$jscomp$170$$},[],$groups$jscomp$15_path$jscomp$278_single_QMARK_$jscomp$14_xform$jscomp$42$$)}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:($APP.$cljs$core$truth_$$($cljs$cst$5790$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?"main_ui_workspace_sidebar_options_menus_component__swap-library-grid":"")+" "+($APP.$cljs$core$not$$($cljs$cst$5790$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$))?
"main_ui_workspace_sidebar_options_menus_component__swap-library-list":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$171$$,$item$jscomp$135$$){$out_arr__44092__auto__$jscomp$171$$.push($APP.$cljs$core$truth_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$135$$))?function(){var $data$jscomp$481_root_shape$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$149$$,
$current_library_id$$),$APP.$cljs$cst$142$data$$),$container$jscomp$89$$=$APP.$app$common$types$file$get_component_page$$($data$jscomp$481_root_shape$jscomp$13$$,$item$jscomp$135$$);$data$jscomp$481_root_shape$jscomp$13$$=$APP.$app$common$types$file$get_component_root$$($data$jscomp$481_root_shape$jscomp$13$$,$item$jscomp$135$$);var $components__$3$$=$APP.$cljs$core$set$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1632$component_id$$,$APP.$app$common$files$helpers$get_children_with_self$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$89$$),
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$481_root_shape$jscomp$13$$)))),$loop_QMARK_$$=$APP.$cljs$core$some$$(function($p1__79134_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($components__$3$$,$p1__79134_SHARP_$$)},$parent_components$jscomp$1$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_swap_item_STAR_$$,{loop:$loop_QMARK_$$,isSearch:$search_QMARK_$$,componentId:$component_id$jscomp$97$$,listingThumbs:$cljs$cst$5790$listing_thumbs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$13$$),
numVariants:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_lib_counts$$,$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$135$$)),rootShape:$data$jscomp$481_root_shape$jscomp$13$$,shapes:$shapes$jscomp$211$$,item:$item$jscomp$135$$,fileId:$current_library_id$$,container:$container$jscomp$89$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$135$$)??""))}():(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_swap_group_title_STAR_$$,
{item:$item$jscomp$135$$,onEnterGroup:$on_enter_group$jscomp$1$$},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$135$$)));return $out_arr__44092__auto__$jscomp$171$$},[],$components__$1_components__$2_every_same_file_QMARK__items$jscomp$64$$)})]})]})]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_pill_STAR_$$=function($props_79136_subtext$$){function $do_action$$($action$jscomp$5$$,$event$jscomp$520$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$520$$);$action$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$action$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$action$jscomp$5$$();return $on_menu_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_menu_close$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_menu_close$jscomp$2$$()}
var $text$jscomp$146$$=$props_79136_subtext$$.text,$disabled$jscomp$17$$=$props_79136_subtext$$.disabled,$menu_entries$jscomp$1$$=$props_79136_subtext$$.menuEntries,$icon$jscomp$22$$=$props_79136_subtext$$.icon,$on_click$jscomp$46$$=$props_79136_subtext$$.onClick;$props_79136_subtext$$=$props_79136_subtext$$.subtext;var $menu_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$menu_open_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($menu_open_STAR_$$),$menu_entries_QMARK_$$=
$APP.$cljs$core$seq$$($menu_entries$jscomp$1$$),$on_menu_click$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($menu_open_STAR_$$),$APP.$rumext$v2$adapt$$($menu_open_QMARK_$jscomp$1$$)],function($event$jscomp$519$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$519$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$519$$);return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$$,$APP.$cljs$core$not$$($menu_open_QMARK_$jscomp$1$$))}),$on_menu_close$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($menu_open_STAR_$$)],function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$$,!1)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{"data-testid":"component-pill-button",onClick:$on_click$jscomp$46$$,disabled:$disabled$jscomp$17$$,className:"main_ui_workspace_sidebar_options_menus_component__pill-btn "+
($menu_entries_QMARK_$$?"main_ui_workspace_sidebar_options_menus_component__with-menu":""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-btn-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{size:"s",iconId:$icon$jscomp$22$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-btn-name",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-btn-text",
children:$text$jscomp$146$$}),$APP.$cljs$core$truth_$$($props_79136_subtext$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-btn-subtext",children:$props_79136_subtext$$}):null]})]}),$menu_entries_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__pill-actions",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_menu_click$jscomp$3$$,className:"main_ui_workspace_sidebar_options_menus_component__pill-actions-btn "+
($APP.$cljs$core$truth_$$($menu_open_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_options_menus_component__selected":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"menu"})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$menu_open_QMARK_$jscomp$1$$,"on-close":$on_menu_close$jscomp$2$$,children:(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown "+($APP.$cljs$core$truth_$$($props_79136_subtext$$)?
"main_ui_workspace_sidebar_options_menus_component__extended":""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$172$$,$p__79137_title$jscomp$41$$){var $action$jscomp$6_map__79138__$1$$=$APP.$cljs$core$__destructure_map$$($p__79137_title$jscomp$41$$);$p__79137_title$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$6_map__79138__$1$$,$APP.$cljs$cst$939$title$$);$action$jscomp$6_map__79138__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$6_map__79138__$1$$,
$APP.$cljs$cst$2694$action$$);$out_arr__44092__auto__$jscomp$172$$.push($p__79137_title$jscomp$41$$!=null?(0,$APP.$rumext$v2$jsx$$)("li",{onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($do_action$$,$action$jscomp$6_map__79138__$1$$),className:"main_ui_workspace_sidebar_options_menus_component__pill-actions-dropdown-item",children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$p__79137_title$jscomp$41$$})},$p__79137_title$jscomp$41$$):null);return $out_arr__44092__auto__$jscomp$172$$},
[],$menu_entries$jscomp$1$$)})})]}):null]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$=function($current_file_id$jscomp$21_props_79140$$){var $shapes$jscomp$212_shapes__$1$jscomp$35$$=$current_file_id$jscomp$21_props_79140$$.shapes,$is_swap_opened$$=$current_file_id$jscomp$21_props_79140$$.isSwapOpened;$current_file_id$jscomp$21_props_79140$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);var $libraries$jscomp$150$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$current_file$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$150$$,$current_file_id$jscomp$21_props_79140$$),$state_STAR_$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1884$show_content$$,!0,$APP.$cljs$cst$5042$menu_open$$,!1],null)}),$open_QMARK_$jscomp$15_state$jscomp$1206$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$14$$);$open_QMARK_$jscomp$15_state$jscomp$1206$$=$APP.$cljs$cst$1884$show_content$$.$cljs$core$IFn$_invoke$arity$1$($open_QMARK_$jscomp$15_state$jscomp$1206$$);
$shapes$jscomp$212_shapes__$1$jscomp$35$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$instance_head_QMARK_$$,$shapes$jscomp$212_shapes__$1$jscomp$35$$);var $multi$jscomp$6$$=$APP.$cljs$core$count$$($shapes$jscomp$212_shapes__$1$jscomp$35$$)>1,$copies$jscomp$3$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$in_component_copy_QMARK_$$,$shapes$jscomp$212_shapes__$1$jscomp$35$$),$can_swap_QMARK_$$=$APP.$cljs$core$boolean$0$$($APP.$cljs$core$seq$$($copies$jscomp$3$$)),
$all_main_QMARK_$jscomp$4$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$component$main_instance_QMARK_$$,$shapes$jscomp$212_shapes__$1$jscomp$35$$),$any_variant_QMARK_$jscomp$3$$=$APP.$cljs$core$some$$($APP.$app$common$types$component$is_variant_QMARK_$$,$shapes$jscomp$212_shapes__$1$jscomp$35$$),$components$jscomp$23$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79139_SHARP_$$){return $APP.$app$common$types$file$resolve_component$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($p1__79139_SHARP_$$,
$current_file$jscomp$1$$,$libraries$jscomp$150$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2551$include_deleted_QMARK_$$,!0],null)]))},$shapes$jscomp$212_shapes__$1$jscomp$35$$),$same_variant_QMARK_$jscomp$1$$=$app$common$types$variant$same_variant_QMARK_$$($components$jscomp$23$$),$shape$jscomp$1007$$=$APP.$cljs$core$first$$($shapes$jscomp$212_shapes__$1$jscomp$35$$),$id$jscomp$968$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1007$$),
$shape_name$jscomp$4$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1007$$),$component$jscomp$134$$=$APP.$cljs$core$first$$($components$jscomp$23$$),$data$jscomp$482$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$150$$,$APP.$cljs$cst$1648$component_file$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1007$$)),$APP.$cljs$cst$142$data$$),$is_variant_QMARK_$jscomp$3$$=$APP.$app$common$types$component$is_variant_QMARK_$$($component$jscomp$134$$),
$main_instance_QMARK_$jscomp$5$$=$APP.$app$common$types$component$main_instance_QMARK_$$($shape$jscomp$1007$$),$toggle_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$14$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$1884$show_content$$,$APP.$cljs$core$not$$)}),$on_click_variant_title_help$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5787$variants_help_modal$$],null));return $app$main$data$modal$allow_click_outside_BANG_$$()}),$on_component_back$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3647$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$)}),$open_component_panel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_swap_QMARK_$$),
$APP.$rumext$v2$adapt$$($shapes$jscomp$212_shapes__$1$jscomp$35$$)],function(){$can_swap_QMARK_$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$specialized_panel$open_specialized_panel$$());return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$goog$dom$getElement$$("swap-component-search-filter"))})}),$transform_into_variant$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$968$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$transform_in_variant$cljs$0core$0IFn$0_invoke$0arity$01$$($id$jscomp$968$$))}),$create_variant$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$968$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"add-new-variant",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:button-design-tab-variant"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$968$$)]))}),$add_new_property$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1007$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-property",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:button-design-tab-variant"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1007$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3573$property_value$$,"Value 1",$APP.$cljs$cst$3571$editing_QMARK_$$,!0],null)]))]))}),$on_combine_as_variants$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$variants$combine_selected_as_variants$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4491$trigger$$,"workspace:button-design-tab"],null)))}),$rerender_fn$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$14$$,
$APP.$cljs$core$update$$,$cljs$cst$5791$render$$,$APP.$cljs$core$inc$$)}),$menu_entries$jscomp$2$$=$app$main$ui$workspace$sidebar$assets$common$generate_components_menu_entries$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shapes$jscomp$212_shapes__$1$jscomp$35$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5698$for_design_tab_QMARK_$$,!0],null)])),$path$jscomp$279$$=$app$common$path_names$join_path_with_dot$$($APP.$app$common$path_names$split_path$$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$134$$)));
return $APP.$cljs$core$seq$$($shapes$jscomp$212_shapes__$1$jscomp$35$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-title",children:$APP.$cljs$core$truth_$$($is_swap_opened$$)?(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_component_back$$,className:"main_ui_workspace_sidebar_options_menus_component__component-title-swap",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-left",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component")})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$15_state$jscomp$1206$$),onCollapsed:$toggle_content$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component"),className:"main_ui_workspace_sidebar_options_menus_component__component-title-bar",titleClass:"main_ui_workspace_sidebar_options_menus_component__component-title-bar-title",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_component__component-title-bar-type",children:$main_instance_QMARK_$jscomp$5$$?$is_variant_QMARK_$jscomp$3$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.variant"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.main"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.copy")})}),$is_variant_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.title"),onClick:$on_click_variant_title_help$$,icon:"help"}):
null,$main_instance_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),onClick:$is_variant_QMARK_$jscomp$3$$?$create_variant$$:$transform_into_variant$$,icon:"variant"}):null]})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$15_state$jscomp$1206$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-content",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-pill",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_pill_STAR_$$,{icon:$main_instance_QMARK_$jscomp$5$$?$is_variant_QMARK_$jscomp$3$$?"variant":"component":"component-copy",text:$multi$jscomp$6$$&&$APP.$cljs$core$not$$($same_variant_QMARK_$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
$APP.$cljs$core$last$$($APP.$app$common$path_names$split_path$$($shape_name$jscomp$4$$)),subtext:$APP.$cljs$core$truth_$$(function(){if($can_swap_QMARK_$$){var $or__5025__auto__$jscomp$1239$$=!$multi$jscomp$6$$;return $or__5025__auto__$jscomp$1239$$?$or__5025__auto__$jscomp$1239$$:$same_variant_QMARK_$jscomp$1$$}return $can_swap_QMARK_$$}())?$APP.$cljs$core$truth_$$($APP.$cljs$cst$2552$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$134$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.unlinked"):
$app$common$path_names$merge_path_item_with_dot$$($path$jscomp$279$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$134$$)):null,onClick:$open_component_panel$$,disabled:$APP.$cljs$core$truth_$$($is_swap_opened$$)?$is_swap_opened$$:!$can_swap_QMARK_$$,menuEntries:$menu_entries$jscomp$2$$}),$is_variant_QMARK_$jscomp$3$$&&$main_instance_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant-property"),
onClick:$add_new_property$$,icon:"add"}):null]}),$APP.$cljs$core$truth_$$($is_swap_opened$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_swap_STAR_$$,{shapes:$copies$jscomp$3$$}):null,$APP.$cljs$core$truth_$$(function(){if($is_variant_QMARK_$jscomp$3$$){var $and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$=!$main_instance_QMARK_$jscomp$5$$;return $and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$?
($and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$=$APP.$cljs$core$not$$($APP.$cljs$cst$2552$deleted$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$134$$)))?($and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$=$APP.$cljs$core$not$$($is_swap_opened$$))?($and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$=
!$multi$jscomp$6$$)?$and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$:$same_variant_QMARK_$jscomp$1$$:$and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$:$and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$:$and__5023__auto____$1$jscomp$141_and__5023__auto____$2$jscomp$50_and__5023__auto____$3$jscomp$8_or__5025__auto__$jscomp$1241$$}return $is_variant_QMARK_$jscomp$3$$}())?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_copy_STAR_$$,{currentFileId:$current_file_id$jscomp$21_props_79140$$,components:$components$jscomp$23$$,shapes:$shapes$jscomp$212_shapes__$1$jscomp$35$$,componentFileData:$data$jscomp$482$$}):null,$APP.$cljs$core$truth_$$($is_variant_QMARK_$jscomp$3$$?$main_instance_QMARK_$jscomp$5$$?$APP.$cljs$core$truth_$$($same_variant_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($is_swap_opened$$):$same_variant_QMARK_$jscomp$1$$:
$main_instance_QMARK_$jscomp$5$$:$is_variant_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_STAR_$$,{components:$components$jscomp$23$$,shapes:$shapes$jscomp$212_shapes__$1$jscomp$35$$,data:$data$jscomp$482$$}):null,$APP.$cljs$core$not$$($is_swap_opened$$)&&!$multi$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_annotation_STAR_$$,{id:$id$jscomp$968$$,shape:$shape$jscomp$1007$$,
component:$component$jscomp$134$$,rerenderFn:$rerender_fn$jscomp$5$$}):null,$multi$jscomp$6$$&&$all_main_QMARK_$jscomp$4$$&&$APP.$cljs$core$not$$($any_variant_QMARK_$jscomp$3$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",className:"main_ui_workspace_sidebar_options_menus_component__component-combine",onClick:$on_combine_as_variants$jscomp$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.combine-as-variants")}):
null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3093$display_touched$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{children:[":touched ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1631$touched$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1007$$))]}):null]}):null]}):null};
$app$main$ui$workspace$sidebar$options$menus$component$move_empty_items_to_end$$=function($v$jscomp$672$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$empty_QMARK_$$),$v$jscomp$672$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$empty_QMARK_$$),$v$jscomp$672$$)};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_property_STAR_$$=function($is_remove_disabled_props_79141$$){var $on_remove$jscomp$1$$=$is_remove_disabled_props_79141$$.onRemove,$property$jscomp$83$$=$is_remove_disabled_props_79141$$.property,$on_blur$jscomp$20$$=$is_remove_disabled_props_79141$$.onBlur,$pos$jscomp$146$$=$is_remove_disabled_props_79141$$.pos,$on_reorder$jscomp$2$$=$is_remove_disabled_props_79141$$.onReorder;$is_remove_disabled_props_79141$$=$is_remove_disabled_props_79141$$.isRemoveDisabled;
var $values$jscomp$82$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$replace$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,["","--"],null),$app$main$ui$workspace$sidebar$options$menus$component$move_empty_items_to_end$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$83$$)))),$dprops$jscomp$4_on_drop$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$,
$data$jscomp$483_from_pos$jscomp$13$$){$data$jscomp$483_from_pos$jscomp$13$$=$cljs$cst$5788$from_pos$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$483_from_pos$jscomp$13$$);$relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$,$APP.$cljs$cst$2963$bot$$)?$pos$jscomp$146$$+1:$pos$jscomp$146$$;return $on_reorder$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$483_from_pos$jscomp$13$$,
$relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$):$on_reorder$jscomp$2$$($data$jscomp$483_from_pos$jscomp$13$$,$relative_pos$jscomp$2_to_space_between_pos$jscomp$13$$)}),$dref$jscomp$4_vec__79142$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,"penpot/variant-main-property",$APP.$cljs$cst$2966$on_drop$$,$dprops$jscomp$4_on_drop$jscomp$12$$,$APP.$cljs$cst$2970$draggable_QMARK_$$,
!0,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5788$from_pos$$,$pos$jscomp$146$$],null)]));$dprops$jscomp$4_on_drop$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$4_vec__79142$$,0,null);$dref$jscomp$4_vec__79142$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$4_vec__79142$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$4_on_drop$jscomp$12$$),$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_sidebar_options_menus_component__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$4_on_drop$jscomp$12$$),$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_sidebar_options_menus_component__dnd-over-bot":""),
children:[$on_reorder$jscomp$2$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$4_vec__79142$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$input_with_meta$input_with_meta_STAR_$$,{value:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($property$jscomp$83$$),"data-position":$pos$jscomp$146$$,
meta:$values$jscomp$82$$,isEditing:$APP.$cljs$cst$3571$editing_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($property$jscomp$83$$)),maxLength:60,onBlur:$on_blur$jscomp$20$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",icon:"remove","data-position":$pos$jscomp$146$$,"aria-label":$APP.$cljs$core$truth_$$($is_remove_disabled_props_79141$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-variant-property.last-property"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-variant-property"),onClick:$on_remove$jscomp$1$$,disabled:$is_remove_disabled_props_79141$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_STAR_$$=function($props_79147_shapes$jscomp$213$$){$props_79147_shapes$jscomp$213$$=$props_79147_shapes$jscomp$213$$.shapes;var $multi_QMARK_$jscomp$1$$=$APP.$cljs$core$count$$($props_79147_shapes$jscomp$213$$)>1,$shape$jscomp$1008$$=$APP.$cljs$core$first$$($props_79147_shapes$jscomp$213$$),$shape_name$jscomp$5$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1008$$),$libraries$jscomp$151_malformed_QMARK_$$=
$APP.$cljs$core$_deref$$($APP.$app$main$refs$libraries$$),$current_file_id$jscomp$22_duplicated_QMARK__variant_components$jscomp$2$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$current_page_id$jscomp$4_open_QMARK_$jscomp$16$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_page_id$$),$data$jscomp$484$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$151_malformed_QMARK_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$current_file_id$jscomp$22_duplicated_QMARK__variant_components$jscomp$2$$,$APP.$cljs$cst$142$data$$],null)),$objects$jscomp$802$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$helpers$get_page$$($data$jscomp$484$$,$current_page_id$jscomp$4_open_QMARK_$jscomp$16$$),$APP.$cljs$cst$1636$objects$$),$variants$jscomp$10$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79145_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$802$$,
$p1__79145_SHARP_$$)},$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1008$$)),$variant_id$jscomp$54$$=$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($variants$jscomp$10$$));$current_file_id$jscomp$22_duplicated_QMARK__variant_components$jscomp$2$$=$APP.$app$common$files$variant$find_variant_components$cljs$0core$0IFn$0_invoke$0arity$03$$($data$jscomp$484$$,$objects$jscomp$802$$,$variant_id$jscomp$54$$);var $malformed_ids$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,
$APP.$cljs$core$filterv$$(function($p1__79146_SHARP_$$){return $APP.$cljs$cst$2019$variant_error$$.$cljs$core$IFn$_invoke$arity$1$($p1__79146_SHARP_$$)!=null},$variants$jscomp$10$$));$libraries$jscomp$151_malformed_QMARK_$$=$APP.$app$common$data$not_empty_QMARK_$$($malformed_ids$$);var $duplicated_ids$jscomp$2$$=$app$main$ui$workspace$sidebar$options$menus$component$get_main_ids_with_duplicated_variant_props_and_values$$($current_file_id$jscomp$22_duplicated_QMARK__variant_components$jscomp$2$$);
$current_file_id$jscomp$22_duplicated_QMARK__variant_components$jscomp$2$$=$APP.$app$common$data$not_empty_QMARK_$$($duplicated_ids$jscomp$2$$);var $properties$jscomp$108$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$484$$),$APP.$rumext$v2$adapt$$($objects$jscomp$802$$),$APP.$rumext$v2$adapt$$($variant_id$jscomp$54$$)],function(){return $APP.$app$common$files$variant$extract_properties_values$$($data$jscomp$484$$,$objects$jscomp$802$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1008$$))}),
$single_property_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($properties$jscomp$108$$),1),$open_STAR_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$current_page_id$jscomp$4_open_QMARK_$jscomp$16$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$6$$);var $menu_entries$jscomp$3_show_in_assets_panel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variants$jscomp$10$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_component_in_assets$$($APP.$cljs$cst$1632$component_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($variants$jscomp$10$$))))}),
$create_variant$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1008$$)],function($trigger$jscomp$4$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-variant",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$trigger$jscomp$4$$],null)),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1008$$))]))}),$add_new_property$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$54$$)],function($trigger$jscomp$5$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"add-new-property",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,$trigger$jscomp$5$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$add_new_property$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($variant_id$jscomp$54$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3573$property_value$$,
"Value 1",$APP.$cljs$cst$3571$editing_QMARK_$$,!0],null)]))]))});$menu_entries$jscomp$3_show_in_assets_panel$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.show-in-assets"),$APP.$cljs$cst$2694$action$$,$menu_entries$jscomp$3_show_in_assets_panel$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),$APP.$cljs$cst$2694$action$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($create_variant$jscomp$1$$,"workspace:design-tab-menu-component")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant-property"),$APP.$cljs$cst$2694$action$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($add_new_property$jscomp$1$$,
"workspace:design-tab-menu-component")],null)],null);var $toggle_content$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$6$$,$APP.$cljs$core$not$$)}),$on_click_variant_title_help$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,
$cljs$cst$5787$variants_help_modal$$],null));return $app$main$data$modal$allow_click_outside_BANG_$$()}),$update_property_name$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$54$$)],function($event$jscomp$521_pos$jscomp$147$$){var $value$jscomp$840$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$521_pos$jscomp$147$$);$event$jscomp$521_pos$jscomp$147$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$521_pos$jscomp$147$$),
"position")|0;return $APP.$cljs$core$seq$$($value$jscomp$840$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$update_property_name$$($variant_id$jscomp$54$$,$event$jscomp$521_pos$jscomp$147$$,$value$jscomp$840$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4491$trigger$$,"workspace:design-tab-component"],null))):null}),$remove_property$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$54$$),
$APP.$rumext$v2$adapt$$($properties$jscomp$108$$)],function($event$jscomp$522_pos$jscomp$148$$){$event$jscomp$522_pos$jscomp$148$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$522_pos$jscomp$148$$),"position")|0;return $APP.$cljs$core$count$$($properties$jscomp$108$$)>1?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"variant-remove-property",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:button-design-tab"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$variants$remove_property$$($variant_id$jscomp$54$$,$event$jscomp$522_pos$jscomp$148$$)])):null}),$reorder_properties$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($variant_id$jscomp$54$$)],function($from_pos$jscomp$14$$,$to_space_between_pos$jscomp$14$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$variants$reorder_variant_poperties$$($variant_id$jscomp$54$$,
$from_pos$jscomp$14$$,$to_space_between_pos$jscomp$14$$))}),$select_shapes_with_malformed$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($malformed_ids$$)],function(){var $JSCompiler_temp_const$jscomp$1600$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1602_param72364$jscomp$inline_9037$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),
$malformed_ids$$);$JSCompiler_inline_result$jscomp$1602_param72364$jscomp$inline_9037$$=$APP.$app$main$data$workspace$selection$select_shapes$$($JSCompiler_inline_result$jscomp$1602_param72364$jscomp$inline_9037$$);return $JSCompiler_temp_const$jscomp$1600$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1602_param72364$jscomp$inline_9037$$)}),$select_shapes_with_duplicated$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($duplicated_ids$jscomp$2$$)],
function(){var $JSCompiler_temp_const$jscomp$1603$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$1605_param72364$jscomp$inline_9039$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$duplicated_ids$jscomp$2$$);$JSCompiler_inline_result$jscomp$1605_param72364$jscomp$inline_9039$$=$APP.$app$main$data$workspace$selection$select_shapes$$($JSCompiler_inline_result$jscomp$1605_param72364$jscomp$inline_9039$$);
return $JSCompiler_temp_const$jscomp$1603$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1605_param72364$jscomp$inline_9039$$)});return $APP.$cljs$core$seq$$($props_79147_shapes$jscomp$213$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-title",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($current_page_id$jscomp$4_open_QMARK_$jscomp$16$$),onCollapsed:$toggle_content$jscomp$1$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component"),className:"main_ui_workspace_sidebar_options_menus_component__component-title-bar",titleClass:"main_ui_workspace_sidebar_options_menus_component__component-title-bar-title",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_menus_component__component-title-bar-type",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.main")})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variants-help-modal.title"),onClick:$on_click_variant_title_help$jscomp$1$$,icon:"help"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant"),onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($create_variant$jscomp$1$$,"workspace:button-design-tab-component"),icon:"variant"})]})}),$APP.$cljs$core$truth_$$($current_page_id$jscomp$4_open_QMARK_$jscomp$16$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__component-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__component-pill",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_pill_STAR_$$,{icon:"component",text:$multi_QMARK_$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):$APP.$cljs$core$last$$($APP.$app$common$path_names$split_path$$($shape_name$jscomp$5$$)),disabled:!0,menuEntries:$menu_entries$jscomp$3_show_in_assets_panel$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-variant-property"),onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($add_new_property$jscomp$1$$,"workspace:button-design-tab-component"),icon:"add"})]}),$multi_QMARK_$jscomp$1$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-property-list",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$173$$,$p__79148_property$jscomp$84$$){var $pos$jscomp$149$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79148_property$jscomp$84$$,0,null);$p__79148_property$jscomp$84$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79148_property$jscomp$84$$,1,null);$out_arr__44092__auto__$jscomp$173$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_property_STAR_$$,
{pos:$pos$jscomp$149$$,property:$p__79148_property$jscomp$84$$,isRemoveDisabled:$single_property_QMARK_$$,onRemove:$remove_property$$,onBlur:$update_property_name$jscomp$1$$,onReorder:$reorder_properties$jscomp$1$$},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1008$$)),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos$jscomp$149$$)].join("")));return $out_arr__44092__auto__$jscomp$173$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,
$properties$jscomp$108$$))})}),$libraries$jscomp$151_malformed_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.group.title")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$select_shapes_with_malformed$$,className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.malformed.group.locate")})]}):$current_file_id$jscomp$22_duplicated_QMARK__variant_components$jscomp$2$$?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"msg-neutral",className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-darken"}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-highlight",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.group.title")}),
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$select_shapes_with_duplicated$$,className:"main_ui_workspace_sidebar_options_menus_component__variant-warning-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.component.variant.duplicated.group.locate")})]}):null]}):null]}):null};
$app$main$ui$workspace$sidebar$options$menus$grid_cell$set_self_alignment$$=function($is_col_QMARK__map__79100_props_79097$$){$is_col_QMARK__map__79100_props_79097$$=$APP.$rumext$v2$util$wrap_props$$($is_col_QMARK__map__79100_props_79097$$);var $alignment__$1_map__79100__$1$$=$APP.$cljs$core$__destructure_map$$($is_col_QMARK__map__79100_props_79097$$);$is_col_QMARK__map__79100_props_79097$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alignment__$1_map__79100__$1$$,$cljs$cst$5792$is_col_QMARK_$$);
var $alignment$jscomp$1_type$jscomp$628$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alignment__$1_map__79100__$1$$,$APP.$cljs$cst$5003$alignment$$),$set_alignment$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($alignment__$1_map__79100__$1$$,$cljs$cst$5793$set_alignment$$);$alignment__$1_map__79100__$1$$=$APP.$cljs$core$truth_$$($alignment$jscomp$1_type$jscomp$628$$)?$alignment$jscomp$1_type$jscomp$628$$:$APP.$cljs$cst$1677$auto$$;$alignment$jscomp$1_type$jscomp$628$$=$APP.$cljs$core$truth_$$($is_col_QMARK__map__79100_props_79097$$)?
"col":"row";var $handle_set_alignment$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set_alignment$$)],function($G__79102_value$jscomp$841$$){$G__79102_value$jscomp$841$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79102_value$jscomp$841$$);return $set_alignment$$.$cljs$core$IFn$_invoke$arity$1$?$set_alignment$$.$cljs$core$IFn$_invoke$arity$1$($G__79102_value$jscomp$841$$):$set_alignment$$($G__79102_value$jscomp$841$$)});return(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_grid_cell__self-align-menu",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($alignment__$1_map__79100__$1$$),"on-change":$handle_set_alignment$$,"allow-empty":!0,name:"flex-align-items-"+($alignment$jscomp$1_type$jscomp$628$$??""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$APP.$cljs$core$truth_$$($is_col_QMARK__map__79100_props_79097$$)?
"align-self-row-left":"align-self-column-top",title:"Align self start",id:"align-self-start-"+($alignment$jscomp$1_type$jscomp$628$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$APP.$cljs$core$truth_$$($is_col_QMARK__map__79100_props_79097$$)?"align-self-row-center":"align-self-column-center",title:"Align self center",id:"align-self-center-"+($alignment$jscomp$1_type$jscomp$628$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"end",icon:$APP.$cljs$core$truth_$$($is_col_QMARK__map__79100_props_79097$$)?"align-self-row-right":"align-self-column-bottom",title:"Align self end",id:"align-self-end-"+($alignment$jscomp$1_type$jscomp$628$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"stretch",icon:$APP.$cljs$core$truth_$$($is_col_QMARK__map__79100_props_79097$$)?"align-self-row-stretch":"align-self-column-stretch",title:"Align self stretch",id:"align-self-stretch-"+($alignment$jscomp$1_type$jscomp$628$$??
"")})]})})};
$app$main$ui$ds$controls$checkbox$checkbox_STAR_$$=function($props_79101_props__$1$jscomp$79$$){var $on_change$jscomp$57$$=void 0,$disabled$jscomp$18$$=void 0,$label$jscomp$46$$=void 0,$id$jscomp$969$$=void 0,$class$$jscomp$73$$=void 0,$checked$jscomp$1$$=void 0,$props$jscomp$319$$=void 0;({id:$id$jscomp$969$$,className:$class$$jscomp$73$$,label:$label$jscomp$46$$,checked:$checked$jscomp$1$$,onChange:$on_change$jscomp$57$$,disabled:$disabled$jscomp$18$$,...$props$jscomp$319$$}=$props_79101_props__$1$jscomp$79$$);$props_79101_props__$1$jscomp$79$$=
{...$props$jscomp$319$$,type:"checkbox",className:"main_ui_ds_controls_checkbox__checkbox-input",id:$id$jscomp$969$$,checked:$checked$jscomp$1$$,onChange:$on_change$jscomp$57$$,disabled:$disabled$jscomp$18$$};return(0,$APP.$rumext$v2$jsx$$)("div",{className:($class$$jscomp$73$$??"")+" main_ui_ds_controls_checkbox__checkbox",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$id$jscomp$969$$,className:"main_ui_ds_controls_checkbox__checkbox-label",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_checkbox__checkbox-box "+
($APP.$cljs$core$truth_$$($checked$jscomp$1$$)?"main_ui_ds_controls_checkbox__checked":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$18$$)?"main_ui_ds_controls_checkbox__disabled":""),children:$APP.$cljs$core$truth_$$($checked$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s"}):null}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_controls_checkbox__checkbox-text",children:$label$jscomp$46$$}),(0,$APP.$rumext$v2$create_element$$)("input",
$props_79101_props__$1$jscomp$79$$)]})})};
$app$main$ui$workspace$sidebar$options$menus$interactions$event_type_name$$=function($interaction$jscomp$50$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1955$click$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-on-click"),$APP.$cljs$cst$1954$mouse_enter$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-mouse-enter"),$APP.$cljs$cst$1952$mouse_leave$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-mouse-leave"),$APP.$cljs$cst$1951$after_delay$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-after-delay")],null),$APP.$cljs$cst$1562$event_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$50$$),"--")};
$app$main$ui$workspace$sidebar$options$menus$interactions$action_summary$$=function($G__79154_interaction$jscomp$51$$,$destination$jscomp$13$$){$G__79154_interaction$jscomp$51$$=$APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($G__79154_interaction$jscomp$51$$);switch($G__79154_interaction$jscomp$51$$ instanceof $APP.$cljs$core$Keyword$$?$G__79154_interaction$jscomp$51$$.$fqn$:null){case "navigate":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.interaction-navigate-to-dest",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($destination$jscomp$13$$,$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-none"))]));case "open-overlay":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.interaction-open-overlay-dest",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($destination$jscomp$13$$,
$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-none"))]));case "toggle-overlay":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.interaction-toggle-overlay-dest",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($destination$jscomp$13$$,$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-none"))]));
case "close-overlay":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.interaction-close-overlay-dest",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($destination$jscomp$13$$,$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-self"))]));case "prev-screen":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-prev-screen");
case "open-url":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-open-url");default:return"--"}};
$app$main$ui$workspace$sidebar$options$menus$interactions$get_frames_options$$=function($frames$jscomp$29$$,$shape$jscomp$1009$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($frame$jscomp$70$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$70$$)),$APP.$cljs$cst$2296$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$70$$)],
null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79155_SHARP_$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79155_SHARP_$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1009$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79155_SHARP_$$),$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1009$$))},
$frames$jscomp$29$$))};
$app$main$ui$workspace$sidebar$options$menus$interactions$get_shared_frames_options$$=function($shared_frames$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($frame$jscomp$71$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$71$$)),$APP.$cljs$cst$2296$label$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$71$$)],null)},
$shared_frames$$)};
$app$main$ui$workspace$sidebar$options$menus$interactions$prototype_pill_STAR_$$=function($left_button_tooltip_props_79156$$,$external_ref$jscomp$3_handle_focus$jscomp$4$$){var $on_change$jscomp$58$$=$left_button_tooltip_props_79156$$.onChange,$is_left_button_active$$=$left_button_tooltip_props_79156$$.isLeftButtonActive,$description$jscomp$17$$=$left_button_tooltip_props_79156$$.description,$is_right_button_active$$=$left_button_tooltip_props_79156$$.isRightButtonActive,$is_editable$jscomp$1$$=$left_button_tooltip_props_79156$$.isEditable,
$right_button_icon_id$$=$left_button_tooltip_props_79156$$.rightButtonIconId,$on_right_button_click$$=$left_button_tooltip_props_79156$$.onRightButtonClick,$left_button_icon_id$$=$left_button_tooltip_props_79156$$.leftButtonIconId,$right_button_tooltip$$=$left_button_tooltip_props_79156$$.rightButtonTooltip,$title$jscomp$42$$=$left_button_tooltip_props_79156$$.title,$on_left_button_click$$=$left_button_tooltip_props_79156$$.onLeftButtonClick;$left_button_tooltip_props_79156$$=$left_button_tooltip_props_79156$$.leftButtonTooltip;
var $handle_key_down$jscomp$9_local_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(),$ref$jscomp$54$$=$APP.$cljs$core$truth_$$($external_ref$jscomp$3_handle_focus$jscomp$4$$)?$external_ref$jscomp$3_handle_focus$jscomp$4$$:$handle_key_down$jscomp$9_local_ref$jscomp$4$$;$external_ref$jscomp$3_handle_focus$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($ref$jscomp$54$$))});$handle_key_down$jscomp$9_local_ref$jscomp$4$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($JSCompiler_inline_result$jscomp$1837_event$jscomp$524$$){var $input_node$jscomp$9$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$54$$),$value$jscomp$846$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($JSCompiler_inline_result$jscomp$1837_event$jscomp$524$$))),$or__5025__auto__$jscomp$inline_9041$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($JSCompiler_inline_result$jscomp$1837_event$jscomp$524$$);
$JSCompiler_inline_result$jscomp$1837_event$jscomp$524$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9041$$)?$or__5025__auto__$jscomp$inline_9041$$:(0,$APP.$app$util$keyboard$enter_QMARK_$$)($JSCompiler_inline_result$jscomp$1837_event$jscomp$524$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1837_event$jscomp$524$$)?($APP.$app$util$dom$blur_BANG_$$($input_node$jscomp$9$$),$on_change$jscomp$58$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$58$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$846$$):
$on_change$jscomp$58$$($value$jscomp$846$$)):null});var $handle_blur$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$525_value$jscomp$847$$){$event$jscomp$525_value$jscomp$847$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$525_value$jscomp$847$$)));return $on_change$jscomp$58$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$58$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$525_value$jscomp$847$$):
$on_change$jscomp$58$$($event$jscomp$525_value$jscomp$847$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill "+($description$jscomp$17$$!=null?"main_ui_workspace_sidebar_options_menus_interactions__double":""),children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-button main_ui_workspace_sidebar_options_menus_interactions__left",
"aria-pressed":$is_left_button_active$$,icon:$left_button_icon_id$$,"aria-label":$left_button_tooltip_props_79156$$,onClick:$on_left_button_click$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-main",children:[$APP.$cljs$core$truth_$$($is_editable$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$ref$jscomp$54$$,defaultValue:$title$jscomp$42$$,onFocus:$external_ref$jscomp$3_handle_focus$jscomp$4$$,onKeyDown:$handle_key_down$jscomp$9_local_ref$jscomp$4$$,
onBlur:$handle_blur$jscomp$6$$,className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-input"}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-center",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-info",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-name",children:$title$jscomp$42$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-description",children:$description$jscomp$17$$})]})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",className:"main_ui_workspace_sidebar_options_menus_interactions__prototype-pill-button main_ui_workspace_sidebar_options_menus_interactions__right","aria-pressed":$is_right_button_active$$,icon:$right_button_icon_id$$,"aria-label":$right_button_tooltip$$,
onClick:$on_right_button_click$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$flow_item_STAR_$$=function($props_79157_start_flow$$){var $flow$jscomp$8$$=$props_79157_start_flow$$.flow;$props_79157_start_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($flow$jscomp$8$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$1371$section$$,"interactions",$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$2061$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$8$$)],null)])))});var $rename_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($flow$jscomp$8$$)],function($value$jscomp$848$$){return $APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$848$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$rename_flow$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$8$$),
$value$jscomp$848$$))}),$remove_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($flow$jscomp$8$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$remove_flow$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$8$$)))});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$prototype_pill_STAR_$$,
{onChange:$rename_flow$$,leftButtonTooltip:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.flows.flow-start"),leftButtonIconId:"play",onRightButtonClick:$remove_flow$$,onLeftButtonClick:$props_79157_start_flow$$,rightButtonTooltip:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.remove"),isEditable:!0,rightButtonIconId:"remove",title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($flow$jscomp$8$$,"")})};
$app$main$ui$workspace$sidebar$options$menus$interactions$interaction_item_STAR_$$=function($destination$jscomp$14_props_79188$$){var $update_interaction$$=$destination$jscomp$14_props_79188$$.updateInteraction,$index$jscomp$486$$=$destination$jscomp$14_props_79188$$.index,$interaction$jscomp$52$$=$destination$jscomp$14_props_79188$$.interaction,$remove_interaction$$=$destination$jscomp$14_props_79188$$.removeInteraction,$shape$jscomp$1010$$=$destination$jscomp$14_props_79188$$.shape,$objects$jscomp$803$$=
$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);$destination$jscomp$14_props_79188$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$803$$,$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$));var $frames$jscomp$30$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$803$$)],function(){return $APP.$app$common$types$shape_tree$get_viewer_frames$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$803$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2096$all_frames_QMARK_$$,!0],null))}),$shape_parent_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$803$$)],function(){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$803$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1010$$))}),$relative_to_opts_shape_parents$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frames$jscomp$30$$),
$APP.$rumext$v2$adapt$$($shape$jscomp$1010$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$set$$($shape_parent_ids$$),$APP.$cljs$cst$266$id$$),$frames$jscomp$30$$)}),$overlay_pos_type$jscomp$4$$=$APP.$cljs$cst$1987$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),$close_click_outside_QMARK_$$=$APP.$cljs$cst$1988$close_click_outside$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$52$$,
!1),$background_overlay_QMARK_$$=$APP.$cljs$cst$1989$background_overlay$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$52$$,!1),$preserve_scroll_QMARK_$$=$APP.$cljs$cst$1984$preserve_scroll$$.$cljs$core$IFn$_invoke$arity$2$($interaction$jscomp$52$$,!1),$way$jscomp$1$$=$APP.$cljs$cst$1978$way$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),$direction$jscomp$26$$=$APP.$cljs$cst$1979$direction$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),
$open_extended_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$open_extended_QMARK_$$=$APP.$cljs$core$_deref$$($open_extended_STAR_$$),$ext_delay_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$ext_duration_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$toggle_extended$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_extended_STAR_$$,$APP.$cljs$core$not$$)}),$change_event_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$526$$){function $G__79204$$($JSCompiler_inline_result$jscomp$1521_p1__79170_SHARP_$$){a:if(!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1562$event_type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1521_p1__79170_SHARP_$$),$value$jscomp$849$$))switch($value$jscomp$849$$ instanceof $APP.$cljs$core$Keyword$$?$value$jscomp$849$$.$fqn$:null){case "after-delay":$JSCompiler_inline_result$jscomp$1521_p1__79170_SHARP_$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$1521_p1__79170_SHARP_$$,$APP.$cljs$cst$1562$event_type$$,$value$jscomp$849$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1330$delay$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1521_p1__79170_SHARP_$$,$APP.$cljs$cst$1330$delay$$,600)]));break a;default:$JSCompiler_inline_result$jscomp$1521_p1__79170_SHARP_$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1521_p1__79170_SHARP_$$,
$APP.$cljs$cst$1562$event_type$$,$value$jscomp$849$$)}return $JSCompiler_inline_result$jscomp$1521_p1__79170_SHARP_$$}var $value$jscomp$849$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$526$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79204$$):$update_interaction$$($index$jscomp$486$$,$G__79204$$)}),$change_action_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$527$$){function $G__79206$$($p1__79171_SHARP_$$){return $app$common$types$shape$interactions$set_action_type$$($p1__79171_SHARP_$$,$value$jscomp$850$$)}var $value$jscomp$850$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$527$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79206$$):$update_interaction$$($index$jscomp$486$$,
$G__79206$$)}),$change_delay$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($value$jscomp$851$$){function $G__79215$$($p1__79172_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79172_SHARP_$$,$APP.$cljs$cst$1330$delay$$,$value$jscomp$851$$)}return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,
$G__79215$$):$update_interaction$$($index$jscomp$486$$,$G__79215$$)}),$change_destination$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$528$$){function $G__79218$$($p1__79173_SHARP_$$){return $app$common$types$shape$interactions$set_destination$$($p1__79173_SHARP_$$,$value__$1$jscomp$51$$)}var $value__$1$jscomp$51$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$528$$,
"")?$APP.$app$common$uuid$parse$$($event$jscomp$528$$):null;return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79218$$):$update_interaction$$($index$jscomp$486$$,$G__79218$$)}),$change_position_relative_to$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$529$$){function $G__79220$$($p1__79174_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79174_SHARP_$$,
$APP.$cljs$cst$1990$position_relative_to$$,$value$jscomp$853$$)}var $value$jscomp$853$$=$APP.$app$common$uuid$parse_STAR_$$($event$jscomp$529$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79220$$):$update_interaction$$($index$jscomp$486$$,$G__79220$$)}),$change_preserve_scroll$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],
function($event$jscomp$530$$){function $G__79223$$($p1__79175_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79175_SHARP_$$,$APP.$cljs$cst$1984$preserve_scroll$$,$value$jscomp$854$$)}var $value$jscomp$854$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$530$$));return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79223$$):$update_interaction$$($index$jscomp$486$$,
$G__79223$$)}),$change_url$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($G__79225_event$jscomp$531_target$jscomp$153$$){$G__79225_event$jscomp$531_target$jscomp$153$$=$APP.$app$util$dom$get_target$$($G__79225_event$jscomp$531_target$jscomp$153$$);var $value$jscomp$855$$=$APP.$app$util$dom$get_value$$($G__79225_event$jscomp$531_target$jscomp$153$$),$has_prefix_QMARK_$$=$APP.$cuerdas$core$starts_with_QMARK_$$($value$jscomp$855$$,
"http://")||$APP.$cuerdas$core$starts_with_QMARK_$$($value$jscomp$855$$,"https://"),$value__$1$jscomp$52$$=$has_prefix_QMARK_$$?$value$jscomp$855$$:["http://",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$855$$)].join("");$has_prefix_QMARK_$$||$app$util$dom$set_value_BANG_$$($G__79225_event$jscomp$531_target$jscomp$153$$,$value__$1$jscomp$52$$);return $APP.$cljs$core$truth_$$($app$util$dom$valid_QMARK_$$($G__79225_event$jscomp$531_target$jscomp$153$$))?($G__79225_event$jscomp$531_target$jscomp$153$$!=
null&&$G__79225_event$jscomp$531_target$jscomp$153$$.classList.remove("error"),$G__79225_event$jscomp$531_target$jscomp$153$$=function($p1__79176_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79176_SHARP_$$,$APP.$cljs$cst$1991$url$$,$value__$1$jscomp$52$$)},$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79225_event$jscomp$531_target$jscomp$153$$):$update_interaction$$($index$jscomp$486$$,
$G__79225_event$jscomp$531_target$jscomp$153$$)):$APP.$app$util$dom$add_class_BANG_$$($G__79225_event$jscomp$531_target$jscomp$153$$,"error")}),$change_overlay_pos_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1010$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($value$jscomp$856$$){function $G__79228_79368$$($p1__79177_SHARP_$$){var $JSCompiler_temp_const$jscomp$inline_13819$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;
var $G__49074$jscomp$inline_13821_JSCompiler_inline_result$jscomp$inline_13820$$=$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__79177_SHARP_$$);$G__49074$jscomp$inline_13821_JSCompiler_inline_result$jscomp$inline_13820$$=$app$common$types$shape$interactions$calc_overlay_pos_initial$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$types$shape$interactions$calc_overlay_pos_initial$$.$cljs$core$IFn$_invoke$arity$4$($G__49074$jscomp$inline_13821_JSCompiler_inline_result$jscomp$inline_13820$$,
$shape$jscomp$1010$$,$objects$jscomp$803$$,$value$jscomp$856$$):$app$common$types$shape$interactions$calc_overlay_pos_initial$$($G__49074$jscomp$inline_13821_JSCompiler_inline_result$jscomp$inline_13820$$,$shape$jscomp$1010$$,$objects$jscomp$803$$,$value$jscomp$856$$);return $JSCompiler_temp_const$jscomp$inline_13819$$.call($APP.$cljs$core$assoc$$,$p1__79177_SHARP_$$,$APP.$cljs$cst$1987$overlay_pos_type$$,$value$jscomp$856$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1986$overlay_position$$,
$G__49074$jscomp$inline_13821_JSCompiler_inline_result$jscomp$inline_13820$$]))}var $shape_id$jscomp$163$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1010$$);$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79228_79368$$):$update_interaction$$($index$jscomp$486$$,$G__79228_79368$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$856$$,$APP.$cljs$cst$1678$manual$$)){var $G__79230$$=
function($p1__79178_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79178_SHARP_$$,$APP.$cljs$cst$1990$position_relative_to$$,$shape_id$jscomp$163$$)};return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79230$$):$update_interaction$$($index$jscomp$486$$,$G__79230$$)}return null}),$toggle_overlay_pos_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$532$$){function $G__79235$$($p1__79179_SHARP_$$){var $new_pos_type$jscomp$inline_13827$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1987$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($p1__79179_SHARP_$$),$pos_type$$)?$APP.$cljs$cst$1678$manual$$:$pos_type$$,$JSCompiler_temp_const$jscomp$inline_13828$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$;var $G__49082$jscomp$inline_13830_JSCompiler_inline_result$jscomp$inline_13829$$=
$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__79179_SHARP_$$);$G__49082$jscomp$inline_13830_JSCompiler_inline_result$jscomp$inline_13829$$=$app$common$types$shape$interactions$calc_overlay_pos_initial$$.$cljs$core$IFn$_invoke$arity$4$?$app$common$types$shape$interactions$calc_overlay_pos_initial$$.$cljs$core$IFn$_invoke$arity$4$($G__49082$jscomp$inline_13830_JSCompiler_inline_result$jscomp$inline_13829$$,$shape$jscomp$1010$$,$objects$jscomp$803$$,$new_pos_type$jscomp$inline_13827$$):
$app$common$types$shape$interactions$calc_overlay_pos_initial$$($G__49082$jscomp$inline_13830_JSCompiler_inline_result$jscomp$inline_13829$$,$shape$jscomp$1010$$,$objects$jscomp$803$$,$new_pos_type$jscomp$inline_13827$$);return $JSCompiler_temp_const$jscomp$inline_13828$$.call($APP.$cljs$core$assoc$$,$p1__79179_SHARP_$$,$APP.$cljs$cst$1987$overlay_pos_type$$,$new_pos_type$jscomp$inline_13827$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1986$overlay_position$$,$G__49082$jscomp$inline_13830_JSCompiler_inline_result$jscomp$inline_13829$$]))}
var $pos_type$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$532$$),"value"));return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79235$$):$update_interaction$$($index$jscomp$486$$,$G__79235$$)}),$change_close_click_outside$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$533$$){function $G__79239$$($p1__79180_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79180_SHARP_$$,$APP.$cljs$cst$1988$close_click_outside$$,$value$jscomp$857$$)}var $value$jscomp$857$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$533$$));return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,
$G__79239$$):$update_interaction$$($index$jscomp$486$$,$G__79239$$)}),$change_background_overlay$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$534$$){function $G__79242$$($p1__79181_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79181_SHARP_$$,$APP.$cljs$cst$1989$background_overlay$$,$value$jscomp$858$$)}var $value$jscomp$858$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$534$$));
return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79242$$):$update_interaction$$($index$jscomp$486$$,$G__79242$$)}),$change_animation_type$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$535$$){function $G__79244$$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$){if(!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$)),
$value$jscomp$859$$))if($value$jscomp$859$$==null)$JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,$APP.$cljs$cst$1985$animation$$);else{var $G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,$APP.$cljs$cst$1985$animation$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1975$animation_type$$,$value$jscomp$859$$);$G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$859$$,$APP.$cljs$cst$1973$dissolve$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$,$APP.$cljs$cst$1985$animation$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$1976$duration$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1976$duration$$],null),300),$APP.$cljs$cst$1977$easing$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1977$easing$$],null),$APP.$cljs$cst$287$linear$$)])):$G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$;$G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$859$$,$APP.$cljs$cst$1974$slide$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$,
$APP.$cljs$cst$1985$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1976$duration$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1976$duration$$],null),300),$APP.$cljs$cst$1977$easing$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1977$easing$$],null),$APP.$cljs$cst$287$linear$$),$APP.$cljs$cst$1978$way$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1978$way$$],null),$APP.$cljs$cst$297$in$$),
$APP.$cljs$cst$1979$direction$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1979$direction$$],null),$APP.$cljs$cst$258$right$$),$APP.$cljs$cst$1980$offset_effect$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1980$offset_effect$$],null),!1)])):$G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$;$JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$859$$,$APP.$cljs$cst$1972$push$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$,
$APP.$cljs$cst$1985$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1976$duration$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1976$duration$$],null),300),$APP.$cljs$cst$1977$easing$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1977$easing$$],null),$APP.$cljs$cst$287$linear$$),$APP.$cljs$cst$1979$direction$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1985$animation$$,$APP.$cljs$cst$1979$direction$$],null),
$APP.$cljs$cst$258$right$$)])):$G__49095__$1$jscomp$inline_9048_G__49095__$2$jscomp$inline_9049_G__49095__$3$jscomp$inline_9050$$}return $JSCompiler_inline_result$jscomp$1522_p1__79182_SHARP_$$}var $value$jscomp$859$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("",$event$jscomp$535$$)?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$535$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,
$G__79244$$):$update_interaction$$($index$jscomp$486$$,$G__79244$$)}),$change_duration$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($value$jscomp$860$$){function $G__79251$$($p1__79183_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__79183_SHARP_$$,$APP.$cljs$cst$1985$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1976$duration$$,$value$jscomp$860$$)}
return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79251$$):$update_interaction$$($index$jscomp$486$$,$G__79251$$)}),$change_easing$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$536$$){function $G__79253$$($p1__79184_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__79184_SHARP_$$,
$APP.$cljs$cst$1985$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1977$easing$$,$value$jscomp$861$$)}var $value$jscomp$861$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$536$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79253$$):$update_interaction$$($index$jscomp$486$$,$G__79253$$)}),$change_way$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),
$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$537$$){function $G__79255$$($p1__79185_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__79185_SHARP_$$,$APP.$cljs$cst$1985$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1978$way$$,$value$jscomp$862$$)}var $value$jscomp$862$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$537$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,
$G__79255$$):$update_interaction$$($index$jscomp$486$$,$G__79255$$)}),$change_direction$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$538$$){function $G__79257$$($p1__79186_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__79186_SHARP_$$,$APP.$cljs$cst$1985$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1979$direction$$,$value$jscomp$863$$)}
var $value$jscomp$863$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$538$$);return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79257$$):$update_interaction$$($index$jscomp$486$$,$G__79257$$)}),$change_offset_effect$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$486$$),$APP.$rumext$v2$adapt$$($update_interaction$$)],function($event$jscomp$539$$){function $G__79264$$($p1__79187_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($p1__79187_SHARP_$$,
$APP.$cljs$cst$1985$animation$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1980$offset_effect$$,$value$jscomp$864$$)}var $value$jscomp$864$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$539$$));return $update_interaction$$.$cljs$core$IFn$_invoke$arity$2$?$update_interaction$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$486$$,$G__79264$$):$update_interaction$$($index$jscomp$486$$,$G__79264$$)}),$event_type_options$$=function(){var $G__79265$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1955$click$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-on-click")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1954$mouse_enter$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-mouse-enter")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1952$mouse_leave$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-mouse-leave")],null)],null);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1010$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__79265$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1951$after_delay$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-after-delay")],null)):$G__79265$$}(),$action_type_options$$=new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1957$navigate$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-navigate-to")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1962$open_overlay$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-open-overlay")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1960$toggle_overlay$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-toggle-overlay")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1958$close_overlay$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-close-overlay")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1959$prev_screen$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-prev-screen")],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1961$open_url$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-open-url")],null)],null),$frames_opts$$=$app$main$ui$workspace$sidebar$options$menus$interactions$get_frames_options$$($frames$jscomp$30$$,$shape$jscomp$1010$$),$default_opts$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),
$APP.$cljs$cst$1958$close_overlay$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-self")],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-none")],null)],null),$destination_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frames_opts$$),
$APP.$rumext$v2$adapt$$($default_opts$$)],function(){var $sorted_frames_opts$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2296$label$$,$frames_opts$$);return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($default_opts$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$sorted_frames_opts$$]))}),$shape_parents_opts$$=$app$main$ui$workspace$sidebar$options$menus$interactions$get_shared_frames_options$$($relative_to_opts_shape_parents$jscomp$1$$);
$relative_to_opts_shape_parents$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_parents_opts$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1987$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),$APP.$cljs$cst$1678$manual$$)?$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-auto")],null)],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shape_parents_opts$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1010$$)),
$APP.$cljs$cst$2296$label$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1010$$))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-self")),")"].join("")],null)],null)])):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1010$$)),$APP.$cljs$cst$2296$label$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1010$$))," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-self")),")"].join("")],null)],null)});var $overlay_position_opts$$=
new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1678$manual$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-manual")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1672$center$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-center")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1891$top_left$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-left")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1892$top_right$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-right")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1963$top_center$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-center")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1894$bottom_left$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-left")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1893$bottom_right$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-right")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1964$bottom_center$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-center")],null)],null),$basic_animation_opts$$=new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation-none")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1973$dissolve$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation-dissolve")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1974$slide$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation-slide")],null)],null),$animation_opts$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($basic_animation_opts$$)],function(){var $action_type$jscomp$inline_9052$$=$APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$);
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1957$navigate$$,$action_type$jscomp$inline_9052$$)?$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($basic_animation_opts$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1972$push$$,$APP.$cljs$cst$2296$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation-push")],null)],null)])):$basic_animation_opts$$}),$easing_options$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1727$icon$$,$cljs$cst$5794$easing_linear$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$287$linear$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-linear")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1727$icon$$,$cljs$cst$5795$easing_ease$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1967$ease$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-ease")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1727$icon$$,$cljs$cst$5796$easing_ease_in$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1966$ease_in$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-ease-in")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1727$icon$$,$cljs$cst$5797$easing_ease_out$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1968$ease_out$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-ease-out")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1727$icon$$,$cljs$cst$5798$easing_ease_in_out$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1965$ease_in_out$$,$APP.$cljs$cst$2296$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing-ease-in-out")],null)],null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-item",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$prototype_pill_STAR_$$,{isLeftButtonActive:$open_extended_QMARK_$$,leftButtonTooltip:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.options"),leftButtonIconId:"hsva",
onRightButtonClick:function(){return $remove_interaction$$.$cljs$core$IFn$_invoke$arity$1$?$remove_interaction$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$486$$):$remove_interaction$$($index$jscomp$486$$)},onLeftButtonClick:$toggle_extended$$,rightButtonTooltip:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.remove"),rightButtonIconId:"remove",title:$app$main$ui$workspace$sidebar$options$menus$interactions$event_type_name$$($interaction$jscomp$52$$),description:$app$main$ui$workspace$sidebar$options$menus$interactions$action_summary$$($interaction$jscomp$52$$,
$destination$jscomp$14_props_79188$$)}),$APP.$cljs$core$truth_$$($open_extended_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("label",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-trigger")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$1562$event_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),options:$event_type_options$$,"on-change":$change_event_type$$})})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1562$event_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),
$APP.$cljs$cst$1951$after_delay$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-delay")})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,{ref:$ext_delay_ref$$,icon:"character-m",property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-ms"),onChange:$change_delay$$,value:$APP.$cljs$cst$1330$delay$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)})})]}):null,(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-action")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),options:$action_type_options$$,"on-change":$change_action_type$$})})]}),$APP.$cljs$core$truth_$$($APP.$app$common$types$shape$interactions$has_destination$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-destination")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,
{"default-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),options:$destination_options$$,"on-change":$change_destination$$,"searchable?":!0,"search-placeholder":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-destination")})})]}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),
$APP.$cljs$cst$1957$navigate$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,{id:["preserve-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$486$$)].join(""),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-preserve-scroll"),
checked:$preserve_scroll_QMARK_$$,onChange:$change_preserve_scroll$$})})}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),$APP.$cljs$cst$1961$open_url$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-url")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-input",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{type:"url",placeholder:"http://example.com",defaultValue:$APP.$cljs$cst$1991$url$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),
onBlur:$change_url$$})})]}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_overlay_opts$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-position")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$1987$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$),options:$overlay_position_opts$$,"on-change":$change_overlay_pos_type$$})})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-relative-to")})}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1990$position_relative_to$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),options:$relative_to_opts_shape_parents$jscomp$1$$,"on-change":$change_position_relative_to$$})})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-position",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__center",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1672$center$$),"data-value":"center",
icon:"corner-center","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-center"),onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__top-left",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,$APP.$cljs$cst$1891$top_left$$),
"data-value":"top-left",icon:"corner-top-left","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-left"),onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__top-right",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,
$APP.$cljs$cst$1892$top_right$$),"data-value":"top-right",icon:"corner-top-right","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-right"),onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__top-center",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,
$APP.$cljs$cst$1963$top_center$$),"data-value":"top-center",icon:"corner-top","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-top-center"),onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__bottom-left",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,
$APP.$cljs$cst$1894$bottom_left$$),"data-value":"bottom-left",icon:"corner-bottom-left","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-left"),onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__bottom-right",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,
$APP.$cljs$cst$1893$bottom_right$$),"data-value":"bottom-right",icon:"corner-bottom-right","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-right"),onClick:$toggle_overlay_pos_type$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__bottom-center",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary","aria-pressed":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($overlay_pos_type$jscomp$4$$,
$APP.$cljs$cst$1964$bottom_center$$),"data-value":"bottom-center",icon:"corner-bottom","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-pos-bottom-center"),onClick:$toggle_overlay_pos_type$$})})]})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,
{id:["close-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$486$$)].join(""),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-close-outside"),checked:$close_click_outside_QMARK_$$,onChange:$change_close_click_outside$$})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,{id:["background-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$486$$)].join(""),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-background"),checked:$background_overlay_QMARK_$$,onChange:$change_background_overlay$$})})})]}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_animation_QMARK_$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-animation")})}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_menus_interactions__animation-select","default-value":function(){var $or__5025__auto__$jscomp$1247$$=$APP.$cljs$cst$1975$animation_type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1247$$)?
$or__5025__auto__$jscomp$1247$$:""}(),options:$animation_opts$$,"on-change":$change_animation_type$$})})]}),$app$common$types$shape$interactions$has_way_QMARK_$$($interaction$jscomp$52$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-radio",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,
{selected:$APP.$app$common$data$name$$($way$jscomp$1$$),"on-change":$change_way$$,name:"animation-way",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"in",id:"animation-way-in"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{id:"animation-way-out",value:"out"})]})})}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_direction_QMARK_$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-radio",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($direction$jscomp$26$$),"on-change":$change_direction$$,name:"animation-direction",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{icon:"row","icon-class":"main_ui_workspace_sidebar_options_menus_interactions__right",value:"right",id:"animation-right"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"row-reverse","icon-class":"main_ui_workspace_sidebar_options_menus_interactions__left",id:"animation-left",value:"left"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"column","icon-class":"main_ui_workspace_sidebar_options_menus_interactions__down",
id:"animation-down",value:"down"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"column-reverse","icon-class":"main_ui_workspace_sidebar_options_menus_interactions__up",id:"animation-up",value:"up"})]})})}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_duration_QMARK_$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-duration")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,
{ref:$ext_duration_ref$$,icon:"character-m",property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-ms"),onChange:$change_duration$$,value:$APP.$cljs$cst$1976$duration$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$))})})]}):null,$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$has_easing_QMARK_$$($interaction$jscomp$52$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-label",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-easing")})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,
{"class":"main_ui_workspace_sidebar_options_menus_interactions__easing-select","dropdown-class":"main_ui_workspace_sidebar_options_menus_interactions__dropdown-upwards","default-value":$APP.$cljs$cst$1977$easing$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),options:$easing_options$$,"on-change":$change_easing$$})})]}):null,$app$common$types$shape$interactions$has_offset_effect_QMARK_$$($interaction$jscomp$52$$)?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__interaction-row-checkbox",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$checkbox$checkbox_STAR_$$,{id:["offset-effect-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$486$$)].join(""),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interaction-offset-effect"),
checked:$APP.$cljs$cst$1980$offset_effect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1985$animation$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$52$$)),onChange:$change_offset_effect$$})})}):null]}):null]}):null]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$page_flows_STAR_$$=function($flows$jscomp$8_props_79293$$){$flows$jscomp$8_props_79293$$=$flows$jscomp$8_props_79293$$.flows;var $show_content_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$show_content_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($show_content_STAR_$$),$toggle_content$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_content_STAR_$$,
$APP.$cljs$core$not$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$APP.$cljs$core$count$$($flows$jscomp$8_props_79293$$)>0,collapsed:$APP.$cljs$core$not$$($show_content_QMARK_$jscomp$1$$),onCollapsed:$toggle_content$jscomp$2$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.flows.flow-starts"),className:"main_ui_workspace_sidebar_options_menus_interactions__title-bar"})}),$APP.$cljs$core$truth_$$($show_content_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$174$$,$flow$jscomp$9_p__79303$$){var $id$jscomp$970$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flow$jscomp$9_p__79303$$,0,null);$flow$jscomp$9_p__79303$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($flow$jscomp$9_p__79303$$,1,null);$out_arr__44092__auto__$jscomp$174$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$flow_item_STAR_$$,{flow:$flow$jscomp$9_p__79303$$},$id$jscomp$970$$));return $out_arr__44092__auto__$jscomp$174$$},[],$flows$jscomp$8_props_79293$$)}):null]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$shape_flows_STAR_$$=function($props_79308_show_content_QMARK_$jscomp$2$$){var $flow$jscomp$10_flows$jscomp$9$$=$props_79308_show_content_QMARK_$jscomp$2$$.flows,$shape$jscomp$1011_toggle_content$jscomp$3$$=$props_79308_show_content_QMARK_$jscomp$2$$.shape,$show_content_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$props_79308_show_content_QMARK_$jscomp$2$$=$APP.$cljs$core$_deref$$($show_content_STAR_$jscomp$1$$);
$flow$jscomp$10_flows$jscomp$9$$=$APP.$app$common$types$page$get_frame_flow$$($flow$jscomp$10_flows$jscomp$9$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1011_toggle_content$jscomp$3$$));$shape$jscomp$1011_toggle_content$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_content_STAR_$jscomp$1$$,$APP.$cljs$core$not$$)});var $add_flow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$add_flow_selected_frame$$())});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$flow$jscomp$10_flows$jscomp$9$$!=null,collapsed:$APP.$cljs$core$not$$($props_79308_show_content_QMARK_$jscomp$2$$),onCollapsed:$shape$jscomp$1011_toggle_content$jscomp$3$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.flows.flow"),className:"main_ui_workspace_sidebar_options_menus_interactions__title-bar",children:$flow$jscomp$10_flows$jscomp$9$$==null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.flows.add-flow-start"),onClick:$add_flow$$,icon:"add"}):null})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($props_79308_show_content_QMARK_$jscomp$2$$)?
$flow$jscomp$10_flows$jscomp$9$$!=null:$props_79308_show_content_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$flow_item_STAR_$$,{flow:$flow$jscomp$10_flows$jscomp$9$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$10_flows$jscomp$9$$))}):null]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$interactions_STAR_$$=function($props_79321_show_content_QMARK_$jscomp$3$$){var $interactions$jscomp$23$$=$props_79321_show_content_QMARK_$jscomp$3$$.interactions,$shape$jscomp$1012$$=$props_79321_show_content_QMARK_$jscomp$3$$.shape,$show_content_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$props_79321_show_content_QMARK_$jscomp$3$$=$APP.$cljs$core$_deref$$($show_content_STAR_$jscomp$2$$);var $toggle_content$jscomp$4$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_content_STAR_$jscomp$2$$,$APP.$cljs$core$not$$)}),$add_interaction$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1012$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$add_new_interaction$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1012$$,
null))}),$remove_interaction$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1012$$)],function($index$jscomp$487$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$remove_interaction$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$1012$$,$index$jscomp$487$$))}),$update_interaction$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1012$$)],
function($index$jscomp$488$$,$update_fn$jscomp$52$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$interactions$update_interaction$cljs$0core$0IFn$0_invoke$0arity$04$$($shape$jscomp$1012$$,$index$jscomp$488$$,$update_fn$jscomp$52$$,null))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__title",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$APP.$cljs$core$count$$($interactions$jscomp$23$$)>0,collapsed:$APP.$cljs$core$not$$($props_79321_show_content_QMARK_$jscomp$3$$),onCollapsed:$toggle_content$jscomp$4$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interactions"),className:"main_ui_workspace_sidebar_options_menus_interactions__title-bar",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.interactions.add-interaction"),onClick:$add_interaction$$,icon:"add"})})}),$APP.$cljs$core$truth_$$($props_79321_show_content_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__content main_ui_workspace_sidebar_options_menus_interactions__content-interactions",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$175$$,
$interaction$jscomp$53_p__79327$$){var $index$jscomp$489$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($interaction$jscomp$53_p__79327$$,0,null);$interaction$jscomp$53_p__79327$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($interaction$jscomp$53_p__79327$$,1,null);$out_arr__44092__auto__$jscomp$175$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$interaction_item_STAR_$$,{index:$index$jscomp$489$$,shape:$shape$jscomp$1012$$,interaction:$interaction$jscomp$53_p__79327$$,
updateInteraction:$update_interaction$jscomp$1$$,removeInteraction:$remove_interaction$jscomp$1$$},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1012$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$489$$)].join("")));return $out_arr__44092__auto__$jscomp$175$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($interactions$jscomp$23$$))}):null]})};
$app$main$ui$workspace$sidebar$options$menus$interactions$interactions_menu_STAR_$$=function($props_79335_shape$jscomp$1013$$){$props_79335_shape$jscomp$1013$$=$props_79335_shape$jscomp$1013$$.shape;var $interactions$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($props_79335_shape$jscomp$1013$$,$APP.$cljs$cst$2059$interactions$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$flows$jscomp$10$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_flows$$),$framed_shape_QMARK_$$=
$APP.$cljs$core$truth_$$($props_79335_shape$jscomp$1013$$)?!$app$common$files$helpers$unframed_shape_QMARK_$$($props_79335_shape$jscomp$1013$$):$props_79335_shape$jscomp$1013$$;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__wrapper",children:[$APP.$cljs$core$truth_$$($props_79335_shape$jscomp$1013$$)?$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($props_79335_shape$jscomp$1013$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$shape_flows_STAR_$$,
{flows:$flows$jscomp$10$$,shape:$props_79335_shape$jscomp$1013$$}):null:$APP.$cljs$core$truth_$$($flows$jscomp$10$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$page_flows_STAR_$$,{flows:$flows$jscomp$10$$}):null,$APP.$cljs$core$truth_$$($framed_shape_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$interactions_STAR_$$,{interactions:$interactions$jscomp$24$$,shape:$props_79335_shape$jscomp$1013$$}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($interactions$jscomp$24$$),
0)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__section",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__content",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_interactions__empty",children:[$APP.$cljs$core$truth_$$($framed_shape_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"add",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.add-interaction")}):
null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"interaction",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.select-a-shape")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"play",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.use-play-button")})]})})}):null]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$=function($G__79189__$1_val$jscomp$213$$){$G__79189__$1_val$jscomp$213$$=$G__79189__$1_val$jscomp$213$$ instanceof $APP.$cljs$core$Keyword$$?$G__79189__$1_val$jscomp$213$$.$fqn$:null;switch($G__79189__$1_val$jscomp$213$$){case "row":return"grid-row";case "row-reverse":return"row-reverse";case "column":return"column";case "column-reverse":return"column-reverse";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79189__$1_val$jscomp$213$$)].join(""));
}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$=function($G__79191__$1_type$jscomp$630$$,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$,$column_QMARK_$$){$G__79191__$1_type$jscomp$630$$=$G__79191__$1_type$jscomp$630$$ instanceof $APP.$cljs$core$Keyword$$?$G__79191__$1_type$jscomp$630$$.$fqn$:null;switch($G__79191__$1_type$jscomp$630$$){case "align-items":if($column_QMARK_$$)switch($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$=$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$ instanceof
$APP.$cljs$core$Keyword$$?$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$.$fqn$:null,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$){case "start":return"align-items-column-start";case "end":return"align-items-column-end";case "center":return"align-items-column-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$)].join(""));
}else switch($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$=$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$ instanceof $APP.$cljs$core$Keyword$$?$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$.$fqn$:null,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$){case "start":return"align-items-row-start";
case "end":return"align-items-row-end";case "center":return"align-items-row-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$)].join(""));}break;case "justify-content":if($column_QMARK_$$)switch($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$=$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$ instanceof
$APP.$cljs$core$Keyword$$?$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$.$fqn$:null,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$){case "start":return"justify-content-column-start";case "end":return"justify-content-column-end";case "center":return"justify-content-column-center";case "space-around":return"justify-content-column-around";case "space-evenly":return"justify-content-column-evenly";
case "space-between":return"justify-content-column-between";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$)].join(""));}else switch($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$=$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$ instanceof
$APP.$cljs$core$Keyword$$?$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$.$fqn$:null,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$){case "start":return"justify-content-row-start";case "end":return"justify-content-row-end";case "center":return"justify-content-row-center";case "space-around":return"justify-content-row-around";case "space-evenly":return"justify-content-row-evenly";
case "space-between":return"justify-content-row-between";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$)].join(""));}break;case "align-content":if($column_QMARK_$$)switch($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$=$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$ instanceof
$APP.$cljs$core$Keyword$$?$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$.$fqn$:null,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$){case "start":return"align-content-column-start";case "end":return"align-content-column-end";case "center":return"align-content-column-center";case "space-around":return"align-content-column-around";case "space-evenly":return"align-content-column-evenly";
case "space-between":return"align-content-column-between";case "stretch":return null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$)].join(""));}else switch($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$=$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$ instanceof
$APP.$cljs$core$Keyword$$?$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$.$fqn$:null,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$){case "start":return"align-content-row-start";case "end":return"align-content-row-end";case "center":return"align-content-row-center";case "space-around":return"align-content-row-around";case "space-evenly":return"align-content-row-evenly";
case "space-between":return"align-content-row-between";case "stretch":return null;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$)].join(""));}break;case "align-self":if($column_QMARK_$$)switch($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$=$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$ instanceof
$APP.$cljs$core$Keyword$$?$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$.$fqn$:null,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$){case "auto":return"remove";case "start":return"align-self-row-left";case "end":return"align-self-row-right";case "center":return"align-self-row-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$)].join(""));
}else switch($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$=$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$ instanceof $APP.$cljs$core$Keyword$$?$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$.$fqn$:null,$G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$){case "auto":return"remove";
case "start":return"align-self-column-top";case "end":return"align-self-column-bottom";case "center":return"align-self-column-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79192__$1_G__79193__$1_G__79194__$1_G__79195__$1_G__79198__$1_G__79200__$1_G__79201__$1_G__79202__$1_val$jscomp$214$$)].join(""));}break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79191__$1_type$jscomp$630$$)].join(""));
}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$=function($G__79207__$1_type$jscomp$631$$,$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$,$column_QMARK_$jscomp$1$$){$G__79207__$1_type$jscomp$631$$=$G__79207__$1_type$jscomp$631$$ instanceof $APP.$cljs$core$Keyword$$?$G__79207__$1_type$jscomp$631$$.$fqn$:null;switch($G__79207__$1_type$jscomp$631$$){case "align-items":if($column_QMARK_$jscomp$1$$)switch($G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$=$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$ instanceof
$APP.$cljs$core$Keyword$$?$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$.$fqn$:null,$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$){case "auto":return"remove";case "start":return"align-self-row-left";case "end":return"align-self-row-right";case "center":return"align-self-row-center";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$)].join(""));
}else switch($G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$=$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$ instanceof $APP.$cljs$core$Keyword$$?$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$.$fqn$:null,$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$){case "auto":return"remove";case "start":return"align-self-column-top";case "end":return"align-self-column-bottom";case "center":return"align-self-column-center";
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$)].join(""));}break;case "justify-items":if($column_QMARK_$jscomp$1$$)switch($G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$=$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$ instanceof $APP.$cljs$core$Keyword$$?$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$.$fqn$:null,
$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$){case "start":return"align-content-row-start";case "center":return"align-content-row-center";case "end":return"align-content-row-end";case "space-around":return"align-content-row-around";case "space-between":return"align-content-row-between";case "stretch":return"align-content-row-stretch";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$)].join(""));
}else switch($G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$=$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$ instanceof $APP.$cljs$core$Keyword$$?$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$.$fqn$:null,$G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$){case "start":return"align-content-column-start";case "center":return"align-content-column-center";case "end":return"align-content-column-end";case "space-around":return"align-content-column-around";
case "space-between":return"align-content-column-between";case "stretch":return"align-content-column-stretch";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79208__$1_G__79209__$1_G__79210__$1_G__79211__$1_val$jscomp$215$$)].join(""));}break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79207__$1_type$jscomp$631$$)].join(""));}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_flex$$=function($props_79212$$){var $on_change$jscomp$59$$=$props_79212$$["on-change"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__direction-row-flex",selected:$APP.$app$common$data$name$$($props_79212$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$59$$,name:"flex-direction",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"row",id:"flex-direction-row",title:"Row",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$1661$row$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"row-reverse",id:"flex-direction-row-reverse",title:"Row reverse",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$1666$row_reverse$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"column",id:"flex-direction-column",title:"Column",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$216$column$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"column-reverse",id:"flex-direction-column-reverse",title:"Column reverse",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$1667$column_reverse$$)})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$wrap_row$$=function($props_79213_wrap_type$jscomp$2$$){var $on_click$jscomp$47$$=$props_79213_wrap_type$jscomp$2$$["on-click"];$props_79213_wrap_type$jscomp$2$$=$props_79213_wrap_type$jscomp$2$$["wrap-type"];return(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$896$wrap$$,$props_79213_wrap_type$jscomp$2$$)?"No wrap":"Wrap",onClick:$on_click$jscomp$47$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__wrap-button "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79213_wrap_type$jscomp$2$$,$APP.$cljs$cst$896$wrap$$)?"main_ui_workspace_sidebar_options_menus_layout_container__selected":""),children:$APP.$app$main$ui$icons$wrap$$})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$align_row$$=function($props_79216$$){var $on_change$jscomp$60$$=$props_79216$$["on-change"],$is_column$$=$props_79216$$["is-column"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__align-row",selected:$APP.$app$common$data$name$$($props_79216$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$60$$,name:"flex-align-items",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4152$align_items$$,$APP.$cljs$cst$1297$start$$,$is_column$$),title:"Align items start",id:"align-items-start"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4152$align_items$$,
$APP.$cljs$cst$1672$center$$,$is_column$$),title:"Align items center",id:"align-items-center"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4152$align_items$$,$APP.$cljs$cst$1298$end$$,$is_column$$),title:"Align items end",id:"align-items-end"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$align_content_row$$=function($props_79221$$){var $on_change$jscomp$61$$=$props_79221$$["on-change"],$is_column$jscomp$1$$=$props_79221$$["is-column"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__align-content-row",selected:$APP.$app$common$data$name$$($props_79221$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$61$$,
name:"flex-align-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4153$align_content$$,$APP.$cljs$cst$1297$start$$,$is_column$jscomp$1$$),title:"Align content start",id:"align-content-start"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4153$align_content$$,
$APP.$cljs$cst$1672$center$$,$is_column$jscomp$1$$),title:"Align content center",id:"align-content-center"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4153$align_content$$,$APP.$cljs$cst$1298$end$$,$is_column$jscomp$1$$),title:"Align content end",id:"align-content-end"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"space-between",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4153$align_content$$,$APP.$cljs$cst$1673$space_between$$,$is_column$jscomp$1$$),title:"Align content space-between",id:"align-content-space-between"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-around",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4153$align_content$$,
$APP.$cljs$cst$1670$space_around$$,$is_column$jscomp$1$$),title:"Align content space-around",id:"align-content-space-around"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-evenly",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4153$align_content$$,$APP.$cljs$cst$1671$space_evenly$$,$is_column$jscomp$1$$),title:"Align content space-evenly",id:"align-content-space-evenly"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$justify_content_row$$=function($props_79226$$){var $on_change$jscomp$62$$=$props_79226$$["on-change"],$is_column$jscomp$2$$=$props_79226$$["is-column"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__justify-content-row",selected:$APP.$app$common$data$name$$($props_79226$$["justify-content"]),"on-change":$on_change$jscomp$62$$,name:"flex-justify",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4155$justify_content$$,$APP.$cljs$cst$1297$start$$,$is_column$jscomp$2$$),title:"Justify content start",id:"justify-content-start"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4155$justify_content$$,
$APP.$cljs$cst$1672$center$$,$is_column$jscomp$2$$),title:"Justify content center",id:"justify-content-center"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4155$justify_content$$,$APP.$cljs$cst$1298$end$$,$is_column$jscomp$2$$),title:"Justify content end",id:"justify-content-end"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"space-between",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4155$justify_content$$,$APP.$cljs$cst$1673$space_between$$,$is_column$jscomp$2$$),title:"Justify content space-between",id:"justify-content-space-between"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-around",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4155$justify_content$$,
$APP.$cljs$cst$1670$space_around$$,$is_column$jscomp$2$$),title:"Justify content space-around",id:"justify-content-space-around"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-evenly",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$4155$justify_content$$,$APP.$cljs$cst$1671$space_evenly$$,$is_column$jscomp$2$$),title:"Justify content space-evenly",id:"justify-content-space-evenly"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$=function(){return $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$(!1,!1,!1,!1)};
$app$main$ui$workspace$sidebar$options$menus$layout_container$simple_padding_selection_STAR_$$=function($props_79240_token_numeric_inputs$jscomp$2$$){var $on_change$jscomp$63$$=$props_79240_token_numeric_inputs$jscomp$2$$.onChange,$p2__$1$jscomp$2_value$jscomp$868$$=$props_79240_token_numeric_inputs$jscomp$2$$.value,$ids$jscomp$289$$=$props_79240_token_numeric_inputs$jscomp$2$$.ids,$applied_to_p1__$1_applied_tokens$jscomp$8$$=$props_79240_token_numeric_inputs$jscomp$2$$.appliedTokens;$props_79240_token_numeric_inputs$jscomp$2$$=
$APP.$app$main$features$use_feature$$("tokens/numeric-input");var $p1$jscomp$84_p1__$1$jscomp$4$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($p2__$1$jscomp$2_value$jscomp$868$$),$applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($p2__$1$jscomp$2_value$jscomp$868$$),$applied_to_p3_on_focus_p1_p3$jscomp$24$$=$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($p2__$1$jscomp$2_value$jscomp$868$$),$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$=
$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($p2__$1$jscomp$2_value$jscomp$868$$);$p1$jscomp$84_p1__$1$jscomp$4$$=!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$p2__$1$jscomp$2_value$jscomp$868$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1$jscomp$84_p1__$1$jscomp$4$$,$applied_to_p3_on_focus_p1_p3$jscomp$24$$)?$p1$jscomp$84_p1__$1$jscomp$4$$:null;$p2__$1$jscomp$2_value$jscomp$868$$=!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$p2__$1$jscomp$2_value$jscomp$868$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$,$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$)?$applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$:null;$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p1__$1_applied_tokens$jscomp$8$$);$applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p1__$1_applied_tokens$jscomp$8$$);
$applied_to_p3_on_focus_p1_p3$jscomp$24$$=$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p1__$1_applied_tokens$jscomp$8$$);var $applied_to_p4_on_focus_p2$$=$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p1__$1_applied_tokens$jscomp$8$$);$applied_to_p1__$1_applied_tokens$jscomp$8$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$,$applied_to_p3_on_focus_p1_p3$jscomp$24$$)?$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$:
null;$applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$,$applied_to_p4_on_focus_p2$$)?$applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$:null;var $on_change_SINGLEQUOTE_$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$63$$),$APP.$rumext$v2$adapt$$($ids$jscomp$289$$)],function($value__$1$jscomp$53$$,$attr$jscomp$74$$,$event$jscomp$540$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$53$$,
function($p1__79233_SHARP_$$){return $on_change$jscomp$63$$.$cljs$core$IFn$_invoke$arity$4$?$on_change$jscomp$63$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$1668$simple$$,$attr$jscomp$74$$,$p1__79233_SHARP_$$,$event$jscomp$540$$):$on_change$jscomp$63$$($APP.$cljs$cst$1668$simple$$,$attr$jscomp$74$$,$p1__79233_SHARP_$$,$event$jscomp$540$$)},$ids$jscomp$289$$,$attr$jscomp$74$$)});$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$289$$)],
function($token_name$jscomp$22$$,$attr$jscomp$75$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$22$$,$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$75$$]),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$289$$],null)))});var $on_focus$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$)],
function($G__79245_79406__$1_attr$jscomp$76$$,$event$jscomp$541$$){$G__79245_79406__$1_attr$jscomp$76$$=$G__79245_79406__$1_attr$jscomp$76$$ instanceof $APP.$cljs$core$Keyword$$?$G__79245_79406__$1_attr$jscomp$76$$.$fqn$:null;switch($G__79245_79406__$1_attr$jscomp$76$$){case "p1":$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$(!0,!1,!0,!1);break;case "p2":$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$(!1,
!0,!1,!0);break;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79245_79406__$1_attr$jscomp$76$$)].join(""));}return $app$util$dom$select_target$$($event$jscomp$541$$)});$applied_to_p3_on_focus_p1_p3$jscomp$24$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$12$$)],function(){return $on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1093$p1$$):
$on_focus$jscomp$12$$($APP.$cljs$cst$1093$p1$$)});$applied_to_p4_on_focus_p2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$12$$)],function(){return $on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$12$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1091$p2$$):$on_focus$jscomp$12$$($APP.$cljs$cst$1091$p2$$)});var $on_p1_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$5$$)],
function($p1__79236_SHARP_$$){var $G__79247$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1692$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null);return $on_change_SINGLEQUOTE_$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($p1__79236_SHARP_$$,$G__79247$$):$on_change_SINGLEQUOTE_$jscomp$5$$($p1__79236_SHARP_$$,$G__79247$$)}),$on_p2_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$5$$)],
function($p1__79237_SHARP_$$){var $G__79249$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1693$p4$$,null],null),null);return $on_change_SINGLEQUOTE_$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($p1__79237_SHARP_$$,$G__79249$$):$on_change_SINGLEQUOTE_$jscomp$5$$($p1__79237_SHARP_$$,$G__79249$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__paddings-simple",
children:[$props_79240_token_numeric_inputs$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_p1_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$applied_to_p1__$1_applied_tokens$jscomp$8$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$p1$jscomp$84_p1__$1$jscomp$4$$)||$p1$jscomp$84_p1__$1$jscomp$4$$==
null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",inputType:$APP.$cljs$cst$2001$vertical_padding$$,attr:$APP.$cljs$cst$1093$p1$$,appliedToken:$applied_to_p1__$1_applied_tokens$jscomp$8$$,value:$p1$jscomp$84_p1__$1$jscomp$4$$,onFocus:$applied_to_p3_on_focus_p1_p3$jscomp$24$$,onDetach:$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.vertical"),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,
nillable:!0,icon:"padding-top-bottom"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.vertical"),className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-simple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_top_bottom$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{min:0,onChange:$on_p1_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.vertical"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),value:$p1$jscomp$84_p1__$1$jscomp$4$$,onFocus:$applied_to_p3_on_focus_p1_p3$jscomp$24$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,nillable:!0})]}),
$props_79240_token_numeric_inputs$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_p2_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$p2__$1$jscomp$2_value$jscomp$868$$)||
$p2__$1$jscomp$2_value$jscomp$868$$==null?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",inputType:$APP.$cljs$cst$2007$horizontal_padding$$,attr:$APP.$cljs$cst$1091$p2$$,appliedToken:$applied_to_p2_applied_to_p2__$1_p2$jscomp$65$$,value:$p2__$1$jscomp$2_value$jscomp$868$$,onFocus:$applied_to_p4_on_focus_p2$$,onDetach:$applied_to_p1_on_detach_token$jscomp$4_p4$jscomp$9$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.horizontal"),
onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,nillable:!0,icon:"padding-left-right"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.horizontal"),className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-simple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_left_right$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p2_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.horizontal"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),value:$p2__$1$jscomp$2_value$jscomp$868$$,onFocus:$applied_to_p4_on_focus_p2$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,
nillable:!0})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$multiple_padding_selection_STAR_$$=function($props_79266_token_numeric_inputs$jscomp$3$$){var $on_change$jscomp$64$$=$props_79266_token_numeric_inputs$jscomp$3$$.onChange,$p4$jscomp$10_value$jscomp$869$$=$props_79266_token_numeric_inputs$jscomp$3$$.value,$ids$jscomp$290$$=$props_79266_token_numeric_inputs$jscomp$3$$.ids,$applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$=$props_79266_token_numeric_inputs$jscomp$3$$.appliedTokens;$props_79266_token_numeric_inputs$jscomp$3$$=
$APP.$app$main$features$use_feature$$("tokens/numeric-input");var $p1$jscomp$85$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($p4$jscomp$10_value$jscomp$869$$),$p2$jscomp$66$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($p4$jscomp$10_value$jscomp$869$$),$p3$jscomp$25$$=$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($p4$jscomp$10_value$jscomp$869$$);$p4$jscomp$10_value$jscomp$869$$=$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($p4$jscomp$10_value$jscomp$869$$);
var $applied_to_p1$jscomp$1$$=$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$),$applied_to_p2$jscomp$1$$=$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$),$applied_to_p3$jscomp$1$$=$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$);$applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$=$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$);
var $on_change_SINGLEQUOTE_$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$64$$),$APP.$rumext$v2$adapt$$($ids$jscomp$290$$)],function($value__$1$jscomp$54$$,$attr$jscomp$77$$,$event$jscomp$542$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$54$$,function($p1__79258_SHARP_$$){return $on_change$jscomp$64$$.$cljs$core$IFn$_invoke$arity$4$?$on_change$jscomp$64$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$cst$1621$multiple$$,
$attr$jscomp$77$$,$p1__79258_SHARP_$$,$event$jscomp$542$$):$on_change$jscomp$64$$($APP.$cljs$cst$1621$multiple$$,$attr$jscomp$77$$,$p1__79258_SHARP_$$,$event$jscomp$542$$)},$ids$jscomp$290$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$77$$]))}),$on_focus$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$)],function($attr$jscomp$78$$,$event$jscomp$543$$){$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$78$$);
return $app$util$dom$select_target$$($event$jscomp$543$$)}),$on_detach_token$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$290$$)],function($token$jscomp$138$$,$attr$jscomp$79$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token$jscomp$138$$,$APP.$cljs$cst$2009$attributes$$,
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$79$$]),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$290$$],null)))}),$on_p1_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$6$$)],function($p1__79259_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__79259_SHARP_$$,$APP.$cljs$cst$1093$p1$$):$on_change_SINGLEQUOTE_$jscomp$6$$($p1__79259_SHARP_$$,
$APP.$cljs$cst$1093$p1$$)}),$on_p2_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$6$$)],function($p1__79260_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__79260_SHARP_$$,$APP.$cljs$cst$1091$p2$$):$on_change_SINGLEQUOTE_$jscomp$6$$($p1__79260_SHARP_$$,$APP.$cljs$cst$1091$p2$$)}),$on_p3_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$6$$)],
function($p1__79261_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__79261_SHARP_$$,$APP.$cljs$cst$1692$p3$$):$on_change_SINGLEQUOTE_$jscomp$6$$($p1__79261_SHARP_$$,$APP.$cljs$cst$1692$p3$$)}),$on_p4_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$6$$)],function($p1__79262_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_SINGLEQUOTE_$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__79262_SHARP_$$,$APP.$cljs$cst$1693$p4$$):$on_change_SINGLEQUOTE_$jscomp$6$$($p1__79262_SHARP_$$,$APP.$cljs$cst$1693$p4$$)}),$on_focus_p1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$13$$)],function(){return $on_focus$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1093$p1$$):$on_focus$jscomp$13$$($APP.$cljs$cst$1093$p1$$)}),
$on_focus_p2$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$13$$)],function(){return $on_focus$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1091$p2$$):$on_focus$jscomp$13$$($APP.$cljs$cst$1091$p2$$)}),$on_focus_p3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$13$$)],function(){return $on_focus$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$?
$on_focus$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1692$p3$$):$on_focus$jscomp$13$$($APP.$cljs$cst$1692$p3$$)}),$on_focus_p4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$13$$)],function(){return $on_focus$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$13$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1693$p4$$):$on_focus$jscomp$13$$($APP.$cljs$cst$1693$p4$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__paddings-multiple",
children:[$props_79266_token_numeric_inputs$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_p1_change$jscomp$1$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$applied_to_p1$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$p1$jscomp$85$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",inputType:$APP.$cljs$cst$2001$vertical_padding$$,attr:$APP.$cljs$cst$1093$p1$$,appliedToken:$applied_to_p1$jscomp$1$$,value:$p1$jscomp$85$$,onFocus:$on_focus_p1$jscomp$1$$,onDetach:$on_detach_token$jscomp$5$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.top"),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,icon:"padding-top"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.top"),
className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_top$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p1_change$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.top"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",
placeholder:"--",value:$p1$jscomp$85$$,onFocus:$on_focus_p1$jscomp$1$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,"data-attr":"p1"})]}),$props_79266_token_numeric_inputs$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_p2_change$jscomp$1$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$applied_to_p2$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$p2$jscomp$66$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",inputType:$APP.$cljs$cst$2007$horizontal_padding$$,attr:$APP.$cljs$cst$1091$p2$$,appliedToken:$applied_to_p2$jscomp$1$$,value:$p2$jscomp$66$$,onFocus:$on_focus_p2$jscomp$1$$,onDetach:$on_detach_token$jscomp$5$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.right"),
onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,icon:"padding-right"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.right"),className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_right$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p2_change$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.right"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:"--",value:$p2$jscomp$66$$,onFocus:$on_focus_p2$jscomp$1$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,"data-attr":"p2"})]}),
$props_79266_token_numeric_inputs$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_p3_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$applied_to_p3$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$p3$jscomp$25$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",inputType:$APP.$cljs$cst$2001$vertical_padding$$,attr:$APP.$cljs$cst$1692$p3$$,appliedToken:$applied_to_p3$jscomp$1$$,value:$p3$jscomp$25$$,onFocus:$on_focus_p3$$,onDetach:$on_detach_token$jscomp$5$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.bottom"),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,icon:"padding-bottom"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.bottom"),
className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_bottom$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p3_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.bottom"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",
placeholder:"--",value:$p3$jscomp$25$$,onFocus:$on_focus_p3$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,"data-attr":"p3"})]}),$props_79266_token_numeric_inputs$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_p4_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$p4$jscomp$10_value$jscomp$869$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",inputType:$APP.$cljs$cst$2007$horizontal_padding$$,attr:$APP.$cljs$cst$1693$p4$$,appliedToken:$applied_to_p4$jscomp$1_applied_tokens$jscomp$9$$,value:$p4$jscomp$10_value$jscomp$869$$,onFocus:$on_focus_p4$$,onDetach:$on_detach_token$jscomp$5$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.left"),
onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,icon:"padding-left"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.left"),className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$padding_left$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:0,onChange:$on_p4_change$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.left"),className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:"--",value:$p4$jscomp$10_value$jscomp$869$$,onFocus:$on_focus_p4$$,onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$,"data-attr":"p4"})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$=function($props_79267$$){var $type$jscomp$632$$=$props_79267$$.type,$on_type_change$jscomp$1$$=$props_79267$$.onTypeChange,$on_type_change_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_type_change$jscomp$1$$)],function($event$jscomp$544_type__$1$jscomp$15_type__$2$$){$event$jscomp$544_type__$1$jscomp$15_type__$2$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$544_type__$1$jscomp$15_type__$2$$),
"type");$event$jscomp$544_type__$1$jscomp$15_type__$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$544_type__$1$jscomp$15_type__$2$$,"multiple")?$APP.$cljs$cst$1668$simple$$:$APP.$cljs$cst$1621$multiple$$;return $on_type_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_type_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$544_type__$1$jscomp$15_type__$2$$):$on_type_change$jscomp$1$$($event$jscomp$544_type__$1$jscomp$15_type__$2$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return function(){return $app$main$ui$workspace$sidebar$options$menus$layout_container$on_padding_blur$$(null)}});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-group",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-inputs",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$632$$,$APP.$cljs$cst$1668$simple$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$simple_padding_selection_STAR_$$,
$props_79267$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$632$$,$APP.$cljs$cst$1621$multiple$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$multiple_padding_selection_STAR_$$,$props_79267$$):null}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.expand"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.padding.expand"),
"data-type":$APP.$app$common$data$name$$($type$jscomp$632$$),onClick:$on_type_change_SINGLEQUOTE_$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-toggle "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$632$$,$APP.$cljs$cst$1621$multiple$$)?"main_ui_workspace_sidebar_options_menus_layout_container__selected":""),children:$APP.$app$main$ui$icons$padding_extended$$})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_focus$$=function($type$jscomp$633$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_gap_selected$$($type$jscomp$633$$))};$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_gap_selected$$(null))};
$app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$=function($applied_tokens$jscomp$10_props_79279$$){var $on_change$jscomp$65$$=$applied_tokens$jscomp$10_props_79279$$.onChange,$col_gap_disabled_QMARK__is_column$jscomp$3$$=$applied_tokens$jscomp$10_props_79279$$.isColumn,$value$jscomp$871$$=$applied_tokens$jscomp$10_props_79279$$.value,$ids$jscomp$291$$=$applied_tokens$jscomp$10_props_79279$$.ids,$wrap_type$jscomp$3$$=$applied_tokens$jscomp$10_props_79279$$.wrapType;
$applied_tokens$jscomp$10_props_79279$$=$applied_tokens$jscomp$10_props_79279$$.appliedTokens;var $token_numeric_inputs$jscomp$4$$=$APP.$app$main$features$use_feature$$("tokens/numeric-input"),$nowrap_QMARK__on_detach_token$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1669$nowrap$$,$wrap_type$jscomp$3$$),$row_gap_disabled_QMARK_$$=$nowrap_QMARK__on_detach_token$jscomp$6$$&&!$col_gap_disabled_QMARK__is_column$jscomp$3$$;$col_gap_disabled_QMARK__is_column$jscomp$3$$=
$nowrap_QMARK__on_detach_token$jscomp$6$$&&$col_gap_disabled_QMARK__is_column$jscomp$3$$;var $on_change_SINGLEQUOTE_$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$65$$),$APP.$rumext$v2$adapt$$($wrap_type$jscomp$3$$),$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],function($value__$1$jscomp$55$$,$event$jscomp$545$$,$attr$jscomp$80$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$55$$,function($p1__79272_SHARP_$$){var $G__79282$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("nowrap",$wrap_type$jscomp$3$$);return $on_change$jscomp$65$$.$cljs$core$IFn$_invoke$arity$4$?$on_change$jscomp$65$$.$cljs$core$IFn$_invoke$arity$4$($G__79282$$,$attr$jscomp$80$$,$p1__79272_SHARP_$$,$event$jscomp$545$$):$on_change$jscomp$65$$($G__79282$$,$attr$jscomp$80$$,$p1__79272_SHARP_$$,$event$jscomp$545$$)},$ids$jscomp$291$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$80$$]))});$nowrap_QMARK__on_detach_token$jscomp$6$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$291$$)],function($token$jscomp$139$$,$attr$jscomp$81$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token$jscomp$139$$,$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$81$$]),
$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$291$$],null)))});var $on_row_gap_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$7$$)],function($p1__79274_SHARP_$$,$p2__79275_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_change_SINGLEQUOTE_$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__79274_SHARP_$$,$p2__79275_SHARP_$$,$APP.$cljs$cst$1686$row_gap$$):$on_change_SINGLEQUOTE_$jscomp$7$$($p1__79274_SHARP_$$,
$p2__79275_SHARP_$$,$APP.$cljs$cst$1686$row_gap$$)}),$on_column_gap_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$7$$)],function($p1__79276_SHARP_$$,$p2__79277_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_change_SINGLEQUOTE_$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__79276_SHARP_$$,$p2__79277_SHARP_$$,$APP.$cljs$cst$1687$column_gap$$):$on_change_SINGLEQUOTE_$jscomp$7$$($p1__79276_SHARP_$$,
$p2__79277_SHARP_$$,$APP.$cljs$cst$1687$column_gap$$)}),$on_focus_row_gap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_focus$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_gap_selected$$($APP.$cljs$cst$1686$row_gap$$))}),$on_focus_column_gap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_focus$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_gap_selected$$($APP.$cljs$cst$1687$column_gap$$))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$(null)}});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__gap-group",children:[$token_numeric_inputs$jscomp$4$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{values:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1686$row_gap$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$871$$)],null),min:0,onChange:$on_row_gap_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$10_props_79279$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$871$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$1686$row_gap$$,appliedToken:$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$10_props_79279$$),value:$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$871$$),onFocus:$on_focus_row_gap$$,
onDetach:$nowrap_QMARK__on_detach_token$jscomp$6$$,property:"Row gap",onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,nillable:!0,disabled:$row_gap_disabled_QMARK_$$,icon:"gap-vertical"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Row gap",className:"main_ui_workspace_sidebar_options_menus_layout_container__row-gap "+($row_gap_disabled_QMARK_$$?"main_ui_workspace_sidebar_options_menus_layout_container__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",
children:$APP.$app$main$ui$icons$gap_vertical$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,min:0,onChange:$on_row_gap_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:"--",value:$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$871$$),onFocus:$on_focus_row_gap$$,"data-wrap-type":$APP.$app$common$data$name$$($wrap_type$jscomp$3$$),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,
"data-type":"row-gap",nillable:!0,disabled:$row_gap_disabled_QMARK_$$})]}),$token_numeric_inputs$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_column_gap_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$10_props_79279$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$871$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$1687$column_gap$$,appliedToken:$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$10_props_79279$$),value:$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$871$$),
onFocus:$on_focus_column_gap$$,onDetach:$nowrap_QMARK__on_detach_token$jscomp$6$$,property:"Column gap",onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,nillable:!0,disabled:$col_gap_disabled_QMARK__is_column$jscomp$3$$,icon:"gap-horizontal"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Column gap",className:"main_ui_workspace_sidebar_options_menus_layout_container__column-gap "+($col_gap_disabled_QMARK__is_column$jscomp$3$$?"main_ui_workspace_sidebar_options_menus_layout_container__disabled":
""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_container__icon",children:$APP.$app$main$ui$icons$gap_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,min:0,onChange:$on_column_gap_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__numeric-input",placeholder:"--",value:$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$871$$),
onFocus:$on_focus_column_gap$$,"data-wrap-type":$APP.$app$common$data$name$$($wrap_type$jscomp$3$$),onBlur:$app$main$ui$workspace$sidebar$options$menus$layout_container$on_gap_blur$$,"data-type":"column-gap",nillable:!0,disabled:$col_gap_disabled_QMARK__is_column$jscomp$3$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_grid$$=function($props_79287$$){var $on_change$jscomp$66$$=$props_79287$$["on-change"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__direction-row-grid",selected:$APP.$app$common$data$name$$($props_79287$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$66$$,name:"grid-direction",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"row",id:"grid-direction-row",title:"Row",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$1661$row$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"column",id:"grid-direction-column",title:"Column",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$dir_icons_refactor$$($APP.$cljs$cst$216$column$$)})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_edit_mode$$=function($edition$jscomp$6_props_79288_toggle_edit_mode$jscomp$1$$){var $id$jscomp$971$$=$edition$jscomp$6_props_79288_toggle_edit_mode$jscomp$1$$.id;$edition$jscomp$6_props_79288_toggle_edit_mode$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$);var $active_QMARK_$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$971$$,$edition$jscomp$6_props_79288_toggle_edit_mode$jscomp$1$$);
$edition$jscomp$6_props_79288_toggle_edit_mode$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$971$$),$APP.$rumext$v2$adapt$$($edition$jscomp$6_props_79288_toggle_edit_mode$jscomp$1$$)],function(){return $active_QMARK_$jscomp$6$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2177$interrupt$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$start_edition_mode$$($id$jscomp$971$$))});
return(0,$APP.$rumext$v2$jsx$$)("button",{alt:"Grid edit mode",onClick:$edition$jscomp$6_props_79288_toggle_edit_mode$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__edit-mode-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.options.edit-grid")})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$=function($props_79296$$){var $on_change$jscomp$67$$=$props_79296$$["on-change"],$is_column$jscomp$4$$=$props_79296$$["is-column"],$type$jscomp$634$$=$is_column$jscomp$4$$?"column":"row";return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__align-grid-row",selected:$APP.$app$common$data$name$$($props_79296$$.value),"decode-fn":$APP.$cljs$core$keyword$$,
"on-change":$on_change$jscomp$67$$,name:"flex-align-items-"+($type$jscomp$634$$??""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4152$align_items$$,$APP.$cljs$cst$1297$start$$,$is_column$jscomp$4$$),title:"Align items start",id:"align-items-start-"+($type$jscomp$634$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4152$align_items$$,$APP.$cljs$cst$1672$center$$,$is_column$jscomp$4$$),title:"Align items center",id:"align-items-center-"+($type$jscomp$634$$??"")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4152$align_items$$,$APP.$cljs$cst$1298$end$$,
$is_column$jscomp$4$$),title:"Align items end",id:"align-items-end-"+($type$jscomp$634$$??"")})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$=function($props_79297$$){var $on_change$jscomp$68$$=$props_79297$$["on-change"],$is_column$jscomp$5$$=$props_79297$$["is-column"],$type$jscomp$635$$=$is_column$jscomp$5$$?"column":"row";return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__justify-grid-row",selected:$APP.$app$common$data$name$$($props_79297$$.value),
"on-change":$on_change$jscomp$68$$,"decode-fn":$APP.$cljs$core$keyword$$,name:"grid-justify-items-"+($type$jscomp$635$$??""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4154$justify_items$$,$APP.$cljs$cst$1297$start$$,$is_column$jscomp$5$$),title:"Justify items start",id:"justify-items-start-"+($type$jscomp$635$$??"")},"justify-item-start"),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4154$justify_items$$,$APP.$cljs$cst$1672$center$$,$is_column$jscomp$5$$),title:"Justify items center",id:"justify-items-center-"+($type$jscomp$635$$??"")},"justify-item-center"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4154$justify_items$$,
$APP.$cljs$cst$1298$end$$,$is_column$jscomp$5$$),title:"Justify items end",id:"justify-items-end-"+($type$jscomp$635$$??"")},"justify-item-end"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-around",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4154$justify_items$$,$APP.$cljs$cst$1670$space_around$$,$is_column$jscomp$5$$),title:"Justify items space-around",id:"justify-items-space-around-"+($type$jscomp$635$$??
"")},"justify-item-space-around"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"space-between",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4154$justify_items$$,$APP.$cljs$cst$1673$space_between$$,$is_column$jscomp$5$$),title:"Justify items space-between",id:"justify-items-space-between-"+($type$jscomp$635$$??"")},"justify-item-space-between"),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"stretch",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_grid_icon$$($APP.$cljs$cst$4154$justify_items$$,$APP.$cljs$cst$1674$stretch$$,$is_column$jscomp$5$$),title:"Justify items stretch",id:"justify-items-stretch-"+($type$jscomp$635$$??"")},"justify-item-stretch")]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$manage_values$$=function($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$){$map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$=$APP.$cljs$core$__destructure_map$$($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$);var $map__51993__$1$jscomp$inline_13833_precision$jscomp$inline_13834_type$jscomp$636$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$,
$APP.$cljs$cst$139$type$$);$map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$,$APP.$cljs$cst$260$value$$);switch($map__51993__$1$jscomp$inline_13833_precision$jscomp$inline_13834_type$jscomp$636$$ instanceof $APP.$cljs$core$Keyword$$?$map__51993__$1$jscomp$inline_13833_precision$jscomp$inline_13834_type$jscomp$636$$.$fqn$:null){case "auto":return"auto";
case "percent":return $APP.$app$main$ui$formats$format_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$/100,null);case "flex":return $map__51993__$1$jscomp$inline_13833_precision$jscomp$inline_13834_type$jscomp$636$$=$APP.$cljs$core$__destructure_map$$(null),$map__51993__$1$jscomp$inline_13833_precision$jscomp$inline_13834_type$jscomp$636$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__51993__$1$jscomp$inline_13833_precision$jscomp$inline_13834_type$jscomp$636$$,
$APP.$cljs$cst$267$precision$$,2),$map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$=typeof $map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$==="string"?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$):$map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$,$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$))?
""+($APP.$app$common$math$precision$$($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$,$map__51993__$1$jscomp$inline_13833_precision$jscomp$inline_13834_type$jscomp$636$$)??"")+"fr":null;case "fixed":return $APP.$app$main$ui$formats$format_pixels$$.$cljs$core$IFn$_invoke$arity$1$($map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$);default:return $map__79302__$1_p__79301_value$jscomp$875_value__$1$jscomp$inline_13835$$}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_track_info$$=function($pointer_enter_props_79313$$){var $remove_element$$=$pointer_enter_props_79313$$["remove-element"],$set_column_type$$=$pointer_enter_props_79313$$["set-column-type"],$on_select_track$$=$pointer_enter_props_79313$$["on-select-track"],$is_column$jscomp$6$$=$pointer_enter_props_79313$$["is-column"],$index$jscomp$490$$=$pointer_enter_props_79313$$.index,$hover_track$$=$pointer_enter_props_79313$$["hover-track"],$type$jscomp$637$$=
$pointer_enter_props_79313$$.type,$set_column_value$$=$pointer_enter_props_79313$$["set-column-value"],$column$jscomp$43$$=$pointer_enter_props_79313$$.column,$reorder_track$$=$pointer_enter_props_79313$$["reorder-track"],$dprops$jscomp$5_drop_track$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$637$$),$APP.$rumext$v2$adapt$$($reorder_track$$),$APP.$rumext$v2$adapt$$($index$jscomp$490$$)],function($G__79319_drop_position$$,$G__79318_data$jscomp$485$$,
$G__79320_event$jscomp$546$$){$G__79318_data$jscomp$485$$=$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($G__79318_data$jscomp$485$$);$G__79319_drop_position$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1567$top$$,$G__79319_drop_position$$)?$index$jscomp$490$$-1:$index$jscomp$490$$;$G__79320_event$jscomp$546$$=!$APP.$app$util$keyboard$mod_QMARK_$$($G__79320_event$jscomp$546$$);return $reorder_track$$.$cljs$core$IFn$_invoke$arity$4$?$reorder_track$$.$cljs$core$IFn$_invoke$arity$4$($type$jscomp$637$$,
$G__79318_data$jscomp$485$$,$G__79319_drop_position$$,$G__79320_event$jscomp$546$$):$reorder_track$$($type$jscomp$637$$,$G__79318_data$jscomp$485$$,$G__79319_drop_position$$,$G__79320_event$jscomp$546$$)});$pointer_enter_props_79313$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$637$$),$APP.$rumext$v2$adapt$$($hover_track$$),$APP.$rumext$v2$adapt$$($index$jscomp$490$$)],function(){return $hover_track$$.$cljs$core$IFn$_invoke$arity$3$?$hover_track$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$637$$,
$index$jscomp$490$$,!0):$hover_track$$($type$jscomp$637$$,$index$jscomp$490$$,!0)});var $pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$637$$),$APP.$rumext$v2$adapt$$($hover_track$$),$APP.$rumext$v2$adapt$$($index$jscomp$490$$)],function(){return $hover_track$$.$cljs$core$IFn$_invoke$arity$3$?$hover_track$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$637$$,$index$jscomp$490$$,!1):$hover_track$$($type$jscomp$637$$,$index$jscomp$490$$,
!1)}),$handle_select_track$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_select_track$$),$APP.$rumext$v2$adapt$$($type$jscomp$637$$),$APP.$rumext$v2$adapt$$($index$jscomp$490$$)],function(){return $APP.$cljs$core$truth_$$($on_select_track$$)?$on_select_track$$.$cljs$core$IFn$_invoke$arity$2$?$on_select_track$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$637$$,$index$jscomp$490$$):$on_select_track$$($type$jscomp$637$$,$index$jscomp$490$$):null}),$dref$jscomp$5_vec__79314$$=
$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,"penpot/grid-track",$APP.$cljs$cst$2966$on_drop$$,$dprops$jscomp$5_drop_track$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5799$is_column$$,$is_column$jscomp$6$$,$APP.$cljs$cst$1801$index$$,$index$jscomp$490$$,$APP.$cljs$cst$216$column$$,$column$jscomp$43$$],null),$APP.$cljs$cst$2970$draggable_QMARK_$$,
!0]));$dprops$jscomp$5_drop_track$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$5_vec__79314$$,0,null);$dref$jscomp$5_vec__79314$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$5_vec__79314$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$dref$jscomp$5_vec__79314$$,onPointerEnter:$pointer_enter_props_79313$$,onPointerLeave:$pointer_leave$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$5_drop_track$$),
$APP.$cljs$cst$1567$top$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$5_drop_track$$),$APP.$cljs$cst$1672$center$$)?"main_ui_workspace_sidebar_options_menus_layout_container__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$5_drop_track$$),$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_sidebar_options_menus_layout_container__dnd-over-bot":
""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$handle_select_track$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info-dir-icon",children:$APP.$cljs$core$truth_$$($is_column$jscomp$6$$)?$APP.$app$main$ui$icons$flex_vertical$$:$APP.$app$main$ui$icons$flex_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info-value",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,value:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$43$$),onChange:function($p1__79311_SHARP_$$){return $set_column_value$$.$cljs$core$IFn$_invoke$arity$3$?$set_column_value$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$637$$,$index$jscomp$490$$,$p1__79311_SHARP_$$):$set_column_value$$($type$jscomp$637$$,$index$jscomp$490$$,$p1__79311_SHARP_$$)},placeholder:"--",
min:0,disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1677$auto$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$43$$))})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__track-info-unit",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_menus_layout_container__track-info-unit-selector","default-value":$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$43$$),
options:new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1665$flex$$,$APP.$cljs$cst$2296$label$$,"FR"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1677$auto$$,$APP.$cljs$cst$2296$label$$,"AUTO"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1676$fixed$$,$APP.$cljs$cst$2296$label$$,
"PX"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1675$percent$$,$APP.$cljs$cst$2296$label$$,"%"],null)],null),"on-change":function($p1__79312_SHARP_$$){return $set_column_type$$.$cljs$core$IFn$_invoke$arity$3$?$set_column_type$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$637$$,$index$jscomp$490$$,$p1__79312_SHARP_$$):$set_column_type$$($type$jscomp$637$$,$index$jscomp$490$$,$p1__79312_SHARP_$$)}})})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.delete"),onClick:$remove_element$$,"data-type":$type$jscomp$637$$,"data-index":$index$jscomp$490$$,icon:"remove"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_columns_row$$=function($column_num$jscomp$1_props_79322_track_name$$){var $remove_element$jscomp$1$$=$column_num$jscomp$1_props_79322_track_name$$["remove-element"],$set_column_type$jscomp$1$$=$column_num$jscomp$1_props_79322_track_name$$["set-column-type"],$column_values$$=$column_num$jscomp$1_props_79322_track_name$$["column-values"],$on_select_track$jscomp$1$$=$column_num$jscomp$1_props_79322_track_name$$["on-select-track"],$is_column$jscomp$7$$=
$column_num$jscomp$1_props_79322_track_name$$["is-column"],$expanded_QMARK_$jscomp$2$$=$column_num$jscomp$1_props_79322_track_name$$["expanded?"],$hover_track$jscomp$1$$=$column_num$jscomp$1_props_79322_track_name$$["hover-track"],$toggle$$=$column_num$jscomp$1_props_79322_track_name$$.toggle,$add_new_element$$=$column_num$jscomp$1_props_79322_track_name$$["add-new-element"],$set_column_value$jscomp$1$$=$column_num$jscomp$1_props_79322_track_name$$["set-column-value"],$reorder_track$jscomp$1$$=$column_num$jscomp$1_props_79322_track_name$$["reorder-track"];
$column_num$jscomp$1_props_79322_track_name$$=$APP.$cljs$core$count$$($column_values$$);$column_num$jscomp$1_props_79322_track_name$$=($column_num$jscomp$1_props_79322_track_name$$>1?$is_column$jscomp$7$$?"Columns ":"Rows ":$is_column$jscomp$7$$?"Column ":"Row ")+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($column_num$jscomp$1_props_79322_track_name$$,0)?" - empty":$column_num$jscomp$1_props_79322_track_name$$)??"");var $track_detail$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$options$menus$layout_container$manage_values$$,$column_values$$)),$type$jscomp$638$$=$APP.$cljs$core$truth_$$($is_column$jscomp$7$$)?$APP.$cljs$cst$216$column$$:$APP.$cljs$cst$1661$row$$;return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":$APP.$cljs$core$not$$($is_column$jscomp$7$$)?"inspect-layout-rows":null,className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-track-header",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__expand-icon",children:$APP.$app$main$ui$icons$menu$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$toggle$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__track-title",children:[(0,$APP.$rumext$v2$jsx$$)("div",{title:$column_num$jscomp$1_props_79322_track_name$$,
className:"main_ui_workspace_sidebar_options_menus_layout_container__track-name",children:$column_num$jscomp$1_props_79322_track_name$$}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$track_detail$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__track-detail",children:$track_detail$$})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){$APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$2$$)||($toggle$$.$cljs$core$IFn$_invoke$arity$0$?$toggle$$.$cljs$core$IFn$_invoke$arity$0$():
$toggle$$());return $add_new_element$$.$cljs$core$IFn$_invoke$arity$2$?$add_new_element$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$638$$,$APP.$app$common$types$shape$layout$default_track_value$$):$add_new_element$$($type$jscomp$638$$,$APP.$app$common$types$shape$layout$default_track_value$$)},className:"main_ui_workspace_sidebar_options_menus_layout_container__add-column",children:$APP.$app$main$ui$icons$add$$})]}),$APP.$cljs$core$truth_$$($expanded_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,
{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks-info-container",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$176$$,$column$jscomp$44_p__79323$$){var $index$jscomp$491$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$44_p__79323$$,0,null);$column$jscomp$44_p__79323$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column$jscomp$44_p__79323$$,
1,null);$out_arr__44092__auto__$jscomp$176$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_track_info$$,{"is-column":$is_column$jscomp$7$$,index:$index$jscomp$491$$,"hover-track":$hover_track$jscomp$1$$,type:$type$jscomp$638$$,"set-column-value":$set_column_value$jscomp$1$$,column:$column$jscomp$44_p__79323$$,"reorder-track":$reorder_track$jscomp$1$$,"remove-element":$remove_element$jscomp$1$$,"set-column-type":$set_column_type$jscomp$1$$,"on-select-track":$on_select_track$jscomp$1$$},
""+($index$jscomp$491$$??"")+"-"+($APP.$app$common$data$name$$($type$jscomp$638$$)??"")));return $out_arr__44092__auto__$jscomp$176$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($column_values$$))})}):null]})};$app$main$ui$workspace$sidebar$options$menus$layout_container$open_flex_help$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$config$flex_help_uri$$))};
$app$main$ui$workspace$sidebar$options$menus$layout_container$open_grid_help$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$config$grid_help_uri$$))};
$app$main$ui$workspace$sidebar$options$menus$blur$create_blur$$=function($type$jscomp$654$$){var $id$jscomp$972$$=$APP.$app$common$uuid$next$$();return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,$id$jscomp$972$$,$APP.$cljs$cst$139$type$$,$type$jscomp$654$$,$APP.$cljs$cst$260$value$$,4,$APP.$cljs$cst$1625$hidden$$,!1],null)};
$app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_content_STAR_$$=function($bg_blur_QMARK_$jscomp$2_props_79271$$){var $change_fn$jscomp$7$$=$bg_blur_QMARK_$jscomp$2_props_79271$$.changeFn,$blur_values_label_ref$$=$bg_blur_QMARK_$jscomp$2_props_79271$$.blurValues,$value$jscomp$890$$=$bg_blur_QMARK_$jscomp$2_props_79271$$.value,$blur_key$$=$bg_blur_QMARK_$jscomp$2_props_79271$$.blurKey;$bg_blur_QMARK_$jscomp$2_props_79271$$=$APP.$app$main$features$use_feature$$("render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1197$background_blur$$);var $is_hidden$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$890$$,$APP.$cljs$cst$1625$hidden$$),$show_more_options_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_more_options$$=$APP.$cljs$core$_deref$$($show_more_options_STAR_$$),$toggle_more_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_more_options_STAR_$$,
$APP.$cljs$core$not$$)}),$handle_delete$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_fn$jscomp$7$$),$APP.$rumext$v2$adapt$$($blur_key$$)],function(){function $G__79273$$($p1__79268_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__79268_SHARP_$$,$blur_key$$)}return $change_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$change_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($G__79273$$):$change_fn$jscomp$7$$($G__79273$$)}),
$handle_toggle_visibility$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_fn$jscomp$7$$),$APP.$rumext$v2$adapt$$($blur_key$$)],function(){function $G__79278$$($p1__79269_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($p1__79269_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$blur_key$$,$APP.$cljs$cst$1625$hidden$$],null),$APP.$cljs$core$not$$)}return $change_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?
$change_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($G__79278$$):$change_fn$jscomp$7$$($G__79278$$)}),$handle_change$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_fn$jscomp$7$$),$APP.$rumext$v2$adapt$$($blur_key$$)],function($value__$1$jscomp$56$$){function $G__79280$$($p1__79270_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__79270_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$blur_key$$,
$APP.$cljs$cst$260$value$$],null),$value__$1$jscomp$56$$)}return $change_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$change_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($G__79280$$):$change_fn$jscomp$7$$($G__79280$$)}),$handle_type_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_fn$jscomp$7$$),$APP.$rumext$v2$adapt$$($value$jscomp$890$$),$APP.$rumext$v2$adapt$$($blur_key$$)],function($type$jscomp$655$$){function $G__79281$$($shape$jscomp$1014$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blur_key$$,
$target_key$$)||$APP.$cljs$core$contains_QMARK_$$($shape$jscomp$1014$$,$target_key$$))return $shape$jscomp$1014$$;if($APP.$cljs$core$contains_QMARK_$$($shape$jscomp$1014$$,$blur_key$$)){var $blur$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1014$$,$blur_key$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1014$$,$blur_key$$),$target_key$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($blur$jscomp$12$$,
$APP.$cljs$cst$139$type$$,$type_kw$$))}return $shape$jscomp$1014$$}var $type_kw$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($type$jscomp$655$$),$target_key$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type_kw$$,$APP.$cljs$cst$1925$layer_blur$$)?$APP.$cljs$cst$1658$blur$$:$APP.$cljs$cst$1197$background_blur$$;return $change_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$?$change_fn$jscomp$7$$.$cljs$core$IFn$_invoke$arity$1$($G__79281$$):$change_fn$jscomp$7$$($G__79281$$)}),
$bb_disabled_QMARK__type_options$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$count$$($blur_values_label_ref$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blur_key$$,$APP.$cljs$cst$1197$background_blur$$),$background_blur_disabled_QMARK__lb_disabled_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$count$$($blur_values_label_ref$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blur_key$$,$APP.$cljs$cst$1658$blur$$);
$blur_values_label_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);$bb_disabled_QMARK__type_options$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"layer-blur",$APP.$cljs$cst$2959$disabled$$,$background_blur_disabled_QMARK__lb_disabled_QMARK_$$,$APP.$cljs$cst$266$id$$,"layer-blur",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.layer-blur")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"background-blur",$APP.$cljs$cst$2959$disabled$$,$bb_disabled_QMARK__type_options$$,$APP.$cljs$cst$266$id$$,"background-blur",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.background-blur")],null)],null);$background_blur_disabled_QMARK__lb_disabled_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blur_key$$,$APP.$cljs$cst$1197$background_blur$$)&&
!$bg_blur_QMARK_$jscomp$2_props_79271$$;var $label$jscomp$47_label_text$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blur_key$$,$APP.$cljs$cst$1197$background_blur$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.background-blur"):$bg_blur_QMARK_$jscomp$2_props_79271$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.layer-blur"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.blur");
$label$jscomp$47_label_text$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)("span",{"aria-labelledby":"background-blur-disabled-label",ref:$blur_values_label_ref$$,className:"main_ui_workspace_sidebar_options_menus_blur__label "+($background_blur_disabled_QMARK__lb_disabled_QMARK_$$?"main_ui_workspace_sidebar_options_menus_blur__disabled-label":""),children:$label$jscomp$47_label_text$jscomp$1$$});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__first-row "+
($APP.$cljs$core$truth_$$($is_hidden$jscomp$3$$)?"main_ui_workspace_sidebar_options_menus_blur__hidden":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"blur-info",className:"main_ui_workspace_sidebar_options_menus_blur__blur-info",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_blur__show-more "+($APP.$cljs$core$truth_$$($show_more_options$$)?"main_ui_workspace_sidebar_options_menus_blur__selected":
""),onClick:$toggle_more_options$$,selected:$show_more_options$$,variant:"ghost",disabled:$APP.$cljs$core$truth_$$($is_hidden$jscomp$3$$)?$is_hidden$jscomp$3$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blur_key$$,$APP.$cljs$cst$1197$background_blur$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$bg_blur_QMARK_$jscomp$2_props_79271$$),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.toggle-more-options"),icon:"menu"}),
$bg_blur_QMARK_$jscomp$2_props_79271$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_blur__blur-type-select",defaultSelected:$APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$890$$)),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.blur-type-select"),options:$bb_disabled_QMARK__type_options$$,disabled:$is_hidden$jscomp$3$$,
onChange:$handle_type_change$$}):$background_blur_disabled_QMARK__lb_disabled_QMARK_$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{triggerRef:$blur_values_label_ref$$,id:"background-blur-disabled-label",className:"main_ui_workspace_sidebar_options_menus_blur__disabled-label-tooltip",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.disabled-blur-label"),children:$label$jscomp$47_label_text$jscomp$1$$}):$label$jscomp$47_label_text$jscomp$1$$]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.toggle-blur"),onClick:$handle_toggle_visibility$$,disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blur_key$$,$APP.$cljs$cst$1197$background_blur$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,
$bg_blur_QMARK_$jscomp$2_props_79271$$),tooltipPlacement:"top-left",icon:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hidden$jscomp$3$$)?$is_hidden$jscomp$3$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($blur_key$$,$APP.$cljs$cst$1197$background_blur$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$bg_blur_QMARK_$jscomp$2_props_79271$$))?"hide":"shown"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.remove-blur"),
onClick:$handle_delete$$,tooltipPlacement:"top-left",icon:"remove"})]})]}),$APP.$cljs$core$truth_$$($show_more_options$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__second-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_blur__numeric-input",placeholder:"--",min:0,textIcon:"value",onChange:$handle_change$jscomp$9$$,name:"blur-value",value:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$890$$)})}):
null]})};
$app$main$ui$workspace$sidebar$options$menus$blur$get_blurs$$=function($values$jscomp$85$$){var $G__79286_G__79286__$1$$=$APP.$cljs$core$PersistentVector$EMPTY$$;$G__79286_G__79286__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1658$blur$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$85$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__79286_G__79286__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1658$blur$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$85$$)],
null)):$G__79286_G__79286__$1$$;return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1197$background_blur$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$85$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__79286_G__79286__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$1197$background_blur$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1197$background_blur$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$85$$)],null)):$G__79286_G__79286__$1$$};
$app$main$ui$workspace$sidebar$options$menus$layer$opacity__GT_string$$=function($opacity$jscomp$51$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($opacity$jscomp$51$$,$APP.$cljs$cst$1621$multiple$$)?""+$APP.$app$common$data$coalesce$$($opacity$jscomp$51$$)*100:$APP.$cljs$cst$1621$multiple$$};
$app$main$ui$workspace$sidebar$options$menus$layer$on_change$$=function($ids$jscomp$298$$,$prop$jscomp$37$$,$value$jscomp$898$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$298$$,function($p1__79410_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79410_SHARP_$$,$prop$jscomp$37$$,$value$jscomp$898$$)}))};
$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$=function($m1_QMARK_$$,$m2_QMARK_$$,$m3_QMARK_$$,$m4_QMARK_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_margins_selected$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1705$m1$$,$m1_QMARK_$$,$APP.$cljs$cst$1706$m2$$,$m2_QMARK_$$,$APP.$cljs$cst$1707$m3$$,$m3_QMARK_$$,$APP.$cljs$cst$1708$m4$$,$m4_QMARK_$$],null)))};
$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margin$$=function($prop$jscomp$38$$){return $app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$38$$,$APP.$cljs$cst$1705$m1$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$38$$,$APP.$cljs$cst$1706$m2$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$38$$,$APP.$cljs$cst$1707$m3$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$38$$,
$APP.$cljs$cst$1708$m4$$))};
$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_simple_STAR_$$=function($props_79420_token_numeric_inputs$jscomp$6$$){var $on_change$jscomp$71$$=$props_79420_token_numeric_inputs$jscomp$6$$.onChange,$m2_placeholder_value$jscomp$903$$=$props_79420_token_numeric_inputs$jscomp$6$$.value,$on_blur$jscomp$22$$=$props_79420_token_numeric_inputs$jscomp$6$$.onBlur,$ids$jscomp$300$$=$props_79420_token_numeric_inputs$jscomp$6$$.ids,$applied_tokens$jscomp$15_token_applied_m2__$1$$=$props_79420_token_numeric_inputs$jscomp$6$$.appliedTokens;
$props_79420_token_numeric_inputs$jscomp$6$$=$APP.$app$main$features$use_feature$$("tokens/numeric-input");var $m1$jscomp$18_m1__$1$jscomp$1$$=$APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($m2_placeholder_value$jscomp$903$$),$m2$jscomp$15_m2__$1$jscomp$1$$=$APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($m2_placeholder_value$jscomp$903$$),$m1_placeholder_m3$jscomp$2$$=$APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($m2_placeholder_value$jscomp$903$$),$m4$jscomp$2_on_detach_horizontal$$=
$APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($m2_placeholder_value$jscomp$903$$);$m1$jscomp$18_m1__$1$jscomp$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2_placeholder_value$jscomp$903$$,$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m1$jscomp$18_m1__$1$jscomp$1$$,$m1_placeholder_m3$jscomp$2$$)?$m1$jscomp$18_m1__$1$jscomp$1$$:null;$m2$jscomp$15_m2__$1$jscomp$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2_placeholder_value$jscomp$903$$,
$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2$jscomp$15_m2__$1$jscomp$1$$,$m4$jscomp$2_on_detach_horizontal$$)?$m2$jscomp$15_m2__$1$jscomp$1$$:null;var $token_applied_m1_token_applied_m1__$1$$=$APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$15_token_applied_m2__$1$$),$on_focus_m2_token_applied_m2$$=$APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$15_token_applied_m2__$1$$),$on_focus_m1_token_applied_m3$$=
$APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$15_token_applied_m2__$1$$),$on_detach_vertical_token_applied_m4$$=$APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$15_token_applied_m2__$1$$);$token_applied_m1_token_applied_m1__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$15_token_applied_m2__$1$$,$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_applied_m1_token_applied_m1__$1$$,
$on_focus_m1_token_applied_m3$$)?$token_applied_m1_token_applied_m1__$1$$:$APP.$cljs$cst$1621$multiple$$;$applied_tokens$jscomp$15_token_applied_m2__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$15_token_applied_m2__$1$$,$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($on_focus_m2_token_applied_m2$$,$on_detach_vertical_token_applied_m4$$)?$on_focus_m2_token_applied_m2$$:$APP.$cljs$cst$1621$multiple$$;$m1_placeholder_m3$jscomp$2$$=
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2_placeholder_value$jscomp$903$$,$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m1$jscomp$18_m1__$1$jscomp$1$$,$m1_placeholder_m3$jscomp$2$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_applied_m1_token_applied_m1__$1$$,$on_focus_m1_token_applied_m3$$)?"--":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple");$m2_placeholder_value$jscomp$903$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2_placeholder_value$jscomp$903$$,
$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($m2$jscomp$15_m2__$1$jscomp$1$$,$m4$jscomp$2_on_detach_horizontal$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$15_token_applied_m2__$1$$,$on_detach_vertical_token_applied_m4$$)?"--":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple");var $on_focus$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$)],
function($G__79426_79518__$1_attr$jscomp$83$$,$event$jscomp$557$$){$G__79426_79518__$1_attr$jscomp$83$$=$G__79426_79518__$1_attr$jscomp$83$$ instanceof $APP.$cljs$core$Keyword$$?$G__79426_79518__$1_attr$jscomp$83$$.$fqn$:null;switch($G__79426_79518__$1_attr$jscomp$83$$){case "m1":$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$(!0,!1,!0,!1);break;case "m2":$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$(!1,!0,!1,!0);break;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79426_79518__$1_attr$jscomp$83$$)].join(""));}return $app$util$dom$select_target$$($event$jscomp$557$$)}),$on_detach_token$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],function($token_name$jscomp$25$$,$attr$jscomp$84$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$25$$,$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$84$$]),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$300$$],null)))});$m4$jscomp$2_on_detach_horizontal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$9$$)],function($token$jscomp$141$$){return $APP.$cljs$core$run_BANG_$$(function($p1__79414_SHARP_$$){return $on_detach_token$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?
$on_detach_token$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$141$$,$p1__79414_SHARP_$$):$on_detach_token$jscomp$9$$($token$jscomp$141$$,$p1__79414_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1706$m2$$,$APP.$cljs$cst$1708$m4$$],null))});$on_detach_vertical_token_applied_m4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$9$$)],function($token$jscomp$142$$){return $APP.$cljs$core$run_BANG_$$(function($p1__79416_SHARP_$$){return $on_detach_token$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?
$on_detach_token$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$142$$,$p1__79416_SHARP_$$):$on_detach_token$jscomp$9$$($token$jscomp$142$$,$p1__79416_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1705$m1$$,$APP.$cljs$cst$1707$m3$$],null))});var $on_change_SINGLEQUOTE_$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$71$$),$APP.$rumext$v2$adapt$$($ids$jscomp$300$$)],
function($value__$1$jscomp$58$$,$attr$jscomp$85$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$58$$,function($p1__79417_SHARP_$$){return $on_change$jscomp$71$$.$cljs$core$IFn$_invoke$arity$3$?$on_change$jscomp$71$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1668$simple$$,$attr$jscomp$85$$,$p1__79417_SHARP_$$):$on_change$jscomp$71$$($APP.$cljs$cst$1668$simple$$,$attr$jscomp$85$$,$p1__79417_SHARP_$$)},$ids$jscomp$300$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1705$m1$$,
$attr$jscomp$85$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1707$m3$$,null,$APP.$cljs$cst$1705$m1$$,null],null),null):new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1708$m4$$,null,$APP.$cljs$cst$1706$m2$$,null],null),null))});$on_focus_m1_token_applied_m3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$15$$)],function(){return $on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$?
$on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1705$m1$$):$on_focus$jscomp$15$$($APP.$cljs$cst$1705$m1$$)});$on_focus_m2_token_applied_m2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$15$$)],function(){return $on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$15$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1706$m2$$):$on_focus$jscomp$15$$($APP.$cljs$cst$1706$m2$$)});var $on_m1_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$8$$)],
function($p1__79418_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($p1__79418_SHARP_$$,$APP.$cljs$cst$1705$m1$$):$on_change_SINGLEQUOTE_$jscomp$8$$($p1__79418_SHARP_$$,$APP.$cljs$cst$1705$m1$$)}),$on_m2_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$8$$)],function($p1__79419_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_SINGLEQUOTE_$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($p1__79419_SHARP_$$,$APP.$cljs$cst$1706$m2$$):$on_change_SINGLEQUOTE_$jscomp$8$$($p1__79419_SHARP_$$,$APP.$cljs$cst$1706$m2$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__margin-simple",children:[$props_79420_token_numeric_inputs$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{onChange:$on_m1_change$$,
className:"main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin-wrapper",placeholder:$m1_placeholder_m3$jscomp$2$$,inputType:$APP.$cljs$cst$2006$vertical_margin$$,attr:$APP.$cljs$cst$1705$m1$$,appliedToken:$token_applied_m1_token_applied_m1__$1$$,value:$m1$jscomp$18_m1__$1$jscomp$1$$,onFocus:$on_focus_m1_token_applied_m3$$,onDetach:$on_detach_vertical_token_applied_m4$$,property:"Vertical margin ",onBlur:$on_blur$jscomp$22$$,nillable:!0,"default":null,icon:"margin-top-bottom"}):(0,$APP.$rumext$v2$jsxs$$)("div",
{title:"Vertical margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__vertical-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_top_bottom$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:$m1_placeholder_m3$jscomp$2$$,"data-name":"m1",onFocus:$on_focus_m1_token_applied_m3$$,
onChange:$on_m1_change$$,onBlur:$on_blur$jscomp$22$$,nillable:!0,value:$m1$jscomp$18_m1__$1$jscomp$1$$})]}),$props_79420_token_numeric_inputs$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{align:$APP.$cljs$cst$258$right$$,onChange:$on_m2_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin-wrapper",placeholder:$m2_placeholder_value$jscomp$903$$,inputType:$APP.$cljs$cst$2003$horizontal_margin$$,
attr:$APP.$cljs$cst$1706$m2$$,appliedToken:$applied_tokens$jscomp$15_token_applied_m2__$1$$,value:$m2$jscomp$15_m2__$1$jscomp$1$$,onFocus:$on_focus_m2_token_applied_m2$$,onDetach:$m4$jscomp$2_on_detach_horizontal$$,property:"Horizontal margin",onBlur:$on_blur$jscomp$22$$,nillable:!0,"default":null,icon:"margin-left-right"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Horizontal margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__horizontal-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_left_right$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:$m2_placeholder_value$jscomp$903$$,"data-name":"m2",onFocus:$on_focus_m2_token_applied_m2$$,onChange:$on_m2_change$$,onBlur:$on_blur$jscomp$22$$,nillable:!0,value:$m2$jscomp$15_m2__$1$jscomp$1$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_multiple_STAR_$$=function($props_79437_token_numeric_inputs$jscomp$7$$){var $on_change$jscomp$72$$=$props_79437_token_numeric_inputs$jscomp$7$$.onChange,$m4$jscomp$3_value$jscomp$904$$=$props_79437_token_numeric_inputs$jscomp$7$$.value,$on_blur$jscomp$23$$=$props_79437_token_numeric_inputs$jscomp$7$$.onBlur,$ids$jscomp$301$$=$props_79437_token_numeric_inputs$jscomp$7$$.ids,$applied_token_to_m4_applied_tokens$jscomp$16$$=$props_79437_token_numeric_inputs$jscomp$7$$.appliedTokens;
$props_79437_token_numeric_inputs$jscomp$7$$=$APP.$app$main$features$use_feature$$("tokens/numeric-input");var $m1$jscomp$19$$=$APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($m4$jscomp$3_value$jscomp$904$$),$m2$jscomp$16$$=$APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($m4$jscomp$3_value$jscomp$904$$),$m3$jscomp$3$$=$APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($m4$jscomp$3_value$jscomp$904$$);$m4$jscomp$3_value$jscomp$904$$=$APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($m4$jscomp$3_value$jscomp$904$$);
var $applied_token_to_m1$$=$APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_to_m4_applied_tokens$jscomp$16$$),$applied_token_to_m2$$=$APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_to_m4_applied_tokens$jscomp$16$$),$applied_token_to_m3$$=$APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_to_m4_applied_tokens$jscomp$16$$);$applied_token_to_m4_applied_tokens$jscomp$16$$=$APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($applied_token_to_m4_applied_tokens$jscomp$16$$);
var $on_detach_token$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$301$$)],function($token_name$jscomp$26$$,$attr$jscomp$86$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$26$$,$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$86$$]),
$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$301$$],null)))}),$on_focus$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_item$select_margin$$)],function($attr$jscomp$87$$,$event$jscomp$558$$){$app$main$ui$workspace$sidebar$options$menus$layout_item$select_margin$$($attr$jscomp$87$$);return $app$util$dom$select_target$$($event$jscomp$558$$)}),$on_focus_m1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$16$$)],
function(){return $on_focus$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1705$m1$$):$on_focus$jscomp$16$$($APP.$cljs$cst$1705$m1$$)}),$on_focus_m2$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$16$$)],function(){return $on_focus$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1706$m2$$):$on_focus$jscomp$16$$($APP.$cljs$cst$1706$m2$$)}),
$on_focus_m3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$16$$)],function(){return $on_focus$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1705$m1$$):$on_focus$jscomp$16$$($APP.$cljs$cst$1705$m1$$)}),$on_focus_m4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$16$$)],function(){return $on_focus$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$?
$on_focus$jscomp$16$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1706$m2$$):$on_focus$jscomp$16$$($APP.$cljs$cst$1706$m2$$)}),$on_change_SINGLEQUOTE_$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$72$$),$APP.$rumext$v2$adapt$$($ids$jscomp$301$$)],function($value__$1$jscomp$59$$,$attr$jscomp$88$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value__$1$jscomp$59$$,function($p1__79432_SHARP_$$){return $on_change$jscomp$72$$.$cljs$core$IFn$_invoke$arity$3$?
$on_change$jscomp$72$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$1621$multiple$$,$attr$jscomp$88$$,$p1__79432_SHARP_$$):$on_change$jscomp$72$$($APP.$cljs$cst$1621$multiple$$,$attr$jscomp$88$$,$p1__79432_SHARP_$$)},$ids$jscomp$301$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$88$$]))}),$on_m1_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$9$$)],function($p1__79433_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($p1__79433_SHARP_$$,$APP.$cljs$cst$1705$m1$$):$on_change_SINGLEQUOTE_$jscomp$9$$($p1__79433_SHARP_$$,$APP.$cljs$cst$1705$m1$$)}),$on_m2_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$9$$)],function($p1__79434_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($p1__79434_SHARP_$$,
$APP.$cljs$cst$1706$m2$$):$on_change_SINGLEQUOTE_$jscomp$9$$($p1__79434_SHARP_$$,$APP.$cljs$cst$1706$m2$$)}),$on_m3_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$9$$)],function($p1__79435_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($p1__79435_SHARP_$$,$APP.$cljs$cst$1707$m3$$):$on_change_SINGLEQUOTE_$jscomp$9$$($p1__79435_SHARP_$$,
$APP.$cljs$cst$1707$m3$$)}),$on_m4_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_SINGLEQUOTE_$jscomp$9$$)],function($p1__79436_SHARP_$$){return $on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_SINGLEQUOTE_$jscomp$9$$.$cljs$core$IFn$_invoke$arity$2$($p1__79436_SHARP_$$,$APP.$cljs$cst$1708$m4$$):$on_change_SINGLEQUOTE_$jscomp$9$$($p1__79436_SHARP_$$,$APP.$cljs$cst$1708$m4$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_item__margin-multiple",children:[$props_79437_token_numeric_inputs$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{onChange:$on_m1_change$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__top-margin-wrapper",inputType:$APP.$cljs$cst$2006$vertical_margin$$,attr:$APP.$cljs$cst$1705$m1$$,appliedToken:$applied_token_to_m1$$,value:$m1$jscomp$19$$,
onFocus:$on_focus_m1$jscomp$1$$,onDetach:$on_detach_token$jscomp$10$$,property:"Top margin",onBlur:$on_blur$jscomp$23$$,nillable:!0,"default":null,icon:"margin-top"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Top margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__top-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_top$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--","data-name":"m1",onFocus:$on_focus_m1$jscomp$1$$,onChange:$on_m1_change$jscomp$1$$,onBlur:$on_blur$jscomp$23$$,nillable:!0,value:$m1$jscomp$19$$})]}),$props_79437_token_numeric_inputs$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{align:$APP.$cljs$cst$258$right$$,onChange:$on_m2_change$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__right-margin-wrapper",
inputType:$APP.$cljs$cst$2003$horizontal_margin$$,attr:$APP.$cljs$cst$1706$m2$$,appliedToken:$applied_token_to_m2$$,value:$m2$jscomp$16$$,onFocus:$on_focus_m2$jscomp$1$$,onDetach:$on_detach_token$jscomp$10$$,property:"Right margin",onBlur:$on_blur$jscomp$23$$,nillable:!0,"default":null,icon:"margin-right"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Right margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__right-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",
children:$APP.$app$main$ui$icons$margin_right$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--","data-name":"m2",onFocus:$on_focus_m2$jscomp$1$$,onChange:$on_m2_change$jscomp$1$$,onBlur:$on_blur$jscomp$23$$,nillable:!0,value:$m2$jscomp$16$$})]}),$props_79437_token_numeric_inputs$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,
{align:$APP.$cljs$cst$258$right$$,onChange:$on_m3_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin-wrapper",inputType:$APP.$cljs$cst$2006$vertical_margin$$,attr:$APP.$cljs$cst$1707$m3$$,appliedToken:$applied_token_to_m3$$,value:$m3$jscomp$3$$,onFocus:$on_focus_m3$$,onDetach:$on_detach_token$jscomp$10$$,property:"Bottom margin",onBlur:$on_blur$jscomp$23$$,nillable:!0,"default":null,icon:"margin-bottom"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Bottom margin",
className:"main_ui_workspace_sidebar_options_menus_layout_item__bottom-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_bottom$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--","data-name":"m3",onFocus:$on_focus_m3$$,onChange:$on_m3_change$$,onBlur:$on_blur$jscomp$23$$,
nillable:!0,value:$m3$jscomp$3$$})]}),$props_79437_token_numeric_inputs$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{onChange:$on_m4_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__left-margin-wrapper",inputType:$APP.$cljs$cst$2003$horizontal_margin$$,attr:$APP.$cljs$cst$1708$m4$$,appliedToken:$applied_token_to_m4_applied_tokens$jscomp$16$$,value:$m4$jscomp$3_value$jscomp$904$$,onFocus:$on_focus_m4$$,
onDetach:$on_detach_token$jscomp$10$$,property:"Left margin",onBlur:$on_blur$jscomp$23$$,nillable:!0,"default":null,icon:"margin-left"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:"Left margin",className:"main_ui_workspace_sidebar_options_menus_layout_item__left-margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon",children:$APP.$app$main$ui$icons$margin_left$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--","data-name":"m4",onFocus:$on_focus_m4$$,onChange:$on_m4_change$$,onBlur:$on_blur$jscomp$23$$,nillable:!0,value:$m4$jscomp$3_value$jscomp$904$$})]})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$margin_section_STAR_$$=function($props_79438_props__$1$jscomp$80$$){var $on_type_change$jscomp$3$$=$props_79438_props__$1$jscomp$80$$.onTypeChange,$type__$1$jscomp$17$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_79438_props__$1$jscomp$80$$.type,$APP.$cljs$cst$1668$simple$$),$on_blur$jscomp$24$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$)],
function(){return $app$main$ui$workspace$sidebar$options$menus$layout_item$select_margins$$(!1,!1,!1,!1)});$props_79438_props__$1$jscomp$80$$={...$props_79438_props__$1$jscomp$80$$,onBlur:$on_blur$jscomp$24$$};var $on_type_change_SINGLEQUOTE_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type__$1$jscomp$17$$),$APP.$rumext$v2$adapt$$($on_type_change$jscomp$3$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type__$1$jscomp$17$$,
$APP.$cljs$cst$1621$multiple$$)?$on_type_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_type_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1668$simple$$):$on_type_change$jscomp$3$$($APP.$cljs$cst$1668$simple$$):$on_type_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_type_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1621$multiple$$):$on_type_change$jscomp$3$$($APP.$cljs$cst$1621$multiple$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return function(){return $on_blur$jscomp$24$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$24$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$24$$()}});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__margin-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__inputs-wrapper",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type__$1$jscomp$17$$,$APP.$cljs$cst$1668$simple$$)?
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$margin_simple_STAR_$$,$props_79438_props__$1$jscomp$80$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type__$1$jscomp$17$$,$APP.$cljs$cst$1621$multiple$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$margin_multiple_STAR_$$,$props_79438_props__$1$jscomp$80$$):null}),(0,$APP.$rumext$v2$jsx$$)("button",{title:"Margin - multiple",onClick:$on_type_change_SINGLEQUOTE_$jscomp$1$$,
className:"main_ui_workspace_sidebar_options_menus_layout_item__margin-mode "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type__$1$jscomp$17$$,$APP.$cljs$cst$1621$multiple$$)?"main_ui_workspace_sidebar_options_menus_layout_item__selected":""),children:$APP.$app$main$ui$icons$margin$$})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_horizontal$$=function($props_79443$$){var $on_change$jscomp$73$$=$props_79443$$["on-change"],$is_auto$$=$props_79443$$["is-auto"],$has_fill$$=$props_79443$$["has-fill"];return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__horizontal-behaviour "+($has_fill$$||$is_auto$$?"":"main_ui_workspace_sidebar_options_menus_layout_item__one-element")+" "+($has_fill$$||$is_auto$$?"main_ui_workspace_sidebar_options_menus_layout_item__two-element":
"")+" "+($has_fill$$&&$is_auto$$?"main_ui_workspace_sidebar_options_menus_layout_item__three-element":""),children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($props_79443$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$73$$,name:"flex-behaviour-h",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"fix",icon:"fixed-width",title:"Fix width",id:"behaviour-h-fix"}),
$has_fill$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"fill",icon:"fill-content",title:"Width 100%",id:"behaviour-h-fill"}):null,$is_auto$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"auto",icon:"hug-content",title:"Fit content (Horizontal)",id:"behaviour-h-auto"}):null]})})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_vertical$$=function($props_79486$$){var $on_change$jscomp$74$$=$props_79486$$["on-change"],$is_auto$jscomp$1$$=$props_79486$$["is-auto"],$has_fill$jscomp$1$$=$props_79486$$["has-fill"];return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__vertical-behaviour "+($has_fill$jscomp$1$$||$is_auto$jscomp$1$$?"":"main_ui_workspace_sidebar_options_menus_layout_item__one-element")+" "+
($has_fill$jscomp$1$$||$is_auto$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_layout_item__two-element":"")+" "+($has_fill$jscomp$1$$&&$is_auto$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_layout_item__three-element":""),children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($props_79486$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$74$$,name:"flex-behaviour-v",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"fix",icon:"fixed-width","icon-class":"main_ui_workspace_sidebar_options_menus_layout_item__rotated",title:"Fix height",id:"behaviour-v-fix"}),$has_fill$jscomp$1$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"fill",icon:"fill-content","icon-class":"main_ui_workspace_sidebar_options_menus_layout_item__rotated",title:"Height 100%",id:"behaviour-v-fill"}):null,$is_auto$jscomp$1$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"auto",icon:"hug-content","icon-class":"main_ui_workspace_sidebar_options_menus_layout_item__rotated",title:"Fit content (Vertical)",id:"behaviour-v-auto"}):null]})})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$align_self_row$$=function($props_79490$$){var $on_change$jscomp$75$$=$props_79490$$["on-change"],$is_col$$=$props_79490$$["is-col"];return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$APP.$app$common$data$name$$($props_79490$$.value),"decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change$jscomp$75$$,name:"flex-align-self","allow-empty":!0,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"start",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$1682$align_self$$,$APP.$cljs$cst$1297$start$$,$is_col$$),title:"Align self start",id:"align-self-start"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"center",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$1682$align_self$$,$APP.$cljs$cst$1672$center$$,$is_col$$),title:"Align self center",
id:"align-self-center"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"end",icon:$app$main$ui$workspace$sidebar$options$menus$layout_container$get_layout_flex_icon$$($APP.$cljs$cst$1682$align_self$$,$APP.$cljs$cst$1298$end$$,$is_col$$),title:"Align self end",id:"align-self-end"})]})};
$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_size_constraints_STAR_$$=function($props_79497_token_numeric_inputs$jscomp$8$$){var $ids$jscomp$302$$=$props_79497_token_numeric_inputs$jscomp$8$$.ids,$values$jscomp$91$$=$props_79497_token_numeric_inputs$jscomp$8$$.values,$applied_token_to_max_h_applied_tokens$jscomp$17$$=$props_79497_token_numeric_inputs$jscomp$8$$.appliedTokens;$props_79497_token_numeric_inputs$jscomp$8$$=$APP.$app$main$features$use_feature$$("tokens/numeric-input");
var $v_sizing$jscomp$2$$=$APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$91$$),$min_w$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$91$$,$APP.$cljs$cst$1712$layout_item_min_w$$),$max_w$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$91$$,$APP.$cljs$cst$1711$layout_item_max_w$$),$min_h$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$91$$,$APP.$cljs$cst$1710$layout_item_min_h$$),
$max_h$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$91$$,$APP.$cljs$cst$1709$layout_item_max_h$$),$applied_token_to_min_w$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_to_max_h_applied_tokens$jscomp$17$$,$APP.$cljs$cst$1712$layout_item_min_w$$),$applied_token_to_max_w$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_to_max_h_applied_tokens$jscomp$17$$,$APP.$cljs$cst$1711$layout_item_max_w$$),$applied_token_to_min_h$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_to_max_h_applied_tokens$jscomp$17$$,$APP.$cljs$cst$1710$layout_item_min_h$$);$applied_token_to_max_h_applied_tokens$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_to_max_h_applied_tokens$jscomp$17$$,$APP.$cljs$cst$1709$layout_item_max_h$$);var $on_detach_token$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$302$$)],function($token_name$jscomp$27$$,
$attr$jscomp$89$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$27$$,$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$89$$]),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$302$$],null)))}),$on_size_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$302$$)],
function($value$jscomp$908$$,$attr$jscomp$90$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value$jscomp$908$$,function($p1__79491_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$302$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$attr$jscomp$90$$,$p1__79491_SHARP_$$])))},$ids$jscomp$302$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$90$$]))}),
$on_layout_item_min_w_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$jscomp$1$$)],function($p1__79492_SHARP_$$){return $on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__79492_SHARP_$$,$APP.$cljs$cst$1712$layout_item_min_w$$):$on_size_change$jscomp$1$$($p1__79492_SHARP_$$,$APP.$cljs$cst$1712$layout_item_min_w$$)}),$on_layout_item_max_w_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$jscomp$1$$)],
function($p1__79493_SHARP_$$){return $on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__79493_SHARP_$$,$APP.$cljs$cst$1711$layout_item_max_w$$):$on_size_change$jscomp$1$$($p1__79493_SHARP_$$,$APP.$cljs$cst$1711$layout_item_max_w$$)}),$on_layout_item_min_h_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$jscomp$1$$)],function($p1__79494_SHARP_$$){return $on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?
$on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__79494_SHARP_$$,$APP.$cljs$cst$1710$layout_item_min_h$$):$on_size_change$jscomp$1$$($p1__79494_SHARP_$$,$APP.$cljs$cst$1710$layout_item_min_h$$)}),$on_layout_item_max_h_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$jscomp$1$$)],function($p1__79495_SHARP_$$){return $on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($p1__79495_SHARP_$$,
$APP.$cljs$cst$1709$layout_item_max_h$$):$on_size_change$jscomp$1$$($p1__79495_SHARP_$$,$APP.$cljs$cst$1709$layout_item_max_h$$)});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"Layout item size constraints",className:"main_ui_workspace_sidebar_options_menus_layout_item__advanced-options",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$91$$),$APP.$cljs$cst$1408$fill$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_item__horizontal-fill",children:[$props_79497_token_numeric_inputs$jscomp$8$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_layout_item_min_w_change$$,inputType:$APP.$cljs$cst$2000$min_width$$,attr:$APP.$cljs$cst$1712$layout_item_min_w$$,appliedToken:$applied_token_to_min_w$$,value:$min_w$jscomp$1$$,onDetach:$on_detach_token$jscomp$11$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-min-w"),
nillable:!0,textIcon:"MIN W",tooltipClass:"main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-min-w"),className:"main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-w",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"MIN W"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,min:0,onChange:$on_layout_item_min_w_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--",value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$91$$,$APP.$cljs$cst$1712$layout_item_min_w$$),onFocus:$app$util$dom$select_target$$,"data-wrap":!0,nillable:!0,"data-attr":"layout-item-min-w"})]}),$props_79497_token_numeric_inputs$jscomp$8$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,
{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_layout_item_max_w_change$$,inputType:$APP.$cljs$cst$281$max_width$$,attr:$APP.$cljs$cst$1711$layout_item_max_w$$,appliedToken:$applied_token_to_max_w$$,value:$max_w$jscomp$1$$,onDetach:$on_detach_token$jscomp$11$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-max-w"),nillable:!0,textIcon:"MAX W",tooltipClass:"main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper"}):(0,$APP.$rumext$v2$jsxs$$)("div",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-max-w"),className:"main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-w",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"MAX W"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,min:0,onChange:$on_layout_item_max_w_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",
placeholder:"--",value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$91$$,$APP.$cljs$cst$1711$layout_item_max_w$$),onFocus:$app$util$dom$select_target$$,"data-wrap":!0,nillable:!0,"data-attr":"layout-item-max-w"})]})]}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v_sizing$jscomp$2$$,$APP.$cljs$cst$1408$fill$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__vertical-fill",children:[$props_79497_token_numeric_inputs$jscomp$8$$?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_layout_item_min_h_change$$,inputType:$APP.$cljs$cst$2002$max_height$$,attr:$APP.$cljs$cst$1710$layout_item_min_h$$,appliedToken:$applied_token_to_min_h$$,value:$min_h$jscomp$1$$,onDetach:$on_detach_token$jscomp$11$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-min-h"),nillable:!0,textIcon:"MIN H",
tooltipClass:"main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-min-h"),className:"main_ui_workspace_sidebar_options_menus_layout_item__layout-item-min-h",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"MIN H"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,min:0,onChange:$on_layout_item_min_h_change$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--",value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$91$$,$APP.$cljs$cst$1710$layout_item_min_h$$),onFocus:$app$util$dom$select_target$$,"data-wrap":!0,nillable:!0,"data-attr":"layout-item-min-h"})]}),$props_79497_token_numeric_inputs$jscomp$8$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,
{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_layout_item_max_h_change$$,inputType:$APP.$cljs$cst$2002$max_height$$,attr:$APP.$cljs$cst$1709$layout_item_max_h$$,appliedToken:$applied_token_to_max_h_applied_tokens$jscomp$17$$,value:$max_h$jscomp$1$$,onDetach:$on_detach_token$jscomp$11$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-max-h"),nillable:!0,textIcon:"MAX H",tooltipClass:"main_ui_workspace_sidebar_options_menus_layout_item__tooltip-wrapper"}):
(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layout-item.layout-item-max-h"),className:"main_ui_workspace_sidebar_options_menus_layout_item__layout-item-max-h",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"MAX H"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,min:0,onChange:$on_layout_item_max_h_change$$,
className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--",value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$91$$,$APP.$cljs$cst$1709$layout_item_max_h$$),onFocus:$app$util$dom$select_target$$,"data-wrap":!0,nillable:!0,"data-attr":"layout-item-max-h"})]})]}):null]})};
$app$main$ui$workspace$sidebar$options$rows$shadow_row$shadow_row_STAR_$$=function($props_79461_shadow_style$$){var $shadow__$1$jscomp$17$$=$props_79461_shadow_style$$.shadow,$on_remove$jscomp$3$$=$props_79461_shadow_style$$.onRemove,$is_open$jscomp$10$$=$props_79461_shadow_style$$.isOpen,$index$jscomp$507$$=$props_79461_shadow_style$$.index,$on_toggle_open$$=$props_79461_shadow_style$$.onToggleOpen,$on_detach_color$$=$props_79461_shadow_style$$.onDetachColor,$on_reorder$jscomp$4$$=$props_79461_shadow_style$$.onReorder,
$on_update$$=$props_79461_shadow_style$$.onUpdate,$on_toggle_visibility$jscomp$2$$=$props_79461_shadow_style$$.onToggleVisibility;$props_79461_shadow_style$$=$APP.$cljs$cst$1921$style$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$);var $shadow_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$),$hidden_QMARK_$jscomp$6$$=$APP.$cljs$cst$1625$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$),$dprops$jscomp$6_on_drop$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reorder$jscomp$4$$),
$APP.$rumext$v2$adapt$$($index$jscomp$507$$)],function($relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$,$data$jscomp$486_from_pos$jscomp$16$$){$data$jscomp$486_from_pos$jscomp$16$$=$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$486_from_pos$jscomp$16$$);$relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$,$APP.$cljs$cst$2963$bot$$)?$index$jscomp$507$$+
1:$index$jscomp$507$$;return $on_reorder$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$486_from_pos$jscomp$16$$,$relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$):$on_reorder$jscomp$4$$($data$jscomp$486_from_pos$jscomp$16$$,$relative_pos$jscomp$3_to_space_between_pos$jscomp$16$$)}),$dref$jscomp$6_vec__79483$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,
"penpot/shadow-entry",$APP.$cljs$cst$2966$on_drop$$,$dprops$jscomp$6_on_drop$jscomp$13$$,$APP.$cljs$cst$2969$detect_center_QMARK_$$,!1,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1801$index$$,$index$jscomp$507$$],null)]));$dprops$jscomp$6_on_drop$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$6_vec__79483$$,0,null);$dref$jscomp$6_vec__79483$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$6_vec__79483$$,
1,null);var $on_remove__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$)],function(){return $on_remove$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$507$$):$on_remove$jscomp$3$$($index$jscomp$507$$)}),$trigger_bounding_box_cloaking$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shadow_id$$)],function(){return $APP.$cljs$core$truth_$$($shadow_id$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shadow_id$$],null))):null}),$on_update_offset_x$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($value$jscomp$914$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?
$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$507$$,$APP.$cljs$cst$1655$offset_x$$,$value$jscomp$914$$):$on_update$$($index$jscomp$507$$,$APP.$cljs$cst$1655$offset_x$$,$value$jscomp$914$$)}),$on_update_offset_y$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],
function($value$jscomp$915$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$507$$,$APP.$cljs$cst$1656$offset_y$$,$value$jscomp$915$$):$on_update$$($index$jscomp$507$$,$APP.$cljs$cst$1656$offset_y$$,$value$jscomp$915$$)}),$on_update_spread$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$),
$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($value$jscomp$916$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$507$$,$APP.$cljs$cst$1657$spread$$,$value$jscomp$916$$):$on_update$$($index$jscomp$507$$,$APP.$cljs$cst$1657$spread$$,$value$jscomp$916$$)}),
$on_update_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($value$jscomp$917$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$507$$,$APP.$cljs$cst$1658$blur$$,
$value$jscomp$917$$):$on_update$$($index$jscomp$507$$,$APP.$cljs$cst$1658$blur$$,$value$jscomp$917$$)}),$on_update_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$),$APP.$rumext$v2$adapt$$($on_update$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($color$jscomp$171$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();
return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$507$$,$APP.$cljs$cst$1303$color$$,$color$jscomp$171$$):$on_update$$($index$jscomp$507$$,$APP.$cljs$cst$1303$color$$,$color$jscomp$171$$)}),$on_detach_color__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$)],function(){return $on_detach_color$$.$cljs$core$IFn$_invoke$arity$1$?$on_detach_color$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$507$$):
$on_detach_color$$($index$jscomp$507$$)}),$on_style_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function($G__79489_value$jscomp$918$$){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();$G__79489_value$jscomp$918$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79489_value$jscomp$918$$);
return $on_update$$.$cljs$core$IFn$_invoke$arity$3$?$on_update$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$507$$,$APP.$cljs$cst$1921$style$$,$G__79489_value$jscomp$918$$):$on_update$$($index$jscomp$507$$,$APP.$cljs$cst$1921$style$$,$G__79489_value$jscomp$918$$)}),$on_toggle_visibility__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$507$$),$APP.$rumext$v2$adapt$$($trigger_bounding_box_cloaking$$)],function(){$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$?
$trigger_bounding_box_cloaking$$.$cljs$core$IFn$_invoke$arity$0$():$trigger_bounding_box_cloaking$$();return $on_toggle_visibility$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle_visibility$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$507$$):$on_toggle_visibility$jscomp$2$$($index$jscomp$507$$)}),$on_toggle_open__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shadow_id$$),$APP.$rumext$v2$adapt$$($on_toggle_open$$)],function(){return $on_toggle_open$$.$cljs$core$IFn$_invoke$arity$1$?
$on_toggle_open$$.$cljs$core$IFn$_invoke$arity$1$($shadow_id$$):$on_toggle_open$$($shadow_id$$)}),$type_options$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"drop-shadow",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.drop-shadow")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"inner-shadow",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.inner-shadow")],null)],null)}),$on_open_row$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$5808$color_row$$))}),$on_close_row$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($cljs$cst$5808$color_row$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"shadow-option main_ui_workspace_sidebar_options_rows_shadow_row__shadow-element "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$6_on_drop$jscomp$13$$),
$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_sidebar_options_rows_shadow_row__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$6_on_drop$jscomp$13$$),$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_sidebar_options_rows_shadow_row__dnd-over-bot":""),children:[$on_reorder$jscomp$4$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$6_vec__79483$$}):
null,(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-info",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",icon:"menu",className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-button "+
($APP.$cljs$core$truth_$$($is_open$jscomp$10$$)?"main_ui_workspace_sidebar_options_rows_shadow_row__selected":""),"aria-label":"open more options",disabled:$hidden_QMARK_$jscomp$6$$,onClick:$on_toggle_open__$1$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-select","default-value":$APP.$app$common$data$name$$($props_79461_shadow_style$$),options:$type_options$jscomp$1$$,disabled:$hidden_QMARK_$jscomp$6$$,
"on-change":$on_style_change$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-basic-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.toggle-shadow"),onClick:$on_toggle_visibility__$1$$,icon:$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$6$$)?"hide":"shown"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.remove-shadow"),onClick:$on_remove__$1$$,icon:"remove"})]})]}),$APP.$cljs$core$truth_$$($is_open$jscomp$10$$)?(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$options$common$advanced_options_STAR_$$,{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced",isVisible:$is_open$jscomp$10$$,onClose:$on_toggle_open__$1$$,children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.offsetx"),className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-x",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label",children:"X"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,placeholder:"--",onChange:$on_update_offset_x$$,value:$APP.$cljs$cst$1655$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.blur"),className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-blur",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.blur")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,placeholder:"--",onChange:$on_update_blur$$,min:0,value:$APP.$cljs$cst$1658$blur$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.spread"),className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-spread",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.spread")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,placeholder:"--",onChange:$on_update_spread$$,value:$APP.$cljs$cst$1657$spread$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$)})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.offsety"),className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-offset-y",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-label",children:"Y"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,placeholder:"--",onChange:$on_update_offset_y$$,value:$APP.$cljs$cst$1656$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$)})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{origin:$APP.$cljs$cst$1659$shadow$$,onClose:$on_close_row$$,onChange:$on_update_color$$,className:"main_ui_workspace_sidebar_options_rows_shadow_row__shadow-advanced-color",onDetach:$on_detach_color__$1$$,disableGradient:!0,disableImage:!0,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.color"),color:$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($shadow__$1$jscomp$17$$),onOpen:$on_open_row$$})]})]}):null]})]})};
$app$main$ui$workspace$sidebar$options$menus$shadow$remove_shadow_by_index$$=function($values$jscomp$93$$,$index$jscomp$508$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filterv$$(function($p__79498$$){var $idx$jscomp$125$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79498$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79498$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$125$$,
$index$jscomp$508$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($values$jscomp$93$$)))};
$app$main$ui$workspace$sidebar$options$rows$stroke_row$stroke_row_STAR_$$=function($hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$){var $on_remove$jscomp$5$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onRemove,$on_detach_token$jscomp$12$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onDetachToken,$on_stroke_style_change$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onStrokeStyleChange,$stroke$jscomp$34$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.stroke,
$select_on_focus$jscomp$4$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.selectOnFocus,$index$jscomp$515$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.index,$on_stroke_alignment_change$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onStrokeAlignmentChange,$disable_stroke_style$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.disableStrokeStyle,$disable_drag$jscomp$2$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.disableDrag,$on_focus$jscomp$17$$=
$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onFocus,$on_stroke_width_change$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onStrokeWidthChange,$on_blur$jscomp$25$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onBlur,$on_stroke_gap_change$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onStrokeGapChange,$ids$jscomp$305$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.ids,$on_stroke_cap_start_change$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onStrokeCapStartChange,
$title$jscomp$44$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.title,$on_reorder$jscomp$5$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onReorder,$on_color_change$jscomp$1$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onColorChange,$on_stroke_cap_switch$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onStrokeCapSwitch,$on_stroke_dash_change$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onStrokeDashChange,$show_caps$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.showCaps,
$on_toggle_visibility$jscomp$4$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onToggleVisibility,$on_stroke_cap_end_change$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onStrokeCapEndChange,$applied_tokens$jscomp$19$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.appliedTokens,$on_color_detach$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$.onColorDetach;$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$=$APP.$cljs$cst$1625$hidden$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$);
$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$=$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$==null?!1:$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$;var $token_numeric_inputs$jscomp$9$$=$APP.$app$main$features$use_feature$$("tokens/numeric-input"),$dprops$jscomp$7_on_drop$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reorder$jscomp$5$$),$APP.$rumext$v2$adapt$$($index$jscomp$515$$)],function($relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$,
$data$jscomp$487_from_pos$jscomp$18$$){$data$jscomp$487_from_pos$jscomp$18$$=$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$487_from_pos$jscomp$18$$);$relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$,$APP.$cljs$cst$2963$bot$$)?$index$jscomp$515$$+1:$index$jscomp$515$$;return $on_reorder$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_reorder$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$487_from_pos$jscomp$18$$,
$relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$):$on_reorder$jscomp$5$$($data$jscomp$487_from_pos$jscomp$18$$,$relative_pos$jscomp$4_to_space_between_pos$jscomp$18$$)}),$dref$jscomp$7_vec__79526$$=$on_reorder$jscomp$5$$!=null?$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,"penpot/stroke-row",$APP.$cljs$cst$2966$on_drop$$,$dprops$jscomp$7_on_drop$jscomp$14$$,$APP.$cljs$cst$2959$disabled$$,
$APP.$cljs$core$_deref$$($disable_drag$jscomp$2$$),$APP.$cljs$cst$2969$detect_center_QMARK_$$,!1,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1801$index$$,$index$jscomp$515$$],null)])):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[null,null],null);$dprops$jscomp$7_on_drop$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$7_vec__79526$$,0,null);$dref$jscomp$7_vec__79526$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$7_vec__79526$$,
1,null);var $stroke_color_token$$=$APP.$cljs$cst$1745$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$19$$),$on_color_change_refactor$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_color_change$jscomp$1$$)],function($color$jscomp$172$$){return $on_color_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_color_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,$color$jscomp$172$$):
$on_color_change$jscomp$1$$($index$jscomp$515$$,$color$jscomp$172$$)}),$on_color_detach__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_color_detach$$)],function($_$jscomp$3067$$,$color$jscomp$173$$){return $on_color_detach$$.$cljs$core$IFn$_invoke$arity$2$?$on_color_detach$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,$color$jscomp$173$$):$on_color_detach$$($index$jscomp$515$$,$color$jscomp$173$$)}),
$on_remove__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_remove$jscomp$5$$)],function(){return $on_remove$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_remove$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$515$$):$on_remove$jscomp$5$$($index$jscomp$515$$)}),$stroke_width$jscomp$8$$=$APP.$cljs$cst$1660$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$),$on_width_change$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_stroke_width_change$$),$APP.$rumext$v2$adapt$$($ids$jscomp$305$$)],function($value$jscomp$920$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value$jscomp$920$$,function($p1__79520_SHARP_$$){return $on_stroke_width_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_width_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,$p1__79520_SHARP_$$):
$on_stroke_width_change$$($index$jscomp$515$$,$p1__79520_SHARP_$$)},$ids$jscomp$305$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1660$stroke_width$$,null],null),null))}),$default_dash_gap$$=typeof $stroke_width$jscomp$8$$==="number"?10+$stroke_width$jscomp$8$$:null,$stroke_gap$$=function(){var $or__5025__auto__$jscomp$1255$$=$APP.$cljs$cst$1871$stroke_gap$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1255$$)?
$or__5025__auto__$jscomp$1255$$:$default_dash_gap$$}(),$stroke_dash$$=function(){var $or__5025__auto__$jscomp$1256$$=$APP.$cljs$cst$1880$stroke_dash$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1256$$)?$or__5025__auto__$jscomp$1256$$:$default_dash_gap$$}(),$on_dash_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_stroke_dash_change$$)],function($p1__79521_SHARP_$$){return $on_stroke_dash_change$$.$cljs$core$IFn$_invoke$arity$2$?
$on_stroke_dash_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,$p1__79521_SHARP_$$):$on_stroke_dash_change$$($index$jscomp$515$$,$p1__79521_SHARP_$$)}),$on_gap_change$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_stroke_gap_change$$)],function($p1__79522_SHARP_$$){return $on_stroke_gap_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_gap_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,
$p1__79522_SHARP_$$):$on_stroke_gap_change$$($index$jscomp$515$$,$p1__79522_SHARP_$$)}),$stroke_alignment$$=function(){var $or__5025__auto__$jscomp$1257$$=$APP.$cljs$cst$1875$stroke_alignment$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1257$$)?$or__5025__auto__$jscomp$1257$$:$APP.$cljs$cst$1672$center$$}(),$stroke_alignment_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stroke_alignment$$)],
function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$stroke_alignment$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$2296$label$$,"--"],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1672$center$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.center"),$APP.$cljs$cst$266$id$$,"center",$APP.$cljs$cst$1727$icon$$,"stroke-center"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1918$inner$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.inner"),
$APP.$cljs$cst$266$id$$,"inner",$APP.$cljs$cst$1727$icon$$,"stroke-inside"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2050$outer$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.outer"),$APP.$cljs$cst$266$id$$,"outer",$APP.$cljs$cst$1727$icon$$,"stroke-outside"],null)],null)]))}),$on_alignment_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),
$APP.$rumext$v2$adapt$$($on_stroke_alignment_change$$)],function($G__79530_p1__79523_SHARP_$$){$G__79530_p1__79523_SHARP_$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79530_p1__79523_SHARP_$$);return $on_stroke_alignment_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_alignment_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,$G__79530_p1__79523_SHARP_$$):$on_stroke_alignment_change$$($index$jscomp$515$$,$G__79530_p1__79523_SHARP_$$)}),$on_token_change$jscomp$6$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$305$$)],function($_$jscomp$3068$$,$token$jscomp$143$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1136$token$$,$token$jscomp$143$$,$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1745$stroke_color$$,null],null),null),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$305$$,$APP.$cljs$cst$4735$expand_with_children$$,!0],null)))}),$stroke_style$jscomp$3$$=function(){var $or__5025__auto__$jscomp$1258$$=$APP.$cljs$cst$1873$stroke_style$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1258$$)?$or__5025__auto__$jscomp$1258$$:$APP.$cljs$cst$1919$solid$$}(),$stroke_style_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stroke_style$jscomp$3$$)],
function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$stroke_style$jscomp$3$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$2296$label$$,"--"],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1919$solid$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.solid"),$APP.$cljs$cst$266$id$$,"solid",$APP.$cljs$cst$1727$icon$$,"stroke-solid"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2049$dotted$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.dotted"),
$APP.$cljs$cst$266$id$$,"dotted",$APP.$cljs$cst$1727$icon$$,"stroke-dotted"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2048$dashed$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.dashed"),$APP.$cljs$cst$266$id$$,"dashed",$APP.$cljs$cst$1727$icon$$,"stroke-dashed"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2047$mixed$$,$APP.$cljs$cst$2296$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.mixed"),$APP.$cljs$cst$266$id$$,"mixed",$APP.$cljs$cst$1727$icon$$,"stroke-mixed"],null)],null)]))}),$on_style_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_stroke_style_change$$)],function($G__79532_p1__79524_SHARP_$$){$G__79532_p1__79524_SHARP_$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($G__79532_p1__79524_SHARP_$$);
return $on_stroke_style_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_style_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,$G__79532_p1__79524_SHARP_$$):$on_stroke_style_change$$($index$jscomp$515$$,$G__79532_p1__79524_SHARP_$$)}),$on_caps_start_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_stroke_cap_start_change$$)],function($cap$jscomp$2_cap__$1$$){$cap$jscomp$2_cap__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap$jscomp$2_cap__$1$$,
"none")?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($cap$jscomp$2_cap__$1$$);return $on_stroke_cap_start_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_cap_start_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,$cap$jscomp$2_cap__$1$$):$on_stroke_cap_start_change$$($index$jscomp$515$$,$cap$jscomp$2_cap__$1$$)}),$on_caps_end_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_stroke_cap_end_change$$)],
function($cap$jscomp$3_cap__$1$jscomp$1$$){$cap$jscomp$3_cap__$1$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cap$jscomp$3_cap__$1$jscomp$1$$,"none")?null:$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($cap$jscomp$3_cap__$1$jscomp$1$$);return $on_stroke_cap_end_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_stroke_cap_end_change$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,$cap$jscomp$3_cap__$1$jscomp$1$$):$on_stroke_cap_end_change$$($index$jscomp$515$$,$cap$jscomp$3_cap__$1$jscomp$1$$)}),
$on_detach_token_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$12$$)],function($token$jscomp$144$$){var $G__79534$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1745$stroke_color$$,null],null),null);return $on_detach_token$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$144$$,$G__79534$$):$on_detach_token$jscomp$12$$($token$jscomp$144$$,
$G__79534$$)}),$on_detach_token_width$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$12$$)],function($token$jscomp$145$$){var $G__79536$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1660$stroke_width$$,null],null),null);return $on_detach_token$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$12$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$145$$,$G__79536$$):
$on_detach_token$jscomp$12$$($token$jscomp$145$$,$G__79536$$)}),$stroke_caps_options$$=new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"none",$APP.$cljs$cst$260$value$$,"none",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.none")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,
"",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1477$separator$$,$APP.$cljs$cst$266$id$$,"separator"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"line-arrow",$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1913$line_arrow$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.line-arrow-short"),$APP.$cljs$cst$1727$icon$$,"stroke-arrow"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,
"triangle-arrow",$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1915$triangle_arrow$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.triangle-arrow-short"),$APP.$cljs$cst$1727$icon$$,"stroke-triangle"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"square-marker",$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1917$square_marker$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.square-marker-short"),
$APP.$cljs$cst$1727$icon$$,"stroke-rectangle"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"circle-marker",$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1916$circle_marker$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.circle-marker-short"),$APP.$cljs$cst$1727$icon$$,"stroke-circle"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"diamond-marker",$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1914$diamond_marker$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.diamond-marker-short"),$APP.$cljs$cst$1727$icon$$,"stroke-diamond"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2296$label$$,"",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1477$separator$$,$APP.$cljs$cst$266$id$$,"separator"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"round",$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1911$round$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.round"),$APP.$cljs$cst$1727$icon$$,"stroke-rounded"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$266$id$$,"square",$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1912$square$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-cap.square"),$APP.$cljs$cst$1727$icon$$,"stroke-squared"],
null)],null),$on_cap_switch$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),$APP.$rumext$v2$adapt$$($on_stroke_cap_switch$$)],function(){return $on_stroke_cap_switch$$.$cljs$core$IFn$_invoke$arity$1$?$on_stroke_cap_switch$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$515$$):$on_stroke_cap_switch$$($index$jscomp$515$$)}),$on_toggle_visibility__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$515$$),
$APP.$rumext$v2$adapt$$($on_toggle_visibility$jscomp$4$$)],function(){return $APP.$cljs$core$truth_$$($on_toggle_visibility$jscomp$4$$)?$on_toggle_visibility$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle_visibility$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$515$$):$on_toggle_visibility$jscomp$4$$($index$jscomp$515$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{"aria-label":["stroke-row-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$515$$)].join(""),
className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-data "+($APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$)?"main_ui_workspace_sidebar_options_rows_stroke_row__hidden":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$7_on_drop$jscomp$14$$),$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_sidebar_options_rows_stroke_row__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$7_on_drop$jscomp$14$$),
$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_sidebar_options_rows_stroke_row__dnd-over-bot":""),children:[$on_reorder$jscomp$5$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$reorder_handler$reorder_handler_STAR_$$,{ref:$dref$jscomp$7_vec__79526$$}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-color-actions",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{origin:$APP.$cljs$cst$1745$stroke_color$$,
index:$index$jscomp$515$$,onChange:$on_color_change_refactor$$,selectOnFocus:$select_on_focus$jscomp$4$$,onTokenChange:$on_token_change$jscomp$6$$,disableDrag:$disable_drag$jscomp$2$$,onDetachToken:$on_detach_token_color$$,appliedToken:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$515$$,0)?$stroke_color_token$$:null,onFocus:$on_focus$jscomp$17$$,onDetach:$on_color_detach__$1$$,onBlur:$on_blur$jscomp$25$$,title:$title$jscomp$44$$,color:$APP.$app$common$types$color$stroke__GT_color$$($stroke$jscomp$34$$)}),
$on_toggle_visibility__$1$jscomp$1$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.toggle-stroke"),onClick:$on_toggle_visibility__$1$jscomp$1$$,icon:$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$)?"hide":"shown"}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.remove-stroke"),onClick:$on_remove__$1$jscomp$1$$,icon:"remove"})]}),$token_numeric_inputs$jscomp$9$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-options-tokens",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_width_change$jscomp$1$$,className:"main_ui_workspace_sidebar_options_rows_stroke_row__numeric-input-wrapper",
attr:$APP.$cljs$cst$1660$stroke_width$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$19$$,$APP.$cljs$cst$1660$stroke_width$$),value:$stroke_width$jscomp$8$$,onFocus:$on_focus$jscomp$17$$,onDetach:$on_detach_token_width$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-width"),onBlur:$on_blur$jscomp$25$$,icon:"stroke-size"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{defaultSelected:$APP.$app$common$data$name$$($stroke_alignment$$),
options:$stroke_alignment_options$$,variant:"icon-only","data-testid":"stroke.alignment",disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$)?!0:$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$,wrapperClass:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-align-icon-select",onChange:$on_alignment_change$$}),$APP.$cljs$core$truth_$$($disable_stroke_style$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,
{defaultSelected:$APP.$app$common$data$name$$($stroke_style$jscomp$3$$),options:$stroke_style_options$$,wrapperClass:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-style-icon-select","data-testid":"stroke.style",variant:"icon-only",disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$)?!0:$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$,dropdownAlignment:$APP.$cljs$cst$258$right$$,onChange:$on_style_change$jscomp$1$$})]}):
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-options",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-width"),className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-width-input",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"stroke-size",size:"s"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{value:$stroke_width$jscomp$8$$,min:0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),onChange:$on_width_change$jscomp$1$$,onFocus:$on_focus$jscomp$17$$,selectOnFocus:$select_on_focus$jscomp$4$$,onBlur:$on_blur$jscomp$25$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"stroke.alignment",className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-alignment-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$stroke_alignment$$,
options:$stroke_alignment_options$$,disabled:$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$,"on-change":$on_alignment_change$$})}),$APP.$cljs$core$truth_$$($disable_stroke_style$$)?null:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"stroke.style",className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-style-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$stroke_style$jscomp$3$$,options:$stroke_style_options$$,disabled:$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$,
"on-change":$on_style_change$jscomp$1$$})})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($stroke_style$jscomp$3$$,$APP.$cljs$cst$2048$dashed$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"stroke.dash-options",className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-dash-options",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_dash_change$$,className:"main_ui_workspace_sidebar_options_rows_stroke_row__numeric-input-wrapper",
attr:$APP.$cljs$cst$1880$stroke_dash$$,value:$stroke_dash$$,onFocus:$on_focus$jscomp$17$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-dash"),onBlur:$on_blur$jscomp$25$$,textIcon:"DASH"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,onChange:$on_gap_change$jscomp$2$$,tooltipPlacement:"top-left",className:"main_ui_workspace_sidebar_options_rows_stroke_row__numeric-input-wrapper",
attr:$APP.$cljs$cst$1871$stroke_gap$$,value:$stroke_gap$$,onFocus:$on_focus$jscomp$17$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-gap"),onBlur:$on_blur$jscomp$25$$,textIcon:"GAP"})]}):null,$APP.$cljs$core$truth_$$($show_caps$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_rows_stroke_row__stroke-caps-options",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{defaultSelected:function(){var $or__5025__auto__$jscomp$1259$$=
$APP.$app$common$data$name$$($APP.$cljs$cst$1872$stroke_cap_start$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1259$$)?$or__5025__auto__$jscomp$1259$$:"none"}(),options:$stroke_caps_options$$,"data-testid":"stroke.cap-start",disabled:$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$,onChange:$on_caps_start_change$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.switch"),disabled:$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$,onClick:$on_cap_switch$$,icon:"switch"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{defaultSelected:function(){var $or__5025__auto__$jscomp$1260$$=$APP.$app$common$data$name$$($APP.$cljs$cst$1876$stroke_cap_end$$.$cljs$core$IFn$_invoke$arity$1$($stroke$jscomp$34$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1260$$)?
$or__5025__auto__$jscomp$1260$$:"none"}(),options:$stroke_caps_options$$,"data-testid":"stroke.cap-end",disabled:$hidden_QMARK_$jscomp$7_hidden_QMARK___$1_props_79525$$,onChange:$on_caps_end_change$$})]}):null]})};
$app$main$ui$workspace$sidebar$options$shapes$bool$options_STAR_$$=function($props_79546_type$jscomp$664$$){var $file_id$jscomp$411$$=$props_79546_type$jscomp$664$$.fileId,$page_id$jscomp$432$$=$props_79546_type$jscomp$664$$.pageId,$shape$jscomp$1023$$=$props_79546_type$jscomp$664$$.shape,$id$jscomp$974$$=$shape$jscomp$1023$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1023$$,$APP.$cljs$cst$266$id$$);$props_79546_type$jscomp$664$$=$shape$jscomp$1023$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1023$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$307$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$974$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$974$$],null)}),$shapes$jscomp$216$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1023$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1023$$],null)}),$applied_tokens$jscomp$21$$=$APP.$cljs$core$seq$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1023$$,$APP.$cljs$cst$1881$applied_tokens$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1023$$,$APP.$cljs$cst$1881$applied_tokens$$):null,$measure_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1023$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1023$$,
$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1023$$,$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$constraint_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1023$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1023$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),
$layout_container_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1023$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),$is_flex_parent_QMARK__is_flex_parent_ref_is_layout_child_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$307$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$307$$)}),$is_layout_child_QMARK_$jscomp$1$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK__is_flex_parent_ref_is_layout_child_ref$$);
$is_flex_parent_QMARK__is_flex_parent_ref_is_layout_child_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$307$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$307$$)});$is_flex_parent_QMARK__is_flex_parent_ref_is_layout_child_ref$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK__is_flex_parent_ref_is_layout_child_ref$$);var $is_grid_parent_ref_is_layout_child_absolute_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$307$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$307$$)}),$is_grid_parent_QMARK_$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref_is_layout_child_absolute_QMARK_$$);$is_grid_parent_ref_is_layout_child_absolute_QMARK_$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1023$$);var $parents$jscomp$13_parents_by_ids_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$307$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$307$$)});$parents$jscomp$13_parents_by_ids_ref$$=$APP.$rumext$v2$deref$$($parents$jscomp$13_parents_by_ids_ref$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$307$$,type:$props_79546_type$jscomp$664$$,appliedTokens:$applied_tokens$jscomp$21$$,values:$layer_values$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$307$$,appliedTokens:$applied_tokens$jscomp$21$$,type:$props_79546_type$jscomp$664$$,values:$measure_values$$,shapes:$shapes$jscomp$216$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,{type:$props_79546_type$jscomp$664$$,ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1023$$)],null),values:$layout_container_values$$,
appliedTokens:$applied_tokens$jscomp$21$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$850$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$307$$),1);return $and__5023__auto__$jscomp$850$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$1$$)?$is_grid_parent_QMARK_$$:$is_layout_child_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$850$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,
{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($parents$jscomp$13_parents_by_ids_ref$$)),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$13_parents_by_ids_ref$$),$APP.$cljs$core$first$$($ids$jscomp$307$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,{ids:$ids$jscomp$307$$,
type:$props_79546_type$jscomp$664$$,values:$layout_item_values$$,isLayoutChild:!0,isFlexParent:$is_flex_parent_QMARK__is_flex_parent_ref_is_layout_child_ref$$,isGridParent:$is_grid_parent_QMARK_$$,appliedTokens:$applied_tokens$jscomp$21$$,shape:$shape$jscomp$1023$$}):null,!$is_layout_child_QMARK_$jscomp$1$$||$is_grid_parent_ref_is_layout_child_absolute_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$307$$,values:$constraint_values$$}):
null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$307$$,type:$props_79546_type$jscomp$664$$,values:$shape$jscomp$1023$$,appliedTokens:$applied_tokens$jscomp$21$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$307$$,type:$props_79546_type$jscomp$664$$,showCaps:!0,values:$stroke_values$$,appliedTokens:$applied_tokens$jscomp$21$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,
{ids:$ids$jscomp$307$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1023$$,$APP.$cljs$cst$1659$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$307$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1023$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1197$background_blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,
{type:$props_79546_type$jscomp$664$$,ids:$ids$jscomp$307$$,shapes:$shapes$jscomp$216$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1023$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$432$$,fileId:$file_id$jscomp$411$$})]})};
$app$main$ui$workspace$sidebar$options$shapes$circle$options_STAR_$$=function($props_79560_type$jscomp$665$$){var $file_id$jscomp$412$$=$props_79560_type$jscomp$665$$.fileId,$page_id$jscomp$433$$=$props_79560_type$jscomp$665$$.pageId,$shape$jscomp$1026$$=$props_79560_type$jscomp$665$$.shape,$id$jscomp$975$$=$shape$jscomp$1026$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1026$$,$APP.$cljs$cst$266$id$$);$props_79560_type$jscomp$665$$=$shape$jscomp$1026$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1026$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$309$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$975$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$975$$],null)}),$shapes$jscomp$217$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1026$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1026$$],null)}),$applied_tokens$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1026$$,$APP.$cljs$cst$1881$applied_tokens$$),$measure_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,
$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$constraint_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$1$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),
$is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$309$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$309$$)}),$is_layout_child_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$);$is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$309$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$309$$)});$is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$);var $is_grid_parent_ref$jscomp$1_is_layout_child_absolute_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$309$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$309$$)}),$is_grid_parent_QMARK_$jscomp$1$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$1_is_layout_child_absolute_QMARK_$jscomp$1$$);$is_grid_parent_ref$jscomp$1_is_layout_child_absolute_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1026$$);var $parents$jscomp$14_parents_by_ids_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$309$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$309$$)});$parents$jscomp$14_parents_by_ids_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($parents$jscomp$14_parents_by_ids_ref$jscomp$1$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$309$$,type:$props_79560_type$jscomp$665$$,appliedTokens:$applied_tokens$jscomp$22$$,values:$layer_values$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$309$$,appliedTokens:$applied_tokens$jscomp$22$$,type:$props_79560_type$jscomp$665$$,values:$measure_values$jscomp$1$$,shapes:$shapes$jscomp$217$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,{type:$props_79560_type$jscomp$665$$,ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1026$$)],null),
values:$layout_container_values$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$22$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$851$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$309$$),1);return $and__5023__auto__$jscomp$851$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$2$$)?$is_grid_parent_QMARK_$jscomp$1$$:$is_layout_child_QMARK_$jscomp$2$$:$and__5023__auto__$jscomp$851$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,
{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($parents$jscomp$14_parents_by_ids_ref$jscomp$1$$)),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$14_parents_by_ids_ref$jscomp$1$$),$APP.$cljs$core$first$$($ids$jscomp$309$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,{values:$layout_item_values$jscomp$1$$,
isLayoutChild:!0,shape:$shape$jscomp$1026$$,appliedTokens:$applied_tokens$jscomp$22$$,ids:$ids$jscomp$309$$,isFlexParent:$is_flex_parent_QMARK_$jscomp$1_is_flex_parent_ref$jscomp$1_is_layout_child_ref$jscomp$1$$,type:$props_79560_type$jscomp$665$$,isLayoutContainer:!1,isGridParent:$is_grid_parent_QMARK_$jscomp$1$$}):null,!$is_layout_child_QMARK_$jscomp$2$$||$is_grid_parent_ref$jscomp$1_is_layout_child_absolute_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,
{ids:$ids$jscomp$309$$,values:$constraint_values$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$309$$,type:$props_79560_type$jscomp$665$$,values:$shape$jscomp$1026$$,appliedTokens:$applied_tokens$jscomp$22$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$309$$,type:$props_79560_type$jscomp$665$$,values:$stroke_values$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$22$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$309$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1026$$,$APP.$cljs$cst$1659$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$309$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1197$background_blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$309$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1898$svg_attrs$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79560_type$jscomp$665$$,
ids:$ids$jscomp$309$$,shapes:$shapes$jscomp$217$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1026$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$433$$,fileId:$file_id$jscomp$412$$})]})};
$app$main$ui$workspace$sidebar$options$menus$color_selection$prepare_colors$$=function($groups$jscomp$16_shapes$jscomp$218$$,$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$,$libraries$jscomp$152_token_colors$$){$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$nil_QMARK_$$),$APP.$app$main$data$workspace$colors$extract_all_colors$$($groups$jscomp$16_shapes$jscomp$218$$,
$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$,$libraries$jscomp$152_token_colors$$));$groups$jscomp$16_shapes$jscomp$218$$=$APP.$app$common$data$group_by$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$2656$attrs$$,function($p1__79561_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__79561_SHARP_$$,$APP.$cljs$cst$2656$attrs$$)},$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$);$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$=$APP.$cljs$core$distinct$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2656$attrs$$,
$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$));$libraries$jscomp$152_token_colors$$=$APP.$cljs$core$filterv$$($APP.$cljs$cst$4253$token_name$$,$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$);var $library_colors$jscomp$2$$=$APP.$cljs$core$filterv$$(function($c$jscomp$316$$){return $APP.$cljs$cst$1741$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$316$$)!=null&&$APP.$cljs$cst$4253$token_name$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$316$$)==null},$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$),
$colors$jscomp$25$$=$APP.$cljs$core$filterv$$(function($c$jscomp$317$$){return $APP.$cljs$cst$1741$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$317$$)==null&&$APP.$cljs$cst$4253$token_name$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$317$$)==null},$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4449$groups$$,$groups$jscomp$16_shapes$jscomp$218$$,$cljs$cst$5810$all_colors$$,$all_colors$jscomp$3_data$jscomp$488_file_id$jscomp$413$$,
$APP.$cljs$cst$2220$colors$$,$colors$jscomp$25$$,$cljs$cst$5811$token_colors$$,$libraries$jscomp$152_token_colors$$,$cljs$cst$5812$library_colors$$,$library_colors$jscomp$2$$],null)};
$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$=function($color_operations_prev_groups$jscomp$17$$,$old_color$jscomp$3_old_color__$1$$,$prev_color$jscomp$3_prev_colors$$){$old_color$jscomp$3_old_color__$1$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($old_color$jscomp$3_old_color__$1$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$])));
$prev_color$jscomp$3_prev_colors$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$get$$,$color_operations_prev_groups$jscomp$17$$),$prev_color$jscomp$3_prev_colors$$);var $color_operations_old$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_operations_prev_groups$jscomp$17$$,$old_color$jscomp$3_old_color__$1$$);$color_operations_prev_groups$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_operations_prev_groups$jscomp$17$$,
$prev_color$jscomp$3_prev_colors$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$truth_$$($color_operations_prev_groups$jscomp$17$$)?$color_operations_prev_groups$jscomp$17$$:$color_operations_old$$,$APP.$cljs$core$truth_$$($prev_color$jscomp$3_prev_colors$$)?$prev_color$jscomp$3_prev_colors$$:$old_color$jscomp$3_old_color__$1$$],null)};
$app$common$geom$grid$calculate_generic_grid$$=function($v$jscomp$673$$,$total_length$$,$map__79627__$1_p__79626$$){$map__79627__$1_p__79626$$=$APP.$cljs$core$__destructure_map$$($map__79627__$1_p__79626$$);var $size$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79627__$1_p__79626$$,$APP.$cljs$cst$874$size$$),$gutter$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79627__$1_p__79626$$,$APP.$cljs$cst$1948$gutter$$),$margin$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79627__$1_p__79626$$,
$APP.$cljs$cst$1946$margin$$),$item_length$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79627__$1_p__79626$$,$APP.$cljs$cst$1947$item_length$$),$type$jscomp$666$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79627__$1_p__79626$$,$APP.$cljs$cst$139$type$$),$size__$1$jscomp$8$$=typeof $size$jscomp$159$$==="number"?$size$jscomp$159$$:$APP.$app$common$math$floor$$(($total_length$$-($margin$jscomp$4$$+($margin$jscomp$4$$-$gutter$jscomp$2$$)))/(($APP.$cljs$core$truth_$$($item_length$jscomp$1$$)?
$item_length$jscomp$1$$:($total_length$$-($margin$jscomp$4$$+($margin$jscomp$4$$-$gutter$jscomp$2$$))-$gutter$jscomp$2$$*12)/12)+$gutter$jscomp$2$$)),$item_length__$1$jscomp$1$$=typeof $item_length$jscomp$1$$==="number"?$item_length$jscomp$1$$:$total_length$$/$size__$1$jscomp$8$$+-$gutter$jscomp$2$$+$gutter$jscomp$2$$/$size__$1$jscomp$8$$+-($margin$jscomp$4$$*2/$size__$1$jscomp$8$$),$offset$jscomp$212$$=function(){switch($type$jscomp$666$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$666$$.$fqn$:
null){case "right":return $total_length$$-$item_length__$1$jscomp$1$$*$size__$1$jscomp$8$$-$gutter$jscomp$2$$*($size__$1$jscomp$8$$-1)-$margin$jscomp$4$$;case "center":return($total_length$$-$item_length__$1$jscomp$1$$*$size__$1$jscomp$8$$-$gutter$jscomp$2$$*($size__$1$jscomp$8$$-1))/2;default:return $margin$jscomp$4$$}}(),$gutter__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1674$stretch$$,$type$jscomp$666$$)?function(){var $gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13837$$=
0>$gutter$jscomp$2$$?0:$gutter$jscomp$2$$;var $y__5111__auto__$jscomp$inline_13838$$=($total_length$$-$item_length__$1$jscomp$1$$*$size__$1$jscomp$8$$-$margin$jscomp$4$$*2)/($size__$1$jscomp$8$$-1);$gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13837$$=$gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13837$$>$y__5111__auto__$jscomp$inline_13838$$?$gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13837$$:$y__5111__auto__$jscomp$inline_13838$$;return $APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13837$$))?
$gutter__$1$jscomp$1_x__5110__auto__$jscomp$inline_13837$$:0}():$gutter$jscomp$2$$;return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$size__$1$jscomp$8$$,$item_length__$1$jscomp$1$$,function($cur_val$jscomp$2$$){return $offset$jscomp$212$$+$v$jscomp$673$$+($item_length__$1$jscomp$1$$+$gutter__$1$$)*$cur_val$jscomp$2$$},$gutter__$1$$],null)};
$app$common$geom$grid$calculate_column_grid$$=function($height$jscomp$171_p__79629$$,$params$jscomp$422_size$jscomp$160$$){var $map__79630__$1_y$jscomp$476$$=$APP.$cljs$core$__destructure_map$$($height$jscomp$171_p__79629$$),$width$jscomp$200_width__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79630__$1_y$jscomp$476$$,$APP.$cljs$cst$290$width$$);$height$jscomp$171_p__79629$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79630__$1_y$jscomp$476$$,$APP.$cljs$cst$1527$height$$);
var $next_x_vec__79631_x$jscomp$1255$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79630__$1_y$jscomp$476$$,$APP.$cljs$cst$1515$x$$);$map__79630__$1_y$jscomp$476$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79630__$1_y$jscomp$476$$,$APP.$cljs$cst$1516$y$$);$next_x_vec__79631_x$jscomp$1255$$=$app$common$geom$grid$calculate_generic_grid$$($next_x_vec__79631_x$jscomp$1255$$,$width$jscomp$200_width__$1$jscomp$10$$,$params$jscomp$422_size$jscomp$160$$);$params$jscomp$422_size$jscomp$160$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_x_vec__79631_x$jscomp$1255$$,0,null);$width$jscomp$200_width__$1$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_x_vec__79631_x$jscomp$1255$$,1,null);$next_x_vec__79631_x$jscomp$1255$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($next_x_vec__79631_x$jscomp$1255$$,2,null);return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$params$jscomp$422_size$jscomp$160$$,
$width$jscomp$200_width__$1$jscomp$10$$,$height$jscomp$171_p__79629$$,$next_x_vec__79631_x$jscomp$1255$$,$APP.$cljs$core$constantly$$($map__79630__$1_y$jscomp$476$$)],null)};
$app$common$geom$grid$calculate_row_grid$$=function($p__79634_width$jscomp$201$$,$params$jscomp$423_size$jscomp$161$$){var $map__79635__$1_next_y_vec__79636_y$jscomp$477$$=$APP.$cljs$core$__destructure_map$$($p__79634_width$jscomp$201$$);$p__79634_width$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79635__$1_next_y_vec__79636_y$jscomp$477$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$172_height__$1$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79635__$1_next_y_vec__79636_y$jscomp$477$$,
$APP.$cljs$cst$1527$height$$),$x$jscomp$1256$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79635__$1_next_y_vec__79636_y$jscomp$477$$,$APP.$cljs$cst$1515$x$$);$map__79635__$1_next_y_vec__79636_y$jscomp$477$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79635__$1_next_y_vec__79636_y$jscomp$477$$,$APP.$cljs$cst$1516$y$$);$map__79635__$1_next_y_vec__79636_y$jscomp$477$$=$app$common$geom$grid$calculate_generic_grid$$($map__79635__$1_next_y_vec__79636_y$jscomp$477$$,$height$jscomp$172_height__$1$jscomp$6$$,
$params$jscomp$423_size$jscomp$161$$);$params$jscomp$423_size$jscomp$161$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__79635__$1_next_y_vec__79636_y$jscomp$477$$,0,null);$height$jscomp$172_height__$1$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__79635__$1_next_y_vec__79636_y$jscomp$477$$,1,null);$map__79635__$1_next_y_vec__79636_y$jscomp$477$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__79635__$1_next_y_vec__79636_y$jscomp$477$$,2,
null);return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$params$jscomp$423_size$jscomp$161$$,$p__79634_width$jscomp$201$$,$height$jscomp$172_height__$1$jscomp$6$$,$APP.$cljs$core$constantly$$($x$jscomp$1256$$),$map__79635__$1_next_y_vec__79636_y$jscomp$477$$],null)};
$app$common$geom$grid$calculate_square_grid$$=function($p__79639_width$jscomp$202$$,$map__79642__$1_p__79640$$){function $as_row_col$$($value$jscomp$931$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$quot$$($value$jscomp$931$$,$col_size$$),$APP.$cljs$core$rem$$($value$jscomp$931$$,$col_size$$)],null)}var $map__79641__$1$$=$APP.$cljs$core$__destructure_map$$($p__79639_width$jscomp$202$$);$p__79639_width$jscomp$202$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79641__$1$$,
$APP.$cljs$cst$290$width$$);var $height$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79641__$1$$,$APP.$cljs$cst$1527$height$$),$x$jscomp$1257$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79641__$1$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$478$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79641__$1$$,$APP.$cljs$cst$1516$y$$);$map__79642__$1_p__79640$$=$APP.$cljs$core$__destructure_map$$($map__79642__$1_p__79640$$);var $size$jscomp$162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79642__$1_p__79640$$,
$APP.$cljs$cst$874$size$$),$col_size$$=$APP.$cljs$core$quot$$($p__79639_width$jscomp$202$$,$size$jscomp$162$$);return new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$col_size$$*$APP.$cljs$core$quot$$($height$jscomp$173$$,$size$jscomp$162$$),$size$jscomp$162$$,$size$jscomp$162$$,function($col$jscomp$24_cur_val$jscomp$3_vec__79643$$){$col$jscomp$24_cur_val$jscomp$3_vec__79643$$=$as_row_col$$($col$jscomp$24_cur_val$jscomp$3_vec__79643$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($col$jscomp$24_cur_val$jscomp$3_vec__79643$$,
0,null);$col$jscomp$24_cur_val$jscomp$3_vec__79643$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($col$jscomp$24_cur_val$jscomp$3_vec__79643$$,1,null);return $x$jscomp$1257$$+$col$jscomp$24_cur_val$jscomp$3_vec__79643$$*$size$jscomp$162$$},function($cur_val$jscomp$4_vec__79646$$){$cur_val$jscomp$4_vec__79646$$=$as_row_col$$($cur_val$jscomp$4_vec__79646$$);var $row$jscomp$34$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_val$jscomp$4_vec__79646$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($cur_val$jscomp$4_vec__79646$$,
1,null);return $y$jscomp$478$$+$row$jscomp$34$$*$size$jscomp$162$$}],null)};
$app$common$geom$grid$grid_gutter$$=function($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,$p__79650_type$jscomp$667$$){var $height$jscomp$174_map__79651__$1$$=$APP.$cljs$core$__destructure_map$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$);$gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$174_map__79651__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$479$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$174_map__79651__$1$$,
$APP.$cljs$cst$1516$y$$),$width$jscomp$203$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$174_map__79651__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$174_map__79651__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$174_map__79651__$1$$,$APP.$cljs$cst$1527$height$$);var $map__79652__$1_params$jscomp$425$$=$APP.$cljs$core$__destructure_map$$($p__79650_type$jscomp$667$$);$p__79650_type$jscomp$667$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79652__$1_params$jscomp$425$$,
$APP.$cljs$cst$139$type$$);$map__79652__$1_params$jscomp$425$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79652__$1_params$jscomp$425$$,$APP.$cljs$cst$1435$params$$);switch($p__79650_type$jscomp$667$$ instanceof $APP.$cljs$core$Keyword$$?$p__79650_type$jscomp$667$$.$fqn$:null){case "column":return $gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$=$app$common$geom$grid$calculate_generic_grid$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,$width$jscomp$203$$,
$map__79652__$1_params$jscomp$425$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,0,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,1,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,2,null),$gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,
3,null);case "row":return $gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$=$app$common$geom$grid$calculate_generic_grid$$($y$jscomp$479$$,$height$jscomp$174_map__79651__$1$$,$map__79652__$1_params$jscomp$425$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,0,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,1,null),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,
2,null),$gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gutter$jscomp$3_p__79649_vec__79654_vec__79657_x$jscomp$1258$$,3,null);default:return null}};
$app$common$geom$grid$grid_areas$$=function($frame$jscomp$75$$,$grid$jscomp$12$$){var $grid_fn$$=function(){var $G__79664_G__79664__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$12$$);$G__79664_G__79664__$1$$=$G__79664_G__79664__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__79664_G__79664__$1$$.$fqn$:null;switch($G__79664_G__79664__$1$$){case "column":return $app$common$geom$grid$calculate_column_grid$$;case "row":return $app$common$geom$grid$calculate_row_grid$$;case "square":return $app$common$geom$grid$calculate_square_grid$$;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79664_G__79664__$1$$)].join(""));}}(),$vec__79661$$=function(){var $G__79666$$=$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$12$$);return $grid_fn$$.$cljs$core$IFn$_invoke$arity$2$?$grid_fn$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$75$$,$G__79666$$):$grid_fn$$($frame$jscomp$75$$,$G__79666$$)}(),$num_items$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79661$$,
0,null),$item_width$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79661$$,1,null),$item_height$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79661$$,2,null),$next_x$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79661$$,3,null),$next_y$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79661$$,4,null);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79660_SHARP_$$){return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1515$x$$,
$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1527$height$$],[$next_x$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$next_x$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($p1__79660_SHARP_$$):$next_x$jscomp$2$$($p1__79660_SHARP_$$),$next_y$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$next_y$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($p1__79660_SHARP_$$):$next_y$jscomp$2$$($p1__79660_SHARP_$$),$item_width$$,$item_height$$])},$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$02$$(0,
$num_items$jscomp$1$$))};
$app$main$data$workspace$grid$add_frame_grid$$=function($frame_id$jscomp$146$$){typeof $app$main$data$workspace$grid$add_frame_grid_79680$$==="undefined"&&($app$main$data$workspace$grid$add_frame_grid_79680$$=function($frame_id$jscomp$147$$,$meta79681$$){this.$frame_id$=$frame_id$jscomp$147$$;this.$meta79681$=$meta79681$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid$add_frame_grid_79680$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$grid$add_frame_grid_79680$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5813$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_add_frame_grid$$},$app$main$data$workspace$grid$add_frame_grid_79680$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79682$$,$meta79681__$1$$){return new $app$main$data$workspace$grid$add_frame_grid_79680$$(this.$frame_id$,$meta79681__$1$$)},$app$main$data$workspace$grid$add_frame_grid_79680$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta79681$},$app$main$data$workspace$grid$add_frame_grid_79680$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$add_frame_grid_79680$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3077_params$jscomp$427$$,$state$jscomp$1210$$){var $page$jscomp$168$$=$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1210$$);$_$jscomp$3077_params$jscomp$427$$=function(){var $or__5025__auto__$jscomp$1264$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$168$$,$APP.$cljs$cst$2063$default_grids$$),$APP.$cljs$cst$1912$square$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1264$$)?$or__5025__auto__$jscomp$1264$$:$APP.$cljs$cst$1912$square$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$types$grid$default_grid_params$$)}();var $grid$jscomp$14$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,
$APP.$cljs$cst$1912$square$$,$APP.$cljs$cst$1435$params$$,$_$jscomp$3077_params$jscomp$427$$,$APP.$cljs$cst$1949$display$$,!0],null);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$frame_id$],null),function($obj$jscomp$223$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($obj$jscomp$223$$,$APP.$cljs$cst$2058$grids$$,
$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79679_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__79679_SHARP_$$,$grid$jscomp$14$$)},$APP.$cljs$core$PersistentVector$EMPTY$$))}))});return new $app$main$data$workspace$grid$add_frame_grid_79680$$($frame_id$jscomp$146$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid$remove_frame_grid$$=function($frame_id$jscomp$148$$,$index$jscomp$532$$){typeof $app$main$data$workspace$grid$remove_frame_grid_79684$$==="undefined"&&($app$main$data$workspace$grid$remove_frame_grid_79684$$=function($frame_id$jscomp$149$$,$index$jscomp$533$$,$meta79685$$){this.$frame_id$=$frame_id$jscomp$149$$;this.index=$index$jscomp$533$$;this.$meta79685$=$meta79685$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid$remove_frame_grid_79684$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$remove_frame_grid_79684$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5814$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_remove_frame_grid$$},$app$main$data$workspace$grid$remove_frame_grid_79684$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79686$$,$meta79685__$1$$){return new $app$main$data$workspace$grid$remove_frame_grid_79684$$(this.$frame_id$,this.index,$meta79685__$1$$)},$app$main$data$workspace$grid$remove_frame_grid_79684$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta79685$},$app$main$data$workspace$grid$remove_frame_grid_79684$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$remove_frame_grid_79684$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7508$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$self__$jscomp$7508$$.$frame_id$],null),function($o$jscomp$276$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($o$jscomp$276$$,$APP.$cljs$cst$2058$grids$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79683_SHARP_$$){return $APP.$app$common$data$remove_at_index$$($p1__79683_SHARP_$$,$self__$jscomp$7508$$.index)},$APP.$cljs$core$PersistentVector$EMPTY$$))}))});return new $app$main$data$workspace$grid$remove_frame_grid_79684$$($frame_id$jscomp$148$$,$index$jscomp$532$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid$set_frame_grid$$=function($frame_id$jscomp$150$$,$index$jscomp$534$$,$data$jscomp$489$$){typeof $app$main$data$workspace$grid$set_frame_grid_79688$$==="undefined"&&($app$main$data$workspace$grid$set_frame_grid_79688$$=function($frame_id$jscomp$151$$,$index$jscomp$535$$,$data$jscomp$490$$,$meta79689$$){this.$frame_id$=$frame_id$jscomp$151$$;this.index=$index$jscomp$535$$;this.data=$data$jscomp$490$$;this.$meta79689$=$meta79689$$;this.$cljs$lang$protocol_mask$partition0$$=
393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid$set_frame_grid_79688$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$set_frame_grid_79688$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5815$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_set_frame_grid$$},$app$main$data$workspace$grid$set_frame_grid_79688$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79690$$,$meta79689__$1$$){return new $app$main$data$workspace$grid$set_frame_grid_79688$$(this.$frame_id$,
this.index,this.data,$meta79689__$1$$)},$app$main$data$workspace$grid$set_frame_grid_79688$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta79689$},$app$main$data$workspace$grid$set_frame_grid_79688$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$set_frame_grid_79688$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7512$$=this;return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$self__$jscomp$7512$$.$frame_id$],null),function($p1__79687_SHARP_$$){return $APP.$cljs$core$assoc_in$$($p1__79687_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2058$grids$$,$self__$jscomp$7512$$.index],null),$self__$jscomp$7512$$.data)}))});return new $app$main$data$workspace$grid$set_frame_grid_79688$$($frame_id$jscomp$150$$,$index$jscomp$534$$,$data$jscomp$489$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$grid$set_default_grid$$=function($type$jscomp$669$$,$params$jscomp$428$$){typeof $app$main$data$workspace$grid$set_default_grid_79691$$==="undefined"&&($app$main$data$workspace$grid$set_default_grid_79691$$=function($type$jscomp$670$$,$params$jscomp$429$$,$meta79692$$){this.type=$type$jscomp$670$$;this.params=$params$jscomp$429$$;this.$meta79692$=$meta79692$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid$set_default_grid_79691$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$set_default_grid_79691$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5816$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_set_default_grid$$},$app$main$data$workspace$grid$set_default_grid_79691$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_79693$$,$meta79692__$1$$){return new $app$main$data$workspace$grid$set_default_grid_79691$$(this.type,this.params,$meta79692__$1$$)},$app$main$data$workspace$grid$set_default_grid_79691$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta79692$},$app$main$data$workspace$grid$set_default_grid_79691$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid$set_default_grid_79691$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$,$page_id$jscomp$inline_9068_state$jscomp$1211$$){$JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$=
$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$inline_9068_state$jscomp$1211$$);var $changes$jscomp$inline_9065_changes__$1$jscomp$inline_9071$$=$APP.$app$common$files$changes_builder$with_page$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),$JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$);$JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$=
this.type;var $params$jscomp$inline_9067$$=this.params;$page_id$jscomp$inline_9068_state$jscomp$1211$$=$APP.$cljs$cst$3190$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$inline_9065_changes__$1$jscomp$inline_9071$$));var $old_val$jscomp$inline_9070_page$jscomp$inline_9069$$=$APP.$cljs$cst$3191$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_page$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$inline_9065_changes__$1$jscomp$inline_9071$$));
$old_val$jscomp$inline_9070_page$jscomp$inline_9069$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_val$jscomp$inline_9070_page$jscomp$inline_9069$$,$APP.$cljs$cst$2058$grids$$),$JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$);$changes$jscomp$inline_9065_changes__$1$jscomp$inline_9071$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_9065_changes__$1$jscomp$inline_9071$$,
$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2613$set_default_grid$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$inline_9068_state$jscomp$1211$$,$APP.$cljs$cst$2614$grid_type$$,$JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$,$APP.$cljs$cst$1435$params$$,$params$jscomp$inline_9067$$],null));$JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$inline_9065_changes__$1$jscomp$inline_9071$$,$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2613$set_default_grid$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$inline_9068_state$jscomp$1211$$,$APP.$cljs$cst$2614$grid_type$$,$JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$,
$APP.$cljs$cst$1435$params$$,$old_val$jscomp$inline_9070_page$jscomp$inline_9069$$],null));$JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($JSCompiler_inline_result$jscomp$1672_changes__$2$jscomp$inline_9072_it$jscomp$278_page$jscomp$169_type$jscomp$inline_9066$$))});
return new $app$main$data$workspace$grid$set_default_grid_79691$$($type$jscomp$669$$,$params$jscomp$428$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$sidebar$options$menus$frame_grid$get_size_options$$=function(){return new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,null,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.auto")],null),$APP.$cljs$cst$1477$separator$$,18,12,10,8,6,4,3,2],null)};
$app$main$ui$workspace$sidebar$options$shapes$frame$options_STAR_$$=function($props_79733_shape_type$jscomp$7$$){var $shapes_with_children$jscomp$1$$=$props_79733_shape_type$jscomp$7$$.shapesWithChildren,$file_id$jscomp$415$$=$props_79733_shape_type$jscomp$7$$.fileId,$libraries$jscomp$154$$=$props_79733_shape_type$jscomp$7$$.libraries,$page_id$jscomp$434$$=$props_79733_shape_type$jscomp$7$$.pageId,$shape$jscomp$1028$$=$props_79733_shape_type$jscomp$7$$.shape,$shape_id$jscomp$165$$=$shape$jscomp$1028$$?.id??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1028$$,$APP.$cljs$cst$266$id$$);$props_79733_shape_type$jscomp$7$$=$shape$jscomp$1028$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1028$$,$APP.$cljs$cst$139$type$$);var $ids$jscomp$311$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$165$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape_id$jscomp$165$$],null)}),$shapes$jscomp$220$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1028$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1028$$],null)}),$applied_tokens$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1028$$,$APP.$cljs$cst$1881$applied_tokens$$),$stroke_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1028$$,
$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1028$$,$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$measure_values$jscomp$2$$=$app$main$ui$workspace$sidebar$options$menus$measures$select_measure_keys$$($shape$jscomp$1028$$),$constraint_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1028$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_container_values$jscomp$2$$=
$APP.$cljs$core$select_keys$$($shape$jscomp$1028$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),$layout_item_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1028$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$311$$)],
function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$311$$)}),$is_layout_child_QMARK_$jscomp$3$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$);$is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$311$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$311$$)});
$is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$);var $is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$311$$)],function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$311$$)}),$is_grid_parent_QMARK_$jscomp$2$$=
$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$);$is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$311$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$311$$)});$is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$);
var $is_layout_container_QMARK_$$=$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1028$$),$is_flex_layout_QMARK_$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1028$$),$is_grid_layout_QMARK_$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1028$$),$is_layout_child_absolute_QMARK_$jscomp$2$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1028$$),
$is_variant_QMARK_$jscomp$4$$=$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$1028$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$311$$,type:$props_79733_shape_type$jscomp$7$$,appliedTokens:$applied_tokens$jscomp$23$$,values:$layer_values$jscomp$2$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$311$$,appliedTokens:$applied_tokens$jscomp$23$$,values:$measure_values$jscomp$2$$,type:$props_79733_shape_type$jscomp$7$$,shapes:$shapes$jscomp$220$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$,{shapes:$shapes$jscomp$220$$}),$is_variant_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_variant_main_STAR_$$,{shapes:$shapes$jscomp$220$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,
{type:$props_79733_shape_type$jscomp$7$$,ids:$ids$jscomp$311$$,appliedTokens:$applied_tokens$jscomp$23$$,values:$layout_container_values$jscomp$2$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$853$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$311$$),1);return $and__5023__auto__$jscomp$853$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$3$$)?$is_grid_parent_QMARK_$jscomp$2$$:$is_layout_child_QMARK_$jscomp$3$$:
$and__5023__auto__$jscomp$853$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$)),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($is_grid_parent_ref$jscomp$2_parents$jscomp$15_parents_by_ids_ref$jscomp$2$$),$APP.$cljs$core$first$$($ids$jscomp$311$$))}):
null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$3$$)?$is_layout_child_QMARK_$jscomp$3$$:$is_layout_container_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,{values:$layout_item_values$jscomp$2$$,isLayoutChild:$is_layout_child_QMARK_$jscomp$3$$,shape:$shape$jscomp$1028$$,appliedTokens:$applied_tokens$jscomp$23$$,ids:$ids$jscomp$311$$,isFlexParent:$is_flex_parent_QMARK_$jscomp$2_is_flex_parent_ref$jscomp$2_is_layout_child_ref$jscomp$2$$,
isFlexLayout:$is_flex_layout_QMARK_$$,isGridLayout:$is_grid_layout_QMARK_$$,type:$props_79733_shape_type$jscomp$7$$,isLayoutContainer:$is_layout_container_QMARK_$$,isGridParent:$is_grid_parent_QMARK_$jscomp$2$$}):null,!$is_layout_child_QMARK_$jscomp$3$$||$is_layout_child_absolute_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$311$$,values:$constraint_values$jscomp$2$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,
{ids:$ids$jscomp$311$$,type:$props_79733_shape_type$jscomp$7$$,values:$shape$jscomp$1028$$,appliedTokens:$applied_tokens$jscomp$23$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$311$$,type:$props_79733_shape_type$jscomp$7$$,values:$stroke_values$jscomp$2$$,appliedTokens:$applied_tokens$jscomp$23$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$,{type:$props_79733_shape_type$jscomp$7$$,
shapes:$shapes_with_children$jscomp$1$$,fileId:$file_id$jscomp$415$$,libraries:$libraries$jscomp$154$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$311$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1028$$,$APP.$cljs$cst$1659$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$311$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1028$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1197$background_blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$frame_grid$frame_grid_STAR_$$,{grids:$APP.$cljs$cst$2058$grids$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1028$$),id:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1028$$),frameWidth:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1028$$),
frameHeight:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1028$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79733_shape_type$jscomp$7$$,ids:$ids$jscomp$311$$,shapes:$shapes$jscomp$220$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1028$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$434$$,fileId:$file_id$jscomp$415$$})]})};
$app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$=function($options__$1$jscomp$88_props_79695$$){var $options$jscomp$625$$=void 0,$on_change$jscomp$79$$=void 0,$selected$jscomp$174$$=void 0,$variant$jscomp$25$$=void 0,$disabled$jscomp$19$$=void 0,$extended$$=void 0,$name$jscomp$463$$=void 0,$allow_empty$jscomp$2$$=void 0,$class$$jscomp$74$$=void 0,$props$jscomp$328$$=void 0;({options:$options$jscomp$625$$,onChange:$on_change$jscomp$79$$,selected:$selected$jscomp$174$$,variant:$variant$jscomp$25$$,
disabled:$disabled$jscomp$19$$,extended:$extended$$,name:$name$jscomp$463$$,allowEmpty:$allow_empty$jscomp$2$$,className:$class$$jscomp$74$$,...$props$jscomp$328$$}=$options__$1$jscomp$88_props_79695$$);$options__$1$jscomp$88_props_79695$$=$APP.$cljs$core$array_QMARK_$$($options$jscomp$625$$)?$APP.$rumext$v2$util$bean$$($options$jscomp$625$$):$options$jscomp$625$$;var $type$jscomp$672$$=$APP.$cljs$core$truth_$$($allow_empty$jscomp$2$$)?"checkbox":"radio",$variant__$1$jscomp$6$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$25$$,
"secondary"),$wrapper_disabled$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($disabled$jscomp$19$$,!1),$handle_click$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$174$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$79$$),$APP.$rumext$v2$adapt$$($allow_empty$jscomp$2$$)],function($disabled_QMARK_$jscomp$7_event$jscomp$560_target$jscomp$154$$){$disabled_QMARK_$jscomp$7_event$jscomp$560_target$jscomp$154$$=$APP.$app$util$dom$get_target$$($disabled_QMARK_$jscomp$7_event$jscomp$560_target$jscomp$154$$);
var $input$jscomp$73_label$jscomp$51$$=$APP.$app$util$dom$get_parent_with_data$$($disabled_QMARK_$jscomp$7_event$jscomp$560_target$jscomp$154$$,"label");$input$jscomp$73_label$jscomp$51$$=$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($input$jscomp$73_label$jscomp$51$$,"input");$disabled_QMARK_$jscomp$7_event$jscomp$560_target$jscomp$154$$=$APP.$app$util$dom$get_attribute$$($disabled_QMARK_$jscomp$7_event$jscomp$560_target$jscomp$154$$,"disabled");return $APP.$cljs$core$truth_$$($disabled_QMARK_$jscomp$7_event$jscomp$560_target$jscomp$154$$)?
null:$APP.$app$util$dom$click$$($input$jscomp$73_label$jscomp$51$$)}),$handle_change$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$174$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$79$$),$APP.$rumext$v2$adapt$$($allow_empty$jscomp$2$$)],function($event$jscomp$561$$){var $input$jscomp$74$$=$APP.$app$util$dom$get_target$$($event$jscomp$561$$),$new_value$jscomp$26_value$jscomp$933$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$561$$),
$JSCompiler_inline_result$jscomp$1843_selected_str$$=$APP.$cljs$core$truth_$$($selected$jscomp$174$$)?$APP.$app$common$data$name$$($selected$jscomp$174$$):null,$and__5023__auto__$jscomp$inline_9074$$=$allow_empty$jscomp$2$$;$JSCompiler_inline_result$jscomp$1843_selected_str$$=$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9074$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$26_value$jscomp$933$$,$JSCompiler_inline_result$jscomp$1843_selected_str$$):$and__5023__auto__$jscomp$inline_9074$$;
$new_value$jscomp$26_value$jscomp$933$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1843_selected_str$$)?null:$new_value$jscomp$26_value$jscomp$933$$;$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$79$$)&&($on_change$jscomp$79$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$79$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$26_value$jscomp$933$$,$event$jscomp$561$$):$on_change$jscomp$79$$($new_value$jscomp$26_value$jscomp$933$$,$event$jscomp$561$$));return $APP.$app$util$dom$blur_BANG_$$($input$jscomp$74$$)});
return(0,$APP.$rumext$v2$create_element$$)("div",{...$props$jscomp$328$$,key:""+($name$jscomp$463$$??"")+"-"+($selected$jscomp$174$$??""),className:($class$$jscomp$74$$??"")+" main_ui_ds_controls_radio_buttons__wrapper "+(($APP.$cljs$core$truth_$$($disabled$jscomp$19$$)?"main_ui_ds_controls_radio_buttons__disabled":"")+" "+($APP.$cljs$core$truth_$$($extended$$)?"main_ui_ds_controls_radio_buttons__extended":""))},$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$188$$,
$id$jscomp$977_map__79700_p__79696$$){var $JSCompiler_inline_result$jscomp$11304_idx$jscomp$126$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$977_map__79700_p__79696$$,0,null);$id$jscomp$977_map__79700_p__79696$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$977_map__79700_p__79696$$,1,null);var $JSCompiler_temp_const$jscomp$11302_map__79700__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$977_map__79700_p__79696$$);$id$jscomp$977_map__79700_p__79696$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11302_map__79700__$1$$,$APP.$cljs$cst$266$id$$);var $class$__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11302_map__79700__$1$$,$APP.$cljs$cst$1296$class$$),$value$jscomp$934$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11302_map__79700__$1$$,$APP.$cljs$cst$260$value$$),$label$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11302_map__79700__$1$$,
$APP.$cljs$cst$2296$label$$),$icon$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11302_map__79700__$1$$,$APP.$cljs$cst$1727$icon$$),$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$11302_map__79700__$1$$,$APP.$cljs$cst$2959$disabled$$);$JSCompiler_temp_const$jscomp$11302_map__79700__$1$$=$out_arr__44092__auto__$jscomp$188$$.push;var $checked_QMARK_$jscomp$inline_13842_value_str$jscomp$inline_13840$$=
$APP.$app$common$data$name$$($value$jscomp$934$$),$selected_str$jscomp$inline_13841$$=$APP.$cljs$core$truth_$$($selected$jscomp$174$$)?$APP.$app$common$data$name$$($selected$jscomp$174$$):null;$checked_QMARK_$jscomp$inline_13842_value_str$jscomp$inline_13840$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected_str$jscomp$inline_13841$$,$checked_QMARK_$jscomp$inline_13842_value_str$jscomp$inline_13840$$);$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$,
!1);$JSCompiler_inline_result$jscomp$11304_idx$jscomp$126$$=(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:$id$jscomp$977_map__79700_p__79696$$,"data-label":!0,"data-testid":$id$jscomp$977_map__79700_p__79696$$,className:($class$__$1$jscomp$10$$??"")+" main_ui_ds_controls_radio_buttons__label "+($APP.$cljs$core$truth_$$($extended$$)?"main_ui_ds_controls_radio_buttons__extended":""),children:[$icon$jscomp$23$$!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:$variant__$1$jscomp$6$$,onClick:$handle_click$jscomp$5$$,"aria-pressed":$checked_QMARK_$jscomp$inline_13842_value_str$jscomp$inline_13840$$,"aria-label":$label$jscomp$52$$,icon:$icon$jscomp$23$$,disabled:$APP.$cljs$core$truth_$$($disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$)?$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$:$wrapper_disabled$$}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:$variant__$1$jscomp$6$$,onClick:$handle_click$jscomp$5$$,
"aria-pressed":$checked_QMARK_$jscomp$inline_13842_value_str$jscomp$inline_13840$$,className:"main_ui_ds_controls_radio_buttons__button "+($APP.$cljs$core$truth_$$($extended$$)?"main_ui_ds_controls_radio_buttons__extended":""),disabled:$APP.$cljs$core$truth_$$($disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$)?$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$:$wrapper_disabled$$,children:$label$jscomp$52$$}),(0,$APP.$rumext$v2$jsx$$)("input",{id:$id$jscomp$977_map__79700_p__79696$$,
onChange:$handle_change$jscomp$13$$,type:$type$jscomp$672$$,name:$name$jscomp$463$$,disabled:$APP.$cljs$core$truth_$$($disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$)?$disabled__$1$jscomp$1_disabled__$2$jscomp$inline_13843$$:$wrapper_disabled$$,value:$value$jscomp$934$$,checked:$checked_QMARK_$jscomp$inline_13842_value_str$jscomp$inline_13840$$,className:"main_ui_ds_controls_radio_buttons__input"})]},$JSCompiler_inline_result$jscomp$11304_idx$jscomp$126$$);$JSCompiler_temp_const$jscomp$11302_map__79700__$1$$.call($out_arr__44092__auto__$jscomp$188$$,
$JSCompiler_inline_result$jscomp$11304_idx$jscomp$126$$);return $out_arr__44092__auto__$jscomp$188$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($options__$1$jscomp$88_props_79695$$)))};
$app$main$ui$ds$controls$shared$dropdown_navigation$use_dropdown_navigation$$=function($map__79728__$1_on_key_down$jscomp$19_p__79727$$){$map__79728__$1_on_key_down$jscomp$19_p__79727$$=$APP.$cljs$core$__destructure_map$$($map__79728__$1_on_key_down$jscomp$19_p__79727$$);var $focusable_ids$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79728__$1_on_key_down$jscomp$19_p__79727$$,$cljs$cst$5821$focusable_ids$$),$nodes_ref$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79728__$1_on_key_down$jscomp$19_p__79727$$,
$cljs$cst$5822$nodes_ref$$),$on_enter$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79728__$1_on_key_down$jscomp$19_p__79727$$,$cljs$cst$5823$on_enter$$),$searchable$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79728__$1_on_key_down$jscomp$19_p__79727$$,$cljs$cst$5824$searchable$$),$search_input_ref$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79728__$1_on_key_down$jscomp$19_p__79727$$,$cljs$cst$5825$search_input_ref$$),$on_close$jscomp$34$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79728__$1_on_key_down$jscomp$19_p__79727$$,$APP.$cljs$cst$5108$on_close$$),$focused_id_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$focused_id$jscomp$4$$=$APP.$cljs$core$_deref$$($focused_id_STAR_$jscomp$3$$),$focus_input_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($search_input_ref$jscomp$2$$)],function(){$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,
null);var $temp__5825__auto__$jscomp$391$$=$APP.$rumext$v2$ref_val$$($search_input_ref$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$391$$)?$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$391$$):null});$map__79728__$1_on_key_down$jscomp$19_p__79727$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$4$$),$APP.$rumext$v2$adapt$$($focusable_ids$$),$APP.$rumext$v2$adapt$$($searchable$$)],function($event$jscomp$562$$){if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$562$$))){$APP.$app$util$dom$prevent_default$$($event$jscomp$562$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$562$$);if($focused_id$jscomp$4$$==null)return $APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,$APP.$cljs$core$first$$($focusable_ids$$));var $idx$jscomp$127_wrap_to_input_QMARK_$$=function(){var $or__5025__auto__$jscomp$1274$$=$APP.$cljs$core$first$$($cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79724_SHARP_$$,$p2__79723_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p2__79723_SHARP_$$,
$focused_id$jscomp$4$$)?$p1__79724_SHARP_$$:null},$focusable_ids$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1274$$)?$or__5025__auto__$jscomp$1274$$:-1}(),$next_idx_prev_idx$$=$APP.$cljs$core$mod$$($idx$jscomp$127_wrap_to_input_QMARK_$$+1,$APP.$cljs$core$count$$($focusable_ids$$));return($idx$jscomp$127_wrap_to_input_QMARK_$$=$searchable$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($next_idx_prev_idx$$,0)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$127_wrap_to_input_QMARK_$$,
$APP.$cljs$core$count$$($focusable_ids$$)-1))?$focus_input_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$focus_input_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$focus_input_BANG_$$():$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($focusable_ids$$,$next_idx_prev_idx$$,null))}if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$562$$))){$APP.$app$util$dom$prevent_default$$($event$jscomp$562$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$562$$);
if($focused_id$jscomp$4$$==null)return $APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,$APP.$cljs$core$last$$($focusable_ids$$));$idx$jscomp$127_wrap_to_input_QMARK_$$=function(){var $or__5025__auto__$jscomp$1275$$=$APP.$cljs$core$first$$($cljs$core$keep_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79726_SHARP_$$,$p2__79725_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p2__79725_SHARP_$$,$focused_id$jscomp$4$$)?$p1__79726_SHARP_$$:null},$focusable_ids$$));
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1275$$)?$or__5025__auto__$jscomp$1275$$:0}();$next_idx_prev_idx$$=$idx$jscomp$127_wrap_to_input_QMARK_$$-1;return($idx$jscomp$127_wrap_to_input_QMARK_$$=$searchable$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($next_idx_prev_idx$$,-1))?$focus_input_BANG_$$.$cljs$core$IFn$_invoke$arity$0$?$focus_input_BANG_$$.$cljs$core$IFn$_invoke$arity$0$():$focus_input_BANG_$$():$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($focusable_ids$$,
$APP.$cljs$core$mod$$($next_idx_prev_idx$$,$APP.$cljs$core$count$$($focusable_ids$$)),null))}if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$562$$))){if($APP.$cljs$core$truth_$$($focused_id$jscomp$4$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$562$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$562$$),$on_enter$$.$cljs$core$IFn$_invoke$arity$1$?$on_enter$$.$cljs$core$IFn$_invoke$arity$1$($focused_id$jscomp$4$$):$on_enter$$($focused_id$jscomp$4$$)}else if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1276$$=
(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$562$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1276$$)?$or__5025__auto__$jscomp$1276$$:(0,$APP.$app$util$keyboard$tab_QMARK_$$)($event$jscomp$562$$)}()))return $APP.$app$util$dom$prevent_default$$($event$jscomp$562$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$562$$),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$3$$,null),$APP.$cljs$core$truth_$$($on_close$jscomp$34$$)?$on_close$jscomp$34$$.$cljs$core$IFn$_invoke$arity$0$?
$on_close$jscomp$34$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$34$$():null;return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$4$$)],function(){if($focused_id$jscomp$4$$!=null){var $temp__5825__auto__$jscomp$392$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$4$$),$focused_id$jscomp$4$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$392$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$392$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1405$block$$,"nearest",$APP.$cljs$cst$2359$inline$$,"nearest"],null)):null}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5826$focused_id$$,$focused_id$jscomp$4$$,$cljs$cst$5827$focused_id_STAR_$$,$focused_id_STAR_$jscomp$3$$,$cljs$cst$5828$on_key_down$$,$map__79728__$1_on_key_down$jscomp$19_p__79727$$],null)};
$app$main$ui$ds$controls$shared$searchable_options_dropdown$searchable_options_dropdown_STAR_$$=function($on_search_change$jscomp$3_props_79737$$){var $options$jscomp$626$$=void 0,$align$jscomp$5_align__$1$jscomp$3$$=void 0,$selected$jscomp$175$$=void 0,$placeholder$jscomp$7$$=void 0,$on_click$jscomp$48$$=void 0,$class$$jscomp$75_list_props$$=void 0,$props$jscomp$329$$=void 0;({onClick:$on_click$jscomp$48$$,options:$options$jscomp$626$$,selected:$selected$jscomp$175$$,align:$align$jscomp$5_align__$1$jscomp$3$$,
className:$class$$jscomp$75_list_props$$,placeholder:$placeholder$jscomp$7$$,...$props$jscomp$329$$}=$on_search_change$jscomp$3_props_79737$$);$align$jscomp$5_align__$1$jscomp$3$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$5_align__$1$jscomp$3$$,$APP.$cljs$cst$257$left$$);var $search_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$search$jscomp$9$$=$APP.$cljs$core$_deref$$($search_STAR_$jscomp$1$$),$search_input_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$list_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$nodes_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(null),$filtered_options$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$626$$),$APP.$rumext$v2$adapt$$($search$jscomp$9$$)],function(){return $APP.$cljs$core$seq$$($search$jscomp$9$$)?$APP.$cljs$core$filterv$$(function($opt$jscomp$3$$){var $or__5025__auto__$jscomp$1277$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1136$token$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($opt$jscomp$3$$));return $or__5025__auto__$jscomp$1277$$?$or__5025__auto__$jscomp$1277$$:$APP.$cuerdas$core$includes_QMARK_$$($APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($opt$jscomp$3$$,"")),$APP.$cuerdas$core$lower$$($search$jscomp$9$$))},$options$jscomp$626$$):$options$jscomp$626$$}),$focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filtered_options$$)],
function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$($filtered_options$$))});$on_search_change$jscomp$3_props_79737$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$563$$){return $APP.$cljs$core$reset_BANG_$$($search_STAR_$jscomp$1$$,(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$563$$))});var $set_option_ref$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$428$$){if($APP.$cljs$core$truth_$$($node$jscomp$428$$)){var $state$jscomp$1213$$=
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$5$$),{}),$id$jscomp$978$$=$APP.$app$util$dom$get_data$$($node$jscomp$428$$,"id");$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$5$$,$APP.$app$util$object$set_BANG_$$($state$jscomp$1213$$,$id$jscomp$978$$,$node$jscomp$428$$));return function(){var $state__$1$jscomp$59$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$5$$),{});return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$5$$,
$APP.$app$util$object$unset_BANG_$$($state__$1$jscomp$59$$,$id$jscomp$978$$))}}return null});$focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$=$app$main$ui$ds$controls$shared$dropdown_navigation$use_dropdown_navigation$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5821$focusable_ids$$,$focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$,$cljs$cst$5822$nodes_ref$$,$nodes_ref$jscomp$5$$,$cljs$cst$5823$on_enter$$,function($id$jscomp$979_temp__5825__auto__$jscomp$393$$){$id$jscomp$979_temp__5825__auto__$jscomp$393$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$5$$),$id$jscomp$979_temp__5825__auto__$jscomp$393$$);return $APP.$cljs$core$truth_$$($id$jscomp$979_temp__5825__auto__$jscomp$393$$)?$id$jscomp$979_temp__5825__auto__$jscomp$393$$.click():null},$cljs$cst$5824$searchable$$,!0,$cljs$cst$5825$search_input_ref$$,$search_input_ref$jscomp$3$$,$APP.$cljs$cst$5108$on_close$$,null],null));$focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$=
$APP.$cljs$core$__destructure_map$$($focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$);var $focused_id$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$,$cljs$cst$5826$focused_id$$),$focused_id_STAR_$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$,$cljs$cst$5827$focused_id_STAR_$$);$focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$,$cljs$cst$5828$on_key_down$$);var $on_click_inner$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$48$$)],function($event$jscomp$564$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$564$$);return $on_click$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$48$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$564$$):
$on_click$jscomp$48$$($event$jscomp$564$$)});$class$$jscomp$75_list_props$$={...$props$jscomp$329$$,className:($class$$jscomp$75_list_props$$??"")+" main_ui_ds_controls_shared_searchable_options_dropdown__option-list "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$5_align__$1$jscomp$3$$,$APP.$cljs$cst$257$left$$)?"main_ui_ds_controls_shared_searchable_options_dropdown__left-align":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$5_align__$1$jscomp$3$$,
$APP.$cljs$cst$258$right$$)?"main_ui_ds_controls_shared_searchable_options_dropdown__right-align":"")),ref:$list_ref$$,tabIndex:"-1",role:"listbox",onKeyDown:$focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(0,function(){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($search_input_ref$jscomp$3$$)))return $APP.$app$util$dom$focus_BANG_$$($APP.$rumext$v2$ref_val$$($search_input_ref$jscomp$3$$));
var $temp__5825__auto__$jscomp$394$$=$APP.$rumext$v2$ref_val$$($list_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$394$$)?$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$394$$):null})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$5$$)],function(){if($focused_id$jscomp$5$$!=null){var $temp__5825__auto__$jscomp$395_temp__5825__auto___79739$$=$APP.$rumext$v2$ref_val$$($list_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$395_temp__5825__auto___79739$$)&&
($APP.$cljs$core$truth_$$($app$util$dom$active_QMARK_$$($temp__5825__auto__$jscomp$395_temp__5825__auto___79739$$))||$APP.$app$util$dom$focus_BANG_$$($temp__5825__auto__$jscomp$395_temp__5825__auto___79739$$));$temp__5825__auto__$jscomp$395_temp__5825__auto___79739$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$5$$),$focused_id$jscomp$5$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$395_temp__5825__auto___79739$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$395_temp__5825__auto___79739$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1405$block$$,"nearest",$APP.$cljs$cst$2359$inline$$,"nearest"],null)):null}return null});return(0,$APP.$rumext$v2$create_element$$)("ul",$class$$jscomp$75_list_props$$,(0,$APP.$rumext$v2$jsx$$)("li",{role:"presentation",className:"main_ui_ds_controls_shared_searchable_options_dropdown__option-search",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{placeholder:function(){var $or__5025__auto__$jscomp$1278$$=
$placeholder$jscomp$7$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1278$$)?$or__5025__auto__$jscomp$1278$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("dashboard.search-placeholder")}(),value:$search$jscomp$9$$,ref:$search_input_ref$jscomp$3$$,variant:"comfortable",onChange:$on_search_change$jscomp$3_props_79737$$,onClick:function(){return $APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$4$$,null)},onKeyDown:$focusable_ids$jscomp$1_map__79738_map__79738__$1_on_key_down$jscomp$20$$})}),
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$189$$,$option$jscomp$23$$){$out_arr__44092__auto__$jscomp$189$$.push($APP.$app$main$ui$ds$controls$shared$render_option$render_option$$($option$jscomp$23$$,$set_option_ref$jscomp$3$$,$on_click_inner$$,$selected$jscomp$175$$,$focused_id$jscomp$5$$));return $out_arr__44092__auto__$jscomp$189$$},[],$filtered_options$$))};
$app$main$ui$workspace$sidebar$options$menus$token_typography_row$token_typography_row_STAR_$$=function($element_ref$jscomp$3_props_79735$$){var $detach_token$jscomp$4$$=void 0,$token_name$jscomp$30$$=void 0,$active_tokens$jscomp$6_broken_state$jscomp$2$$=void 0;({tokenName:$token_name$jscomp$30$$,activeTokens:$active_tokens$jscomp$6_broken_state$jscomp$2$$,detachToken:$detach_token$jscomp$4$$}=$element_ref$jscomp$3_props_79735$$);$element_ref$jscomp$3_props_79735$$=(0,$APP.$rumext$v2$use_ref$$)(null);
var $id$jscomp$980$$=(0,$APP.$rumext$v2$use_id$$)(),$token$jscomp$147$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79734_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__79734_SHARP_$$),$token_name$jscomp$30$$)},$APP.$cljs$cst$1997$typography$$.$cljs$core$IFn$_invoke$arity$1$($active_tokens$jscomp$6_broken_state$jscomp$2$$)),$display_name$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1279$$=
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$147$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1279$$)?$or__5025__auto__$jscomp$1279$$:$token_name$jscomp$30$$}(),$resolved_value$jscomp$4_tooltip_content$jscomp$2$$=$APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$147$$),$on_detach$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($display_name$jscomp$1$$)],function(){return $detach_token$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?
$detach_token$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($display_name$jscomp$1$$):$detach_token$jscomp$4$$($display_name$jscomp$1$$)}),$all_tokens_map$jscomp$2_token_exists_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_map$$),$has_errors$jscomp$2$$=($all_tokens_map$jscomp$2_token_exists_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($all_tokens_map$jscomp$2_token_exists_QMARK_$jscomp$2$$,$token_name$jscomp$30$$))&&$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$147$$)!=
null,$not_active$jscomp$1$$=$all_tokens_map$jscomp$2_token_exists_QMARK_$jscomp$2$$&&($token$jscomp$147$$==null||$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1997$typography$$.$cljs$core$IFn$_invoke$arity$1$($active_tokens$jscomp$6_broken_state$jscomp$2$$)));$active_tokens$jscomp$6_broken_state$jscomp$2$$=!$all_tokens_map$jscomp$2_token_exists_QMARK_$jscomp$2$$||$has_errors$jscomp$2$$||$not_active$jscomp$1$$;$resolved_value$jscomp$4_tooltip_content$jscomp$2$$=$not_active$jscomp$1$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("ds.inputs.token-field.no-active-token-option",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_name$jscomp$30$$])):$all_tokens_map$jscomp$2_token_exists_QMARK_$jscomp$2$$?$has_errors$jscomp$2$$?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.ref-not-valid",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_name$jscomp$30$$])):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$token_option$resolved_value_tooltip_STAR_$$,{tokenName:$token_name$jscomp$30$$,resolvedValue:$resolved_value$jscomp$4_tooltip_content$jscomp$2$$}):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("options.deleted-token-with-name",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_name$jscomp$30$$]));return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row "+($active_tokens$jscomp$6_broken_state$jscomp$2$$?"main_ui_workspace_sidebar_options_menus_token_typography_row__token-typography-row-with-errors":""),children:[$active_tokens$jscomp$6_broken_state$jscomp$2$$?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_token_typography_row__error-dot"}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"text-typography",className:"main_ui_workspace_sidebar_options_menus_token_typography_row__icon"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$resolved_value$jscomp$4_tooltip_content$jscomp$2$$,triggerRef:$element_ref$jscomp$3_props_79735$$,className:"main_ui_workspace_sidebar_options_menus_token_typography_row__token-tooltip",
id:$id$jscomp$980$$,children:(0,$APP.$rumext$v2$jsx$$)("span",{"aria-labelledby":""+($id$jscomp$980$$??""),ref:$element_ref$jscomp$3_props_79735$$,className:"main_ui_workspace_sidebar_options_menus_token_typography_row__token-name",children:$display_name$jscomp$1$$})}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("token-actions.detach-token"),tooltipClass:"main_ui_workspace_sidebar_options_menus_token_typography_row__detach-button",
tooltipPlacement:"top-left",onClick:$on_detach$jscomp$6$$,icon:"detach"})]})};$app$util$text$ui$get_element$$=function($target$jscomp$155$$){return $target$jscomp$155$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($target$jscomp$155$$.nodeType,Node.ELEMENT_NODE)?$target$jscomp$155$$.parentElement:$target$jscomp$155$$};
$app$util$text$ui$closest_text_editor_content$$=function($JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$){$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?($JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$=$app$util$text$ui$get_element$$($JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$),
$JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$)?$JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$.closest('[data-itype\x3d"editor"]'):null):($JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$=
$app$util$text$ui$get_element$$($JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$),$JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$)?$JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$.closest(".public-DraftEditor-content"):
null);return $JSCompiler_temp$jscomp$1844_target$jscomp$158_temp__5825__auto__$jscomp$inline_9077_temp__5825__auto__$jscomp$inline_9080$$};
$app$main$ui$workspace$sidebar$options$menus$text$text_align_options_STAR_$$=function($props_79741_values$jscomp$97$$){var $on_change$jscomp$80$$=$props_79741_values$jscomp$97$$.onChange,$on_blur$jscomp$27$$=$props_79741_values$jscomp$97$$.onBlur;$props_79741_values$jscomp$97$$=$props_79741_values$jscomp$97$$.values;var $options$jscomp$627$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"left",$APP.$cljs$cst$266$id$$,"text-align-left",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-align-left"),$APP.$cljs$cst$1727$icon$$,"text-align-left"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"center",$APP.$cljs$cst$266$id$$,"text-align-center",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-align-center"),
$APP.$cljs$cst$1727$icon$$,"text-align-center"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"right",$APP.$cljs$cst$266$id$$,"text-align-right",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-align-right"),$APP.$cljs$cst$1727$icon$$,"text-align-right"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"justify",$APP.$cljs$cst$266$id$$,"text-align-justify",
$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-align-justify"),$APP.$cljs$cst$1727$icon$$,"text-justify"],null)],null)}),$handle_change$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$80$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$27$$)],function($G__79742_79762_value$jscomp$935$$){$G__79742_79762_value$jscomp$935$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1769$text_align$$,$G__79742_79762_value$jscomp$935$$],null);$on_change$jscomp$80$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$80$$.$cljs$core$IFn$_invoke$arity$1$($G__79742_79762_value$jscomp$935$$):$on_change$jscomp$80$$($G__79742_79762_value$jscomp$935$$);return $on_blur$jscomp$27$$!=null?$on_blur$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$27$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$27$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__align-options",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$APP.$cljs$cst$1769$text_align$$.$cljs$core$IFn$_invoke$arity$1$($props_79741_values$jscomp$97$$),onChange:$handle_change$jscomp$14$$,name:"align-text-options",options:$options$jscomp$627$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$text_direction_options_STAR_$$=function($options$jscomp$628_props_79743$$){var $on_change$jscomp$81$$=$options$jscomp$628_props_79743$$.onChange,$on_blur$jscomp$28$$=$options$jscomp$628_props_79743$$.onBlur,$direction$jscomp$28$$=$APP.$cljs$cst$1770$text_direction$$.$cljs$core$IFn$_invoke$arity$1$($options$jscomp$628_props_79743$$.values);$options$jscomp$628_props_79743$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"ltr",$APP.$cljs$cst$266$id$$,"ltr-text-direction",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.direction-ltr"),$APP.$cljs$cst$1727$icon$$,"text-ltr"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"rtl",$APP.$cljs$cst$266$id$$,"rtl-text-direction",$APP.$cljs$cst$2296$label$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.direction-rtl"),$APP.$cljs$cst$1727$icon$$,"text-rtl"],null)],null)});var $handle_change$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$81$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$28$$),$APP.$rumext$v2$adapt$$($direction$jscomp$28$$)],function($G__79744_79763_value$jscomp$936$$){$G__79744_79763_value$jscomp$936$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1770$text_direction$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__79744_79763_value$jscomp$936$$,$direction$jscomp$28$$)?"none":$G__79744_79763_value$jscomp$936$$],null);$on_change$jscomp$81$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$81$$.$cljs$core$IFn$_invoke$arity$1$($G__79744_79763_value$jscomp$936$$):$on_change$jscomp$81$$($G__79744_79763_value$jscomp$936$$);return $on_blur$jscomp$28$$!=null?$on_blur$jscomp$28$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$28$$.$cljs$core$IFn$_invoke$arity$0$():
$on_blur$jscomp$28$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__text-direction-options",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$direction$jscomp$28$$,onChange:$handle_change$jscomp$15$$,name:"text-direction-options",options:$options$jscomp$628_props_79743$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$vertical_align_STAR_$$=function($props_79745_vertical_align$jscomp$4$$){var $on_change$jscomp$82$$=$props_79745_vertical_align$jscomp$4$$.onChange,$on_blur$jscomp$29$$=$props_79745_vertical_align$jscomp$4$$.onBlur,$values$jscomp$99$$=$props_79745_vertical_align$jscomp$4$$.values;$props_79745_vertical_align$jscomp$4$$=function(){var $or__5025__auto__$jscomp$1280$$=$APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$99$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1280$$)?$or__5025__auto__$jscomp$1280$$:"top"}();var $options$jscomp$629$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"top",$APP.$cljs$cst$266$id$$,"vertical-text-align-top",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.align-top"),
$APP.$cljs$cst$1727$icon$$,"text-top"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"center",$APP.$cljs$cst$266$id$$,"vertical-text-align-center",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.align-middle"),$APP.$cljs$cst$1727$icon$$,"text-middle"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"bottom",$APP.$cljs$cst$266$id$$,"vertical-text-align-bottom",
$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.align-bottom"),$APP.$cljs$cst$1727$icon$$,"text-bottom"],null)],null)}),$handle_change$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$82$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$29$$)],function($G__79746_79764_value$jscomp$937$$){$G__79746_79764_value$jscomp$937$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1773$vertical_align$$,
$G__79746_79764_value$jscomp$937$$],null);$on_change$jscomp$82$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$82$$.$cljs$core$IFn$_invoke$arity$1$($G__79746_79764_value$jscomp$937$$):$on_change$jscomp$82$$($G__79746_79764_value$jscomp$937$$);return $on_blur$jscomp$29$$!=null?$on_blur$jscomp$29$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$29$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$29$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__vertical-align-options",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$props_79745_vertical_align$jscomp$4$$,onChange:$handle_change$jscomp$16$$,name:"vertical-align-text-options",options:$options$jscomp$629$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$grow_options_STAR_$$=function($grow_type$jscomp$10_props_79748$$){var $on_blur$jscomp$30$$=$grow_type$jscomp$10_props_79748$$.onBlur,$ids$jscomp$312$$=$grow_type$jscomp$10_props_79748$$.ids;$grow_type$jscomp$10_props_79748$$=$APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($grow_type$jscomp$10_props_79748$$.values);var $editor_instance$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor$$),$options$jscomp$630$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"fixed",$APP.$cljs$cst$266$id$$,"text-fixed-grow",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.grow-fixed"),$APP.$cljs$cst$1727$icon$$,"text-fixed"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"auto-width",
$APP.$cljs$cst$266$id$$,"text-auto-width-grow",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.grow-auto-width"),$APP.$cljs$cst$1727$icon$$,"text-auto-width"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$260$value$$,"auto-height",$APP.$cljs$cst$266$id$$,"text-auto-height-grow",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.grow-auto-height"),
$APP.$cljs$cst$1727$icon$$,"text-auto-height"],null)],null)}),$handle_change$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$312$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$30$$),$APP.$rumext$v2$adapt$$($editor_instance$jscomp$4$$)],function($content_79767_value$jscomp$938$$){$on_blur$jscomp$30$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$30$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$30$$();var $uid_79765$$=Symbol(),$grow_type_79766__$1$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($content_79767_value$jscomp$938$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($uid_79765$$));$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")&&($content_79767_value$jscomp$938$$=$APP.$cljs$core$truth_$$($editor_instance$jscomp$4$$)?$APP.$app$util$text$content$dom__GT_cljs$$((0,$APP.$app$main$data$workspace$texts$get_editor_root$$)($editor_instance$jscomp$4$$)):
null,$content_79767_value$jscomp$938$$!=null&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$first$$($ids$jscomp$312$$),$content_79767_value$jscomp$938$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4111$finalize_QMARK_$$,!0]))));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$312$$,
function($p1__79747_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79747_SHARP_$$,$APP.$cljs$cst$1776$grow_type$$,$grow_type_79766__$1$$)}));$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$wasm_text$resize_wasm_text_all$$($ids$jscomp$312$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,$ids$jscomp$312$$],null))]));$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($uid_79765$$))});return $on_blur$jscomp$30$$!=null?$on_blur$jscomp$30$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$30$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$30$$():null});
return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__grow-options",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$APP.$app$common$data$name$$($grow_type$jscomp$10_props_79748$$),onChange:$handle_change$jscomp$17$$,name:"grow-text-options",options:$options$jscomp$630$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$text_decoration_options_STAR_$$=function($props_79749_text_decoration$jscomp$5$$){var $on_change$jscomp$83$$=$props_79749_text_decoration$jscomp$5$$.onChange,$on_blur$jscomp$31$$=$props_79749_text_decoration$jscomp$5$$.onBlur,$token_applied$jscomp$1$$=$props_79749_text_decoration$jscomp$5$$.tokenApplied,$values$jscomp$101$$=$props_79749_text_decoration$jscomp$5$$.values;$props_79749_text_decoration$jscomp$5$$=function(){var $G__79750$$=$APP.$cljs$cst$1774$text_decoration$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$101$$);
return $G__79750$$==null?null:$APP.$app$common$data$name$$($G__79750$$)}();var $options$jscomp$631$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_applied$jscomp$1$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$260$value$$,"underline",$APP.$cljs$cst$266$id$$,"underline-text-decoration",$APP.$cljs$cst$2959$disabled$$,$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&
$token_applied$jscomp$1$$!=null,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.text-options.underline",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4897$underline$$)])),$APP.$cljs$cst$1727$icon$$,"text-underlined"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$260$value$$,"line-through",$APP.$cljs$cst$266$id$$,"line-through-text-decoration",
$APP.$cljs$cst$2959$disabled$$,$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&$token_applied$jscomp$1$$!=null,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.text-options.strikethrough",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4900$line_through$$)])),$APP.$cljs$cst$1727$icon$$,"text-stroked"],null)],null)}),$handle_change$jscomp$18$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$83$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$31$$)],function($G__79751_79768_value$jscomp$939$$){$G__79751_79768_value$jscomp$939$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1774$text_decoration$$,$G__79751_79768_value$jscomp$939$$],null);$on_change$jscomp$83$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$83$$.$cljs$core$IFn$_invoke$arity$1$($G__79751_79768_value$jscomp$939$$):
$on_change$jscomp$83$$($G__79751_79768_value$jscomp$939$$);return $on_blur$jscomp$31$$!=null?$on_blur$jscomp$31$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$31$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$31$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__text-decoration-options",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$radio_buttons$radio_buttons_STAR_$$,{selected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79749_text_decoration$jscomp$5$$,
"none")?null:$props_79749_text_decoration$jscomp$5$$,onChange:$handle_change$jscomp$18$$,name:"text-decoration-options",disabled:$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&$token_applied$jscomp$1$$!=null,allowEmpty:!0,options:$options$jscomp$631$$})})};
$app$main$ui$workspace$sidebar$options$menus$text$get_option_by_name$$=function($options$jscomp$632_options__$1$jscomp$89$$,$name$jscomp$464$$){$options$jscomp$632_options__$1$jscomp$89$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$632_options__$1$jscomp$89$$)?$APP.$cljs$core$_deref$$($options$jscomp$632_options__$1$jscomp$89$$):$options$jscomp$632_options__$1$jscomp$89$$;return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79752_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$464$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__79752_SHARP_$$,$APP.$cljs$cst$725$name$$))},$options$jscomp$632_options__$1$jscomp$89$$)};$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$=function($tokens$jscomp$52$$){return $APP.$cljs$core$delay_QMARK_$$($tokens$jscomp$52$$)?$APP.$cljs$core$_deref$$($tokens$jscomp$52$$):$tokens$jscomp$52$$};
$app$main$ui$workspace$sidebar$options$menus$text$find_token_by_id$$=function($tokens$jscomp$53$$,$id$jscomp$981$$){return $APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79753_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79753_SHARP_$$),$APP.$cljs$core$uuid$$($id$jscomp$981$$))},$APP.$cljs$cst$1997$typography$$.$cljs$core$IFn$_invoke$arity$1$($tokens$jscomp$53$$))};
$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_eq$$=function($s1$jscomp$21$$,$s2$jscomp$18$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($s1$jscomp$21$$),$APP.$cljs$core$count$$($s2$jscomp$18$$))&&$APP.$cljs$core$every_QMARK_$$(function($p__79770_v2$jscomp$31$$){var $v1$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79770_v2$jscomp$31$$,0,null);$p__79770_v2$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79770_v2$jscomp$31$$,
1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$select_keys$$($v1$jscomp$39$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_keys$$),$APP.$cljs$core$select_keys$$($p__79770_v2$jscomp$31$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_keys$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vector$$,$s1$jscomp$21$$,$s2$jscomp$18$$))};
$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_sel$$=function($v$jscomp$674$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79774_SHARP_$$){return $APP.$cljs$core$select_keys$$($p1__79774_SHARP_$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_keys$$)},$v$jscomp$674$$)};
$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_eq$$=function($v1$jscomp$40$$,$v2$jscomp$32$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$select_keys$$($v1$jscomp$40$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_keys$$),$APP.$cljs$core$select_keys$$($v2$jscomp$32$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_keys$$))};
$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_sel$$=function($v$jscomp$675$$){return $APP.$cljs$core$truth_$$($v$jscomp$675$$)?$APP.$cljs$core$select_keys$$($v$jscomp$675$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_keys$$):null};
$app$main$ui$workspace$sidebar$options$shapes$path$options_STAR_$$=function($props_79782_type$jscomp$677$$){var $file_id$jscomp$419$$=$props_79782_type$jscomp$677$$.fileId,$page_id$jscomp$437$$=$props_79782_type$jscomp$677$$.pageId,$shape$jscomp$1033$$=$props_79782_type$jscomp$677$$.shape,$id$jscomp$989$$=$shape$jscomp$1033$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1033$$,$APP.$cljs$cst$266$id$$);$props_79782_type$jscomp$677$$=$shape$jscomp$1033$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1033$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$316$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$989$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$989$$],null)}),$shapes$jscomp$224$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1033$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1033$$],null)}),$applied_tokens$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1033$$,$APP.$cljs$cst$1881$applied_tokens$$),$measure_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,
$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$constraint_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$5$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),
$is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$316$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$316$$)}),$is_layout_child_QMARK_$jscomp$6$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$);$is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$316$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$316$$)});$is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$);var $is_grid_parent_ref$jscomp$5_is_layout_child_absolute_QMARK_$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$316$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$316$$)}),$is_grid_parent_QMARK_$jscomp$5$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$5_is_layout_child_absolute_QMARK_$jscomp$4$$);$is_grid_parent_ref$jscomp$5_is_layout_child_absolute_QMARK_$jscomp$4$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1033$$);var $parents$jscomp$17_parents_by_ids_ref$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$316$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$316$$)});$parents$jscomp$17_parents_by_ids_ref$jscomp$4$$=$APP.$rumext$v2$deref$$($parents$jscomp$17_parents_by_ids_ref$jscomp$4$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$316$$,appliedTokens:$applied_tokens$jscomp$30$$,type:$props_79782_type$jscomp$677$$,values:$layer_values$jscomp$5$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$316$$,type:$props_79782_type$jscomp$677$$,appliedTokens:$applied_tokens$jscomp$30$$,values:$measure_values$jscomp$5$$,shapes:$shapes$jscomp$224$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,{type:$props_79782_type$jscomp$677$$,ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1033$$)],null),
values:$layout_container_values$jscomp$5$$,appliedTokens:$applied_tokens$jscomp$30$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$862$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$316$$),1);return $and__5023__auto__$jscomp$862$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$6$$)?$is_grid_parent_QMARK_$jscomp$5$$:$is_layout_child_QMARK_$jscomp$6$$:$and__5023__auto__$jscomp$862$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,
{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($parents$jscomp$17_parents_by_ids_ref$jscomp$4$$)),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$17_parents_by_ids_ref$jscomp$4$$),$APP.$cljs$core$first$$($ids$jscomp$316$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$6$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,{values:$layout_item_values$jscomp$5$$,
isLayoutChild:!0,shape:$shape$jscomp$1033$$,appliedTokens:$applied_tokens$jscomp$30$$,ids:$ids$jscomp$316$$,isFlexParent:$is_flex_parent_QMARK_$jscomp$5_is_flex_parent_ref$jscomp$5_is_layout_child_ref$jscomp$5$$,type:$props_79782_type$jscomp$677$$,isLayoutContainer:!1,isGridParent:$is_grid_parent_QMARK_$jscomp$5$$}):null,!$is_layout_child_QMARK_$jscomp$6$$||$is_grid_parent_ref$jscomp$5_is_layout_child_absolute_QMARK_$jscomp$4$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,
{ids:$ids$jscomp$316$$,values:$constraint_values$jscomp$5$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$316$$,type:$props_79782_type$jscomp$677$$,values:$shape$jscomp$1033$$,appliedTokens:$applied_tokens$jscomp$30$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$316$$,type:$props_79782_type$jscomp$677$$,showCaps:!0,values:$stroke_values$jscomp$5$$,appliedTokens:$applied_tokens$jscomp$30$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$316$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1033$$,$APP.$cljs$cst$1659$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$316$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1197$background_blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$316$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1898$svg_attrs$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79782_type$jscomp$677$$,
ids:$ids$jscomp$316$$,shapes:$shapes$jscomp$224$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1033$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$437$$,fileId:$file_id$jscomp$419$$})]})};
$app$main$ui$workspace$sidebar$options$shapes$rect$options_STAR_$$=function($props_79830_type$jscomp$678$$){var $file_id$jscomp$420$$=$props_79830_type$jscomp$678$$.fileId,$page_id$jscomp$438$$=$props_79830_type$jscomp$678$$.pageId,$shape$jscomp$1034$$=$props_79830_type$jscomp$678$$.shape,$id$jscomp$990$$=$shape$jscomp$1034$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1034$$,$APP.$cljs$cst$266$id$$);$props_79830_type$jscomp$678$$=$shape$jscomp$1034$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1034$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$317$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$990$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$990$$],null)}),$shapes$jscomp$225$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1034$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1034$$],null)}),$applied_tokens$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1034$$,$APP.$cljs$cst$1881$applied_tokens$$),$measure_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$stroke_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,
$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$constraint_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$6$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),
$is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$317$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$317$$)}),$is_layout_child_QMARK_$jscomp$7$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$);$is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$317$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$317$$)});$is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$);var $is_grid_parent_ref$jscomp$6_is_layout_child_absolute_QMARK_$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$317$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$317$$)}),$is_grid_parent_QMARK_$jscomp$6$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$6_is_layout_child_absolute_QMARK_$jscomp$5$$);$is_grid_parent_ref$jscomp$6_is_layout_child_absolute_QMARK_$jscomp$5$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1034$$);var $parents$jscomp$18_parents_by_ids_ref$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$317$$)],
function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$317$$)});$parents$jscomp$18_parents_by_ids_ref$jscomp$5$$=$APP.$rumext$v2$deref$$($parents$jscomp$18_parents_by_ids_ref$jscomp$5$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,{ids:$ids$jscomp$317$$,type:$props_79830_type$jscomp$678$$,appliedTokens:$applied_tokens$jscomp$31$$,values:$layer_values$jscomp$6$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,
{ids:$ids$jscomp$317$$,type:$props_79830_type$jscomp$678$$,values:$measure_values$jscomp$6$$,appliedTokens:$applied_tokens$jscomp$31$$,shapes:$shapes$jscomp$225$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,{type:$props_79830_type$jscomp$678$$,ids:$ids$jscomp$317$$,values:$layout_container_values$jscomp$6$$,appliedTokens:$applied_tokens$jscomp$31$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$863$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$317$$),1);return $and__5023__auto__$jscomp$863$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$7$$)?$is_grid_parent_QMARK_$jscomp$6$$:$is_layout_child_QMARK_$jscomp$7$$:$and__5023__auto__$jscomp$863$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($parents$jscomp$18_parents_by_ids_ref$jscomp$5$$)),
cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$18_parents_by_ids_ref$jscomp$5$$),$APP.$cljs$core$first$$($ids$jscomp$317$$))}):null,$is_layout_child_QMARK_$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,{ids:$ids$jscomp$317$$,type:$props_79830_type$jscomp$678$$,values:$layout_item_values$jscomp$6$$,isLayoutChild:!0,isFlexParent:$is_flex_parent_QMARK_$jscomp$6_is_flex_parent_ref$jscomp$6_is_layout_child_ref$jscomp$6$$,
appliedTokens:$applied_tokens$jscomp$31$$,isGridParent:$is_grid_parent_QMARK_$jscomp$6$$,shape:$shape$jscomp$1034$$}):null,!$is_layout_child_QMARK_$jscomp$7$$||$is_grid_parent_ref$jscomp$6_is_layout_child_absolute_QMARK_$jscomp$5$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$317$$,values:$constraint_values$jscomp$6$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,
{ids:$ids$jscomp$317$$,type:$props_79830_type$jscomp$678$$,values:$shape$jscomp$1034$$,appliedTokens:$applied_tokens$jscomp$31$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$317$$,type:$props_79830_type$jscomp$678$$,values:$stroke_values$jscomp$6$$,appliedTokens:$applied_tokens$jscomp$31$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$317$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1034$$,
$APP.$cljs$cst$1659$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$317$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1197$background_blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$317$$,
values:$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1898$svg_attrs$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79830_type$jscomp$678$$,ids:$ids$jscomp$317$$,shapes:$shapes$jscomp$225$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1034$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),
pageId:$page_id$jscomp$438$$,fileId:$file_id$jscomp$420$$})]})};
$app$main$ui$workspace$sidebar$options$shapes$svg_raw$parse_color$$=function($color$jscomp$184$$){try{return $APP.$cljs$core$not$$($color$jscomp$184$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$184$$,"none")?null:$APP.$cuerdas$core$starts_with_QMARK_$$($color$jscomp$184$$,"url")?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1740$opacity$$,$APP.$cljs$cst$1621$multiple$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1303$color$$,$APP.$app$common$types$color$parse$$($color$jscomp$184$$),$APP.$cljs$cst$1740$opacity$$,1],null)}catch($e79836$$){return console.error("Error parsing color",$e79836$$),null}};
$app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_fill_values$$=function($shape$jscomp$1035$$){var $fill_values$jscomp$2$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1035$$,$app$main$ui$workspace$sidebar$options$menus$fill$fill_attrs$$),$color$jscomp$185$$=$app$main$ui$workspace$sidebar$options$shapes$svg_raw$parse_color$$(function(){var $or__5025__auto__$jscomp$1282$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1035$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$cst$1408$fill$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1282$$)?$or__5025__auto__$jscomp$1282$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1035$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$cst$1921$style$$,$APP.$cljs$cst$1408$fill$$],
null))}());return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$864$$=$APP.$cljs$core$empty_QMARK_$$($fill_values$jscomp$2$$);return $and__5023__auto__$jscomp$864$$?$color$jscomp$185$$:$and__5023__auto__$jscomp$864$$}())?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1752$fill_color$$,$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$185$$),$APP.$cljs$cst$1753$fill_opacity$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$185$$)],
null):$fill_values$jscomp$2$$};
$app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_stroke_values$$=function($shape$jscomp$1036$$){var $stroke_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1036$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$color$jscomp$186$$=$app$main$ui$workspace$sidebar$options$shapes$svg_raw$parse_color$$(function(){var $or__5025__auto__$jscomp$1283$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1036$$,new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$cst$2914$stroke$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1283$$)?$or__5025__auto__$jscomp$1283$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1036$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$cst$1921$style$$,$APP.$cljs$cst$2914$stroke$$],
null))}()),$stroke_color$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186$$,"#000000"),$stroke_opacity$$=$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$186$$,1),$stroke_style$jscomp$4$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $or__5025__auto__$jscomp$1284_or__5025__auto____$1$jscomp$138$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1036$$,new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$cst$1873$stroke_style$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1284_or__5025__auto____$1$jscomp$138$$))return $or__5025__auto__$jscomp$1284_or__5025__auto____$1$jscomp$138$$;$or__5025__auto__$jscomp$1284_or__5025__auto____$1$jscomp$138$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1036$$,new $APP.$cljs$core$PersistentVector$$(null,
4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$cst$1921$style$$,$APP.$cljs$cst$1873$stroke_style$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1284_or__5025__auto____$1$jscomp$138$$)?$or__5025__auto__$jscomp$1284_or__5025__auto____$1$jscomp$138$$:$APP.$cljs$core$truth_$$($color$jscomp$186$$)?"solid":"none"}()),$stroke_width$jscomp$9$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $or__5025__auto__$jscomp$1285_or__5025__auto____$1$jscomp$139$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1036$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$cst$1660$stroke_width$$],null));if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1285_or__5025__auto____$1$jscomp$139$$))return $or__5025__auto__$jscomp$1285_or__5025__auto____$1$jscomp$139$$;$or__5025__auto__$jscomp$1285_or__5025__auto____$1$jscomp$139$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1036$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1642$content$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$cst$1921$style$$,$APP.$cljs$cst$1660$stroke_width$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1285_or__5025__auto____$1$jscomp$139$$)?$or__5025__auto__$jscomp$1285_or__5025__auto____$1$jscomp$139$$:"1"}());return $APP.$cljs$core$empty_QMARK_$$($stroke_values$jscomp$7$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1745$stroke_color$$,$stroke_color$$,$APP.$cljs$cst$1746$stroke_opacity$$,$stroke_opacity$$,$APP.$cljs$cst$1873$stroke_style$$,$stroke_style$jscomp$4$$,$APP.$cljs$cst$1875$stroke_alignment$$,$APP.$cljs$cst$1672$center$$,$APP.$cljs$cst$1660$stroke_width$$,$stroke_width$jscomp$9$$],null):$stroke_values$jscomp$7$$};
$app$main$ui$workspace$sidebar$options$shapes$svg_raw$options_STAR_$$=function($props_79864_type$jscomp$679$$){var $file_id$jscomp$421$$=$props_79864_type$jscomp$679$$.fileId,$page_id$jscomp$439$$=$props_79864_type$jscomp$679$$.pageId,$shape$jscomp$1037$$=$props_79864_type$jscomp$679$$.shape,$id$jscomp$991$$=$shape$jscomp$1037$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1037$$,$APP.$cljs$cst$266$id$$);$props_79864_type$jscomp$679$$=$shape$jscomp$1037$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1037$$,
$APP.$cljs$cst$139$type$$);var $ids$jscomp$318$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$991$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$991$$],null)}),$shapes$jscomp$226$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1037$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$shape$jscomp$1037$$],null)}),$applied_tokens$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1037$$,$APP.$cljs$cst$1881$applied_tokens$$),$map__79866_map__79866__$1_tag$jscomp$94$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1037$$,$APP.$cljs$cst$1642$content$$);$map__79866_map__79866__$1_tag$jscomp$94$$=$APP.$cljs$core$__destructure_map$$($map__79866_map__79866__$1_tag$jscomp$94$$);$map__79866_map__79866__$1_tag$jscomp$94$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79866_map__79866__$1_tag$jscomp$94$$,
$APP.$cljs$cst$78$tag$$);var $fill_values$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1037$$)],function(){return $app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_fill_values$$($shape$jscomp$1037$$)}),$stroke_values$jscomp$8$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1037$$)],function(){return $app$main$ui$workspace$sidebar$options$shapes$svg_raw$get_stroke_values$$($shape$jscomp$1037$$)}),
$measure_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1037$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),$constraint_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1037$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$),$layout_item_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1037$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$7$$=
$APP.$cljs$core$select_keys$$($shape$jscomp$1037$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),$is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$318$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$318$$)}),$is_layout_child_QMARK_$jscomp$8$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$);
$is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$318$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$318$$)});$is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$);var $is_grid_parent_ref$jscomp$7_is_layout_child_absolute_QMARK_$jscomp$6$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$318$$)],function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$318$$)}),$is_grid_parent_QMARK_$jscomp$7$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$7_is_layout_child_absolute_QMARK_$jscomp$6$$);$is_grid_parent_ref$jscomp$7_is_layout_child_absolute_QMARK_$jscomp$6$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1037$$);
var $parents$jscomp$19_parents_by_ids_ref$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$318$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$318$$)});$parents$jscomp$19_parents_by_ids_ref$jscomp$6$$=$APP.$rumext$v2$deref$$($parents$jscomp$19_parents_by_ids_ref$jscomp$6$$);return $APP.$cljs$core$contains_QMARK_$$($app$main$ui$workspace$sidebar$options$shapes$svg_raw$svg_elements$$,$map__79866_map__79866__$1_tag$jscomp$94$$)?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,{ids:$ids$jscomp$318$$,type:$props_79864_type$jscomp$679$$,appliedTokens:$applied_tokens$jscomp$32$$,values:$measure_values$jscomp$7$$,shapes:$shapes$jscomp$226$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,{type:$props_79864_type$jscomp$679$$,ids:new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1037$$)],null),values:$layout_container_values$jscomp$7$$,appliedTokens:$applied_tokens$jscomp$32$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$865$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$318$$),1);return $and__5023__auto__$jscomp$865$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$8$$)?
$is_grid_parent_QMARK_$jscomp$7$$:$is_layout_child_QMARK_$jscomp$8$$:$and__5023__auto__$jscomp$865$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($parents$jscomp$19_parents_by_ids_ref$jscomp$6$$)),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$19_parents_by_ids_ref$jscomp$6$$),$APP.$cljs$core$first$$($ids$jscomp$318$$))}):
null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$8$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,{ids:$ids$jscomp$318$$,type:$props_79864_type$jscomp$679$$,values:$layout_item_values$jscomp$7$$,isLayoutChild:!0,isFlexParent:$is_flex_parent_QMARK_$jscomp$7_is_flex_parent_ref$jscomp$7_is_layout_child_ref$jscomp$7$$,isGridParent:$is_grid_parent_QMARK_$jscomp$7$$,appliedTokens:$applied_tokens$jscomp$32$$,shape:$shape$jscomp$1037$$}):
null,!$is_layout_child_QMARK_$jscomp$8$$||$is_grid_parent_ref$jscomp$7_is_layout_child_absolute_QMARK_$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$ids$jscomp$318$$,values:$constraint_values$jscomp$7$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$318$$,type:$props_79864_type$jscomp$679$$,values:$fill_values$jscomp$3$$,appliedTokens:$applied_tokens$jscomp$32$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$318$$,type:$props_79864_type$jscomp$679$$,values:$stroke_values$jscomp$8$$,appliedTokens:$applied_tokens$jscomp$32$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$318$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1037$$,$APP.$cljs$cst$1659$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,
{ids:$ids$jscomp$318$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1037$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1197$background_blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$318$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1037$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1898$svg_attrs$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79864_type$jscomp$679$$,ids:$ids$jscomp$318$$,shapes:$shapes$jscomp$226$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1037$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$439$$,fileId:$file_id$jscomp$421$$})]}):null};
$app$main$ui$workspace$sidebar$options$shapes$text$options_STAR_$$=function($props_79865_type$jscomp$680$$){var $file_id$jscomp$422$$=$props_79865_type$jscomp$680$$.fileId,$libraries$jscomp$158$$=$props_79865_type$jscomp$680$$.libraries,$page_id$jscomp$440$$=$props_79865_type$jscomp$680$$.pageId,$shape$jscomp$1038$$=$props_79865_type$jscomp$680$$.shape,$id$jscomp$992$$=$shape$jscomp$1038$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1038$$,$APP.$cljs$cst$266$id$$);$props_79865_type$jscomp$680$$=
$shape$jscomp$1038$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1038$$,$APP.$cljs$cst$139$type$$);var $ids$jscomp$319$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$992$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$992$$],null)}),$shapes$jscomp$227$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1038$$)],
function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1038$$],null)}),$typographies$jscomp$14$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),$applied_tokens$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1038$$,$APP.$cljs$cst$1881$applied_tokens$$),$measure_values$jscomp$8$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$),
$stroke_values$jscomp$9$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$),$layer_values$jscomp$7$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$),$layout_item_values$jscomp$8$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$),$layout_container_values$jscomp$8$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),$is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$319$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$319$$)}),$is_layout_child_QMARK_$jscomp$9$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$);
$is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$319$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$319$$)});$is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$);var $is_grid_parent_ref$jscomp$8_is_layout_child_absolute_QMARK_$jscomp$7$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$319$$)],function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$319$$)}),$is_grid_parent_QMARK_$jscomp$8$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$8_is_layout_child_absolute_QMARK_$jscomp$7$$);$is_grid_parent_ref$jscomp$8_is_layout_child_absolute_QMARK_$jscomp$7$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1038$$);
var $parents$jscomp$20_parents_by_ids_ref$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$319$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$319$$)});$parents$jscomp$20_parents_by_ids_ref$jscomp$7$$=$APP.$rumext$v2$deref$$($parents$jscomp$20_parents_by_ids_ref$jscomp$7$$);var $editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_editor_styles$$),
$v2_editor_state_map$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_v2_editor_state$$),$v1_editor_state_map$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$),$editor$jscomp$8_fill_values$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor$$),$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor-wasm/v1"),$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$=
$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2");$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$=$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$?$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$:$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$?$v2_editor_state_map$$:$v1_editor_state_map$$;$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$=$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,$id$jscomp$992$$):null;$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$=$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$?null:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,$id$jscomp$992$$);$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$=$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$?
$editor$jscomp$8_fill_values$jscomp$4$$:null;$editor$jscomp$8_fill_values$jscomp$4$$=$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4076$editor_styles$$,$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$,$APP.$cljs$cst$4078$editor_state$$,$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,$APP.$cljs$cst$4077$editor_instance$$,$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$,$APP.$cljs$cst$1817$shape$$,
$shape$jscomp$1038$$,$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$text$text_fill_attrs$$,$APP.$cljs$cst$1639$fills$$)],null));$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$=$APP.$app$common$data$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1776$grow_type$$],null)),$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,$app$main$ui$workspace$sidebar$options$menus$fill$fill_attrs$$),$APP.$app$main$data$workspace$texts$current_root_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1817$shape$$,$shape$jscomp$1038$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$text_valign_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_paragraph_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$4076$editor_styles$$,$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$,$APP.$cljs$cst$4078$editor_state$$,$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,$APP.$cljs$cst$4077$editor_instance$$,$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$,$APP.$cljs$cst$1817$shape$$,$shape$jscomp$1038$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$paragraph_attrs$$],null)),$APP.$app$main$data$workspace$texts$current_text_values$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$4076$editor_styles$$,$editor_styles$jscomp$4_text_editor_wasm_QMARK_$$,$APP.$cljs$cst$4078$editor_state$$,$editor_state$jscomp$9_state_map$jscomp$1_wasm_editor_styles_map$$,$APP.$cljs$cst$4077$editor_instance$$,$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$,$APP.$cljs$cst$1817$shape$$,$shape$jscomp$1038$$,$APP.$cljs$cst$2656$attrs$$,$APP.$app$common$types$text$text_node_attrs$$],null))]));return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,
{ids:$ids$jscomp$319$$,type:$props_79865_type$jscomp$680$$,appliedTokens:$applied_tokens$jscomp$33$$,values:$layer_values$jscomp$7$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,{ids:$ids$jscomp$319$$,type:$props_79865_type$jscomp$680$$,values:$measure_values$jscomp$8$$,appliedTokens:$applied_tokens$jscomp$33$$,shapes:$shapes$jscomp$227$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,
{type:$props_79865_type$jscomp$680$$,ids:$ids$jscomp$319$$,values:$layout_container_values$jscomp$8$$,appliedTokens:$applied_tokens$jscomp$33$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$866$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$319$$),1);return $and__5023__auto__$jscomp$866$$?$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$9$$)?$is_grid_parent_QMARK_$jscomp$8$$:$is_layout_child_QMARK_$jscomp$9$$:$and__5023__auto__$jscomp$866$$}())?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($parents$jscomp$20_parents_by_ids_ref$jscomp$7$$)),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$20_parents_by_ids_ref$jscomp$7$$),$APP.$cljs$core$first$$($ids$jscomp$319$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,
{ids:$ids$jscomp$319$$,type:$props_79865_type$jscomp$680$$,values:$layout_item_values$jscomp$8$$,isLayoutChild:!0,isFlexParent:$is_flex_parent_QMARK_$jscomp$8_is_flex_parent_ref$jscomp$8_is_layout_child_ref$jscomp$8$$,isGridParent:$is_grid_parent_QMARK_$jscomp$8$$,appliedTokens:$applied_tokens$jscomp$33$$,shape:$shape$jscomp$1038$$}):null,!$is_layout_child_QMARK_$jscomp$9$$||$is_grid_parent_ref$jscomp$8_is_layout_child_absolute_QMARK_$jscomp$7$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,
{ids:$ids$jscomp$319$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$)}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$text$text_menu_STAR_$$,{ids:$ids$jscomp$319$$,type:$props_79865_type$jscomp$680$$,appliedTokens:$applied_tokens$jscomp$33$$,values:$editor_instance$jscomp$5_text_editor_v2_QMARK__text_values$jscomp$5$$,libraries:$libraries$jscomp$158$$,fileId:$file_id$jscomp$422$$,
typographies:$typographies$jscomp$14$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{ids:$ids$jscomp$319$$,type:$props_79865_type$jscomp$680$$,values:$editor$jscomp$8_fill_values$jscomp$4$$,appliedTokens:$applied_tokens$jscomp$33$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{ids:$ids$jscomp$319$$,type:$props_79865_type$jscomp$680$$,values:$stroke_values$jscomp$9$$,disableStrokeStyle:!0,appliedTokens:$applied_tokens$jscomp$33$$}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($editor$jscomp$8_fill_values$jscomp$4$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$,{type:$props_79865_type$jscomp$680$$,shapes:$shapes$jscomp$227$$,fileId:$file_id$jscomp$422$$,libraries:$libraries$jscomp$158$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,
{ids:$ids$jscomp$319$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1038$$,$APP.$cljs$cst$1659$shadow$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{ids:$ids$jscomp$319$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1197$background_blur$$],null))}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,
{type:$props_79865_type$jscomp$680$$,ids:$ids$jscomp$319$$,shapes:$shapes$jscomp$227$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1038$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$440$$,fileId:$file_id$jscomp$422$$})]})};
$app$main$ui$workspace$sidebar$options$single_shape_options_STAR_$$=function($file_id$jscomp$423_props_79881$$){var $libraries$jscomp$159$$,$page_id$jscomp$441$$;({shape:$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,pageId:$page_id$jscomp$441$$,fileId:$file_id$jscomp$423_props_79881$$,libraries:$libraries$jscomp$159$$,...$props$jscomp$332_props__$1$jscomp$82$$}=$file_id$jscomp$423_props_79881$$);var $shape_type$jscomp$8$$=$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$?.type??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,$APP.$cljs$cst$139$type$$),$shape_id$jscomp$167$$=$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,$APP.$cljs$cst$266$id$$),$wasm_modifiers_wasm_modifiers__$1$jscomp$inline_9098$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_modifiers$$),
$modifiers$jscomp$115$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$);if($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")){$wasm_modifiers_wasm_modifiers__$1$jscomp$inline_9098$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$wasm_modifiers_wasm_modifiers__$1$jscomp$inline_9098$$);var $JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$=
$APP.$app$common$geom$shapes$apply_transform$$($JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($wasm_modifiers_wasm_modifiers__$1$jscomp$inline_9098$$,$shape_id$jscomp$167$$))}else $JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$115$$,
$shape_id$jscomp$167$$),$APP.$cljs$cst$1816$modifiers$$));var $props$jscomp$332_props__$1$jscomp$82$$={...$props$jscomp$332_props__$1$jscomp$82$$,shape:$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$423_props_79881$$,pageId:$page_id$jscomp$441$$,libraries:$libraries$jscomp$159$$};switch($shape_type$jscomp$8$$ instanceof $APP.$cljs$core$Keyword$$?$shape_type$jscomp$8$$.$fqn$:null){case "frame":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$shapes$frame$options_STAR_$$,
$props$jscomp$332_props__$1$jscomp$82$$);case "group":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$shapes$group$options_STAR_$$,$props$jscomp$332_props__$1$jscomp$82$$);case "text":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$text$options_STAR_$$,{shape:$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$423_props_79881$$,pageId:$page_id$jscomp$441$$,libraries:$libraries$jscomp$159$$});case "rect":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$rect$options_STAR_$$,
{shape:$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$423_props_79881$$,pageId:$page_id$jscomp$441$$});case "circle":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$circle$options_STAR_$$,{shape:$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$423_props_79881$$,pageId:$page_id$jscomp$441$$});case "path":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$path$options_STAR_$$,
{shape:$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$423_props_79881$$,pageId:$page_id$jscomp$441$$});case "svg-raw":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$svg_raw$options_STAR_$$,{shape:$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$423_props_79881$$,pageId:$page_id$jscomp$441$$});case "bool":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$bool$options_STAR_$$,
{shape:$JSCompiler_temp$jscomp$1849_shape$jscomp$1039_shape__$1$jscomp$109$$,fileId:$file_id$jscomp$423_props_79881$$,pageId:$page_id$jscomp$441$$});default:return null}};
$app$main$ui$workspace$sidebar$options$specialized_panel_STAR_$$=function($panel$jscomp$2_props_79901$$){$panel$jscomp$2_props_79901$$=$panel$jscomp$2_props_79901$$.panel;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($panel$jscomp$2_props_79901$$),$APP.$cljs$cst$4027$component_swap$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$,{shapes:$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($panel$jscomp$2_props_79901$$),
isSwapOpened:!0}):null};
$app$main$ui$workspace$sidebar$options$design_menu_STAR_$$=function($page_id$jscomp$443_props_79915$$){var $shapes$jscomp$229$$=$page_id$jscomp$443_props_79915$$.shapes,$selected$jscomp$177$$=$page_id$jscomp$443_props_79915$$.selected,$file_id$jscomp$425$$=$page_id$jscomp$443_props_79915$$.fileId,$objects$jscomp$809$$=$page_id$jscomp$443_props_79915$$.objects;$page_id$jscomp$443_props_79915$$=$page_id$jscomp$443_props_79915$$.pageId;var $sp_panel$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$specialized_panel$$),$drawing$jscomp$3$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_drawing$$),$edition$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$),$files$jscomp$29$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$libraries$jscomp$161$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$29$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$425$$)],function(){return $APP.$app$main$refs$select_libraries$$($files$jscomp$29$$,$file_id$jscomp$425$$)}),
$edit_grid_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$809$$),$APP.$rumext$v2$adapt$$($edition$jscomp$7$$)],function(){return $APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$809$$,$edition$jscomp$7$$)}),$grid_edition$jscomp$1_selected_cells$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_grid_edition$$);$grid_edition$jscomp$1_selected_cells$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79906_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$809$$,
$edition$jscomp$7$$),$APP.$cljs$cst$1701$layout_grid_cells$$),$p1__79906_SHARP_$$)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$1_selected_cells$$,$edition$jscomp$7$$),$APP.$cljs$cst$1938$selected$$));var $shapes_with_children_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$177$$),
$APP.$rumext$v2$adapt$$($objects$jscomp$809$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$229$$)],function(){$APP.$cljs$core$reset_BANG_$$($shapes_with_children_STAR_$$,null);a:{var $G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentQueue$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$selected$jscomp$177$$);for(var $G__79956$jscomp$inline_9107_G__79958$jscomp$inline_9109_visited$jscomp$inline_9101$$=
$selected$jscomp$177$$;;){var $children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$=$APP.$cljs$core$peek$$($G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$);if($APP.$cljs$core$truth_$$($children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$))$children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$809$$,$children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$),$children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$=$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$),
$APP.$cljs$core$seq$$($children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$)?($children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($G__79956$jscomp$inline_9107_G__79958$jscomp$inline_9109_visited$jscomp$inline_9101$$,$children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$),
$G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$pop$$($G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$),$children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$),$G__79956$jscomp$inline_9107_G__79958$jscomp$inline_9109_visited$jscomp$inline_9101$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($G__79956$jscomp$inline_9107_G__79958$jscomp$inline_9109_visited$jscomp$inline_9101$$,
$children$jscomp$inline_9104_new_children$jscomp$inline_9105_shape$jscomp$inline_9103_temp__5823__auto__$jscomp$inline_9102$$)):$G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$=$APP.$cljs$core$pop$$($G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$);else{$G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$=$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$809$$)),
$G__79956$jscomp$inline_9107_G__79958$jscomp$inline_9109_visited$jscomp$inline_9101$$);break a}}$G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$=void 0}return $APP.$cljs$core$reset_BANG_$$($shapes_with_children_STAR_$$,$G__79955$jscomp$inline_9106_G__79957$jscomp$inline_9108_queue$jscomp$inline_9100_result$jscomp$374$$)});var $shapes_with_children$jscomp$5$$=$APP.$cljs$core$_deref$$($shapes_with_children_STAR_$$),$total_selected$jscomp$1$$=$APP.$cljs$core$count$$($selected$jscomp$177$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options__element-options main_ui_workspace_sidebar_options__design-options",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$align$align_options_STAR_$$,{shapes:$shapes$jscomp$229$$,objects:$objects$jscomp$809$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$bool$bool_options_STAR_$$,{totalSelected:$total_selected$jscomp$1$$,shapes:$shapes$jscomp$229$$,shapesWithChildren:$shapes_with_children$jscomp$5$$}),
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($edit_grid_QMARK_$$)?$APP.$app$common$data$not_empty_QMARK_$$($grid_edition$jscomp$1_selected_cells$$):$edit_grid_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$809$$,$edition$jscomp$7$$)),cells:$grid_edition$jscomp$1_selected_cells$$}):$APP.$cljs$core$truth_$$($edit_grid_QMARK_$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_layout_edition$$,{ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$edition$jscomp$7$$],null),values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$809$$,$edition$jscomp$7$$)}):$sp_panel$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$specialized_panel_STAR_$$,{panel:$sp_panel$$}):$APP.$app$common$data$not_empty_QMARK_$$($drawing$jscomp$3$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$drawing$drawing_options_STAR_$$,{drawingState:$drawing$jscomp$3$$}):$total_selected$jscomp$1$$===0?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$page$options_STAR_$$,{}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shape_options_STAR_$$,{shapes:$shapes$jscomp$229$$,shapesWithChildren:$shapes_with_children$jscomp$5$$,pageId:$page_id$jscomp$443_props_79915$$,fileId:$file_id$jscomp$425$$,selected:$selected$jscomp$177$$,
libraries:$libraries$jscomp$161$$})]})};$app$main$ui$workspace$sidebar$options$inspect_tab_STAR_$$=function($props_79931$$){var $frame$jscomp$76$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($props_79931$$.objects,$APP.$cljs$core$first$$($props_79931$$.shapes));return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$inspect$right_sidebar$right_sidebar_STAR_$$,{...$props_79931$$,frame:$frame$jscomp$76$$,from:$APP.$cljs$cst$2543$workspace$$})};
$app$main$ui$workspace$sidebar$options$on_option_tab_change$$=function($mode$jscomp$51_mode__$1$jscomp$3$$){$mode$jscomp$51_mode__$1$jscomp$3$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($mode$jscomp$51_mode__$1$jscomp$3$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$layout$set_options_mode$$($mode$jscomp$51_mode__$1$jscomp$3$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$51_mode__$1$jscomp$3$$,$APP.$cljs$cst$2683$inspect$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$common$set_workspace_read_only$$(!0)])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$common$set_workspace_read_only$$(!1)]))};
$app$main$ui$workspace$sidebar$options$options_content_STAR_$$=function($props_79939$$){var $on_expand$jscomp$2$$=$props_79939$$.onExpand,$on_change_section$jscomp$1$$=$props_79939$$.onChangeSection,$selected$jscomp$178$$=$props_79939$$.selected,$file_id$jscomp$426$$=$props_79939$$.fileId,$objects$jscomp$811$$=$props_79939$$.objects,$page_id$jscomp$444$$=$props_79939$$.pageId,$permissions$jscomp$35$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$),$render_context_lost_QMARK_$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$render_context_lost_QMARK_$$),$options_mode$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$options_mode_global$$),$shapes$jscomp$231$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$178$$),$APP.$rumext$v2$adapt$$($objects$jscomp$811$$)],function(){return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$811$$)),
$selected$jscomp$178$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options__tool-window",children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$868$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$35$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$868$$)?$APP.$cljs$core$not$$($render_context_lost_QMARK_$$):$and__5023__auto__$jscomp$868$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,
{tabs:$app$main$ui$workspace$sidebar$options$options_tabs$$,onChange:$app$main$ui$workspace$sidebar$options$on_option_tab_change$$,selected:$APP.$cljs$core$name$$($options_mode$jscomp$1$$),className:"main_ui_workspace_sidebar_options__options-tab-switcher",children:function(){var $G__79943__$1$$=$options_mode$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$options_mode$jscomp$1$$.$fqn$:null;switch($G__79943__$1$$){case "prototype":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options__element-options main_ui_workspace_sidebar_options__interaction-options",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$interactions$interactions_menu_STAR_$$,{shape:$APP.$cljs$core$first$$($shapes$jscomp$231$$)})});case "inspect":return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options__element-options main_ui_workspace_sidebar_options__inspect-options",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$inspect_tab_STAR_$$,{pageId:$page_id$jscomp$444$$,fileId:$file_id$jscomp$426$$,objects:$objects$jscomp$811$$,
selected:$selected$jscomp$178$$,shapes:$shapes$jscomp$231$$,onChangeSection:$on_change_section$jscomp$1$$,onExpand:$on_expand$jscomp$2$$})});case "design":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$design_menu_STAR_$$,{selected:$selected$jscomp$178$$,objects:$objects$jscomp$811$$,pageId:$page_id$jscomp$444$$,fileId:$file_id$jscomp$426$$,shapes:$shapes$jscomp$231$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79943__$1$$)].join(""));
}}()}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options__element-options main_ui_workspace_sidebar_options__inspect-options main_ui_workspace_sidebar_options__read-only",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$inspect_tab_STAR_$$,{pageId:$page_id$jscomp$444$$,fileId:$file_id$jscomp$426$$,objects:$objects$jscomp$811$$,selected:$selected$jscomp$178$$,shapes:$shapes$jscomp$231$$,onChangeSection:$on_change_section$jscomp$1$$,onExpand:$on_expand$jscomp$2$$})})})};
$app$main$ui$workspace$sidebar$options$make_page_objects_ref$$=function($file_id$jscomp$427$$,$page_id$jscomp$445$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79944_SHARP_$$){return $APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$3$($p1__79944_SHARP_$$,$file_id$jscomp$427$$,$page_id$jscomp$445$$)},$APP.$app$main$store$state$$)};
$app$main$ui$workspace$sidebar$shortcuts$converted_chars_STAR_$$=function($command$jscomp$21_props_79867_unique_key$$){var $char$$jscomp$5$$=$command$jscomp$21_props_79867_unique_key$$.char;$command$jscomp$21_props_79867_unique_key$$=$command$jscomp$21_props_79867_unique_key$$.command;var $modified_keys$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$1970$up$$,"↑",$APP.$cljs$cst$1969$down$$,"↓",$APP.$cljs$cst$257$left$$,"←",$APP.$cljs$cst$258$right$$,"→",$cljs$cst$5564$plus$$,"+"],
null),$macos_keys$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2157$shift$$,$APP.$cljs$cst$3779$del$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5836$esc$$,$APP.$cljs$cst$1818$command$$,$APP.$cljs$cst$4945$delete$$,$APP.$cljs$cst$381$enter$$,$cljs$cst$5649$option$$,$cljs$cst$5837$control$$],"⇧⌫⌥⎋⌘⌫⏎⌥⌃".split("")),$char$__$2_is_macos_QMARK_$$=$APP.$app$config$check_platform_QMARK_$$(),$char$__$1$$=$APP.$cljs$core$contains_QMARK_$$($modified_keys$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($char$$jscomp$5$$))?
function(){var $fexpr__79868$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($char$$jscomp$5$$);return $fexpr__79868$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__79868$$.$cljs$core$IFn$_invoke$arity$1$($modified_keys$$):$fexpr__79868$$($modified_keys$$)}():$char$$jscomp$5$$;$char$__$2_is_macos_QMARK_$$=$char$__$2_is_macos_QMARK_$$&&$APP.$cljs$core$contains_QMARK_$$($macos_keys$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($char$__$1$$))?function(){var $fexpr__79869$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($char$__$1$$);
return $fexpr__79869$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__79869$$.$cljs$core$IFn$_invoke$arity$1$($macos_keys$$):$fexpr__79869$$($macos_keys$$)}():$char$__$1$$;$command$jscomp$21_props_79867_unique_key$$=[$APP.$app$common$data$name$$($command$jscomp$21_props_79867_unique_key$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($char$__$2_is_macos_QMARK_$$)].join("");return(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_shortcuts__key",children:$char$__$2_is_macos_QMARK_$$},
$command$jscomp$21_props_79867_unique_key$$)};
$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$=function($type$jscomp$681$$,$keyname$$){var $translat_pre$$=function(){var $G__79870__$1$$=$type$jscomp$681$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$681$$.$fqn$:null;switch($G__79870__$1$$){case "sc":return"shortcuts.";case "sec":return"shortcut-section.";case "sub-sec":return"shortcut-subsection.";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79870__$1$$)].join(""));}}();
return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($translat_pre$$),$APP.$app$common$data$name$$($keyname$$)].join(""))};
$app$main$ui$workspace$sidebar$shortcuts$add_translation$$=function($type$jscomp$682$$,$item$jscomp$137$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__79871_v$jscomp$676$$){var $k$jscomp$695$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79871_v$jscomp$676$$,0,null);$p__79871_v$jscomp$676$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79871_v$jscomp$676$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$k$jscomp$695$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__79871_v$jscomp$676$$,$cljs$cst$5838$translation$$,$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($type$jscomp$682$$,$k$jscomp$695$$))],null)},$item$jscomp$137$$)};
$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$=function($shortcuts$jscomp$8$$){function $get_sc_by_subsection$$($subsection$jscomp$1$$,$p__79876_v$jscomp$677$$){var $k$jscomp$696$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79876_v$jscomp$677$$,0,null);$p__79876_v$jscomp$677$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79876_v$jscomp$677$$,1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__79875_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subsection$jscomp$1$$,
$p1__79875_SHARP_$$)},$APP.$cljs$cst$4898$subsections$$.$cljs$core$IFn$_invoke$arity$1$($p__79876_v$jscomp$677$$)))?$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$k$jscomp$696$$,$p__79876_v$jscomp$677$$]):null}var $subsections$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4898$subsections$$),$APP.$cljs$core$vals$$($shortcuts$jscomp$8$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$167$$,
$subsection$jscomp$2$$){var $shortcuts_by_subsection$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($get_sc_by_subsection$$,$subsection$jscomp$2$$),$shortcuts$jscomp$8$$));return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$167$$,$subsection$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$342$children$$,
$shortcuts_by_subsection$$],null))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$subsections$$)};
$app$main$ui$workspace$sidebar$shortcuts$shortcuts_keys_STAR_$$=function($last_element_managed_list_props_79880$$){var $chars_list_content$jscomp$251_short_char_list$$=$last_element_managed_list_props_79880$$.content,$command$jscomp$22$$=$last_element_managed_list_props_79880$$.command;$last_element_managed_list_props_79880$$=$APP.$cljs$core$coll_QMARK_$$($chars_list_content$jscomp$251_short_char_list$$)?$chars_list_content$jscomp$251_short_char_list$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$List$EMPTY$$,
$chars_list_content$jscomp$251_short_char_list$$);$chars_list_content$jscomp$251_short_char_list$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$shortcuts$split_sc$$,$last_element_managed_list_props_79880$$);$last_element_managed_list_props_79880$$=$APP.$cljs$core$last$$($chars_list_content$jscomp$251_short_char_list$$);$chars_list_content$jscomp$251_short_char_list$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($chars_list_content$jscomp$251_short_char_list$$))?
$chars_list_content$jscomp$251_short_char_list$$:$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($chars_list_content$jscomp$251_short_char_list$$);var $penultimate$$=$APP.$cljs$core$last$$($chars_list_content$jscomp$251_short_char_list$$);return(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_sidebar_shortcuts__keys",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$190$$,$chars$jscomp$5$$){$out_arr__44092__auto__$jscomp$190$$.push((0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$20$$,$char$$jscomp$6$$){$out_arr__44092__auto____$1$jscomp$20$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$converted_chars_STAR_$$,{"char":$char$$jscomp$6$$,command:$command$jscomp$22$$},""+($char$$jscomp$6$$??"")+"-"+($APP.$cljs$core$name$$($command$jscomp$22$$)??"")));return $out_arr__44092__auto____$1$jscomp$20$$},[],$chars$jscomp$5$$),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($chars$jscomp$5$$,
$penultimate$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_shortcuts__space",children:","}):null]},$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$1$($chars$jscomp$5$$)));return $out_arr__44092__auto__$jscomp$190$$},[],$chars_list_content$jscomp$251_short_char_list$$),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_element_managed_list_props_79880$$,$penultimate$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_shortcuts__space",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.or")}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$191$$,$char$$jscomp$7$$){$out_arr__44092__auto__$jscomp$191$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$converted_chars_STAR_$$,{"char":$char$$jscomp$7$$,command:$command$jscomp$22$$},""+($char$$jscomp$7$$??"")+"-"+($APP.$cljs$core$name$$($command$jscomp$22$$)??
"")));return $out_arr__44092__auto__$jscomp$191$$},[],$last_element_managed_list_props_79880$$)]}):null]})};
$app$main$ui$workspace$sidebar$shortcuts$shortcut_row_STAR_$$=function($filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$){var $is_match_subsection$$=$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$.isMatchSubsection,$is_match_section$$=$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$.isMatchSection,$filter_term$jscomp$2$$=$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$.filterTerm,
$elements$jscomp$7$$=$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$.elements;$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$=$APP.$cljs$core$keys$$($elements$jscomp$7$$);$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79882_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5839$sc$$,
$p1__79882_SHARP_$$)},$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$);var $match_shortcut_QMARK_$$=$APP.$cljs$core$some$$(function($p1__79883_SHARP_$$){return $app$util$strings$matches_search$$($p1__79883_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$2$$))},$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$);$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$869$$=
$APP.$cljs$core$truth_$$($is_match_section$$)?$is_match_section$$:$is_match_subsection$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$869$$)?$APP.$cljs$core$not$$($match_shortcut_QMARK_$$):$and__5023__auto__$jscomp$869$$}())?$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$:$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79884_SHARP_$$){return $app$util$strings$matches_search$$($p1__79884_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$2$$))},
$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$);$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$=$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$);return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_shortcuts__sub-menu",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$192$$,
$command_translate$$){$out_arr__44092__auto__$jscomp$192$$.push(function(){var $content$jscomp$252_vec__79888$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79885_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5838$translation$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__79885_SHARP_$$)),$command_translate$$)},$elements$jscomp$7$$)),$command$jscomp$23$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$252_vec__79888$$,
0,null),$comand_info$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$252_vec__79888$$,1,null);$content$jscomp$252_vec__79888$$=function(){var $or__5025__auto__$jscomp$1287$$=$APP.$cljs$cst$5005$show_command$$.$cljs$core$IFn$_invoke$arity$1$($comand_info$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1287$$)?$or__5025__auto__$jscomp$1287$$:$APP.$cljs$cst$1818$command$$.$cljs$core$IFn$_invoke$arity$1$($comand_info$$)}();return(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_sidebar_shortcuts__shortcuts-name",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_shortcuts__command-name",children:$command_translate$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcuts_keys_STAR_$$,{content:$content$jscomp$252_vec__79888$$,command:$command$jscomp$23$$})]},$command_translate$$)}());return $out_arr__44092__auto__$jscomp$192$$},[],$filtered$jscomp$3_props_79886_shortcut_name_shortcut_translations_sorted_filtered$$)})};
$app$main$ui$workspace$sidebar$shortcuts$section_title_STAR_$$=function($props_79891$$){var $is_sub$$=$props_79891$$.isSub,$name$jscomp$465$$=$props_79891$$.name;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:$APP.$cljs$core$truth_$$($is_sub$$)?"main_ui_workspace_sidebar_shortcuts__subsection-title":"main_ui_workspace_sidebar_shortcuts__section-title",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$APP.$cljs$core$truth_$$($props_79891$$.isVisible)?
"arrow-down":"arrow-right",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{className:$APP.$cljs$core$truth_$$($is_sub$$)?"main_ui_workspace_sidebar_shortcuts__subsection-name":"main_ui_workspace_sidebar_shortcuts__section-name",children:$name$jscomp$465$$})]})};
$app$main$ui$workspace$sidebar$shortcuts$shortcut_subsection_STAR_$$=function($basic_shortcuts_props_79898_subsections_names$$){var $manage_sections$$=$basic_shortcuts_props_79898_subsections_names$$.manageSections,$is_match_section$jscomp$1$$=$basic_shortcuts_props_79898_subsections_names$$.isMatchSection,$filter_term$jscomp$3$$=$basic_shortcuts_props_79898_subsections_names$$.filterTerm,$subsections$jscomp$1$$=$basic_shortcuts_props_79898_subsections_names$$.subsections,$open_sections$$=$basic_shortcuts_props_79898_subsections_names$$.openSections;
$basic_shortcuts_props_79898_subsections_names$$=$APP.$cljs$core$keys$$($subsections$jscomp$1$$);var $sorted_translations_subsection_translations$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$226$none$$,$APP.$cljs$core$first$$($basic_shortcuts_props_79898_subsections_names$$))?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79892_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5839$sc$$,$p1__79892_SHARP_$$)},$basic_shortcuts_props_79898_subsections_names$$):
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79893_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5840$sub_sec$$,$p1__79893_SHARP_$$)},$basic_shortcuts_props_79898_subsections_names$$);$sorted_translations_subsection_translations$$=$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($sorted_translations_subsection_translations$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$226$none$$,$APP.$cljs$core$first$$($basic_shortcuts_props_79898_subsections_names$$))?
($basic_shortcuts_props_79898_subsections_names$$=$APP.$cljs$cst$226$none$$.$cljs$core$IFn$_invoke$arity$1$($subsections$jscomp$1$$),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcut_row_STAR_$$,{elements:$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($basic_shortcuts_props_79898_subsections_names$$),filterTerm:$filter_term$jscomp$3$$,isMatchSection:$is_match_section$jscomp$1$$,isMatchSubsection:!0})):(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_shortcuts__subsection-menu",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$193$$,$sub_translated$$){$out_arr__44092__auto__$jscomp$193$$.push(function(){var $vec__79902_visible_QMARK_$jscomp$5$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79894_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5838$translation$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($p1__79894_SHARP_$$)),
$sub_translated$$)},$subsections$jscomp$1$$)),$match_subsection_QMARK__sub_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79902_visible_QMARK_$jscomp$5$$,0,null),$sub_info$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__79902_visible_QMARK_$jscomp$5$$,1,null);$vec__79902_visible_QMARK_$jscomp$5$$=$APP.$cljs$core$some$$(function($p1__79895_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79895_SHARP_$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sub_info$$))},
$APP.$cljs$core$_deref$$($open_sections$$));$match_subsection_QMARK__sub_name$$=$app$util$strings$matches_search$$($app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5840$sub_sec$$,$match_subsection_QMARK__sub_name$$),$APP.$cljs$core$_deref$$($filter_term$jscomp$3$$));var $match_shortcuts_QMARK__shortcut_names$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79896_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5839$sc$$,
$p1__79896_SHARP_$$)},$APP.$cljs$core$keys$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($sub_info$$)));$match_shortcuts_QMARK__shortcut_names$$=$APP.$cljs$core$some$$(function($p1__79897_SHARP_$$){return $app$util$strings$matches_search$$($p1__79897_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$3$$))},$match_shortcuts_QMARK__shortcut_names$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($match_subsection_QMARK__sub_name$$)?$match_subsection_QMARK__sub_name$$:
$APP.$cljs$core$truth_$$($match_shortcuts_QMARK__shortcut_names$$)?$match_shortcuts_QMARK__shortcut_names$$:$is_match_section$jscomp$1$$)?(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:function(){var $G__79905$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($sub_info$$);return $manage_sections$$.$cljs$core$IFn$_invoke$arity$1$?$manage_sections$$.$cljs$core$IFn$_invoke$arity$1$($G__79905$$):$manage_sections$$($G__79905$$)}(),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$section_title_STAR_$$,
{name:$sub_translated$$,isVisible:$vec__79902_visible_QMARK_$jscomp$5$$,isSub:!0}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{display:$APP.$cljs$core$truth_$$($vec__79902_visible_QMARK_$jscomp$5$$)?"initial":"none"},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcut_row_STAR_$$,{elements:$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($sub_info$$),filterTerm:$filter_term$jscomp$3$$,isMatchSection:$is_match_section$jscomp$1$$,isMatchSubsection:$match_subsection_QMARK__sub_name$$})})]},
$sub_translated$$):null}());return $out_arr__44092__auto__$jscomp$193$$},[],$sorted_translations_subsection_translations$$)})};
$app$main$ui$workspace$sidebar$shortcuts$shortcut_section_STAR_$$=function($props_79914_section_key_section_translation$$){var $manage_sections$jscomp$1$$=$props_79914_section_key_section_translation$$.manageSections,$filter_term$jscomp$4$$=$props_79914_section_key_section_translation$$.filterTerm,$open_sections$jscomp$1$$=$props_79914_section_key_section_translation$$.openSections,$match_section_QMARK__vec__79916$$=$props_79914_section_key_section_translation$$.section;$props_79914_section_key_section_translation$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($match_section_QMARK__vec__79916$$,0,null);var $match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($match_section_QMARK__vec__79916$$,1,null),$section_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);$props_79914_section_key_section_translation$$=$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5841$sec$$,
$props_79914_section_key_section_translation$$);$match_section_QMARK__vec__79916$$=$app$util$strings$matches_search$$($props_79914_section_key_section_translation$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$4$$));var $subsections$jscomp$2$$=$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$=$APP.$cljs$core$keys$$($subsections$jscomp$2$$);var $match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__79907_SHARP_$$,$p2__79908_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__79907_SHARP_$$,$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($p2__79908_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$?$p2__79908_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$($subsections$jscomp$2$$):$p2__79908_SHARP_$$($subsections$jscomp$2$$)))},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);
$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79909_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("none",$APP.$app$common$data$name$$($p1__79909_SHARP_$$))?null:$app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5840$sub_sec$$,$p1__79909_SHARP_$$)},$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$=
$APP.$cljs$core$some$$(function($p1__79910_SHARP_$$){return $app$util$strings$matches_search$$($p1__79910_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$4$$))},$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$);$match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79911_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5839$sc$$,$p1__79911_SHARP_$$)},
$APP.$cljs$core$keys$$($match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$));$match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$=$APP.$cljs$core$some$$(function($p1__79912_SHARP_$$){return $app$util$strings$matches_search$$($p1__79912_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$4$$))},$match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$);var $visible_QMARK_$jscomp$6$$=$APP.$cljs$core$some$$(function($p1__79913_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79913_SHARP_$$,
$section_id$$)},$APP.$cljs$core$_deref$$($open_sections$jscomp$1$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($match_section_QMARK__vec__79916$$)?$match_section_QMARK__vec__79916$$:$APP.$cljs$core$truth_$$($match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$)?$match_subsection_QMARK_$jscomp$1_section_info_sub_trans_subs_names$$:$match_shortcut_QMARK_$jscomp$1_subs_bodys_translations$jscomp$3$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$manage_sections$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$manage_sections$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($section_id$$):$manage_sections$jscomp$1$$($section_id$$),className:"main_ui_workspace_sidebar_shortcuts__section",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$section_title_STAR_$$,{name:$props_79914_section_key_section_translation$$,isVisible:$visible_QMARK_$jscomp$6$$,isSub:!1}),(0,$APP.$rumext$v2$jsx$$)("div",{style:{display:$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$6$$)?"initial":"none"},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcut_subsection_STAR_$$,
{subsections:$subsections$jscomp$2$$,openSections:$open_sections$jscomp$1$$,manageSections:$manage_sections$jscomp$1$$,isMatchSection:$match_section_QMARK__vec__79916$$,filterTerm:$filter_term$jscomp$4$$})})]}):null};
$app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR_$$=function($class$$jscomp$76_props_79925$$){function $manage_section_on_search$$($node_seq$jscomp$1_section$jscomp$33$$,$term$jscomp$12$$){$node_seq$jscomp$1_section$jscomp$33$$=$APP.$cljs$core$tree_seq$$($APP.$cljs$cst$342$children$$,function($p1__79924_SHARP_$$){return $APP.$cljs$core$vals$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($p1__79924_SHARP_$$))},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_shortcuts__$1$$,
$node_seq$jscomp$1_section$jscomp$33$$));return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$169$$,$node$jscomp$433$$){return $APP.$cljs$core$truth_$$($app$util$strings$matches_search$$($cljs$cst$5838$translation$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$433$$),$term$jscomp$12$$))?$add_ids$$($acc$jscomp$169$$,$node$jscomp$433$$):$acc$jscomp$169$$},$APP.$cljs$core$PersistentVector$EMPTY$$,$node_seq$jscomp$1_section$jscomp$33$$)}function $add_ids$$($acc$jscomp$168$$,
$addition_node$jscomp$432$$){var $id$jscomp$994$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($addition_node$jscomp$432$$);$addition_node$jscomp$432$$=function(){var $G__79930$$=$APP.$cljs$core$count$$($id$jscomp$994$$);switch($G__79930$$){case 1:return $id$jscomp$994$$;case 2:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($id$jscomp$994$$)],
null),$id$jscomp$994$$],null);case 3:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($id$jscomp$994$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($id$jscomp$994$$),$APP.$cljs$core$second$$($id$jscomp$994$$)],null)],null);case "default":return null;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79930$$)].join(""));}}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($addition_node$jscomp$432$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$168$$,$addition_node$jscomp$432$$):$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$168$$,
$addition_node$jscomp$432$$))}function $manage_sections$jscomp$2$$($item$jscomp$139$$){return function($event$jscomp$566_is_present_QMARK__new_value$jscomp$27$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$566_is_present_QMARK__new_value$jscomp$27$$);$event$jscomp$566_is_present_QMARK__new_value$jscomp$27$$=$APP.$cljs$core$some$$(function($p1__79923_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79923_SHARP_$$,$item$jscomp$139$$)},$APP.$cljs$core$_deref$$($open_sections$jscomp$2$$));
$event$jscomp$566_is_present_QMARK__new_value$jscomp$27$$=$APP.$cljs$core$truth_$$($event$jscomp$566_is_present_QMARK__new_value$jscomp$27$$)?$APP.$cljs$core$filterv$$(function($element$jscomp$84$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($element$jscomp$84$$,$item$jscomp$139$$)},$APP.$cljs$core$_deref$$($open_sections$jscomp$2$$)):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($open_sections$jscomp$2$$),$item$jscomp$139$$);return $APP.$cljs$core$reset_BANG_$$($open_sections$jscomp$2$$,
$event$jscomp$566_is_present_QMARK__new_value$jscomp$27$$)}}$class$$jscomp$76_props_79925$$=$class$$jscomp$76_props_79925$$.className;var $all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5839$sc$$,$APP.$app$common$data$deep_merge$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$path$shortcuts$shortcuts$$,
$APP.$app$main$data$workspace$shortcuts$shortcuts$$))),$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5839$sc$$,$APP.$app$main$data$dashboard$shortcuts$shortcuts$$)),$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5839$sc$$,$APP.$app$main$data$viewer$shortcuts$shortcuts$$)),$open_sections$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1],null)],null)),$filter_term$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),
$workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5840$sub_sec$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$($all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$))),$dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5840$sub_sec$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$($all_sub_names_dashboard_shortcuts_on_search_term_change_2$$))),$viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$app$main$ui$workspace$sidebar$shortcuts$add_translation$$($cljs$cst$5840$sub_sec$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts__GT_subsections$$($all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$))),
$basics_elements$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4999$basics$$.$cljs$core$IFn$_invoke$arity$1$($workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$)),$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4999$basics$$.$cljs$core$IFn$_invoke$arity$1$($dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$)),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4999$basics$$.$cljs$core$IFn$_invoke$arity$1$($viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$))])));$workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$,$APP.$cljs$cst$4999$basics$$);$dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$,$APP.$cljs$cst$4999$basics$$);$viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$,$cljs$cst$5842$bassics$$);var $all_shortcuts__$1$$=function $app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR__$_walk$$($element$jscomp$83$$,$parent_id$jscomp$108$$){return $element$jscomp$83$$==
null?$element$jscomp$83$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$538_item_id$$,$item$jscomp$138_p__79926$$){var $k$jscomp$697$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$138_p__79926$$,0,null);$item$jscomp$138_p__79926$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$138_p__79926$$,1,null);$index$jscomp$538_item_id$$=
$parent_id$jscomp$108$$==null?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$538_item_id$$],null):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($parent_id$jscomp$108$$,$index$jscomp$538_item_id$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$k$jscomp$697$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($item$jscomp$138_p__79926$$,$APP.$cljs$cst$266$id$$,
$index$jscomp$538_item_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$342$children$$,$app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR__$_walk$$($APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$138_p__79926$$),$index$jscomp$538_item_id$$)]))],null)},$element$jscomp$83$$))}(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$4999$basics$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1],null),$APP.$cljs$cst$342$children$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$226$none$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$342$children$$,$basics_elements$$],null)],null),$cljs$cst$5838$translation$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-section.basics")],null),$APP.$cljs$cst$2543$workspace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$266$id$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[2],null),$APP.$cljs$cst$342$children$$,$workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$,$cljs$cst$5838$translation$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-section.workspace")],null),$APP.$cljs$cst$5238$dashboard$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[3],null),$APP.$cljs$cst$342$children$$,$dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$,$cljs$cst$5838$translation$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-section.dashboard")],null),$APP.$cljs$cst$1597$viewer$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[4],null),$APP.$cljs$cst$342$children$$,$viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$,
$cljs$cst$5838$translation$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcut-section.viewer")],null)],null),null);$all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79919_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5839$sc$$,$p1__79919_SHARP_$$)},$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$keys$$($all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$),
$APP.$cljs$core$keys$$($all_sub_names_dashboard_shortcuts_on_search_term_change_2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$keys$$($all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$)])));$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79920_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5840$sub_sec$$,$p1__79920_SHARP_$$)},
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$keys$$($workspace_sc_by_subsections_workspace_sc_by_subsections__$1$$),$APP.$cljs$core$keys$$($dashboard_sc_by_subsections_dashboard_sc_by_subsections__$1$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$keys$$($viewer_sc_by_subsections_viewer_sc_by_subsections__$1$$)])));$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79921_SHARP_$$){return $app$main$ui$workspace$sidebar$shortcuts$translation_keyname$$($cljs$cst$5841$sec$$,
$p1__79921_SHARP_$$)},$APP.$cljs$core$keys$$($all_shortcuts__$1$$));$all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$,$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$]));$all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$=
$APP.$cljs$core$some$$(function($p1__79922_SHARP_$$){return $app$util$strings$matches_search$$($p1__79922_SHARP_$$,$APP.$cljs$core$_deref$$($filter_term$jscomp$5$$))},$all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$);$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$940$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$940$$,""))$APP.$cljs$core$reset_BANG_$$($open_sections$jscomp$2$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1],null)],null));else{var $ids$jscomp$inline_9112$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$variadic$($manage_section_on_search$$($APP.$cljs$cst$4999$basics$$,$value$jscomp$940$$),$manage_section_on_search$$($APP.$cljs$cst$2543$workspace$$,$value$jscomp$940$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$manage_section_on_search$$($APP.$cljs$cst$5238$dashboard$$,
$value$jscomp$940$$),$manage_section_on_search$$($APP.$cljs$cst$1597$viewer$$,$value$jscomp$940$$)]));$APP.$cljs$core$reset_BANG_$$($open_sections$jscomp$2$$,$ids$jscomp$inline_9112$$)}return $APP.$cljs$core$reset_BANG_$$($filter_term$jscomp$5$$,$value$jscomp$940$$)});$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($open_sections$jscomp$2$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[1],null)],null));return $APP.$cljs$core$reset_BANG_$$($filter_term$jscomp$5$$,"")});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:""+($class$$jscomp$76_props_79925$$??"")+" main_ui_workspace_sidebar_shortcuts__shortcuts",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$panel_title$panel_title_STAR_$$,{className:"main_ui_workspace_sidebar_shortcuts__shortcuts-title",
text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.title"),onClose:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$2961$shortcuts$$))}}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_shortcuts__search-field",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$all_sub_names_dashboard_shortcuts_on_search_term_change_2$$,
onClear:$all_section_names_on_search_clear_click$jscomp$1_viewer_shortcuts$$,value:$APP.$cljs$core$_deref$$($filter_term$jscomp$5$$),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.title"),iconId:"search",autoFocus:!0})}),$APP.$cljs$core$truth_$$($all_item_names_all_sc_names_all_workspace_shortcuts_match_any_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_shortcuts__shortcuts-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$194$$,
$section$jscomp$34$$){$out_arr__44092__auto__$jscomp$194$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcut_section_STAR_$$,{section:$section$jscomp$34$$,manageSections:$manage_sections$jscomp$2$$,openSections:$open_sections$jscomp$2$$,filterTerm:$filter_term$jscomp$5$$},$APP.$cljs$core$first$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$second$$($section$jscomp$34$$)))));return $out_arr__44092__auto__$jscomp$194$$},[],$all_shortcuts__$1$$)}):
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_shortcuts__not-found",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.not-found")})]})};
$app$main$ui$workspace$sidebar$sitemap$make_page_ref$$=function($page_id$jscomp$447$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($fdata$jscomp$23_page$jscomp$170$$){$fdata$jscomp$23_page$jscomp$170$$=$APP.$app$main$data$helpers$get_page$$($fdata$jscomp$23_page$jscomp$170$$,$page_id$jscomp$447$$);return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($fdata$jscomp$23_page$jscomp$170$$,$cljs$cst$5843$empty_QMARK_$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($fdata$jscomp$23_page$jscomp$170$$)))),$APP.$cljs$cst$1636$objects$$)},$APP.$app$main$refs$workspace_data$$,$APP.$cljs$core$_EQ_$$)};
$app$main$ui$workspace$sidebar$sitemap$page_item$$=function($on_click$jscomp$49_props_79935$$){var $selected_QMARK_$jscomp$2$$=$on_click$jscomp$49_props_79935$$["selected?"],$editing_QMARK_$jscomp$9$$=$on_click$jscomp$49_props_79935$$["editing?"],$hovering_QMARK_$jscomp$1$$=$on_click$jscomp$49_props_79935$$["hovering?"],$index$jscomp$539$$=$on_click$jscomp$49_props_79935$$.index,$deletable_QMARK_$jscomp$1$$=$on_click$jscomp$49_props_79935$$["deletable?"],$page$jscomp$171$$=$on_click$jscomp$49_props_79935$$.page,
$current_page_id$jscomp$5$$=$on_click$jscomp$49_props_79935$$["current-page-id"],$input_ref$jscomp$12$$=(0,$APP.$rumext$v2$use_ref$$)(),$id$jscomp$995$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$171$$),$name$jscomp$466$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$171$$,""),$is_separator_QMARK_$$=function(){var $and__5023__auto__$jscomp$870$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("---",$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$466$$));
return $and__5023__auto__$jscomp$870$$?$cljs$cst$5843$empty_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$171$$):$and__5023__auto__$jscomp$870$$}(),$delete_fn$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$995$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$delete_page$$($id$jscomp$995$$))}),$navigate_fn$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$995$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2051$page_id$$,$id$jscomp$995$$]))]))}),$read_only_QMARK_$jscomp$21$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);
$on_click$jscomp$49_props_79935$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$995$$),$APP.$rumext$v2$adapt$$($current_page_id$jscomp$5$$),$APP.$rumext$v2$adapt$$($is_separator_QMARK_$$)],function(){if($APP.$cljs$core$truth_$$($is_separator_QMARK_$$))var $JSCompiler_temp$jscomp$1850_JSCompiler_temp$jscomp$1851_JSCompiler_temp$jscomp$1852$$=null;else $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"render-wasm/v1")&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$995$$,$current_page_id$jscomp$5$$)?($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$))?$JSCompiler_temp$jscomp$1850_JSCompiler_temp$jscomp$1851_JSCompiler_temp$jscomp$1852$$=$APP.$promesa$impl$promise$resolved$$(null):($app$render_wasm$api$render_blurred_snapshot_BANG_$$(),$JSCompiler_temp$jscomp$1850_JSCompiler_temp$jscomp$1851_JSCompiler_temp$jscomp$1852$$=
$APP.$app$render_wasm$api$capture_canvas_snapshot$$()),$JSCompiler_temp$jscomp$1850_JSCompiler_temp$jscomp$1851_JSCompiler_temp$jscomp$1852$$=$APP.$promesa$core$finally$0$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1850_JSCompiler_temp$jscomp$1851_JSCompiler_temp$jscomp$1852$$,function(){$app$render_wasm$api$apply_canvas_blur$$();return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return(0,$APP.$app$util$timers$request_animation_frame$$)($navigate_fn$$)})})):$JSCompiler_temp$jscomp$1850_JSCompiler_temp$jscomp$1851_JSCompiler_temp$jscomp$1852$$=
$navigate_fn$$.$cljs$core$IFn$_invoke$arity$0$?$navigate_fn$$.$cljs$core$IFn$_invoke$arity$0$():$navigate_fn$$();return $JSCompiler_temp$jscomp$1850_JSCompiler_temp$jscomp$1851_JSCompiler_temp$jscomp$1852$$});var $on_delete$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$995$$)],function($event$jscomp$567$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$567$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2484$confirm$$,$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.title"),$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.body"),$APP.$cljs$cst$2490$on_accept$$,$delete_fn$jscomp$5$$],null)))}),$on_double_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$21$$)],function($event$jscomp$568$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$568$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$568$$);return $APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$21$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$start_rename_page_item$$($id$jscomp$995$$))}),$on_blur$jscomp$32$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$995$$),$APP.$rumext$v2$adapt$$($is_separator_QMARK_$$)],function($event$jscomp$569_new_name_79954$$){$event$jscomp$569_new_name_79954$$=
$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$569_new_name_79954$$));$APP.$cuerdas$core$empty_QMARK_$$($event$jscomp$569_new_name_79954$$)?$APP.$cljs$core$truth_$$($is_separator_QMARK_$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$delete_page$$($id$jscomp$995$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$rename_page$$($id$jscomp$995$$,
$event$jscomp$569_new_name_79954$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$stop_rename_page_item$$())}),$on_key_down$jscomp$21$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$570$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$570$$))?$on_blur$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$32$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$570$$):
$on_blur$jscomp$32$$($event$jscomp$570$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$570$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$stop_rename_page_item$$()):null}),$dprops$jscomp$8_on_drop$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$995$$),$APP.$rumext$v2$adapt$$($index$jscomp$539$$)],function($index__$1$jscomp$24_side$jscomp$4$$,$id__$1$jscomp$21_map__79941__$1_p__79940$$){$id__$1$jscomp$21_map__79941__$1_p__79940$$=
$APP.$cljs$core$__destructure_map$$($id__$1$jscomp$21_map__79941__$1_p__79940$$);$id__$1$jscomp$21_map__79941__$1_p__79940$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id__$1$jscomp$21_map__79941__$1_p__79940$$,$APP.$cljs$cst$266$id$$);$index__$1$jscomp$24_side$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2963$bot$$,$index__$1$jscomp$24_side$jscomp$4$$)?$index$jscomp$539$$+1:$index$jscomp$539$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$relocate_page$$($id__$1$jscomp$21_map__79941__$1_p__79940$$,
$index__$1$jscomp$24_side$jscomp$4$$))}),$on_context_menu$jscomp$11_vec__79936$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,"penpot/page",$APP.$cljs$cst$2966$on_drop$$,$dprops$jscomp$8_on_drop$jscomp$15$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$id$jscomp$995$$,$APP.$cljs$cst$1801$index$$,$index$jscomp$539$$,
$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$171$$)],null),$APP.$cljs$cst$2970$draggable_QMARK_$$,$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$21$$)&&$APP.$cljs$core$not$$($editing_QMARK_$jscomp$9$$)]));$dprops$jscomp$8_on_drop$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($on_context_menu$jscomp$11_vec__79936$$,0,null);var $dref$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($on_context_menu$jscomp$11_vec__79936$$,
1,null);$on_context_menu$jscomp$11_vec__79936$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$995$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$21$$)],function($event$jscomp$571_position$jscomp$200$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$571_position$jscomp$200$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$571_position$jscomp$200$$);if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$21$$))return null;$event$jscomp$571_position$jscomp$200$$=
$APP.$app$util$dom$get_client_position$$($event$jscomp$571_position$jscomp$200$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_page_item_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1681$position$$,$event$jscomp$571_position$jscomp$200$$,$APP.$cljs$cst$1629$page$$,$page$jscomp$171$$,$cljs$cst$5714$deletable_QMARK_$$,$deletable_QMARK_$jscomp$1$$],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$2$$)],
function(){return $APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$2$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($dref$jscomp$8$$),!1):null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_QMARK_$jscomp$9$$)],function(){$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$9$$)&&$APP.$app$util$dom$select_text_BANG_$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$12$$));return null});
var $selected_QMARK___$1$$=$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$2$$)?$APP.$cljs$core$not$$($is_separator_QMARK_$$):$selected_QMARK_$jscomp$2$$;return(0,$APP.$rumext$v2$jsx$$)("li",{ref:$dref$jscomp$8$$,className:"main_ui_workspace_sidebar_sitemap__page-element "+($APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?"main_ui_workspace_sidebar_sitemap__separator":"")+" "+($APP.$cljs$core$truth_$$($selected_QMARK___$1$$)?"main_ui_workspace_sidebar_sitemap__selected":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$8_on_drop$jscomp$15$$),
$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_sidebar_sitemap__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$8_on_drop$jscomp$15$$),$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_sidebar_sitemap__dnd-over-bot":""),children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"page-"+($id$jscomp$995$$??""),tabIndex:"0",onClick:$on_click$jscomp$49_props_79935$$,onDoubleClick:$on_double_click$jscomp$1$$,
onContextMenu:$on_context_menu$jscomp$11_vec__79936$$,className:"main_ui_workspace_sidebar_sitemap__element-list-body "+($APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?"main_ui_workspace_sidebar_sitemap__separator-body":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hovering_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($is_separator_QMARK_$$):$hovering_QMARK_$jscomp$1$$)?"main_ui_workspace_sidebar_sitemap__hover":"")+" "+($APP.$cljs$core$truth_$$($selected_QMARK___$1$$)?"main_ui_workspace_sidebar_sitemap__selected":
""),children:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?$APP.$cljs$core$not$$($editing_QMARK_$jscomp$9$$):$is_separator_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"page-separator",className:"main_ui_workspace_sidebar_sitemap__page-separator"}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($is_separator_QMARK_$$)?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_sitemap__page-icon",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"document",size:"s"})}),$APP.$cljs$core$truth_$$($editing_QMARK_$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$input_ref$jscomp$12$$,onBlur:$on_blur$jscomp$32$$,onKeyDown:$on_key_down$jscomp$21$$,autoFocus:!0,defaultValue:$name$jscomp$466$$,className:"main_ui_workspace_sidebar_sitemap__element-name"}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("span",{title:$name$jscomp$466$$,"data-testid":"page-name",className:"main_ui_workspace_sidebar_sitemap__page-name",
children:$name$jscomp$466$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_sitemap__page-actions",children:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($deletable_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$21$$):$deletable_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.delete-page.title"),onClick:$on_delete$jscomp$12$$,
iconSize:"s",className:"main_ui_workspace_sidebar_sitemap__page-delete-button",iconClass:"main_ui_workspace_sidebar_sitemap__page-delete-button-icon",icon:"delete"}):null})]})]})})})};
$app$main$ui$workspace$sidebar$sitemap$page_item_wrapper$$=function($current_page_id$jscomp$6_props_79945$$){var $selected_QMARK_$jscomp$3$$=$current_page_id$jscomp$6_props_79945$$["selected?"],$editing_QMARK_$jscomp$10$$=$current_page_id$jscomp$6_props_79945$$["editing?"],$index$jscomp$540$$=$current_page_id$jscomp$6_props_79945$$.index,$deletable_QMARK_$jscomp$2$$=$current_page_id$jscomp$6_props_79945$$["deletable?"],$page_id$jscomp$448$$=$current_page_id$jscomp$6_props_79945$$["page-id"];$current_page_id$jscomp$6_props_79945$$=
$current_page_id$jscomp$6_props_79945$$["current-page-id"];var $page$jscomp$172_page_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$448$$)],function(){return $app$main$ui$workspace$sidebar$sitemap$make_page_ref$$($page_id$jscomp$448$$)});$page$jscomp$172_page_ref$$=$APP.$rumext$v2$deref$$($page$jscomp$172_page_ref$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sitemap$page_item$$,{page:$page$jscomp$172_page_ref$$,index:$index$jscomp$540$$,
"current-page-id":$current_page_id$jscomp$6_props_79945$$,"deletable?":$deletable_QMARK_$jscomp$2$$,"selected?":$selected_QMARK_$jscomp$3$$,"editing?":$editing_QMARK_$jscomp$10$$})};
$app$main$ui$workspace$sidebar$sitemap$pages_list_STAR_$$=function($pages$jscomp$11_props_79947$$){$pages$jscomp$11_props_79947$$=$APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($pages$jscomp$11_props_79947$$.file);var $deletable_QMARK_$jscomp$3$$=$APP.$cljs$core$count$$($pages$jscomp$11_props_79947$$)>1,$editing_page_id$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$editing_page_item$$),$current_page_id$jscomp$7$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_page_id$$);
return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_sitemap__page-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$195$$,$p__79948_page_id$jscomp$449$$){var $index$jscomp$541$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79948_page_id$jscomp$449$$,0,null);$p__79948_page_id$jscomp$449$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79948_page_id$jscomp$449$$,
1,null);$out_arr__44092__auto__$jscomp$195$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sitemap$page_item_wrapper$$,{"page-id":$p__79948_page_id$jscomp$449$$,index:$index$jscomp$541$$,"deletable?":$deletable_QMARK_$jscomp$3$$,"editing?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__79948_page_id$jscomp$449$$,$editing_page_id$$),"selected?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__79948_page_id$jscomp$449$$,$current_page_id$jscomp$7$$),"current-page-id":$current_page_id$jscomp$7$$},
$p__79948_page_id$jscomp$449$$));return $out_arr__44092__auto__$jscomp$195$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($pages$jscomp$11_props_79947$$))})})};
$app$main$ui$workspace$sidebar$sitemap$sitemap_STAR_$$=function($on_toggle_collapsed_props_79952$$){var $height$jscomp$177$$=$on_toggle_collapsed_props_79952$$.height,$collapsed$jscomp$3$$=$on_toggle_collapsed_props_79952$$.collapsed;$on_toggle_collapsed_props_79952$$=$on_toggle_collapsed_props_79952$$.onToggleCollapsed;var $file$jscomp$176$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$sitemap$ref_COLON_file_with_pages$$),$file_id$jscomp$429$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$176$$,
$APP.$cljs$cst$266$id$$),$project_id$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$176$$,$APP.$cljs$cst$2189$project_id$$),$on_create$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$429$$),$APP.$rumext$v2$adapt$$($project_id$jscomp$36$$)],function($event$jscomp$572$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$create_page$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$429$$,$APP.$cljs$cst$2189$project_id$$,$project_id$jscomp$36$$],null)));return $APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_current_target$$($event$jscomp$572$$))}),$read_only_QMARK_$jscomp$22$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$permissions$jscomp$36$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--height":""+($height$jscomp$177$$??
"")+"px"},className:"main_ui_workspace_sidebar_sitemap__sitemap",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$collapsed$jscomp$3$$,onCollapsed:$on_toggle_collapsed_props_79952$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.sitemap"),className:"main_ui_workspace_sidebar_sitemap__title-spacing-sitemap",children:$read_only_QMARK_$jscomp$22$$?$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$36$$)?
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$badge$badge_notification$$,{"is-focus":!0,size:$APP.$cljs$cst$3945$small$$,content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.view-only")}):null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_workspace_sidebar_sitemap__add-page","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.sitemap.add-page"),onClick:$on_create$$,
icon:"add"})}),$collapsed$jscomp$3$$?null:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_sitemap__tool-window-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sitemap$pages_list_STAR_$$,{file:$file$jscomp$176$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$176$$)??""))})]})};
$app$main$ui$ds$product$avatar$avatar_STAR_$$=function($props_79964_variant__$1$jscomp$7$$){var $tag$jscomp$95$$=$props_79964_variant__$1$jscomp$7$$.tag,$href$jscomp$19_profile$jscomp$80$$=$props_79964_variant__$1$jscomp$7$$.profile,$class_SINGLEQUOTE__selected$jscomp$180$$=$props_79964_variant__$1$jscomp$7$$.selected,$class$$jscomp$77$$=$props_79964_variant__$1$jscomp$7$$.className;$props_79964_variant__$1$jscomp$7$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_79964_variant__$1$jscomp$7$$.variant,
"S");var $profile__$1$jscomp$6$$=$APP.$cljs$core$object_QMARK_$$($href$jscomp$19_profile$jscomp$80$$)?$APP.$rumext$v2$util$bean$$($href$jscomp$19_profile$jscomp$80$$):$href$jscomp$19_profile$jscomp$80$$;$href$jscomp$19_profile$jscomp$80$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($profile__$1$jscomp$6$$)],function(){var $fullname$jscomp$inline_13849_map__79962__$1$jscomp$inline_13846$$=$APP.$cljs$core$__destructure_map$$($profile__$1$jscomp$6$$);var $JSCompiler_inline_result$jscomp$11305_or__5025__auto____$1$jscomp$inline_13850_photo_url$jscomp$inline_13847$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullname$jscomp$inline_13849_map__79962__$1$jscomp$inline_13846$$,$APP.$cljs$cst$3209$photo_url$$);var $photo_id$jscomp$inline_13848$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullname$jscomp$inline_13849_map__79962__$1$jscomp$inline_13846$$,$APP.$cljs$cst$1364$photo_id$$);$fullname$jscomp$inline_13849_map__79962__$1$jscomp$inline_13846$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fullname$jscomp$inline_13849_map__79962__$1$jscomp$inline_13846$$,
$APP.$cljs$cst$1365$fullname$$);$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11305_or__5025__auto____$1$jscomp$inline_13850_photo_url$jscomp$inline_13847$$)||($JSCompiler_inline_result$jscomp$11305_or__5025__auto____$1$jscomp$inline_13850_photo_url$jscomp$inline_13847$$=$photo_id$jscomp$inline_13848$$==null?null:$APP.$app$config$resolve_media$$($photo_id$jscomp$inline_13848$$),$JSCompiler_inline_result$jscomp$11305_or__5025__auto____$1$jscomp$inline_13850_photo_url$jscomp$inline_13847$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11305_or__5025__auto____$1$jscomp$inline_13850_photo_url$jscomp$inline_13847$$)?$JSCompiler_inline_result$jscomp$11305_or__5025__auto____$1$jscomp$inline_13850_photo_url$jscomp$inline_13847$$:(0,$APP.$app$util$avatars$generate$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$fullname$jscomp$inline_13849_map__79962__$1$jscomp$inline_13846$$],null)));return $JSCompiler_inline_result$jscomp$11305_or__5025__auto____$1$jscomp$inline_13850_photo_url$jscomp$inline_13847$$});
$class_SINGLEQUOTE__selected$jscomp$180$$="main_ui_ds_product_avatar__avatar "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79964_variant__$1$jscomp$7$$,"S")?"main_ui_ds_product_avatar__avatar-small":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79964_variant__$1$jscomp$7$$,"M")?"main_ui_ds_product_avatar__avatar-medium":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_79964_variant__$1$jscomp$7$$,"L")?"main_ui_ds_product_avatar__avatar-large":
"")+" "+($APP.$cljs$core$truth_$$($class_SINGLEQUOTE__selected$jscomp$180$$)?"main_ui_ds_product_avatar__is-selected":"");return(0,$APP.$rumext$v2$jsx$$)($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($tag$jscomp$95$$,"div"),{className:($class$$jscomp$77$$??"")+" "+($class_SINGLEQUOTE__selected$jscomp$180$$??""),title:$APP.$cljs$cst$1365$fullname$$.$cljs$core$IFn$_invoke$arity$1$($profile__$1$jscomp$6$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_avatar__avatar-image",
children:(0,$APP.$rumext$v2$jsx$$)("img",{alt:$APP.$cljs$cst$1365$fullname$$.$cljs$core$IFn$_invoke$arity$1$($profile__$1$jscomp$6$$),src:$href$jscomp$19_profile$jscomp$80$$})})})};
$app$main$ui$ds$product$milestone$milestone_STAR_$$=function($props_79965_props__$1$jscomp$84$$){var $created_at$jscomp$1_created_at__$1$jscomp$1$$=void 0,$profile$jscomp$81$$=void 0,$on_blur_input$$=void 0,$on_key_down_input$$=void 0,$on_focus_input$$=void 0,$editing$jscomp$2$$=void 0,$active$jscomp$2$$=void 0,$locked$$=void 0,$label$jscomp$54$$=void 0,$class$$jscomp$78$$=void 0,$on_open_menu$jscomp$1$$=void 0,$props$jscomp$334$$=void 0;({createdAt:$created_at$jscomp$1_created_at__$1$jscomp$1$$,
profile:$profile$jscomp$81$$,onBlurInput:$on_blur_input$$,onKeyDownInput:$on_key_down_input$$,onFocusInput:$on_focus_input$$,editing:$editing$jscomp$2$$,active:$active$jscomp$2$$,locked:$locked$$,label:$label$jscomp$54$$,className:$class$$jscomp$78$$,onOpenMenu:$on_open_menu$jscomp$1$$,...$props$jscomp$334$$}=$props_79965_props__$1$jscomp$84$$);$props_79965_props__$1$jscomp$84$$={...$props$jscomp$334$$,className:($class$$jscomp$78$$??"")+" main_ui_ds_product_milestone__milestone "+($APP.$cljs$core$truth_$$($active$jscomp$2$$)?
"main_ui_ds_product_milestone__is-selected":""),"data-testid":"milestone"};$created_at$jscomp$1_created_at__$1$jscomp$1$$=$APP.$app$common$time$inst_QMARK_$$($created_at$jscomp$1_created_at__$1$jscomp$1$$)?$created_at$jscomp$1_created_at__$1$jscomp$1$$:$APP.$app$common$time$inst$$($created_at$jscomp$1_created_at__$1$jscomp$1$$);return(0,$APP.$rumext$v2$create_element$$)("div",$props_79965_props__$1$jscomp$84$$,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$avatar$avatar_STAR_$$,{profile:$profile$jscomp$81$$,
variant:"S",className:"main_ui_ds_product_milestone__avatar"}),$editing$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{className:"main_ui_ds_product_milestone__name-input",variant:"seamless",defaultValue:$label$jscomp$54$$,autoFocus:!0,onFocus:$on_focus_input$$,onBlur:$on_blur_input$$,onKeyDown:$on_key_down_input$$}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_milestone__name-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-small",className:"main_ui_ds_product_milestone__name",children:$label$jscomp$54$$}),$APP.$cljs$core$truth_$$($locked$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"lock",className:"main_ui_ds_product_milestone__lock-icon"}):null]}),(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("time",{dateTime:$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($created_at$jscomp$1_created_at__$1$jscomp$1$$,
$APP.$cljs$cst$1138$iso$$),className:"main_ui_ds_product_milestone__date",children:$APP.$app$common$time$timeago$$($created_at$jscomp$1_created_at__$1$jscomp$1$$)}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_product_milestone__milestone-buttons",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_ds_product_milestone__menu-button",variant:"ghost",icon:"menu","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.version-menu"),
onClick:$on_open_menu$jscomp$1$$})})]}))};
$app$main$ui$ds$utilities$date$date_STAR_$$=function($date__$1_props_79966$$){var $date$jscomp$24$$=void 0,$selected$jscomp$181$$=void 0,$class$$jscomp$79$$=void 0,$typography$jscomp$38$$=void 0;({className:$class$$jscomp$79$$,date:$date$jscomp$24$$,selected:$selected$jscomp$181$$,typography:$typography$jscomp$38$$}=$date__$1_props_79966$$);$date__$1_props_79966$$=function(){var $G__79967$$=$date$jscomp$24$$;return $APP.$app$common$time$inst_QMARK_$$($date$jscomp$24$$)?$G__79967$$:$APP.$app$common$time$inst$$($G__79967$$)}();
return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"time",typography:function(){var $or__5025__auto__$jscomp$1291$$=$typography$jscomp$38$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1291$$)?$or__5025__auto__$jscomp$1291$$:"body-medium"}(),className:($class$$jscomp$79$$??"")+" main_ui_ds_utilities_date__date "+($APP.$cljs$core$truth_$$($selected$jscomp$181$$)?"main_ui_ds_utilities_date__is-selected":""),dateTime:$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($date__$1_props_79966$$,
$APP.$cljs$cst$1138$iso$$),children:$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($date__$1_props_79966$$,$cljs$cst$5848$localized_date_time$$)})};
$app$main$ui$ds$product$milestone_group$milestone_group_STAR_$$=function($props_79968_props__$1$jscomp$85$$){var $on_menu_click$jscomp$4$$=void 0,$active$jscomp$3_open_QMARK_$jscomp$29$$=void 0,$label$jscomp$55$$=void 0,$class$$jscomp$80_on_toggle_visibility$jscomp$6$$=void 0,$snapshots$$=void 0,$props$jscomp$336_snapshots__$1$$=void 0;({className:$class$$jscomp$80_on_toggle_visibility$jscomp$6$$,active:$active$jscomp$3_open_QMARK_$jscomp$29$$,label:$label$jscomp$55$$,snapshots:$snapshots$$,onMenuClick:$on_menu_click$jscomp$4$$,
...$props$jscomp$336_snapshots__$1$$}=$props_79968_props__$1$jscomp$85$$);$props_79968_props__$1$jscomp$85$$={...$props$jscomp$336_snapshots__$1$$,className:($class$$jscomp$80_on_toggle_visibility$jscomp$6$$??"")+" main_ui_ds_product_milestone_group__milestone "+($APP.$cljs$core$truth_$$($active$jscomp$3_open_QMARK_$jscomp$29$$)?"main_ui_ds_product_milestone_group__is-selected":""),"data-testid":"milestone"};var $open_STAR_$jscomp$11$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);
$active$jscomp$3_open_QMARK_$jscomp$29$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$11$$);$class$$jscomp$80_on_toggle_visibility$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$11$$,$APP.$cljs$core$not$$)});var $on_menu_click__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_menu_click$jscomp$4$$)],function($event$jscomp$573$$){var $index$jscomp$542$$=
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$573$$),"index"));return $APP.$cljs$core$fn_QMARK_$$($on_menu_click$jscomp$4$$)?$on_menu_click$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$on_menu_click$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$542$$,$event$jscomp$573$$):$on_menu_click$jscomp$4$$($index$jscomp$542$$,$event$jscomp$573$$):null});$props$jscomp$336_snapshots__$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($snapshots$$)],function(){return $APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$543$$,$date$jscomp$25$$){return new $APP.$cljs$core$MapEntry$$($date$jscomp$25$$,$index$jscomp$543$$,null)},$snapshots$$)});return(0,$APP.$rumext$v2$create_element$$)("div",$props_79968_props__$1$jscomp$85$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",
typography:"body-small",className:"main_ui_ds_product_milestone_group__name",children:$label$jscomp$55$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_milestone_group__snapshots",children:[(0,$APP.$rumext$v2$jsxs$$)("button",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.expand-snapshot"),onClick:$class$$jscomp$80_on_toggle_visibility$jscomp$6$$,className:"main_ui_ds_product_milestone_group__toggle-snapshots",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"clock",className:"main_ui_ds_product_milestone_group__icon-clock"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",className:"main_ui_ds_product_milestone_group__toggle-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.autosaved.entry",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$count$$($props$jscomp$336_snapshots__$1$$)]))}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow",className:"main_ui_ds_product_milestone_group__icon-arrow "+($APP.$cljs$core$truth_$$($active$jscomp$3_open_QMARK_$jscomp$29$$)?"main_ui_ds_product_milestone_group__icon-arrow-toggled":"")})]}),$active$jscomp$3_open_QMARK_$jscomp$29$$?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$196$$,$index$jscomp$544_p__79969$$){var $date$jscomp$26$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$544_p__79969$$,0,null);
$index$jscomp$544_p__79969$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($index$jscomp$544_p__79969$$,1,null);$out_arr__44092__auto__$jscomp$196$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_product_milestone_group__version-entry",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$utilities$date$date_STAR_$$,{date:$date$jscomp$26$$,className:"main_ui_ds_product_milestone_group__date",typography:"body-small"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{className:"main_ui_ds_product_milestone_group__entry-button",variant:"ghost",icon:"menu","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.version-menu"),"data-index":$index$jscomp$544_p__79969$$,onClick:$on_menu_click__$1$$})]},"entry-"+($index$jscomp$544_p__79969$$??"")));return $out_arr__44092__auto__$jscomp$196$$},[],$props$jscomp$336_snapshots__$1$$):null]}))};
$app$main$ui$workspace$sidebar$versions$get_versions_stored_days$$=function($subscription_type$jscomp$10_team$jscomp$68$$,$profile$jscomp$82$$){$subscription_type$jscomp$10_team$jscomp$68$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($subscription_type$jscomp$10_team$jscomp$68$$));var $nitrate_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$82$$,
$APP.$cljs$cst$3226$subscription$$),$APP.$cljs$cst$139$type$$);return $APP.$app$main$data$nitrate$is_valid_license_QMARK_$$($profile$jscomp$82$$)&&$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["enterprise",null,"nitrate",null],null),null),$nitrate_type$$)?90:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$10_team$jscomp$68$$,"unlimited")?30:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($subscription_type$jscomp$10_team$jscomp$68$$,
"enterprise")?90:7};
$app$main$ui$workspace$sidebar$versions$get_versions_warning_subtext$$=function($email_owner_team$jscomp$69$$){var $subscription_type$jscomp$11$$=$APP.$app$main$ui$dashboard$subscription$get_subscription_type$$($APP.$cljs$cst$3226$subscription$$.$cljs$core$IFn$_invoke$arity$1$($email_owner_team$jscomp$69$$)),$is_owner_QMARK_$jscomp$2$$=$APP.$cljs$cst$1603$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($email_owner_team$jscomp$69$$));$email_owner_team$jscomp$69$$=
$APP.$cljs$cst$3207$email$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some$$(function($p1__79973_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1603$is_owner$$.$cljs$core$IFn$_invoke$arity$1$($p1__79973_SHARP_$$))?$p1__79973_SHARP_$$:null},$APP.$cljs$cst$3321$members$$.$cljs$core$IFn$_invoke$arity$1$($email_owner_team$jscomp$69$$)));var $go_to_subscription$jscomp$3$$=""+($APP.$lambdaisland$uri$join$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$config$public_uri$$,
"#/settings/subscriptions"]))??"");return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1224$subscriptions$$)?$APP.$cljs$core$truth_$$($is_owner_QMARK_$jscomp$2$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("enterprise",$subscription_type$jscomp$11$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.workspace.versions.warning.enterprise.subtext-owner",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["support@penpot.app",
"support@penpot.app"])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.workspace.versions.warning.subtext-owner",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$go_to_subscription$jscomp$3$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("subscription.workspace.versions.warning.subtext-member",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$email_owner_team$jscomp$69$$,$email_owner_team$jscomp$69$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.warning.subtext",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["support@penpot.app"]))};
$app$main$ui$workspace$sidebar$versions$group_snapshots$$=function($data$jscomp$493$$){return $APP.$cljs$core$reverse$$($APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$(function($index$jscomp$545$$,$item$jscomp$140$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($item$jscomp$140$$,$APP.$cljs$cst$1801$index$$,$index$jscomp$545$$)},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79975_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79975_SHARP_$$,
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1726$version$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79974_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("user",$APP.$cljs$cst$5162$created_by$$.$cljs$core$IFn$_invoke$arity$1$($p1__79974_SHARP_$$))},$data$jscomp$493$$)),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($entries$jscomp$42_p__79978$$){var $day$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entries$jscomp$42_p__79978$$,
0,null);$entries$jscomp$42_p__79978$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($entries$jscomp$42_p__79978$$,1,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$5850$snapshot$$,$APP.$cljs$cst$1574$created_at$$,$APP.$app$common$time$inst$$($day$jscomp$3$$),$cljs$cst$5849$snapshots$$,$entries$jscomp$42_p__79978$$],null)},$APP.$cljs$core$group_by$$(function($p1__79977_SHARP_$$){return $APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__79977_SHARP_$$),
$cljs$cst$5851$iso_date$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79976_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("system",$APP.$cljs$cst$5162$created_by$$.$cljs$core$IFn$_invoke$arity$1$($p1__79976_SHARP_$$))},$data$jscomp$493$$)))))))};$app$main$ui$workspace$sidebar$versions$on_name_input_focus$$=function($event$jscomp$574$$){return $APP.$app$util$dom$select_text_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$574$$))};
$app$main$ui$workspace$sidebar$versions$on_create_version$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$create_version$$())};
$app$main$ui$workspace$sidebar$versions$on_edit_version$$=function($id$jscomp$996$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2160$editing$$,$id$jscomp$996$$],null)))};
$app$main$ui$workspace$sidebar$versions$on_cancel_version_edition$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2160$editing$$,null],null)))};
$app$main$ui$workspace$sidebar$versions$on_rename_version$$=function($id$jscomp$997$$,$label$jscomp$56$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$rename_version$$($id$jscomp$997$$,$label$jscomp$56$$))};$app$main$ui$workspace$sidebar$versions$on_delete_version$$=function($id$jscomp$998$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$delete_version$$($id$jscomp$998$$))};
$app$main$ui$workspace$sidebar$versions$on_pin_version$$=function($id$jscomp$999$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$pin_version$$($id$jscomp$999$$))};$app$main$ui$workspace$sidebar$versions$on_lock_version$$=function($id$jscomp$1000$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$lock_version$$($id$jscomp$1000$$))};
$app$main$ui$workspace$sidebar$versions$on_unlock_version$$=function($id$jscomp$1001$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$unlock_version$$($id$jscomp$1001$$))};
$app$main$ui$workspace$sidebar$versions$version_entry_STAR_$$=function($on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$){var $current_profile$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.currentProfile,$on_preview$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.onPreview,$on_delete$jscomp$13$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.onDelete,$on_cancel_edit$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.onCancelEdit,$on_lock$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.onLock,
$on_unlock$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.onUnlock,$on_edit$jscomp$8$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.onEdit,$is_editing$jscomp$3$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.isEditing,$on_restore$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.onRestore,$on_rename$jscomp$2$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.onRename,$entry$jscomp$78$$=$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$.entry,$show_menu_QMARK_$jscomp$3$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$);var $created_by$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$,$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$));$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_menu_QMARK_$jscomp$3$$,
!0)});var $on_close_menu$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_menu_QMARK_$jscomp$3$$,!1)}),$on_edit__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_edit$jscomp$8$$),$APP.$rumext$v2$adapt$$($entry$jscomp$78$$)],function($event$jscomp$576$$){var $G__79983$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_edit$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$?
$on_edit$jscomp$8$$.$cljs$core$IFn$_invoke$arity$2$($G__79983$$,$event$jscomp$576$$):$on_edit$jscomp$8$$($G__79983$$,$event$jscomp$576$$)}),$on_preview__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$78$$),$APP.$rumext$v2$adapt$$($on_preview$$)],function(){if($APP.$cljs$core$fn_QMARK_$$($on_preview$$)){var $G__79985$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_preview$$.$cljs$core$IFn$_invoke$arity$1$?
$on_preview$$.$cljs$core$IFn$_invoke$arity$1$($G__79985$$):$on_preview$$($G__79985$$)}return null}),$on_restore__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$78$$),$APP.$rumext$v2$adapt$$($on_restore$$)],function(){if($APP.$cljs$core$fn_QMARK_$$($on_restore$$)){var $G__79986$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_restore$$.$cljs$core$IFn$_invoke$arity$1$?$on_restore$$.$cljs$core$IFn$_invoke$arity$1$($G__79986$$):
$on_restore$$($G__79986$$)}return null}),$on_delete__$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$78$$),$APP.$rumext$v2$adapt$$($on_delete$jscomp$13$$)],function($event$jscomp$577$$){if($APP.$cljs$core$fn_QMARK_$$($on_delete$jscomp$13$$)){var $G__79987$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_delete$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$?$on_delete$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$($G__79987$$,
$event$jscomp$577$$):$on_delete$jscomp$13$$($G__79987$$,$event$jscomp$577$$)}return null}),$on_lock__$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$78$$),$APP.$rumext$v2$adapt$$($on_lock$$)],function(){if($APP.$cljs$core$truth_$$($on_lock$$)){var $G__79989$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_lock$$.$cljs$core$IFn$_invoke$arity$1$?$on_lock$$.$cljs$core$IFn$_invoke$arity$1$($G__79989$$):
$on_lock$$($G__79989$$)}return null}),$on_unlock__$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$78$$),$APP.$rumext$v2$adapt$$($on_unlock$$)],function(){if($APP.$cljs$core$truth_$$($on_unlock$$)){var $G__79990$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_unlock$$.$cljs$core$IFn$_invoke$arity$1$?$on_unlock$$.$cljs$core$IFn$_invoke$arity$1$($G__79990$$):$on_unlock$$($G__79990$$)}return null}),
$on_name_input_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$78$$),$APP.$rumext$v2$adapt$$($on_rename$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_cancel_edit$$)],function($event$jscomp$578$$){var $G__79994_label$jscomp$57$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$578$$));if(!$APP.$cuerdas$core$empty_QMARK_$$($G__79994_label$jscomp$57$$)&&$APP.$cljs$core$fn_QMARK_$$($on_rename$jscomp$2$$)){var $G__79991$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_rename$jscomp$2$$.$cljs$core$IFn$_invoke$arity$3$?$on_rename$jscomp$2$$.$cljs$core$IFn$_invoke$arity$3$($G__79991$$,$G__79994_label$jscomp$57$$,$event$jscomp$578$$):$on_rename$jscomp$2$$($G__79991$$,$G__79994_label$jscomp$57$$,$event$jscomp$578$$)}$G__79994_label$jscomp$57$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_cancel_edit$$.$cljs$core$IFn$_invoke$arity$2$?$on_cancel_edit$$.$cljs$core$IFn$_invoke$arity$2$($G__79994_label$jscomp$57$$,
$event$jscomp$578$$):$on_cancel_edit$$($G__79994_label$jscomp$57$$,$event$jscomp$578$$)}),$on_name_input_key_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$78$$),$APP.$rumext$v2$adapt$$($on_cancel_edit$$),$APP.$rumext$v2$adapt$$($on_name_input_blur$$)],function($event$jscomp$579$$){if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$579$$)))return $on_name_input_blur$$.$cljs$core$IFn$_invoke$arity$1$?$on_name_input_blur$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$579$$):
$on_name_input_blur$$($event$jscomp$579$$);if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$579$$))&&$APP.$cljs$core$fn_QMARK_$$($on_cancel_edit$$)){var $G__79996$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$);return $on_cancel_edit$$.$cljs$core$IFn$_invoke$arity$2$?$on_cancel_edit$$.$cljs$core$IFn$_invoke$arity$2$($G__79996$$,$event$jscomp$579$$):$on_cancel_edit$$($G__79996$$,$event$jscomp$579$$)}return null});return(0,$APP.$rumext$v2$jsxs$$)("li",
{className:"main_ui_workspace_sidebar_versions__version-entry-wrap",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$milestone$milestone_STAR_$$,{onBlurInput:$on_name_input_blur$$,createdAt:$APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$),label:$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$),profile:$created_by$$,onKeyDownInput:$on_name_input_key_down$$,editing:$is_editing$jscomp$3$$,onFocusInput:$app$main$ui$workspace$sidebar$versions$on_name_input_focus$$,
locked:$cljs$cst$5852$locked_by$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$)!=null,onOpenMenu:$on_open_menu$jscomp$2_profiles$jscomp$4_props_79982$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_menu_QMARK_$jscomp$3$$),"on-close":$on_close_menu$jscomp$5$$,children:function(){var $current_user_id_is_locked_by_me_QMARK_$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_profile$$),$is_locked_QMARK__locked_by_id$$=
$cljs$cst$5852$locked_by$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$78$$),$im_the_owner_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_user_id_is_locked_by_me_QMARK_$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($created_by$$));$current_user_id_is_locked_by_me_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_user_id_is_locked_by_me_QMARK_$$,$is_locked_QMARK__locked_by_id$$);$is_locked_QMARK__locked_by_id$$=$is_locked_QMARK__locked_by_id$$!=
null;var $can_delete_QMARK_$jscomp$2$$=!$is_locked_QMARK__locked_by_id$$||$is_locked_QMARK__locked_by_id$$&&$current_user_id_is_locked_by_me_QMARK_$$;return(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_sidebar_versions__version-options-dropdown",children:[$im_the_owner_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_edit__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename")}):
null,(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_preview__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.preview")}),(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_restore__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.restore")}),$current_user_id_is_locked_by_me_QMARK_$$?
(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_unlock__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.unlock")}):$im_the_owner_QMARK_$$&&!$is_locked_QMARK__locked_by_id$$?(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_lock__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.lock")}):null,$can_delete_QMARK_$jscomp$2$$?
(0,$APP.$rumext$v2$jsx$$)("li",{role:"button",onClick:$on_delete__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")}):null]})}()})]})};
$app$main$ui$workspace$sidebar$versions$snapshot_entry_STAR_$$=function($on_pin_snapshot__$1_props_80005$$){var $on_restore_snapshot$$=$on_pin_snapshot__$1_props_80005$$.onRestoreSnapshot,$on_pin_snapshot$$=$on_pin_snapshot__$1_props_80005$$.onPinSnapshot,$on_preview_snapshot$$=$on_pin_snapshot__$1_props_80005$$.onPreviewSnapshot,$entry$jscomp$79$$=$on_pin_snapshot__$1_props_80005$$.entry,$open_menu_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$entry_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);
$on_pin_snapshot__$1_props_80005$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_pin_snapshot$$)],function($event$jscomp$580$$){if($APP.$cljs$core$fn_QMARK_$$($on_pin_snapshot$$)){var $G__80010$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$580$$),"id"));return $on_pin_snapshot$$.$cljs$core$IFn$_invoke$arity$2$?$on_pin_snapshot$$.$cljs$core$IFn$_invoke$arity$2$($G__80010$$,$event$jscomp$580$$):
$on_pin_snapshot$$($G__80010$$,$event$jscomp$580$$)}return null});var $on_restore_snapshot__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_restore_snapshot$$)],function($event$jscomp$581$$){if($APP.$cljs$core$fn_QMARK_$$($on_restore_snapshot$$)){var $G__80012$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$581$$),"id"));return $on_restore_snapshot$$.$cljs$core$IFn$_invoke$arity$2$?$on_restore_snapshot$$.$cljs$core$IFn$_invoke$arity$2$($G__80012$$,
$event$jscomp$581$$):$on_restore_snapshot$$($G__80012$$,$event$jscomp$581$$)}return null}),$on_preview_snapshot__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_preview_snapshot$$)],function($event$jscomp$582$$){if($APP.$cljs$core$fn_QMARK_$$($on_preview_snapshot$$)){var $G__80014$$=$APP.$app$common$uuid$parse$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$582$$),"id"));return $on_preview_snapshot$$.$cljs$core$IFn$_invoke$arity$2$?
$on_preview_snapshot$$.$cljs$core$IFn$_invoke$arity$2$($G__80014$$,$event$jscomp$582$$):$on_preview_snapshot$$($G__80014$$,$event$jscomp$582$$)}return null}),$on_open_snapshot_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($entry$jscomp$79$$)],function($index$jscomp$546_snapshot$jscomp$5$$,$event$jscomp$583_offset$jscomp$213$$){$index$jscomp$546_snapshot$jscomp$5$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5849$snapshots$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$79$$),
$index$jscomp$546_snapshot$jscomp$5$$);var $current_bb$$=$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$rumext$v2$ref_val$$($entry_ref$$)));$event$jscomp$583_offset$jscomp$213$$=$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$get_target$$($event$jscomp$583_offset$jscomp$213$$)))-$current_bb$$+32;return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($open_menu_STAR_$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5850$snapshot$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$546_snapshot$jscomp$5$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$195$offset$$,$event$jscomp$583_offset$jscomp$213$$]))});return(0,$APP.$rumext$v2$jsxs$$)("li",{ref:$entry_ref$$,className:"main_ui_workspace_sidebar_versions__version-entry-wrap",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$product$milestone_group$milestone_group_STAR_$$,
{label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.autosaved.version",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$time$format_inst$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$79$$),$APP.$cljs$cst$5141$localized_date$$)])),snapshots:$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1574$created_at$$,$cljs$cst$5849$snapshots$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$79$$)),
onMenuClick:$on_open_snapshot_menu$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($open_menu_STAR_$$)!=null,"on-close":function(){return $APP.$cljs$core$reset_BANG_$$($open_menu_STAR_$$,null)},children:(0,$APP.$rumext$v2$jsxs$$)("ul",{style:{"--offset":""+($APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($open_menu_STAR_$$))??"")+"px"},className:"main_ui_workspace_sidebar_versions__version-options-dropdown",
children:[(0,$APP.$rumext$v2$jsx$$)("li",{role:"button","data-id":""+($cljs$cst$5850$snapshot$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($open_menu_STAR_$$))??""),onClick:$on_preview_snapshot__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.preview")}),(0,$APP.$rumext$v2$jsx$$)("li",{role:"button","data-id":""+($cljs$cst$5850$snapshot$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($open_menu_STAR_$$))??
""),onClick:$on_restore_snapshot__$1$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.restore")}),(0,$APP.$rumext$v2$jsx$$)("li",{role:"button","data-id":""+($cljs$cst$5850$snapshot$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($open_menu_STAR_$$))??""),onClick:$on_pin_snapshot__$1_props_80005$$,className:"main_ui_workspace_sidebar_versions__menu-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.pin")})]})})]})};
$app$main$ui$workspace$sidebar$versions$versions_toolbox_STAR_$$=function(){var $profiles$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$),$profile$jscomp$83$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$team$jscomp$70$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$team$$),$map__80024_status$jscomp$26$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$versions$versions$$),$map__80024__$1$$=$APP.$cljs$core$__destructure_map$$($map__80024_status$jscomp$26$$);$map__80024_status$jscomp$26$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80024__$1$$,$APP.$cljs$cst$109$status$$);var $data$jscomp$494$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80024__$1$$,$APP.$cljs$cst$142$data$$),$editing$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80024__$1$$,$APP.$cljs$cst$2160$editing$$),$users$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($data$jscomp$494$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($created_by$jscomp$1_p__80033$$){var $map__80034__$1_profile_id$jscomp$30$$=$APP.$cljs$core$__destructure_map$$($created_by$jscomp$1_p__80033$$);$created_by$jscomp$1_p__80033$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80034__$1_profile_id$jscomp$30$$,$APP.$cljs$cst$5162$created_by$$);$map__80034__$1_profile_id$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80034__$1_profile_id$jscomp$30$$,
$APP.$cljs$cst$2321$profile_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("user",$created_by$jscomp$1_p__80033$$)?$map__80034__$1_profile_id$jscomp$30$$:null}),$data$jscomp$494$$)}),$entries$jscomp$43$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($map__80024__$1$$)],function(){return $app$main$ui$workspace$sidebar$versions$group_snapshots$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80020_SHARP_$$){return $APP.$cljs$core$not$$($APP.$cljs$cst$2702$filter$$.$cljs$core$IFn$_invoke$arity$1$($map__80024__$1$$))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("user",$APP.$cljs$cst$5162$created_by$$.$cljs$core$IFn$_invoke$arity$1$($p1__80020_SHARP_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2702$filter$$.$cljs$core$IFn$_invoke$arity$1$($map__80024__$1$$),$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80020_SHARP_$$))},$APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($map__80024__$1$$)))}),$on_preview_version$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1002$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$enter_preview$$($id$jscomp$1002$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"preview-version",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$139$type$$,"pinned-version"],null))]))}),$on_preview_snapshot$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1003$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$enter_preview$$($id$jscomp$1003$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"preview-version",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$139$type$$,"autosaved-version"],null))]))}),$on_restore_version$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1004$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$enter_restore$$($id$jscomp$1004$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-version",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$139$type$$,"pinned-version"],null))]))}),$on_restore_snapshot$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1005$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$versions$enter_restore$$($id$jscomp$1005$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"restore-version",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar",$APP.$cljs$cst$139$type$$,"autosaved-version"],null))]))}),$on_change_filter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($filter_value$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2132$all$$,
$filter_value$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2702$filter$$,null],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5853$own$$,$filter_value$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2702$filter$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$83$$)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$update_versions_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2702$filter$$,$filter_value$$],null)))}),$options$jscomp$633$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($users$jscomp$3$$),$APP.$rumext$v2$adapt$$($profile$jscomp$83$$)],function(){var $current_profile_id$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$83$$,$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2132$all$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.filter.all")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$cljs$cst$5853$own$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.filter.mine")],null)],null),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1006$$){if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1006$$,$current_profile_id$$)){var $temp__5825__auto__$jscomp$398$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profiles$jscomp$5$$,
$id$jscomp$1006$$),$APP.$cljs$cst$1365$fullname$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$398$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$id$jscomp$1006$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.filter.user",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$temp__5825__auto__$jscomp$398$$]))],null):null}return null}),$users$jscomp$3$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$versions$init_versions_state$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_versions__version-toolbox",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$cst$2132$all$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.filter.label"),options:$options$jscomp$633$$,
"on-change":$on_change_filter$$}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__80024_status$jscomp$26$$,$APP.$cljs$cst$5133$loading$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_versions__versions-empty",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"clock",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.loading")})}):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($map__80024_status$jscomp$26$$,
$APP.$cljs$cst$5138$loaded$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_versions__version-save-version",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.save"),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.button.save"),
onClick:$app$main$ui$workspace$sidebar$versions$on_create_version$$,icon:"pin"})]}),$APP.$cljs$core$empty_QMARK_$$($data$jscomp$494$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_versions__versions-empty",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$empty_state$empty_state_STAR_$$,{icon:"history",text:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.empty")})}):(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_versions__versions-entries",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$197$$,$entry$jscomp$80$$){$out_arr__44092__auto__$jscomp$197$$.push(function(){var $G__80039$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$80$$);switch($G__80039$$ instanceof $APP.$cljs$core$Keyword$$?$G__80039$$.$fqn$:null){case "version":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$versions$version_entry_STAR_$$,{entry:$entry$jscomp$80$$,onPreview:$on_preview_version$$,
onDelete:$app$main$ui$workspace$sidebar$versions$on_delete_version$$,onLock:$app$main$ui$workspace$sidebar$versions$on_lock_version$$,currentProfile:$profile$jscomp$83$$,onRestore:$on_restore_version$$,onUnlock:$app$main$ui$workspace$sidebar$versions$on_unlock_version$$,onEdit:$app$main$ui$workspace$sidebar$versions$on_edit_version$$,onCancelEdit:$app$main$ui$workspace$sidebar$versions$on_cancel_version_edition$$,onRename:$app$main$ui$workspace$sidebar$versions$on_rename_version$$,isEditing:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$80$$),
$editing$jscomp$3$$)},$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$80$$));case "snapshot":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$versions$snapshot_entry_STAR_$$,{entry:$entry$jscomp$80$$,onPreviewSnapshot:$on_preview_snapshot$jscomp$1$$,onRestoreSnapshot:$on_restore_snapshot$jscomp$1$$,onPinSnapshot:$app$main$ui$workspace$sidebar$versions$on_pin_version$$},$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($entry$jscomp$80$$));default:return null}}());
return $out_arr__44092__auto__$jscomp$197$$},[],$entries$jscomp$43$$)}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$cta$cta_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.versions.warning.text",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$workspace$sidebar$versions$get_versions_stored_days$$($team$jscomp$70$$,$profile$jscomp$83$$)])),children:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,{tagName:"div",className:"main_ui_workspace_sidebar_versions__cta",
content:$app$main$ui$workspace$sidebar$versions$get_versions_warning_subtext$$($team$jscomp$70$$)})})]}):null]})};
$app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens$$=function($shape$jscomp$1041$$,$token_name$jscomp$32$$,$container$jscomp$90$$){var $temp__5825__auto__$jscomp$399$$=$APP.$cljs$cst$1881$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1041$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$399$$)?function $app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens_$_iter__79998$$($s__79999$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(var $s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$=
$s__79999$$;;)if($s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$=$APP.$cljs$core$seq$$($s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$)){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$)){var $JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$=$APP.$cljs$core$_chunked_first$$($s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$),$size__5502__auto__$jscomp$47$$=
$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$),$attribute$jscomp$2_b__80001$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$47$$);a:{for(var $i__80000$jscomp$inline_9115$$=0;;)if($i__80000$jscomp$inline_9115$$<$size__5502__auto__$jscomp$47$$){var $b$jscomp$inline_13852_vec__80002$jscomp$inline_9116$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$,
$i__80000$jscomp$inline_9115$$),$attribute$jscomp$inline_9117_x$jscomp$inline_13853$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13852_vec__80002$jscomp$inline_9116$$,0,null),$applied_token_name$jscomp$inline_9118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_13852_vec__80002$jscomp$inline_9116$$,1,null);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($applied_token_name$jscomp$inline_9118$$,$token_name$jscomp$32$$)&&($b$jscomp$inline_13852_vec__80002$jscomp$inline_9116$$=
$attribute$jscomp$2_b__80001$$,$attribute$jscomp$inline_9117_x$jscomp$inline_13853$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,$cljs$cst$5685$applied_token$$,$APP.$cljs$cst$2554$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1041$$),$cljs$cst$5854$attribute$$,$attribute$jscomp$inline_9117_x$jscomp$inline_13853$$,$APP.$cljs$cst$4253$token_name$$,$applied_token_name$jscomp$inline_9118$$,$APP.$cljs$cst$2599$container$$,$container$jscomp$90$$],
null),$b$jscomp$inline_13852_vec__80002$jscomp$inline_9116$$.add($attribute$jscomp$inline_9117_x$jscomp$inline_13853$$));$i__80000$jscomp$inline_9115$$+=1}else{$JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$=!0;break a}$JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$=void 0}return $JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($attribute$jscomp$2_b__80001$$),
$app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens_$_iter__79998$$($APP.$cljs$core$_chunked_rest$$($s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($attribute$jscomp$2_b__80001$$),null)}$JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$=$APP.$cljs$core$first$$($s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$);$attribute$jscomp$2_b__80001$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$,
0,null);$JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$,1,null);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$,$token_name$jscomp$32$$))return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$139$type$$,$cljs$cst$5685$applied_token$$,$APP.$cljs$cst$2554$shape_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1041$$),$cljs$cst$5854$attribute$$,$attribute$jscomp$2_b__80001$$,$APP.$cljs$cst$4253$token_name$$,$JSCompiler_inline_result$jscomp$1853_applied_token_name$jscomp$3_c__5501__auto__$jscomp$47_vec__80006$$,$APP.$cljs$cst$2599$container$$,$container$jscomp$90$$],null),$app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens_$_iter__79998$$($APP.$cljs$core$rest$$($s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$)));
$s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$=$APP.$cljs$core$rest$$($s__79999__$1_s__79999__$2_temp__5825__auto____$1$jscomp$22$$)}else return null},null,null)}($temp__5825__auto__$jscomp$399$$):null};
$app$main$data$workspace$tokens$remapping$scan_token_value_references$$=function($token$jscomp$149$$,$token_name$jscomp$33$$){var $find_all_token_value_references$$=function $app$main$data$workspace$tokens$remapping$scan_token_value_references_$_find_all_token_value_references$$($token_value$jscomp$7$$){return typeof $token_value$jscomp$7$$==="string"?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80009_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__80009_SHARP_$$,
$token_name$jscomp$33$$)},$APP.$app$common$types$token$find_token_value_references$$($token_value$jscomp$7$$)):$APP.$cljs$core$map_QMARK_$$($token_value$jscomp$7$$)?$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$tokens$remapping$scan_token_value_references_$_find_all_token_value_references$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($token_value$jscomp$7$$)])):$APP.$cljs$core$sequential_QMARK_$$($token_value$jscomp$7$$)?
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$data$workspace$tokens$remapping$scan_token_value_references_$_find_all_token_value_references$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_value$jscomp$7$$])):$APP.$cljs$core$PersistentVector$EMPTY$$},$temp__5825__auto__$jscomp$400$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$149$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$400$$)?function $app$main$data$workspace$tokens$remapping$scan_token_value_references_$_iter__80016$$($s__80017$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__80017__$2_temp__5825__auto____$1$jscomp$23$$=$APP.$cljs$core$seq$$($s__80017$$);if($s__80017__$2_temp__5825__auto____$1$jscomp$23$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__80017__$2_temp__5825__auto____$1$jscomp$23$$)){var $JSCompiler_inline_result$jscomp$1854_c__5501__auto__$jscomp$48$$=$APP.$cljs$core$_chunked_first$$($s__80017__$2_temp__5825__auto____$1$jscomp$23$$),$size__5502__auto__$jscomp$48$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1854_c__5501__auto__$jscomp$48$$),
$b__80019_referenced_token_name$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$48$$);a:{for(var $i__80018$jscomp$inline_9120$$=0;;)if($i__80018$jscomp$inline_9120$$<$size__5502__auto__$jscomp$48$$){var $referenced_token_name$jscomp$inline_9121_x$jscomp$inline_13856$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1854_c__5501__auto__$jscomp$48$$,$i__80018$jscomp$inline_9120$$),$b$jscomp$inline_13855$$=$b__80019_referenced_token_name$$;$referenced_token_name$jscomp$inline_9121_x$jscomp$inline_13856$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$5855$token_alias$$,$cljs$cst$5856$source_token_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$149$$),$cljs$cst$5857$referenced_token_name$$,$referenced_token_name$jscomp$inline_9121_x$jscomp$inline_13856$$],null);$b$jscomp$inline_13855$$.add($referenced_token_name$jscomp$inline_9121_x$jscomp$inline_13856$$);$i__80018$jscomp$inline_9120$$+=1}else{$JSCompiler_inline_result$jscomp$1854_c__5501__auto__$jscomp$48$$=
!0;break a}$JSCompiler_inline_result$jscomp$1854_c__5501__auto__$jscomp$48$$=void 0}return $JSCompiler_inline_result$jscomp$1854_c__5501__auto__$jscomp$48$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80019_referenced_token_name$$),$app$main$data$workspace$tokens$remapping$scan_token_value_references_$_iter__80016$$($APP.$cljs$core$_chunked_rest$$($s__80017__$2_temp__5825__auto____$1$jscomp$23$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80019_referenced_token_name$$),
null)}$b__80019_referenced_token_name$$=$APP.$cljs$core$first$$($s__80017__$2_temp__5825__auto____$1$jscomp$23$$);return $APP.$cljs$core$cons$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$cljs$cst$5855$token_alias$$,$cljs$cst$5856$source_token_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$149$$),$cljs$cst$5857$referenced_token_name$$,$b__80019_referenced_token_name$$],null),$app$main$data$workspace$tokens$remapping$scan_token_value_references_$_iter__80016$$($APP.$cljs$core$rest$$($s__80017__$2_temp__5825__auto____$1$jscomp$23$$)))}return null}},
null,null)}($find_all_token_value_references$$($temp__5825__auto__$jscomp$400$$)):null};
$app$main$data$workspace$tokens$remapping$scan_workspace_token_references$$=function($file_data$jscomp$117$$,$old_token_name$$){var $tokens_lib$jscomp$40$$=$APP.$cljs$cst$2147$tokens_lib$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$117$$),$containers$jscomp$1$$=$APP.$app$common$types$file$object_containers_seq$$($file_data$jscomp$117$$),$matching_applied$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($container$jscomp$91$$){var $shapes$jscomp$232$$=$APP.$cljs$core$vals$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($container$jscomp$91$$));
return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__80021_SHARP_$$){return $app$main$data$workspace$tokens$remapping$scan_shape_applied_tokens$$($p1__80021_SHARP_$$,$old_token_name$$,$container$jscomp$91$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$shapes$jscomp$232$$]))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$containers$jscomp$1$$])),$matching_aliases$$=$APP.$cljs$core$truth_$$($tokens_lib$jscomp$40$$)?function(){var $all_tokens$$=
$app$common$types$tokens_lib$get_all_tokens$$($tokens_lib$jscomp$40$$);return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__80022_SHARP_$$){return $app$main$data$workspace$tokens$remapping$scan_token_value_references$$($p1__80022_SHARP_$$,$old_token_name$$)},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$all_tokens$$]))}():$APP.$cljs$core$PersistentVector$EMPTY$$;$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.remapping",
$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"token-scan-details"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4253$token_name$$,$old_token_name$$],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5858$containers_count$$,$APP.$cljs$core$count$$($containers$jscomp$1$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5859$total_applied_refs$$,$APP.$cljs$core$count$$($matching_applied$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5860$matching_applied$$,
$APP.$cljs$core$count$$($matching_applied$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5861$total_alias_refs$$,$APP.$cljs$core$count$$($matching_aliases$$)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5862$matching_aliases$$,$APP.$cljs$core$count$$($matching_aliases$$)],null)],null)}),null,"app.main.data.workspace.tokens.remapping",$APP.$cljs$cst$1161$info$$,!1);
return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1881$applied_tokens$$,$matching_applied$$,$cljs$cst$5863$token_aliases$$,$matching_aliases$$,$cljs$cst$5864$total_references$$,$APP.$cljs$core$count$$($matching_applied$$)+$APP.$cljs$core$count$$($matching_aliases$$)],null)};
$app$main$data$workspace$tokens$remapping$build_remap_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($file_data$jscomp$118$$,$old_token_name$jscomp$1$$,$new_token_name$$,$map__80036__$1_p__80035_undo_group$jscomp$44$$){$map__80036__$1_p__80035_undo_group$jscomp$44$$=$APP.$cljs$core$__destructure_map$$($map__80036__$1_p__80035_undo_group$jscomp$44$$);$map__80036__$1_p__80035_undo_group$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80036__$1_p__80035_undo_group$jscomp$44$$,
$APP.$cljs$cst$3162$undo_group$$);var $G__80038_scan_results$$=$app$main$data$workspace$tokens$remapping$scan_workspace_token_references$$($file_data$jscomp$118$$,$old_token_name$jscomp$1$$),$tokens_lib$jscomp$41$$=$APP.$cljs$cst$2147$tokens_lib$$.$cljs$core$IFn$_invoke$arity$1$($file_data$jscomp$118$$),$refs_by_container_sets$jscomp$22_shape_changes$jscomp$3$$=$APP.$app$common$types$tokens_lib$get_sets$$($tokens_lib$jscomp$41$$),$tokens_with_sets$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($set$jscomp$21$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$150$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1136$token$$,$token$jscomp$150$$,$APP.$cljs$cst$203$set$$,$set$jscomp$21$$],null)},$APP.$cljs$core$vals$$($APP.$app$common$types$tokens_lib$get_tokens$$($tokens_lib$jscomp$41$$,$APP.$app$common$types$tokens_lib$get_id$$($set$jscomp$21$$))))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$refs_by_container_sets$jscomp$22_shape_changes$jscomp$3$$]));$refs_by_container_sets$jscomp$22_shape_changes$jscomp$3$$=$APP.$cljs$core$group_by$$($APP.$cljs$cst$2599$container$$,
$APP.$cljs$cst$1881$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($G__80038_scan_results$$));$refs_by_container_sets$jscomp$22_shape_changes$jscomp$3$$=$APP.$cljs$core$reduce_kv$$(function($changes$jscomp$334$$,$container$jscomp$92_container_changes$$,$refs$jscomp$3$$){var $shape_ids$jscomp$112$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2554$shape_id$$,$refs$jscomp$3$$),$token$jscomp$151$$=function(){var $or__5025__auto__$jscomp$1292$$=$APP.$cljs$core$some$$(function($p1__80025_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($p1__80025_SHARP_$$)),
$new_token_name$$)?$p1__80025_SHARP_$$:null},$tokens_with_sets$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1292$$)?$or__5025__auto__$jscomp$1292$$:$APP.$cljs$core$some$$(function($p1__80026_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($p1__80026_SHARP_$$)),$old_token_name$jscomp$1$$)?$p1__80026_SHARP_$$:null},$tokens_with_sets$$)}(),$attributes$jscomp$79$$=
$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5854$attribute$$,$refs$jscomp$3$$));return $APP.$cljs$core$truth_$$($token$jscomp$151$$)?($container$jscomp$92_container_changes$$=$APP.$app$common$files$changes_builder$update_shapes$cljs$0core$0IFn$0_invoke$0arity$04$$($APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$with_container$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$container$jscomp$92_container_changes$$),$file_data$jscomp$118$$),$shape_ids$jscomp$112$$,function($shape$jscomp$1042$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1042$$,$APP.$cljs$cst$1881$applied_tokens$$,function($p1__80027_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80027_SHARP_$$,$APP.$app$common$files$tokens$attributes_map$$($attributes$jscomp$79$$,$APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$151$$))]))})},
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2567$ignore_touched$$,!0],null)),$APP.$app$common$files$changes_builder$concat_changes$$($changes$jscomp$334$$,$container$jscomp$92_container_changes$$)):$changes$jscomp$334$$},$APP.$app$common$files$changes_builder$with_library_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$00$$(),$file_data$jscomp$118$$),$refs_by_container_sets$jscomp$22_shape_changes$jscomp$3$$);$G__80038_scan_results$$=
$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($changes$jscomp$335$$,$ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$){var $source_token_id$$=$cljs$cst$5856$source_token_id$$.$cljs$core$IFn$_invoke$arity$1$($ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$);$ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$=$APP.$cljs$core$some$$(function($p1__80028_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1136$token$$.$cljs$core$IFn$_invoke$arity$1$($p1__80028_SHARP_$$)),
$source_token_id$$)?$p1__80028_SHARP_$$:null},$tokens_with_sets$$);if($APP.$cljs$core$truth_$$($ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$)){var $map__80037__$1_set$jscomp$22$$=$APP.$cljs$core$__destructure_map$$($ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$);$ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80037__$1_set$jscomp$22$$,$APP.$cljs$cst$1136$token$$);$map__80037__$1_set$jscomp$22$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80037__$1_set$jscomp$22$$,$APP.$cljs$cst$203$set$$);var $new_value$jscomp$28_old_value$jscomp$3$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$);$new_value$jscomp$28_old_value$jscomp$3$$=$app$common$types$token$update_token_value_references$$($new_value$jscomp$28_old_value$jscomp$3$$,$old_token_name$jscomp$1$$,$new_token_name$$);return $APP.$app$common$files$changes_builder$set_token$$($changes$jscomp$335$$,
$APP.$app$common$types$tokens_lib$get_id$$($map__80037__$1_set$jscomp$22$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($ref$jscomp$55_temp__5825__auto__$jscomp$401_token$jscomp$152$$,$APP.$cljs$cst$260$value$$,$new_value$jscomp$28_old_value$jscomp$3$$))}return null},$refs_by_container_sets$jscomp$22_shape_changes$jscomp$3$$,$cljs$cst$5863$token_aliases$$.$cljs$core$IFn$_invoke$arity$1$($G__80038_scan_results$$));
return $map__80036__$1_p__80035_undo_group$jscomp$44$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80038_scan_results$$,$APP.$cljs$cst$3162$undo_group$$,$map__80036__$1_p__80035_undo_group$jscomp$44$$):$G__80038_scan_results$$};
$app$main$data$workspace$tokens$remapping$remap_tokens$$=function($var_args$jscomp$1464$$){for(var $args__5755__auto__$jscomp$257$$=[],$len__5749__auto___80071$$=arguments.length,$i__5750__auto___80072$$=0;;)if($i__5750__auto___80072$$<$len__5749__auto___80071$$)$args__5755__auto__$jscomp$257$$.push(arguments[$i__5750__auto___80072$$]),$i__5750__auto___80072$$+=1;else break;return $app$main$data$workspace$tokens$remapping$remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(arguments[0],arguments[1],
2<$args__5755__auto__$jscomp$257$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$257$$.slice(2),0,null):null)};
$app$main$data$workspace$tokens$remapping$remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($old_token_name$jscomp$2$$,$new_token_name$jscomp$1$$,$p__80043$$){var $map__80044__$1$$=$APP.$cljs$core$__destructure_map$$($p__80043$$),$undo_group$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80044__$1$$,$APP.$cljs$cst$3162$undo_group$$);typeof $app$main$data$workspace$tokens$remapping$remap_tokens_80045$$==="undefined"&&($app$main$data$workspace$tokens$remapping$remap_tokens_80045$$=
function($old_token_name$jscomp$3$$,$new_token_name$jscomp$2$$,$p__80043$jscomp$1$$,$map__80044$jscomp$1$$,$undo_group$jscomp$46$$,$meta80046$$){this.$old_token_name$=$old_token_name$jscomp$3$$;this.$new_token_name$=$new_token_name$jscomp$2$$;this.$p__80043$=$p__80043$jscomp$1$$;this.$map__80044$=$map__80044$jscomp$1$$;this.$undo_group$=$undo_group$jscomp$46$$;this.$meta80046$=$meta80046$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$remapping$remap_tokens_80045$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$remapping$remap_tokens_80045$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5865$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_remapping_SLASH_remap_tokens$$},$app$main$data$workspace$tokens$remapping$remap_tokens_80045$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_80047$$,$meta80046__$1$$){return new $app$main$data$workspace$tokens$remapping$remap_tokens_80045$$(this.$old_token_name$,
this.$new_token_name$,this.$p__80043$,this.$map__80044$,this.$undo_group$,$meta80046__$1$$)},$app$main$data$workspace$tokens$remapping$remap_tokens_80045$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta80046$},$app$main$data$workspace$tokens$remapping$remap_tokens_80045$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$remapping$remap_tokens_80045$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3085_file_data$jscomp$119_token_changes$jscomp$1$$,
$state$jscomp$1216$$){var $self__$jscomp$7520$$=this;$_$jscomp$3085_file_data$jscomp$119_token_changes$jscomp$1$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1216$$);$_$jscomp$3085_file_data$jscomp$119_token_changes$jscomp$1$$=$app$main$data$workspace$tokens$remapping$build_remap_changes$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($_$jscomp$3085_file_data$jscomp$119_token_changes$jscomp$1$$,$self__$jscomp$7520$$.$old_token_name$,$self__$jscomp$7520$$.$new_token_name$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3162$undo_group$$,$self__$jscomp$7520$$.$undo_group$]));$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.remapping",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$275$hint$$,"token-remapping"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5866$old_name$$,$self__$jscomp$7520$$.$old_token_name$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5867$new_name$$,$self__$jscomp$7520$$.$new_token_name$],null)],null)}),null,"app.main.data.workspace.tokens.remapping",$APP.$cljs$cst$1161$info$$,!1);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($_$jscomp$3085_file_data$jscomp$119_token_changes$jscomp$1$$))});
return new $app$main$data$workspace$tokens$remapping$remap_tokens_80045$$($old_token_name$jscomp$2$$,$new_token_name$jscomp$1$$,$p__80043$$,$map__80044__$1$$,$undo_group$jscomp$45$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$remapping$bulk_remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($tokens_in_path$$,$new_tokens$jscomp$1$$,$p__80051$$){var $map__80052__$1$$=$APP.$cljs$core$__destructure_map$$($p__80051$$),$undo_group$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80052__$1$$,$APP.$cljs$cst$3162$undo_group$$);typeof $app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$==="undefined"&&($app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$=
function($tokens_in_path$jscomp$1$$,$new_tokens$jscomp$2$$,$p__80051$jscomp$1$$,$map__80052$jscomp$1$$,$undo_group$jscomp$48$$,$meta80054$$){this.$tokens_in_path$=$tokens_in_path$jscomp$1$$;this.$new_tokens$=$new_tokens$jscomp$2$$;this.$p__80051$=$p__80051$jscomp$1$$;this.$map__80052$=$map__80052$jscomp$1$$;this.$undo_group$=$undo_group$jscomp$48$$;this.$meta80054$=$meta80054$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5868$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_remapping_SLASH_bulk_remap_tokens$$},$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_80055$$,$meta80054__$1$$){return new $app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$(this.$tokens_in_path$,
this.$new_tokens$,this.$p__80051$,this.$map__80052$,this.$undo_group$,$meta80054__$1$$)},$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta80054$},$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function(){var $self__$jscomp$7524$$=
this;return $APP.$beicon$v2$core$concat$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$(function($old_token$$,$new_token$jscomp$1$$){return $app$main$data$workspace$tokens$remapping$remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($old_token$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($new_token$jscomp$1$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3162$undo_group$$,$self__$jscomp$7524$$.$undo_group$]))},
$self__$jscomp$7524$$.$tokens_in_path$,$self__$jscomp$7524$$.$new_tokens$))});return new $app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$($tokens_in_path$$,$new_tokens$jscomp$1$$,$p__80051$$,$map__80052__$1$$,$undo_group$jscomp$47$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$tokens$remapping$count_token_references$$=function($file_data$jscomp$120$$,$token_name$jscomp$34$$){var $scan_results$jscomp$1$$=$app$main$data$workspace$tokens$remapping$scan_workspace_token_references$$($file_data$jscomp$120$$,$token_name$jscomp$34$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.remapping",$APP.$cljs$cst$1161$info$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"token-reference-scan"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$34$$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5872$applied_refs$$,$APP.$cljs$core$count$$($APP.$cljs$cst$1881$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($scan_results$jscomp$1$$))],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5873$alias_refs$$,$APP.$cljs$core$count$$($cljs$cst$5863$token_aliases$$.$cljs$core$IFn$_invoke$arity$1$($scan_results$jscomp$1$$))],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2338$total$$,$cljs$cst$5864$total_references$$.$cljs$core$IFn$_invoke$arity$1$($scan_results$jscomp$1$$)],null)],null)}),null,"app.main.data.workspace.tokens.remapping",
$APP.$cljs$cst$1161$info$$,!1);return $cljs$cst$5864$total_references$$.$cljs$core$IFn$_invoke$arity$1$($scan_results$jscomp$1$$)};$app$main$ui$workspace$tokens$management$context_menu$key_in_map_QMARK_$$=function($ks$jscomp$64$$,$m$jscomp$240$$){return $APP.$cljs$core$some$$(function($p1__80060_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($m$jscomp$240$$,$p1__80060_SHARP_$$)},$ks$jscomp$64$$)};
$app$main$ui$workspace$tokens$management$context_menu$clean_separators$$=function($items$jscomp$65_items_SINGLEQUOTE_$$){$items$jscomp$65_items_SINGLEQUOTE_$$=$APP.$cljs$core$drop_while$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__80061_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__80061_SHARP_$$,$APP.$cljs$cst$1477$separator$$)},$APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$core$dedupe$cljs$0core$0IFn$0_invoke$0arity$00$$(),$items$jscomp$65_items_SINGLEQUOTE_$$));
return $APP.$cljs$core$every_QMARK_$$(function($p1__80062_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__80062_SHARP_$$,$APP.$cljs$cst$1477$separator$$)},$items$jscomp$65_items_SINGLEQUOTE_$$)?null:$items$jscomp$65_items_SINGLEQUOTE_$$};
$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$=function($shape_ids$jscomp$113_token$jscomp$153$$,$selected_shapes$jscomp$15$$,$attributes$jscomp$80$$){var $ids_by_attributes$jscomp$1$$=$app$common$files$tokens$shapes_ids_by_applied_attributes$$($shape_ids$jscomp$113_token$jscomp$153$$,$selected_shapes$jscomp$15$$,$attributes$jscomp$80$$);$shape_ids$jscomp$113_token$jscomp$153$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$selected_shapes$jscomp$15$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5874$all_selected_QMARK_$$,$app$common$files$tokens$shapes_applied_all_QMARK_$$($ids_by_attributes$jscomp$1$$,$shape_ids$jscomp$113_token$jscomp$153$$,$attributes$jscomp$80$$),$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$113_token$jscomp$153$$,$cljs$cst$5875$selected_pred$$,function($p1__80066_SHARP_$$){return $APP.$cljs$core$seq$$($p1__80066_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$?
$p1__80066_SHARP_$$.$cljs$core$IFn$_invoke$arity$1$($ids_by_attributes$jscomp$1$$):$p1__80066_SHARP_$$($ids_by_attributes$jscomp$1$$))}],null)};
$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$=function($allowed_attributes_attributes$jscomp$81$$,$title$jscomp$45$$,$map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$){var $allowed_shape_attributes_map__80069__$1$$=$APP.$cljs$core$__destructure_map$$($map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$),$token$jscomp$154$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__80069__$1$$,$APP.$cljs$cst$1136$token$$);
$map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__80069__$1$$,$APP.$cljs$cst$3050$selected_shapes$$);var $on_update_shape$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__80069__$1$$,$APP.$cljs$cst$4727$on_update_shape$$),$hint$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__80069__$1$$,$APP.$cljs$cst$275$hint$$);
$allowed_shape_attributes_map__80069__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes_map__80069__$1$$,$cljs$cst$5876$allowed_shape_attributes$$);$allowed_attributes_attributes$jscomp$81$$=$APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($allowed_attributes_attributes$jscomp$81$$,$allowed_shape_attributes_map__80069__$1$$);var $on_update_shape_fn$$=$APP.$cljs$core$truth_$$($on_update_shape$jscomp$5$$)?$on_update_shape$jscomp$5$$:$APP.$cljs$core$truth_$$($token$jscomp$154$$)?
$APP.$cljs$cst$4727$on_update_shape$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$get_token_properties$$($token$jscomp$154$$)):null;$map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$=$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$($token$jscomp$154$$,$map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$,$allowed_attributes_attributes$jscomp$81$$);$map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$=$APP.$cljs$core$__destructure_map$$($map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$);
var $selected_pred$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$,$cljs$cst$5875$selected_pred$$),$shape_ids$jscomp$114$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80070_map__80070__$1_p__80068_selected_shapes$jscomp$16$$,$APP.$cljs$cst$4722$shape_ids$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($attribute$jscomp$4$$){var $selected_QMARK_$jscomp$4$$=$selected_pred$$.$cljs$core$IFn$_invoke$arity$1$?
$selected_pred$$.$cljs$core$IFn$_invoke$arity$1$($attribute$jscomp$4$$):$selected_pred$$($attribute$jscomp$4$$),$props$jscomp$337$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attribute$jscomp$4$$]),$APP.$cljs$cst$1136$token$$,$token$jscomp$154$$,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$114$$],null),$unnaply_props$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$154$$),$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attribute$jscomp$4$$]),$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$114$$],null);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,$title$jscomp$45$$,$APP.$cljs$cst$275$hint$$,$hint$jscomp$17$$,$cljs$cst$5877$selected_QMARK_$$,$selected_QMARK_$jscomp$4$$,$APP.$cljs$cst$2694$action$$,function(){return $APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$4$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$337$$,$APP.$cljs$cst$4727$on_update_shape$$,$on_update_shape_fn$$)))}],null)},$allowed_attributes_attributes$jscomp$81$$)};
$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$=function($attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$,$all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$){var $allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$=$APP.$cljs$core$__destructure_map$$($attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$);$attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$,
$cljs$cst$5878$attribute_labels$$);var $on_update_shape_all$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$,$cljs$cst$5879$on_update_shape_all$$),$on_update_shape$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$,$APP.$cljs$cst$4727$on_update_shape$$),$hint$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$,
$APP.$cljs$cst$275$hint$$);$allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$=$APP.$cljs$core$__destructure_map$$($all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$);var $token$jscomp$155$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$,$APP.$cljs$cst$1136$token$$);$all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$,
$APP.$cljs$cst$3050$selected_shapes$$);$allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$,$cljs$cst$5876$allowed_shape_attributes$$);if($attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$=$APP.$cljs$core$seq$$($APP.$cljs$core$select_keys$$($attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$,$allowed_shape_attributes$jscomp$1_map__80076__$1_map__80077__$1$$))){var $attributes$jscomp$82$$=
$APP.$cljs$core$set$$($APP.$cljs$core$keys$$($attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$));$all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$=$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$($token$jscomp$155$$,$all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$,$attributes$jscomp$82$$);$all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$=$APP.$cljs$core$__destructure_map$$($all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$);
var $all_selected_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$,$cljs$cst$5874$all_selected_QMARK_$$),$selected_pred$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$,$cljs$cst$5875$selected_pred$$),$shape_ids$jscomp$115$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$,
$APP.$cljs$cst$4722$shape_ids$$);$all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$=function(){var $props$jscomp$338$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2009$attributes$$,$attributes$jscomp$82$$,$APP.$cljs$cst$1136$token$$,$token$jscomp$155$$,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$115$$],null),$unnaply_props$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$155$$),
$APP.$cljs$cst$2009$attributes$$,$attributes$jscomp$82$$,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$115$$],null);return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.all"),$cljs$cst$5877$selected_QMARK_$$,$all_selected_QMARK_$$,$APP.$cljs$cst$275$hint$$,$hint$jscomp$18$$,$APP.$cljs$cst$2694$action$$,function(){return $APP.$cljs$core$truth_$$($all_selected_QMARK_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$jscomp$1$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$338$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$cljs$core$truth_$$($on_update_shape_all$$)?$on_update_shape_all$$:$on_update_shape$jscomp$6$$)))}],null)}();$attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80082_title$jscomp$46$$){var $attr$jscomp$95$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80082_title$jscomp$46$$,0,null);$p__80082_title$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80082_title$jscomp$46$$,1,null);var $selected_QMARK_$jscomp$5$$=$selected_pred$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$selected_pred$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$95$$):$selected_pred$jscomp$1$$($attr$jscomp$95$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,
$p__80082_title$jscomp$46$$,$cljs$cst$5877$selected_QMARK_$$,function(){var $and__5023__auto__$jscomp$875$$=$APP.$cljs$core$not$$($all_selected_QMARK_$$);return $and__5023__auto__$jscomp$875$$?$selected_QMARK_$jscomp$5$$:$and__5023__auto__$jscomp$875$$}(),$APP.$cljs$cst$2694$action$$,function(){var $event$jscomp$584_props$jscomp$339$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$95$$]),$APP.$cljs$cst$1136$token$$,
$token$jscomp$155$$,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$115$$],null),$unnaply_props$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$155$$),$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$95$$]),$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$115$$],null);$event$jscomp$584_props$jscomp$339$$=$APP.$cljs$core$truth_$$($all_selected_QMARK_$$)?
$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$584_props$jscomp$339$$,$APP.$cljs$cst$4726$attributes_to_remove$$,$attributes$jscomp$82$$)):$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$5$$)?$APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$jscomp$2$$):$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$584_props$jscomp$339$$,
$APP.$cljs$cst$4727$on_update_shape$$,$on_update_shape$jscomp$6$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$584_props$jscomp$339$$)}],null)},$attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$all_action_map__80078_map__80078__$1_p__80075_selected_shapes$jscomp$17$$],null):null,$attribute_labels_p__80074_single_actions_temp__5825__auto__$jscomp$402$$)}return null};
$app$main$ui$workspace$tokens$management$context_menu$layout_spacing_items$$=function($all_attr_labels_p__80086_single_items$$){var $hint$jscomp$19_map__80087__$1_multi_items$$=$APP.$cljs$core$__destructure_map$$($all_attr_labels_p__80086_single_items$$),$token$jscomp$156$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$19_map__80087__$1_multi_items$$,$APP.$cljs$cst$1136$token$$),$map__80088_map__80088__$1_selected_shapes$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$19_map__80087__$1_multi_items$$,
$APP.$cljs$cst$3050$selected_shapes$$);$all_attr_labels_p__80086_single_items$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$19_map__80087__$1_multi_items$$,$cljs$cst$5880$all_attr_labels$$);var $horizontal_attr_labels$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$19_map__80087__$1_multi_items$$,$cljs$cst$5881$horizontal_attr_labels$$),$vertical_attr_labels$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$19_map__80087__$1_multi_items$$,
$cljs$cst$5882$vertical_attr_labels$$),$on_update_shape$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$19_map__80087__$1_multi_items$$,$APP.$cljs$cst$4727$on_update_shape$$);$hint$jscomp$19_map__80087__$1_multi_items$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$19_map__80087__$1_multi_items$$,$APP.$cljs$cst$275$hint$$);var $horizontal_attrs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keys$$($horizontal_attr_labels$$)),
$vertical_attrs$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$keys$$($vertical_attr_labels$$)),$attrs$jscomp$182$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($horizontal_attrs$$,$vertical_attrs$$);$map__80088_map__80088__$1_selected_shapes$jscomp$18$$=$app$main$ui$workspace$tokens$management$context_menu$attribute_actions$$($token$jscomp$156$$,$map__80088_map__80088__$1_selected_shapes$jscomp$18$$,$attrs$jscomp$182$$);
$map__80088_map__80088__$1_selected_shapes$jscomp$18$$=$APP.$cljs$core$__destructure_map$$($map__80088_map__80088__$1_selected_shapes$jscomp$18$$);var $all_selected_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80088_map__80088__$1_selected_shapes$jscomp$18$$,$cljs$cst$5874$all_selected_QMARK_$$),$selected_pred$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80088_map__80088__$1_selected_shapes$jscomp$18$$,$cljs$cst$5875$selected_pred$$),$shape_ids$jscomp$116$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80088_map__80088__$1_selected_shapes$jscomp$18$$,$APP.$cljs$cst$4722$shape_ids$$),$horizontal_selected_QMARK_$$=$APP.$cljs$core$not$$($all_selected_QMARK_$jscomp$1$$)&&$APP.$cljs$core$every_QMARK_$$($selected_pred$jscomp$2$$,$horizontal_attrs$$),$vertical_selected_QMARK_$$=$APP.$cljs$core$not$$($all_selected_QMARK_$jscomp$1$$)&&$APP.$cljs$core$every_QMARK_$$($selected_pred$jscomp$2$$,$vertical_attrs$$);$hint$jscomp$19_map__80087__$1_multi_items$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.all"),$cljs$cst$5877$selected_QMARK_$$,$all_selected_QMARK_$jscomp$1$$,$APP.$cljs$cst$275$hint$$,$hint$jscomp$19_map__80087__$1_multi_items$$,$APP.$cljs$cst$2694$action$$,function(){var $props$jscomp$340$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2009$attributes$$,
$attrs$jscomp$182$$,$APP.$cljs$cst$1136$token$$,$token$jscomp$156$$,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$116$$],null),$unnaply_props$jscomp$3$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$156$$),$APP.$cljs$cst$2009$attributes$$,$attrs$jscomp$182$$,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$116$$],null);return $APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$jscomp$3$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$340$$,$APP.$cljs$cst$4727$on_update_shape$$,$on_update_shape$jscomp$7$$)))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,"Horizontal",$cljs$cst$5877$selected_QMARK_$$,$horizontal_selected_QMARK_$$,$APP.$cljs$cst$2694$action$$,function(){var $event$jscomp$585_props$jscomp$341$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1136$token$$,$token$jscomp$156$$,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$116$$],null);$event$jscomp$585_props$jscomp$341$$=$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$1$$)?$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$585_props$jscomp$341$$,$APP.$cljs$cst$4726$attributes_to_remove$$,$vertical_attrs$$)):$horizontal_selected_QMARK_$$?
$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$585_props$jscomp$341$$,$APP.$cljs$cst$4726$attributes_to_remove$$,$horizontal_attrs$$)):$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($event$jscomp$585_props$jscomp$341$$,$APP.$cljs$cst$2009$attributes$$,$horizontal_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4727$on_update_shape$$,
$on_update_shape$jscomp$7$$])));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$585_props$jscomp$341$$)}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,"Vertical",$cljs$cst$5877$selected_QMARK_$$,$vertical_selected_QMARK_$$,$APP.$cljs$cst$2694$action$$,function(){var $event$jscomp$586_props$jscomp$342$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1136$token$$,$token$jscomp$156$$,$APP.$cljs$cst$4722$shape_ids$$,
$shape_ids$jscomp$116$$],null);$event$jscomp$586_props$jscomp$342$$=$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$1$$)?$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$586_props$jscomp$342$$,$APP.$cljs$cst$4726$attributes_to_remove$$,$horizontal_attrs$$)):$vertical_selected_QMARK_$$?$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$586_props$jscomp$342$$,
$APP.$cljs$cst$4726$attributes_to_remove$$,$vertical_attrs$$)):$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($event$jscomp$586_props$jscomp$342$$,$APP.$cljs$cst$2009$attributes$$,$vertical_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4727$on_update_shape$$,$on_update_shape$jscomp$7$$])));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$586_props$jscomp$342$$)}],
null)],null);$all_attr_labels_p__80086_single_items$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80089_title$jscomp$47$$){var $attr$jscomp$96$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80089_title$jscomp$47$$,0,null);$p__80089_title$jscomp$47$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80089_title$jscomp$47$$,1,null);var $same_axis_selected_QMARK_$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($horizontal_attrs$$,
$attr$jscomp$96$$))?$horizontal_selected_QMARK_$$:$APP.$cljs$core$truth_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vertical_attrs$$,$attr$jscomp$96$$))?$vertical_selected_QMARK_$$:!0,$selected_QMARK_$jscomp$6$$=function(){var $and__5023__auto__$jscomp$876_and__5023__auto____$1$jscomp$153$$=$APP.$cljs$core$not$$($all_selected_QMARK_$jscomp$1$$);return $and__5023__auto__$jscomp$876_and__5023__auto____$1$jscomp$153$$?($and__5023__auto__$jscomp$876_and__5023__auto____$1$jscomp$153$$=!$same_axis_selected_QMARK_$$)?
$selected_pred$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$selected_pred$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$96$$):$selected_pred$jscomp$2$$($attr$jscomp$96$$):$and__5023__auto__$jscomp$876_and__5023__auto____$1$jscomp$153$$:$and__5023__auto__$jscomp$876_and__5023__auto____$1$jscomp$153$$}();return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$p__80089_title$jscomp$47$$,$cljs$cst$5877$selected_QMARK_$$,$selected_QMARK_$jscomp$6$$,$APP.$cljs$cst$2694$action$$,
function(){var $event$jscomp$587_props$jscomp$343$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$96$$]),$APP.$cljs$cst$1136$token$$,$token$jscomp$156$$,$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$116$$],null),$unnaply_props$jscomp$4$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$156$$),
$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$96$$]),$APP.$cljs$cst$4722$shape_ids$$,$shape_ids$jscomp$116$$],null);$event$jscomp$587_props$jscomp$343$$=$APP.$cljs$core$truth_$$($all_selected_QMARK_$jscomp$1$$)?$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$587_props$jscomp$343$$,$APP.$cljs$cst$4726$attributes_to_remove$$,$attrs$jscomp$182$$)):$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$6$$)?
$APP.$app$main$data$workspace$tokens$application$unapply_token$$($unnaply_props$jscomp$4$$):$APP.$app$main$data$workspace$tokens$application$apply_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$587_props$jscomp$343$$,$APP.$cljs$cst$4727$on_update_shape$$,$on_update_shape$jscomp$7$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$587_props$jscomp$343$$)}],null)},$all_attr_labels_p__80086_single_items$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($hint$jscomp$19_map__80087__$1_multi_items$$,
$all_attr_labels_p__80086_single_items$$)};
$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_padding$$=function($value$jscomp$942$$,$shape_ids$jscomp$117$$,$attributes$jscomp$83$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($attributes$jscomp$83$$),1)?$APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$117$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1690$layout_padding_type$$,$APP.$cljs$cst$1621$multiple$$],null)):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$application$update_layout_padding$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$942$$,$shape_ids$jscomp$117$$,$attributes$jscomp$83$$)]))};
$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_margin$$=function($value$jscomp$943$$,$shape_ids$jscomp$118$$,$attributes$jscomp$84$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($attributes$jscomp$84$$),1)?$APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($shape_ids$jscomp$118$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1703$layout_item_margin_type$$,$APP.$cljs$cst$1621$multiple$$],null)):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$application$update_layout_item_margin$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$943$$,$shape_ids$jscomp$118$$,$attributes$jscomp$84$$)]))};
$app$main$ui$workspace$tokens$management$context_menu$spacing_attribute_actions$$=function($gap_items_map__80094__$1_p__80093$$){$gap_items_map__80094__$1_p__80093$$=$APP.$cljs$core$__destructure_map$$($gap_items_map__80094__$1_p__80093$$);var $margin_items_token$jscomp$157$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap_items_map__80094__$1_p__80093$$,$APP.$cljs$cst$1136$token$$),$selected_shapes$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap_items_map__80094__$1_p__80093$$,
$APP.$cljs$cst$3050$selected_shapes$$),$allowed_shape_attributes$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap_items_map__80094__$1_p__80093$$,$cljs$cst$5876$allowed_shape_attributes$$),$is_selected_inside_layout$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap_items_map__80094__$1_p__80093$$,$cljs$cst$5883$is_selected_inside_layout$$),$padding_attr_labels_padding_items$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,"Padding top",$APP.$cljs$cst$1091$p2$$,
"Padding right",$APP.$cljs$cst$1692$p3$$,"Padding bottom",$APP.$cljs$cst$1693$p4$$,"Padding left"],null);$padding_attr_labels_padding_items$$=$APP.$cljs$core$truth_$$($app$main$ui$workspace$tokens$management$context_menu$key_in_map_QMARK_$$($allowed_shape_attributes$jscomp$2$$,$padding_attr_labels_padding_items$$))?$app$main$ui$workspace$tokens$management$context_menu$layout_spacing_items$$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1136$token$$,$margin_items_token$jscomp$157$$,
$APP.$cljs$cst$3050$selected_shapes$$,$selected_shapes$jscomp$19$$,$cljs$cst$5880$all_attr_labels$$,$padding_attr_labels_padding_items$$,$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.paddings"),$cljs$cst$5881$horizontal_attr_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,"Padding right",$APP.$cljs$cst$1693$p4$$,"Padding left"],null),$cljs$cst$5882$vertical_attr_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1093$p1$$,"Padding top",$APP.$cljs$cst$1692$p3$$,"Padding bottom"],null),$APP.$cljs$cst$4727$on_update_shape$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_padding$$],null)):null;var $margin_attr_labels$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1705$m1$$,"Margin top",$APP.$cljs$cst$1706$m2$$,"Margin right",$APP.$cljs$cst$1707$m3$$,"Margin bottom",$APP.$cljs$cst$1708$m4$$,"Margin left"],null);$margin_items_token$jscomp$157$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_selected_inside_layout$$)?
$is_selected_inside_layout$$:$app$main$ui$workspace$tokens$management$context_menu$key_in_map_QMARK_$$($allowed_shape_attributes$jscomp$2$$,$margin_attr_labels$$))?$app$main$ui$workspace$tokens$management$context_menu$layout_spacing_items$$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1136$token$$,$margin_items_token$jscomp$157$$,$APP.$cljs$cst$3050$selected_shapes$$,$selected_shapes$jscomp$19$$,$cljs$cst$5880$all_attr_labels$$,$margin_attr_labels$$,$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.margins"),
$cljs$cst$5881$horizontal_attr_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1706$m2$$,"Margin right",$APP.$cljs$cst$1708$m4$$,"Margin left"],null),$cljs$cst$5882$vertical_attr_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1705$m1$$,"Margin top",$APP.$cljs$cst$1707$m3$$,"Margin bottom"],null),$APP.$cljs$cst$4727$on_update_shape$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_layout_margin$$],null)):null;$gap_items_map__80094__$1_p__80093$$=
$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5878$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1687$column_gap$$,"Column Gap",$APP.$cljs$cst$1686$row_gap$$,"Row Gap"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.gaps"),$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_layout_gap$$],
null),$gap_items_map__80094__$1_p__80093$$);return $app$main$ui$workspace$tokens$management$context_menu$clean_separators$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($gap_items_map__80094__$1_p__80093$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1477$separator$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$padding_attr_labels_padding_items$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1477$separator$$],null),$margin_items_token$jscomp$157$$])))};
$app$main$ui$workspace$tokens$management$context_menu$sizing_attribute_actions$$=function($context_data$jscomp$1$$){return $app$main$ui$workspace$tokens$management$context_menu$clean_separators$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5878$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$290$width$$,"Width",
$APP.$cljs$cst$1527$height$$,"Height"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.size"),$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$apply_dimensions_token$$],null),$context_data$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1477$separator$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5878$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1712$layout_item_min_w$$,"Min Width",$APP.$cljs$cst$1710$layout_item_min_h$$,"Min Height"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.min-size"),$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$],null),$context_data$jscomp$1$$),new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1477$separator$$],null),$app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5878$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1711$layout_item_max_w$$,"Max Width",$APP.$cljs$cst$1709$layout_item_max_h$$,"Max Height"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.max-size"),
$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_layout_sizing_limits$$],null),$context_data$jscomp$1$$)])))};
$app$main$ui$workspace$tokens$management$context_menu$update_shape_radius_for_corners$$=function($value$jscomp$944$$,$shape_ids$jscomp$119$$,$attributes$jscomp$85$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5782$expand_border_radius$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$application$update_shape_radius_for_corners$$.$cljs$core$IFn$_invoke$arity$3$($value$jscomp$944$$,
$shape_ids$jscomp$119$$,$attributes$jscomp$85$$)]))};
$app$main$ui$workspace$tokens$management$context_menu$default_actions$$=function($map__80098__$1_map__80099_map__80099__$1_p__80097$$){$map__80098__$1_map__80099_map__80099__$1_p__80097$$=$APP.$cljs$core$__destructure_map$$($map__80098__$1_map__80099_map__80099__$1_p__80097$$);var $token$jscomp$158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80098__$1_map__80099_map__80099__$1_p__80097$$,$APP.$cljs$cst$1136$token$$),$selected_token_set_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80098__$1_map__80099_map__80099__$1_p__80097$$,
$APP.$cljs$cst$2146$selected_token_set_id$$),$on_delete_token$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80098__$1_map__80099_map__80099__$1_p__80097$$,$cljs$cst$5885$on_delete_token$$),$errors$jscomp$30$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80098__$1_map__80099_map__80099__$1_p__80097$$,$APP.$cljs$cst$570$errors$$);$map__80098__$1_map__80099_map__80099__$1_p__80097$$=$app$main$data$workspace$tokens$application$get_token_properties$$($token$jscomp$158$$);
$map__80098__$1_map__80099_map__80099__$1_p__80097$$=$APP.$cljs$core$__destructure_map$$($map__80098__$1_map__80099_map__80099__$1_p__80097$$);var $modal$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80098__$1_map__80099_map__80099__$1_p__80097$$,$APP.$cljs$cst$4618$modal$$);return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.edit"),
$cljs$cst$5886$no_selectable$$,!0,$APP.$cljs$cst$2694$action$$,function($event$jscomp$588$$){var $fields$jscomp$8_map__80100__$1$$=$APP.$cljs$core$__destructure_map$$($modal$jscomp$2$$),$key$jscomp$421$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fields$jscomp$8_map__80100__$1$$,$APP.$cljs$cst$302$key$$);$fields$jscomp$8_map__80100__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fields$jscomp$8_map__80100__$1$$,$APP.$cljs$cst$4741$fields$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$588$$);
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$(null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($key$jscomp$421$$,new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1515$x$$,$event$jscomp$588$$.clientX,$APP.$cljs$cst$1516$y$$,$event$jscomp$588$$.clientY,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$258$right$$,
$APP.$cljs$cst$4741$fields$$,$fields$jscomp$8_map__80100__$1$$,$APP.$cljs$cst$4841$initial_errors$$,$errors$jscomp$30$$,$APP.$cljs$cst$2694$action$$,"edit",$APP.$cljs$cst$2146$selected_token_set_id$$,$selected_token_set_id$$,$APP.$cljs$cst$1136$token$$,$token$jscomp$158$$],null))]))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.duplicate"),$cljs$cst$5886$no_selectable$$,!0,$APP.$cljs$cst$2694$action$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$duplicate_token$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$158$$)))}],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.copy-name"),$cljs$cst$5886$no_selectable$$,!0,$APP.$cljs$cst$2694$action$$,function(){return $APP.$app$util$clipboard$to_clipboard$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$158$$))}],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$939$title$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.delete"),$cljs$cst$5886$no_selectable$$,!0,$APP.$cljs$cst$2694$action$$,function(){return $on_delete_token$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete_token$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$158$$):$on_delete_token$$($token$jscomp$158$$)}],null)],null)};
$app$main$ui$workspace$tokens$management$context_menu$allowed_shape_attributes$$=function($shapes$jscomp$233$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$into$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80101_SHARP_$$){return $APP.$app$common$types$token$shape_type__GT_attributes$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__80101_SHARP_$$),$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($p1__80101_SHARP_$$))},
$shapes$jscomp$233$$))};
$app$main$ui$workspace$tokens$management$context_menu$menu_actions$$=function($p__80102_type$jscomp$683_with_actions$$){var $context_data__$1_map__80103__$1$$=$APP.$cljs$core$__destructure_map$$($p__80102_type$jscomp$683_with_actions$$);$p__80102_type$jscomp$683_with_actions$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($context_data__$1_map__80103__$1$$,$APP.$cljs$cst$139$type$$);var $token$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($context_data__$1_map__80103__$1$$,$APP.$cljs$cst$1136$token$$),
$selected_shapes$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($context_data__$1_map__80103__$1$$,$APP.$cljs$cst$3050$selected_shapes$$);$context_data__$1_map__80103__$1$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($context_data__$1_map__80103__$1$$,$cljs$cst$5876$allowed_shape_attributes$$,$app$main$ui$workspace$tokens$management$context_menu$allowed_shape_attributes$$($selected_shapes$jscomp$20$$));$p__80102_type$jscomp$683_with_actions$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$context_menu$shape_attribute_actions_map$$,
$APP.$cljs$core$truth_$$($p__80102_type$jscomp$683_with_actions$$)?$p__80102_type$jscomp$683_with_actions$$:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$159$$));return $APP.$cljs$core$truth_$$($p__80102_type$jscomp$683_with_actions$$)?$p__80102_type$jscomp$683_with_actions$$.$cljs$core$IFn$_invoke$arity$1$?$p__80102_type$jscomp$683_with_actions$$.$cljs$core$IFn$_invoke$arity$1$($context_data__$1_map__80103__$1$$):$p__80102_type$jscomp$683_with_actions$$($context_data__$1_map__80103__$1$$):
$APP.$cljs$core$PersistentVector$EMPTY$$};
$app$main$ui$workspace$tokens$management$context_menu$selection_actions$$=function($context_data$jscomp$6$$){var $attribute_actions$jscomp$1$$=$app$main$ui$workspace$tokens$management$context_menu$menu_actions$$($context_data$jscomp$6$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($attribute_actions$jscomp$1$$,$APP.$cljs$core$seq$$($attribute_actions$jscomp$1$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1477$separator$$],
null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$workspace$tokens$management$context_menu$default_actions$$($context_data$jscomp$6$$)]))};$app$main$ui$workspace$tokens$management$context_menu$prevent_default$$=function($event$jscomp$589$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$589$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$589$$)};
$app$main$ui$workspace$tokens$management$context_menu$menu_entry$$=function($on_click$jscomp$50_props_80104$$){var $selected_QMARK_$jscomp$7$$=$on_click$jscomp$50_props_80104$$["selected?"],$children$jscomp$303$$=$on_click$jscomp$50_props_80104$$.children,$no_selectable$$=$on_click$jscomp$50_props_80104$$["no-selectable"],$value$jscomp$945$$=$on_click$jscomp$50_props_80104$$.value,$hint$jscomp$20$$=$on_click$jscomp$50_props_80104$$.hint,$submenu_offset$$=$on_click$jscomp$50_props_80104$$["submenu-offset"],
$title$jscomp$48$$=$on_click$jscomp$50_props_80104$$.title;$on_click$jscomp$50_props_80104$$=$on_click$jscomp$50_props_80104$$["on-click"];var $submenu_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$hovering_QMARK_$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$parent_menu_dom_element_pos_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$parent_menu_dom_element_pos$$=$APP.$cljs$core$_deref$$($parent_menu_dom_element_pos_STAR_$$),$is_submenu_outside_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$is_submenu_outside_QMARK_$$=$APP.$cljs$core$_deref$$($is_submenu_outside_STAR_$$),$hint_QMARK_$$=$APP.$cljs$core$truth_$$($hint$jscomp$20$$)?$APP.$cljs$core$seq$$($hint$jscomp$20$$):$hint$jscomp$20$$,$on_pointer_enter$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_submenu_outside_QMARK_$$)],function(){$APP.$rumext$v2$set_ref_val_BANG_$$($hovering_QMARK_$jscomp$2$$,!0);var $temp__5825__auto__$jscomp$403$$=$APP.$rumext$v2$ref_val$$($submenu_ref$jscomp$1$$);
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$403$$)?($APP.$app$util$dom$set_css_property_BANG_$$($temp__5825__auto__$jscomp$403$$,"display","block"),$APP.$cljs$core$reset_BANG_$$($is_submenu_outside_STAR_$$,$APP.$app$util$dom$is_element_outside_QMARK_$$($temp__5825__auto__$jscomp$403$$))):null}),$on_pointer_leave$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_submenu_outside_QMARK_$$)],function(){$APP.$rumext$v2$set_ref_val_BANG_$$($hovering_QMARK_$jscomp$2$$,
!1);var $temp__5825__auto__$jscomp$404$$=$APP.$rumext$v2$ref_val$$($submenu_ref$jscomp$1$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$404$$)?$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(50,function(){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($hovering_QMARK_$jscomp$2$$)))return null;$APP.$app$util$dom$set_css_property_BANG_$$($temp__5825__auto__$jscomp$404$$,"display","none");return $APP.$cljs$core$reset_BANG_$$($is_submenu_outside_STAR_$$,!1)}):
null}),$get_parent_menu_entry_position$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($parent_menu_dom_element$$){return $parent_menu_dom_element$$!=null?$APP.$cljs$core$reset_BANG_$$($parent_menu_dom_element_pos_STAR_$$,""+($parent_menu_dom_element$$.offsetTop??"")+"px"):null});return(0,$APP.$rumext$v2$jsxs$$)("li",{ref:$get_parent_menu_entry_position$$,"data-value":$value$jscomp$945$$,onClick:$on_click$jscomp$50_props_80104$$,onPointerEnter:$on_pointer_enter$jscomp$6$$,onPointerLeave:$on_pointer_leave$jscomp$6$$,
className:"main_ui_workspace_tokens_management_context_menu__context-menu-item "+($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$878$$=$APP.$cljs$core$not$$($no_selectable$$);return $and__5023__auto__$jscomp$878$$?$selected_QMARK_$jscomp$7$$:$and__5023__auto__$jscomp$878$$}())?"main_ui_workspace_tokens_management_context_menu__context-menu-item-selected":"")+" "+($APP.$cljs$core$not$$($no_selectable$$)&&$APP.$cljs$core$not$$($selected_QMARK_$jscomp$7$$)?"main_ui_workspace_tokens_management_context_menu__context-menu-item-unselected":
"")+" "+($APP.$cljs$core$truth_$$($hint_QMARK_$$)?"main_ui_workspace_tokens_management_context_menu__context-menu-item-hint-wrapper":""),children:[$APP.$cljs$core$truth_$$($hint$jscomp$20$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_context_menu__context-menu-item-hint",children:$hint$jscomp$20$$}):null,$APP.$cljs$core$not$$($no_selectable$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s",className:"main_ui_workspace_tokens_management_context_menu__icon-wrapper"}):
null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_context_menu__item-text",children:$title$jscomp$48$$}),$APP.$cljs$core$truth_$$($children$jscomp$303$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("ul",{ref:$submenu_ref$jscomp$1$$,style:{left:""+($submenu_offset$$??"")+"px",top:$APP.$cljs$core$truth_$$($is_submenu_outside_QMARK_$$)?
"unset":$parent_menu_dom_element_pos$$},onContextMenu:$app$main$ui$workspace$tokens$management$context_menu$prevent_default$$,className:"main_ui_workspace_tokens_management_context_menu__token-context-submenu "+($APP.$cljs$core$truth_$$($is_submenu_outside_QMARK_$$)?"main_ui_workspace_tokens_management_context_menu__token-context-submenu-top":""),children:$children$jscomp$303$$})]}):null]})};
$app$main$ui$workspace$tokens$management$context_menu$token_context_menu_tree$$=function($map__80116_props_80115_width$jscomp$206$$){$map__80116_props_80115_width$jscomp$206$$=$APP.$rumext$v2$util$wrap_props$$($map__80116_props_80115_width$jscomp$206$$);var $map__80116__$1_token$jscomp$160_token_id$jscomp$24$$=$APP.$cljs$core$__destructure_map$$($map__80116_props_80115_width$jscomp$206$$);$map__80116_props_80115_width$jscomp$206$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80116__$1_token$jscomp$160_token_id$jscomp$24$$,
$APP.$cljs$cst$290$width$$);var $errors$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80116__$1_token$jscomp$160_token_id$jscomp$24$$,$APP.$cljs$cst$570$errors$$),$on_delete_token$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80116__$1_token$jscomp$160_token_id$jscomp$24$$,$cljs$cst$5885$on_delete_token$$),$objects$jscomp$813$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$selected$jscomp$182$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$);
$map__80116__$1_token$jscomp$160_token_id$jscomp$24$$=$APP.$cljs$cst$2655$token_id$$.$cljs$core$IFn$_invoke$arity$1$($map__80116__$1_token$jscomp$160_token_id$jscomp$24$$);$map__80116__$1_token$jscomp$160_token_id$jscomp$24$$=$APP.$rumext$v2$deref$$($app$main$refs$workspace_token_in_selected_set$$($map__80116__$1_token$jscomp$160_token_id$jscomp$24$$));var $token_type$jscomp$16$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($map__80116__$1_token$jscomp$160_token_id$jscomp$24$$),$selected_token_set_id$jscomp$1$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$selected_shapes$jscomp$22$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$182$$),$APP.$rumext$v2$adapt$$($objects$jscomp$813$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$813$$)),$selected$jscomp$182$$)}),
$is_selected_inside_layout$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_type$jscomp$16$$),$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$22$$),$APP.$rumext$v2$adapt$$($objects$jscomp$813$$)],function(){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1996$dimensions$$,null,$APP.$cljs$cst$1999$spacing$$,null],null),null),$token_type$jscomp$16$$)?
$APP.$cljs$core$some$$(function($p1__80114_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$813$$,$p1__80114_SHARP_$$)},$selected_shapes$jscomp$22$$):null});return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_management_context_menu__context-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$context_menu$menu_tree$$,{"submenu-offset":$map__80116_props_80115_width$jscomp$206$$,token:$map__80116__$1_token$jscomp$160_token_id$jscomp$24$$,
errors:$errors$jscomp$32$$,"selected-token-set-id":$selected_token_set_id$jscomp$1$$,"selected-shapes":$selected_shapes$jscomp$22$$,"is-selected-inside-layout":$is_selected_inside_layout$jscomp$1$$,"on-delete-token":$on_delete_token$jscomp$1$$})})};
$app$main$ui$workspace$tokens$management$context_menu$token_context_menu$$=function($map__80119_map__80119__$1_on_delete_token$jscomp$2_props_80118$$){$map__80119_map__80119__$1_on_delete_token$jscomp$2_props_80118$$=$APP.$rumext$v2$util$wrap_props$$($map__80119_map__80119__$1_on_delete_token$jscomp$2_props_80118$$);$map__80119_map__80119__$1_on_delete_token$jscomp$2_props_80118$$=$APP.$cljs$core$__destructure_map$$($map__80119_map__80119__$1_on_delete_token$jscomp$2_props_80118$$);$map__80119_map__80119__$1_on_delete_token$jscomp$2_props_80118$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80119_map__80119__$1_on_delete_token$jscomp$2_props_80118$$,$cljs$cst$5885$on_delete_token$$);var $mdata$jscomp$23$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$management$context_menu$tokens_menu_ref$$),$is_open_QMARK_$jscomp$2$$=$APP.$cljs$core$boolean$0$$($mdata$jscomp$23$$),$width$jscomp$207$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$dropdown_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(),$dropdown_direction_STAR_$jscomp$1$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("down"),$dropdown_direction$jscomp$1$$=$APP.$cljs$core$_deref$$($dropdown_direction_STAR_$jscomp$1$$),$dropdown_direction_change_STAR_$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(0),$top$jscomp$17$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$23$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1516$y$$],null))+5,$left$jscomp$35$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$23$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1515$x$$],null))+5,$container$jscomp$93$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5888$popup$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$2$$)],function(){var $temp__5825__auto__$jscomp$405$$=
$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$2$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$405$$)?$APP.$cljs$core$reset_BANG_$$($width$jscomp$207$$,$temp__5825__auto__$jscomp$405$$.offsetWidth):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$2$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,
$is_open_QMARK_$jscomp$2$$)?($APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$jscomp$1$$,"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$jscomp$1$$,0)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($dropdown_ref$jscomp$2$$)],function(){var $dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$2$$),$and__5023__auto__$jscomp$inline_9125$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$1$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9125$$?$dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$inline_9125$$)?($dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$=$APP.$app$util$dom$is_element_outside_QMARK_$$($dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$),$APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$jscomp$1$$,
$dropdown_element$jscomp$1_is_outside_QMARK_$jscomp$1$$?"up":"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$jscomp$1$$,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$1$$)+1)):null});return $is_open_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$portal$$)($APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$is_open_QMARK_$jscomp$2$$,"on-close":function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$(null))},
children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"tokens-context-menu-for-token",ref:$dropdown_ref$jscomp$2$$,"data-direction":$dropdown_direction$jscomp$1$$,style:{"--bottom":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dropdown_direction$jscomp$1$$,"up")?"40px":"unset","--top":""+($top$jscomp$17$$??"")+"px",left:""+($left$jscomp$35$$??"")+"px"},onContextMenu:$app$main$ui$workspace$tokens$management$context_menu$prevent_default$$,className:"main_ui_workspace_tokens_management_context_menu__token-context-menu",
children:$APP.$cljs$core$truth_$$($mdata$jscomp$23$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$context_menu$token_context_menu_tree$$,$APP.$rumext$v2$util$map__GT_obj$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($mdata$jscomp$23$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$core$_deref$$($width$jscomp$207$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5885$on_delete_token$$,$map__80119_map__80119__$1_on_delete_token$jscomp$2_props_80118$$])))):
null})}),$container$jscomp$93$$):null};
$app$main$ui$ds$layers$layer_button$layer_button_STAR_$$=function($props_80095$$){var $expanded$jscomp$7$$=void 0,$description$jscomp$18$$=void 0,$children$jscomp$304$$=void 0,$is_expandable$$=void 0,$on_toggle_expand$jscomp$1$$=void 0,$on_context_menu$jscomp$12$$=void 0,$icon$jscomp$24$$=void 0,$label$jscomp$58$$=void 0,$class$$jscomp$81$$=void 0,$props$jscomp$344$$=void 0;({expanded:$expanded$jscomp$7$$,description:$description$jscomp$18$$,children:$children$jscomp$304$$,isExpandable:$is_expandable$$,
onToggleExpand:$on_toggle_expand$jscomp$1$$,onContextMenu:$on_context_menu$jscomp$12$$,icon:$icon$jscomp$24$$,label:$label$jscomp$58$$,className:$class$$jscomp$81$$,...$props$jscomp$344$$}=$props_80095$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_layers_layer_button__layer-button-wrapper",children:[(0,$APP.$rumext$v2$create_element$$)("button",{...$props$jscomp$344$$,className:($class$$jscomp$81$$??"")+" main_ui_ds_layers_layer_button__layer-button "+($APP.$cljs$core$truth_$$($expanded$jscomp$7$$)?
"main_ui_ds_layers_layer_button__layer-button-expanded":""),type:"button",onClick:$on_toggle_expand$jscomp$1$$,onContextMenu:$on_context_menu$jscomp$12$$},(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_ds_layers_layer_button__layer-button-content",children:[$APP.$cljs$core$truth_$$($is_expandable$$)?$APP.$cljs$core$truth_$$($expanded$jscomp$7$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-down",className:"main_ui_ds_layers_layer_button__folder-node-icon"}):
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right",className:"main_ui_ds_layers_layer_button__folder-node-icon"}):null,$APP.$cljs$core$truth_$$($icon$jscomp$24$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$icon$jscomp$24$$,className:"main_ui_ds_layers_layer_button__layer-button-icon"}):null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_layers_layer_button__layer-button-name",children:$label$jscomp$58$$}),
$APP.$cljs$core$truth_$$($description$jscomp$18$$)?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_layers_layer_button__layer-button-description",children:$description$jscomp$18$$}):null,(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_ds_layers_layer_button__layer-button-quantity"})]})),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_ds_layers_layer_button__layer-button-actions",children:$children$jscomp$304$$})]})};
$app$main$data$workspace$tokens$color$resolved_token_bullet_color$$=function($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$){$JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$);
var $JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$,$APP.$cljs$cst$4686$resolved_value$$);$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$)?
$APP.$app$main$data$tokenscript$color_symbol_QMARK_$$($JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$):$JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$)?($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$=$APP.$app$main$data$tokenscript$color_symbol_QMARK_$$($JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$)?
$JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$.to("hex").toString():null,$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$.isHex())?$JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$=1:($JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$=$JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$.getAttribute("alpha"),
$JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$)?$JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$:1),$JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,$JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$,$APP.$cljs$cst$1740$opacity$$,$JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$],null)):$JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$=
null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$),$APP.$cljs$cst$1303$color$$):
$JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$)?($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$=$APP.$app$main$data$tinycolor$valid_color$$($JSCompiler_inline_result$jscomp$inline_13860_or__5025__auto__$jscomp$inline_13861_resolved_value$jscomp$5$$),$JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$=
$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$)?$APP.$cljs$core$truth_$$($APP.$app$main$data$tinycolor$alpha$$($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$))?new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1303$color$$,$APP.$app$main$data$tinycolor$__GT_hex_string$$($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$),$APP.$cljs$cst$1740$opacity$$,$APP.$app$main$data$tinycolor$alpha$$($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$)],
null):$APP.$app$main$data$tinycolor$__GT_hex_string$$($JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$):null):$JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$=null;return $JSCompiler_temp$jscomp$11225_JSCompiler_temp$jscomp$11226_JSCompiler_temp$jscomp$11306_JSCompiler_temp_const$jscomp$inline_13859_map__80108__$1_p__80107_temp__5825__auto__$jscomp$inline_13865$$};
$app$main$ui$ds$foundations$utilities$token$token_status$token_status_icon_STAR_$$=function($icon_id$jscomp$6_props_80120$$){var $class$$jscomp$82_or__5025__auto__$jscomp$inline_9127$$,$props$jscomp$345$$;({iconId:$icon_id$jscomp$6_props_80120$$,className:$class$$jscomp$82_or__5025__auto__$jscomp$inline_9127$$,...$props$jscomp$345$$}=$icon_id$jscomp$6_props_80120$$);return(0,$APP.$rumext$v2$create_element$$)("svg",{...$props$jscomp$345$$,className:""+(($APP.$cljs$core$truth_$$($class$$jscomp$82_or__5025__auto__$jscomp$inline_9127$$)?
$class$$jscomp$82_or__5025__auto__$jscomp$inline_9127$$:"")??"")+" main_ui_ds_foundations_utilities_token_token_status__token-icon",width:"14px",height:"14px"},(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-"+($icon_id$jscomp$6_props_80120$$??""),width:"14px",height:"14px",x:0,y:0}))};
$app$main$ui$workspace$tokens$management$token_pill$partially_applied_attr$$=function($app_token_keys_filtered_keys$$,$is_applied$$,$map__80124__$1_p__80123$$){$map__80124__$1_p__80123$$=$APP.$cljs$core$__destructure_map$$($map__80124__$1_p__80123$$);var $attributes$jscomp$86$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80124__$1_p__80123$$,$APP.$cljs$cst$2009$attributes$$),$all_attributes$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80124__$1_p__80123$$,
$APP.$cljs$cst$4737$all_attributes$$);$app_token_keys_filtered_keys$$=$APP.$cljs$core$truth_$$($all_attributes$jscomp$1$$)?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80121_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($all_attributes$jscomp$1$$,$p1__80121_SHARP_$$)},$app_token_keys_filtered_keys$$):$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80122_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($attributes$jscomp$86$$,$p1__80122_SHARP_$$)},
$app_token_keys_filtered_keys$$);return $APP.$cljs$core$truth_$$($is_applied$$)?$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$token_pill$attribute_dictionary$$,$app_token_keys_filtered_keys$$)):null};
$app$main$ui$workspace$tokens$management$token_pill$translate_and_format$$=function($grouped_values$$){return $APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80125_values$jscomp$104$$){var $category$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80125_values$jscomp$104$$,0,null);$p__80125_values$jscomp$104$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80125_values$jscomp$104$$,
1,null);var $JSCompiler_inline_result$jscomp$1861_fexpr__80129$jscomp$inline_9129$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1516$y$$,null,$APP.$cljs$cst$1515$x$$,null],null),null);$JSCompiler_inline_result$jscomp$1861_fexpr__80129$jscomp$inline_9129$$=$JSCompiler_inline_result$jscomp$1861_fexpr__80129$jscomp$inline_9129$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1861_fexpr__80129$jscomp$inline_9129$$.$cljs$core$IFn$_invoke$arity$1$($category$jscomp$2$$):
$JSCompiler_inline_result$jscomp$1861_fexpr__80129$jscomp$inline_9129$$($category$jscomp$2$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1861_fexpr__80129$jscomp$inline_9129$$)?"- "+(($APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$($category$jscomp$2$$):(0,$APP.$app$main$data$workspace$tokens$format$category_dictionary$$)($category$jscomp$2$$))??
""):"- "+(($APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$main$data$workspace$tokens$format$category_dictionary$$.$cljs$core$IFn$_invoke$arity$1$($category$jscomp$2$$):(0,$APP.$app$main$data$workspace$tokens$format$category_dictionary$$)($category$jscomp$2$$))??"")+": "+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$token_pill$attribute_dictionary$$,
$p__80125_values$jscomp$104$$))??"")+"."},$grouped_values$$))};$app$main$ui$workspace$tokens$management$token_pill$contains_reference_value_QMARK_$$=function($match$jscomp$58_text$jscomp$147$$,$active_tokens$jscomp$8$$){$match$jscomp$58_text$jscomp$147$$=$APP.$cljs$core$second$$($APP.$cljs$core$re_find$$(/\{([^}]+)\}/,$match$jscomp$58_text$jscomp$147$$));return $APP.$cljs$core$contains_QMARK_$$($active_tokens$jscomp$8$$,$match$jscomp$58_text$jscomp$147$$)};
$app$main$ui$workspace$tokens$management$token_pill$applied_all_attributes_QMARK_$$=function($ids_by_attributes$jscomp$2_token$jscomp$163$$,$selected_shapes$jscomp$23_shape_ids$jscomp$120$$,$attributes$jscomp$87$$){$ids_by_attributes$jscomp$2_token$jscomp$163$$=$app$common$files$tokens$shapes_ids_by_applied_attributes$$($ids_by_attributes$jscomp$2_token$jscomp$163$$,$selected_shapes$jscomp$23_shape_ids$jscomp$120$$,$attributes$jscomp$87$$);$selected_shapes$jscomp$23_shape_ids$jscomp$120$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$app$main$ui$workspace$tokens$management$token_pill$xf_COLON_map_id$$,$selected_shapes$jscomp$23_shape_ids$jscomp$120$$);return $app$common$files$tokens$shapes_applied_all_QMARK_$$($ids_by_attributes$jscomp$2_token$jscomp$163$$,$selected_shapes$jscomp$23_shape_ids$jscomp$120$$,$attributes$jscomp$87$$)};
$app$main$ui$workspace$tokens$management$token_pill$attributes_match_selection_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($selected_shapes$jscomp$24$$,$attrs$jscomp$183$$,$map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$){$map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$=$APP.$cljs$core$__destructure_map$$($map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$);$map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$,$cljs$cst$5892$selected_inside_layout_QMARK_$$);$map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$=$APP.$cljs$core$truth_$$($map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$)?$APP.$clojure$set$subset_QMARK_$$($APP.$app$common$types$token$spacing_margin_keys$$,$attrs$jscomp$183$$):$map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$;
return $APP.$cljs$core$truth_$$($map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$)?$map__80136__$1_or__5025__auto__$jscomp$1299_p__80135_selected_inside_layout_QMARK_$$:$APP.$cljs$core$some$$(function($is_layout$jscomp$inline_13869_shape$jscomp$1044$$){var $token_type$jscomp$inline_13868$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($is_layout$jscomp$inline_13869_shape$jscomp$1044$$);$is_layout$jscomp$inline_13869_shape$jscomp$1044$$=$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($is_layout$jscomp$inline_13869_shape$jscomp$1044$$);
return $APP.$app$common$data$not_empty_QMARK_$$($APP.$clojure$set$intersection$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$183$$,$APP.$app$common$types$token$shape_type__GT_attributes$$($token_type$jscomp$inline_13868$$,$is_layout$jscomp$inline_13869_shape$jscomp$1044$$)))},$selected_shapes$jscomp$24$$)};
$app$main$ui$workspace$tokens$management$token_tree$token_tree_STAR_$$=function($ordered_nodes_permissions$jscomp$37_props_80154$$){var $active_theme_tokens$jscomp$2$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.activeThemeTokens,$folded_token_paths$jscomp$1$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.foldedTokenPaths,$selected_shapes$jscomp$27$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.selectedShapes,$is_selected_inside_layout$jscomp$4$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.isSelectedInsideLayout,
$on_token_pill_click$jscomp$4$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.onTokenPillClick,$selected_token_set_id$jscomp$3$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.selectedTokenSetId,$type$jscomp$688$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.type,$on_pill_context_menu$jscomp$1$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.onPillContextMenu,$on_node_context_menu$jscomp$1$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.onNodeContextMenu,$tokens_lib$jscomp$43$$=
$ordered_nodes_permissions$jscomp$37_props_80154$$.tokensLib,$tokens$jscomp$55$$=$ordered_nodes_permissions$jscomp$37_props_80154$$.tokens,$raw_tree$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$55$$)],function(){return $app$common$path_names$build_tree_root$$($tokens$jscomp$55$$)});$ordered_nodes_permissions$jscomp$37_props_80154$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$);var $can_edit_QMARK_$jscomp$4$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($ordered_nodes_permissions$jscomp$37_props_80154$$),
$on_node_context_menu__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($on_node_context_menu$jscomp$1$$)],function($event$jscomp$594$$,$node$jscomp$438$$){return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$4$$)?$on_node_context_menu$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?$on_node_context_menu$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$594$$,$node$jscomp$438$$):$on_node_context_menu$jscomp$1$$($event$jscomp$594$$,
$node$jscomp$438$$):null});$ordered_nodes_permissions$jscomp$37_props_80154$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($raw_tree$$)],function(){var $groups$jscomp$20_sorted_groups$jscomp$1_vec__80155$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($g$jscomp$163_p__80158$$,$item$jscomp$142$$){var $l$jscomp$111$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($g$jscomp$163_p__80158$$,0,null);$g$jscomp$163_p__80158$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($g$jscomp$163_p__80158$$,
1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2015$leaf$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$142$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($l$jscomp$111$$,$item$jscomp$142$$),$g$jscomp$163_p__80158$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$l$jscomp$111$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$163_p__80158$$,
$item$jscomp$142$$)],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$raw_tree$$),$leafs$jscomp$1_sorted_leafs$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($groups$jscomp$20_sorted_groups$jscomp$1_vec__80155$$,0,null);$groups$jscomp$20_sorted_groups$jscomp$1_vec__80155$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($groups$jscomp$20_sorted_groups$jscomp$1_vec__80155$$,
1,null);$leafs$jscomp$1_sorted_leafs$jscomp$1$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$725$name$$,$app$common$data$natural_compare$$,$leafs$jscomp$1_sorted_leafs$jscomp$1$$);$groups$jscomp$20_sorted_groups$jscomp$1_vec__80155$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$725$name$$,$app$common$data$natural_compare$$,$groups$jscomp$20_sorted_groups$jscomp$1_vec__80155$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($leafs$jscomp$1_sorted_leafs$jscomp$1$$,
$groups$jscomp$20_sorted_groups$jscomp$1_vec__80155$$)});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_token_tree__token-tree-wrapper",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$200$$,$JSCompiler_temp$jscomp$1869_node$jscomp$439$$){var $JSCompiler_temp_const$jscomp$1867$$=$out_arr__44092__auto__$jscomp$200$$.push;if($APP.$cljs$core$truth_$$($APP.$cljs$cst$2015$leaf$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1869_node$jscomp$439$$))){var $token$jscomp$inline_9141$$=
$APP.$app$common$types$tokens_lib$get_token$$($tokens_lib$jscomp$43$$,$selected_token_set_id$jscomp$3$$,$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1869_node$jscomp$439$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2015$leaf$$,$APP.$cljs$cst$266$id$$],null)));$JSCompiler_temp$jscomp$1869_node$jscomp$439$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_pill$token_pill_STAR_$$,
{token:$token$jscomp$inline_9141$$,selectedShapes:$selected_shapes$jscomp$27$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$4$$,activeThemeTokens:$active_theme_tokens$jscomp$2$$,onClick:$on_token_pill_click$jscomp$4$$,onContextMenu:$on_pill_context_menu$jscomp$1$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2015$leaf$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1869_node$jscomp$439$$)))}else $JSCompiler_temp$jscomp$1869_node$jscomp$439$$=(0,$APP.$rumext$v2$jsx$$)("ul",
{className:"main_ui_workspace_tokens_management_token_tree__node-parent",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_tree$folder_node_STAR_$$,{foldedTokenPaths:$folded_token_paths$jscomp$1$$,tokensLib:$tokens_lib$jscomp$43$$,onPillContextMenu:$on_pill_context_menu$jscomp$1$$,onTokenPillClick:$on_token_pill_click$jscomp$4$$,onNodeContextMenu:$on_node_context_menu__$1$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$4$$,type:$type$jscomp$688$$,activeThemeTokens:$active_theme_tokens$jscomp$2$$,
selectedShapes:$selected_shapes$jscomp$27$$,selectedTokenSetId:$selected_token_set_id$jscomp$3$$,node:$JSCompiler_temp$jscomp$1869_node$jscomp$439$$})},$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1869_node$jscomp$439$$));$JSCompiler_temp_const$jscomp$1867$$.call($out_arr__44092__auto__$jscomp$200$$,$JSCompiler_temp$jscomp$1869_node$jscomp$439$$);return $out_arr__44092__auto__$jscomp$200$$},[],$ordered_nodes_permissions$jscomp$37_props_80154$$)})};
$app$main$ui$workspace$tokens$management$group$token_section_icon$$=function($type$jscomp$689$$){switch($type$jscomp$689$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$689$$.$fqn$:null){case "border-radius":return"corner-radius";case "color":return"drop";case "boolean":return"boolean-difference";case "font-family":return"text-font-family";case "font-size":return"text-font-size";case "letter-spacing":return"text-letterspacing";case "text-case":return"text-mixed";case "text-decoration":return"text-underlined";
case "font-weight":return"text-font-weight";case "typography":return"text-typography";case "opacity":return"percentage";case "number":return"number";case "rotation":return"rotation";case "spacing":return"padding-extended";case "string":return"text-mixed";case "stroke-width":return"stroke-size";case "dimensions":return"expand";case "sizing":return"expand";case "shadow":return"drop-shadow";default:return"add"}};
$app$main$ui$workspace$tokens$management$group$token_group_STAR_$$=function($folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$){var $active_theme_tokens$jscomp$3$$=$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$.activeThemeTokens,$selected_shapes$jscomp$28$$=$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$.selectedShapes,$is_selected_inside_layout$jscomp$5_is_selected_inside_layout__$1$$=$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$.isSelectedInsideLayout,
$selected_token_set_id$jscomp$4$$=$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$.selectedTokenSetId,$type$jscomp$690$$=$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$.type,$selected_ids$jscomp$10$$=$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$.selectedIds,$tokens_lib$jscomp$44$$=$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$.tokensLib,$tokens$jscomp$56$$=$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$.tokens;
$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$type$jscomp$690$$);$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$=$APP.$cljs$core$__destructure_map$$($folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$);var $modal$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$,
$APP.$cljs$cst$4618$modal$$),$title$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$,$APP.$cljs$cst$939$title$$);$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$management$group$ref_COLON_folded_token_paths$$);var $is_type_unfolded_unfolded_token_types_state$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$management$group$ref_COLON_unfolded_token_types$$),
$can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$file$$);$is_type_unfolded_unfolded_token_types_state$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1649$file_id$$.$cljs$core$IFn$_invoke$arity$1$($is_type_unfolded_unfolded_token_types_state$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2654$set_id$$.$cljs$core$IFn$_invoke$arity$1$($is_type_unfolded_unfolded_token_types_state$$),
$selected_token_set_id$jscomp$4$$)&&$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$set$$($APP.$cljs$cst$925$types$$.$cljs$core$IFn$_invoke$arity$1$($is_type_unfolded_unfolded_token_types_state$$)),$type$jscomp$690$$);$can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$);var $edition$jscomp$8_tokens__$1$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$),$objects$jscomp$814_on_pill_context_menu$jscomp$2$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$not_editing_QMARK_$jscomp$1$$=$APP.$cljs$core$empty_QMARK_$$($can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$)&&!($edition$jscomp$8_tokens__$1$jscomp$5$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$814_on_pill_context_menu$jscomp$2$$,$edition$jscomp$8_tokens__$1$jscomp$5$$))));
$can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$);$is_selected_inside_layout$jscomp$5_is_selected_inside_layout__$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($is_selected_inside_layout$jscomp$5_is_selected_inside_layout__$1$$,!1);$edition$jscomp$8_tokens__$1$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$56$$)],function(){return $APP.$cljs$core$vec$$($APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,
$tokens$jscomp$56$$))});var $expandable_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$($edition$jscomp$8_tokens__$1$jscomp$5$$),!1);$objects$jscomp$814_on_pill_context_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_theme_tokens$jscomp$3$$)],function($event$jscomp$595$$,$token$jscomp$167$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$595$$);var $resolved_token$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_tokens$jscomp$3$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$167$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1136$token$$,$APP.$cljs$cst$1681$position$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$595$$),$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$18$$),
$APP.$cljs$cst$2655$token_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$167$$)],null)))});var $on_node_context_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$596$$,$node$jscomp$440$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$596$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_node_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$3817$node$$,$node$jscomp$440$$,$APP.$cljs$cst$139$type$$,$type$jscomp$690$$,$APP.$cljs$cst$1681$position$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$596$$)],null)))}),$on_toggle_open_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$690$$),$APP.$rumext$v2$adapt$$($expandable_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($expandable_QMARK_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$toggle_token_type$$($type$jscomp$690$$)):
null}),$on_popover_open_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$690$$),$APP.$rumext$v2$adapt$$($title$jscomp$52$$),$APP.$rumext$v2$adapt$$($modal$jscomp$3$$)],function($JSCompiler_inline_result$jscomp$1872_event$jscomp$597_pos$jscomp$inline_9143$$){$APP.$app$util$dom$stop_propagation$$($JSCompiler_inline_result$jscomp$1872_event$jscomp$597_pos$jscomp$inline_9143$$);var $JSCompiler_temp_const$jscomp$1870$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;
$JSCompiler_inline_result$jscomp$1872_event$jscomp$597_pos$jscomp$inline_9143$$=$APP.$app$util$dom$get_client_position$$($JSCompiler_inline_result$jscomp$1872_event$jscomp$597_pos$jscomp$inline_9143$$);$JSCompiler_inline_result$jscomp$1872_event$jscomp$597_pos$jscomp$inline_9143$$=$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($modal$jscomp$3$$),new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1872_event$jscomp$597_pos$jscomp$inline_9143$$),
$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1872_event$jscomp$597_pos$jscomp$inline_9143$$),$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$4741$fields$$,$APP.$cljs$cst$4741$fields$$.$cljs$core$IFn$_invoke$arity$1$($modal$jscomp$3$$),$APP.$cljs$cst$939$title$$,$title$jscomp$52$$,$APP.$cljs$cst$2694$action$$,"create",$cljs$cst$5537$token_type$$,$type$jscomp$690$$],null));return $JSCompiler_temp_const$jscomp$1870$$.call($APP.$app$main$store$emit_BANG_$$,
$JSCompiler_inline_result$jscomp$1872_event$jscomp$597_pos$jscomp$inline_9143$$)}),$on_token_pill_click$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($not_editing_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($selected_ids$jscomp$10$$),$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$44$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$4$$)],function($event$jscomp$598$$,$token$jscomp$168_token__$1$jscomp$1$$){$token$jscomp$168_token__$1$jscomp$1$$=$APP.$app$common$types$tokens_lib$get_token$$($tokens_lib$jscomp$44$$,
$selected_token_set_id$jscomp$4$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$168_token__$1$jscomp$1$$));$APP.$app$util$dom$stop_propagation$$($event$jscomp$598$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$168_token__$1$jscomp$1$$),$APP.$cljs$cst$1994$number$$)?$not_editing_QMARK_$jscomp$1$$&&$APP.$cljs$core$seq$$($selected_shapes$jscomp$28$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$toggle_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1136$token$$,$token$jscomp$168_token__$1$jscomp$1$$,$APP.$cljs$cst$4722$shape_ids$$,$selected_ids$jscomp$10$$],null))):$APP.$cljs$core$seq$$($selected_shapes$jscomp$28$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.error-text-edition"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,
$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$2354$warning$$,$APP.$cljs$cst$2364$timeout$$,3E3],null))):null:null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$restore_unfolded_token_types$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"section-"+($APP.$cljs$core$name$$($type$jscomp$690$$)??""),className:"main_ui_workspace_tokens_management_group__token-section-wrapper",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$layers$layer_button$layer_button_STAR_$$,{"aria-expanded":$is_type_unfolded_unfolded_token_types_state$$,isExpandable:$expandable_QMARK_$$,label:$title$jscomp$52$$,children:$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$5_current_file$jscomp$2_editing_ref$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{id:["add-token-button-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($title$jscomp$52$$)].join(""),
icon:"add","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.add-token",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$title$jscomp$52$$])),variant:"ghost",onClick:$on_popover_open_click$$,className:"main_ui_workspace_tokens_management_group__token-section-icon"}):null,onToggleExpand:$on_toggle_open_click$$,"aria-controls":"token-tree-"+($APP.$cljs$core$name$$($type$jscomp$690$$)??""),expanded:$is_type_unfolded_unfolded_token_types_state$$,
description:$APP.$cljs$core$truth_$$($expandable_QMARK_$$)?""+($APP.$cljs$core$count$$($edition$jscomp$8_tokens__$1$jscomp$5$$)??""):null,icon:$app$main$ui$workspace$tokens$management$group$token_section_icon$$($type$jscomp$690$$)}),$is_type_unfolded_unfolded_token_types_state$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_tree$token_tree_STAR_$$,{foldedTokenPaths:$folded_token_paths$jscomp$2_map__80164_map__80164__$1_props_80163$$,tokensLib:$tokens_lib$jscomp$44$$,onPillContextMenu:$objects$jscomp$814_on_pill_context_menu$jscomp$2$$,
onTokenPillClick:$on_token_pill_click$jscomp$5$$,onNodeContextMenu:$on_node_context_menu$jscomp$2$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$5_is_selected_inside_layout__$1$$,type:$type$jscomp$690$$,activeThemeTokens:$active_theme_tokens$jscomp$3$$,selectedShapes:$selected_shapes$jscomp$28$$,selectedTokenSetId:$selected_token_set_id$jscomp$4$$,tokens:$edition$jscomp$8_tokens__$1$jscomp$5$$}):null]})};
$app$main$ui$workspace$tokens$management$node_context_menu$prevent_default$$=function($event$jscomp$599$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$599$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$599$$)};
$app$main$ui$workspace$tokens$management$node_context_menu$token_node_context_menu_STAR_$$=function($dropdown_action_props_80139$$){var $on_delete_node$$=$dropdown_action_props_80139$$.onDeleteNode,$on_duplicate_node$$=$dropdown_action_props_80139$$.onDuplicateNode,$on_rename_node$$=$dropdown_action_props_80139$$.onRenameNode,$mdata$jscomp$24$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$management$node_context_menu$tokens_node_menu_ref$$),$is_open_QMARK_$jscomp$3$$=$APP.$cljs$core$boolean$0$$($mdata$jscomp$24$$),
$dropdown_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)();$dropdown_action_props_80139$$=(0,$APP.$rumext$v2$use_ref$$)();var $dropdown_direction_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("down"),$dropdown_direction$jscomp$2$$=$APP.$cljs$core$_deref$$($dropdown_direction_STAR_$jscomp$2$$),$dropdown_direction_change_STAR_$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(0),$top$jscomp$18$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1516$y$$],null))+5,$left$jscomp$36$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1515$x$$],null))+5,$container$jscomp$94$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5888$popup$$),$rename_node$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mdata$jscomp$24$$),$APP.$rumext$v2$adapt$$($on_rename_node$$)],function(){var $node$jscomp$441$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,$APP.$cljs$cst$3817$node$$),$type$jscomp$691$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$truth_$$($node$jscomp$441$$)?$on_rename_node$$.$cljs$core$IFn$_invoke$arity$2$?
$on_rename_node$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$441$$,$type$jscomp$691$$):$on_rename_node$$($node$jscomp$441$$,$type$jscomp$691$$):null}),$duplicate_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mdata$jscomp$24$$),$APP.$rumext$v2$adapt$$($on_duplicate_node$$)],function(){var $node$jscomp$442$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,$APP.$cljs$cst$3817$node$$),$type$jscomp$692$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,
$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$truth_$$($node$jscomp$442$$)?$on_duplicate_node$$.$cljs$core$IFn$_invoke$arity$2$?$on_duplicate_node$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$442$$,$type$jscomp$692$$):$on_duplicate_node$$($node$jscomp$442$$,$type$jscomp$692$$):null}),$delete_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mdata$jscomp$24$$)],function(){var $node$jscomp$443$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,
$APP.$cljs$cst$3817$node$$),$type$jscomp$693$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($mdata$jscomp$24$$,$APP.$cljs$cst$139$type$$);return $APP.$cljs$core$truth_$$($node$jscomp$443$$)?$on_delete_node$$.$cljs$core$IFn$_invoke$arity$2$?$on_delete_node$$.$cljs$core$IFn$_invoke$arity$2$($node$jscomp$443$$,$type$jscomp$693$$):$on_delete_node$$($node$jscomp$443$$,$type$jscomp$693$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$3$$)],
function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$2$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(!1,$is_open_QMARK_$jscomp$3$$)?($APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$jscomp$2$$,"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$jscomp$2$$,0)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_QMARK_$jscomp$3$$),
$APP.$rumext$v2$adapt$$($dropdown_ref$jscomp$3$$),$APP.$rumext$v2$adapt$$($dropdown_action_props_80139$$)],function(){var $dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$3$$),$and__5023__auto__$jscomp$inline_9145$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$2$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9145$$?$dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$:
$and__5023__auto__$jscomp$inline_9145$$)?($dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$=$APP.$app$util$dom$is_element_outside_QMARK_$$($dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$),$APP.$cljs$core$reset_BANG_$$($dropdown_direction_STAR_$jscomp$2$$,$dropdown_element$jscomp$2_is_outside_QMARK_$jscomp$2$$?"up":"down"),$APP.$rumext$v2$set_ref_val_BANG_$$($dropdown_direction_change_STAR_$jscomp$2$$,$APP.$rumext$v2$ref_val$$($dropdown_direction_change_STAR_$jscomp$2$$)+1)):null});return $is_open_QMARK_$jscomp$3$$?
(0,$APP.$rumext$v2$portal$$)($APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$is_open_QMARK_$jscomp$3$$,"on-close":function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_node_context_menu$$(null))},children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"tokens-context-menu-for-token-node",ref:$dropdown_ref$jscomp$3$$,"data-direction":$dropdown_direction$jscomp$2$$,style:{"--bottom":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dropdown_direction$jscomp$2$$,
"up")?"40px":"unset","--top":""+($top$jscomp$18$$??"")+"px",left:""+($left$jscomp$36$$??"")+"px"},onContextMenu:$app$main$ui$workspace$tokens$management$node_context_menu$prevent_default$$,className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu",children:$APP.$cljs$core$truth_$$($mdata$jscomp$24$$)?(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-list",children:[(0,$APP.$rumext$v2$jsx$$)("li",
{className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-listitem",children:(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",onClick:$rename_node$$,className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename")})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-listitem",children:(0,$APP.$rumext$v2$jsx$$)("button",
{type:"button",onClick:$duplicate_node$$,className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.duplicate")})}),(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-listitem",children:(0,$APP.$rumext$v2$jsx$$)("button",{type:"button",onClick:$delete_node$$,className:"main_ui_workspace_tokens_management_node_context_menu__token-node-context-menu-action",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")})})]}):null})}),$container$jscomp$94$$):null};
$app$main$ui$workspace$tokens$management$selected_set_info_STAR_$$=function($props_80184$$){var $selected_token_set_id$jscomp$5$$=$props_80184$$.selectedTokenSetId,$tokens_lib$jscomp$45$$=$props_80184$$.tokensLib,$selected_token_set$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$45$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$5$$)],function(){return $APP.$cljs$core$truth_$$($selected_token_set_id$jscomp$5$$)?$tokens_lib$jscomp$45$$==
null?null:$APP.$app$common$types$tokens_lib$get_set$$($tokens_lib$jscomp$45$$,$selected_token_set_id$jscomp$5$$):null}),$active_token_sets_names$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$45$$)],function(){return $tokens_lib$jscomp$45$$==null?null:$APP.$app$common$types$tokens_lib$get_active_themes_set_names$$($tokens_lib$jscomp$45$$)}),$token_set_active_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_token_sets_names$$)],
function($name$jscomp$469$$){return $APP.$cljs$core$contains_QMARK_$$($active_token_sets_names$$,$name$jscomp$469$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management__sets-header-container",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"headline-small",className:"main_ui_workspace_tokens_management__sets-header","data-testid":"active-token-set-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.tokens-section-title",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$tokens_lib$get_name$$($selected_token_set$$)]))}),$selected_token_set_id$jscomp$5$$!=null&&$APP.$cljs$core$not$$(function(){var $G__80188$$=$APP.$app$common$types$tokens_lib$get_name$$($selected_token_set$$);return $token_set_active_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$token_set_active_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__80188$$):$token_set_active_QMARK_$$($G__80188$$)}())?(0,$APP.$rumext$v2$jsx$$)("div",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.inactive-set-description"),className:"main_ui_workspace_tokens_management__sets-header-status",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{className:"main_ui_workspace_tokens_management__sets-header-status-icon",iconId:"eye-off"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_management__sets-header-status-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.inactive-set")})]})}):null]})};
$app$main$ui$workspace$tokens$management$tokens_section_STAR_$$=function($empty_group_props_80195$$){function $on_duplicate_node$jscomp$1$$($node$jscomp$450$$,$type$jscomp$702$$,$new_node_name$jscomp$6$$){var $G__80215$jscomp$inline_9149_tokens_in_path_ids$jscomp$4$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$450$$);$G__80215$jscomp$inline_9149_tokens_in_path_ids$jscomp$4$$=$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$702$$,
$G__80215$jscomp$inline_9149_tokens_in_path_ids$jscomp$4$$):$filter_tokens_by_path_ids$$($type$jscomp$702$$,$G__80215$jscomp$inline_9149_tokens_in_path_ids$jscomp$4$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$bulk_create_tokens$$($selected_token_set_id$jscomp$6$$,$G__80215$jscomp$inline_9149_tokens_in_path_ids$jscomp$4$$,
$type$jscomp$702$$,$node$jscomp$450$$,$new_node_name$jscomp$6$$)]))}var $resolved_active_tokens$jscomp$1$$=$empty_group_props_80195$$.resolvedActiveTokens,$active_tokens$jscomp$9$$=$empty_group_props_80195$$.activeTokens,$tokens_lib$jscomp$46$$=$empty_group_props_80195$$.tokensLib,$objects$jscomp$815$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),$selected$jscomp$183$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$),$selected_shapes$jscomp$29$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$183$$),
$APP.$rumext$v2$adapt$$($objects$jscomp$815$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$815$$)),$selected$jscomp$183$$)}),$is_selected_inside_layout$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$29$$),$APP.$rumext$v2$adapt$$($objects$jscomp$815$$)],
function(){return $APP.$cljs$core$some$$(function($p1__80189_SHARP_$$){return $APP.$app$common$types$shape$layout$any_layout_immediate_child_QMARK_$$($objects$jscomp$815$$,$p1__80189_SHARP_$$)},$selected_shapes$jscomp$29$$)}),$selected_token_set_id$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$selected_token_set_tokens$$=$APP.$cljs$core$truth_$$($selected_token_set_id$jscomp$6$$)?$tokens_lib$jscomp$46$$==null?null:$APP.$app$common$types$tokens_lib$get_tokens$$($tokens_lib$jscomp$46$$,
$selected_token_set_id$jscomp$6$$):null,$tokens$jscomp$57$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$9$$),$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$)],function(){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$active_tokens$jscomp$9$$,$selected_token_set_tokens$$]))}),$tokens_by_type$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens$jscomp$57$$),
$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$)],function(){var $tokens__$1$jscomp$6$$=$APP.$cljs$core$reduce_kv$$(function($tokens__$1$jscomp$7$$,$k$jscomp$698$$){return $APP.$cljs$core$contains_QMARK_$$($selected_token_set_tokens$$,$k$jscomp$698$$)?$tokens__$1$jscomp$7$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens__$1$jscomp$7$$,$k$jscomp$698$$)},$tokens$jscomp$57$$,$tokens$jscomp$57$$);return $app$common$types$tokens_lib$group_by_type$$($tokens__$1$jscomp$6$$)}),$filled_group_vec__80197$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_by_type$jscomp$1$$)],function(){a:{var $G__80220$jscomp$inline_13907_G__80223$jscomp$inline_13910_all_types$jscomp$inline_13899_types$jscomp$inline_13902$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1191$token_shadow$$)?$APP.$app$main$data$workspace$tokens$application$token_properties$$:$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,
$APP.$cljs$cst$1659$shadow$$),$G__80218$jscomp$inline_13905_G__80221$jscomp$inline_13908_a$jscomp$inline_14922_empty$jscomp$inline_13900$$=[];var $G__80219$jscomp$inline_13906_G__80222$jscomp$inline_13909_JSCompiler_inline_result$jscomp$11307_a$jscomp$inline_14919_filled$jscomp$inline_13901$$=[];for($G__80220$jscomp$inline_13907_G__80223$jscomp$inline_13910_all_types$jscomp$inline_13899_types$jscomp$inline_13902$$=$APP.$cljs$core$seq$$($APP.$cljs$core$keys$$($G__80220$jscomp$inline_13907_G__80223$jscomp$inline_13910_all_types$jscomp$inline_13899_types$jscomp$inline_13902$$));;){var $temp__5823__auto__$jscomp$inline_13903_type$jscomp$inline_13904$$=
$APP.$cljs$core$first$$($G__80220$jscomp$inline_13907_G__80223$jscomp$inline_13910_all_types$jscomp$inline_13899_types$jscomp$inline_13902$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$inline_13903_type$jscomp$inline_13904$$))$APP.$cljs$core$truth_$$($APP.$cljs$core$not_empty$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type$jscomp$1$$,$temp__5823__auto__$jscomp$inline_13903_type$jscomp$inline_13904$$)))?($G__80219$jscomp$inline_13906_G__80222$jscomp$inline_13909_JSCompiler_inline_result$jscomp$11307_a$jscomp$inline_14919_filled$jscomp$inline_13901$$.push($temp__5823__auto__$jscomp$inline_13903_type$jscomp$inline_13904$$),
$G__80220$jscomp$inline_13907_G__80223$jscomp$inline_13910_all_types$jscomp$inline_13899_types$jscomp$inline_13902$$=$APP.$cljs$core$rest$$($G__80220$jscomp$inline_13907_G__80223$jscomp$inline_13910_all_types$jscomp$inline_13899_types$jscomp$inline_13902$$)):($G__80218$jscomp$inline_13905_G__80221$jscomp$inline_13908_a$jscomp$inline_14922_empty$jscomp$inline_13900$$.push($temp__5823__auto__$jscomp$inline_13903_type$jscomp$inline_13904$$),$G__80220$jscomp$inline_13907_G__80223$jscomp$inline_13910_all_types$jscomp$inline_13899_types$jscomp$inline_13902$$=
$APP.$cljs$core$rest$$($G__80220$jscomp$inline_13907_G__80223$jscomp$inline_13910_all_types$jscomp$inline_13899_types$jscomp$inline_13902$$));else{$G__80219$jscomp$inline_13906_G__80222$jscomp$inline_13909_JSCompiler_inline_result$jscomp$11307_a$jscomp$inline_14919_filled$jscomp$inline_13901$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$seq$$($app$util$array$sort_BANG_$$($G__80218$jscomp$inline_13905_G__80221$jscomp$inline_13908_a$jscomp$inline_14922_empty$jscomp$inline_13900$$)),
$APP.$cljs$core$seq$$($app$util$array$sort_BANG_$$($G__80219$jscomp$inline_13906_G__80222$jscomp$inline_13909_JSCompiler_inline_result$jscomp$11307_a$jscomp$inline_14919_filled$jscomp$inline_13901$$))],null);break a}}$G__80219$jscomp$inline_13906_G__80222$jscomp$inline_13909_JSCompiler_inline_result$jscomp$11307_a$jscomp$inline_14919_filled$jscomp$inline_13901$$=void 0}return $G__80219$jscomp$inline_13906_G__80222$jscomp$inline_13909_JSCompiler_inline_result$jscomp$11307_a$jscomp$inline_14919_filled$jscomp$inline_13901$$});
$empty_group_props_80195$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filled_group_vec__80197$$,0,null);$filled_group_vec__80197$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filled_group_vec__80197$$,1,null);var $filter_tokens_by_path$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($tokens_filtered_by_type$$,$node$jscomp$444$$){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$169$$){var $token_path$jscomp$1$$=
$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$169$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,"."]));return $APP.$cljs$core$count$$($token_path$jscomp$1$$)>0&&$APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$169$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$444$$)),
"."].join(""))},$tokens_filtered_by_type$$)}),$filter_tokens_by_path_ids$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$)],function($type$jscomp$695$$,$path$jscomp$280$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$170_token_value$jscomp$8$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token$jscomp$170_token_value$jscomp$8$$,0,null);$token$jscomp$170_token_value$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token$jscomp$170_token_value$jscomp$8$$,
1,null);return $APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$170_token_value$jscomp$8$$)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$171_token_value$jscomp$9$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token$jscomp$171_token_value$jscomp$9$$,0,null);$token$jscomp$171_token_value$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($token$jscomp$171_token_value$jscomp$9$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$171_token_value$jscomp$9$$),
$type$jscomp$695$$)&&$APP.$cuerdas$core$starts_with_QMARK_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$171_token_value$jscomp$9$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$280$$),"."].join(""))},$selected_token_set_tokens$$))}),$remaining_tokens_of_type_in_set_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($remaining_tokens_selected_token_set_tokens__$1$$,$tokens_in_path_ids$$){var $token_ids$jscomp$6$$=$APP.$cljs$core$set$$($tokens_in_path_ids$$);
$remaining_tokens_selected_token_set_tokens__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$172$$){return!$APP.$cljs$core$contains_QMARK_$$($token_ids$jscomp$6$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$172$$))},$remaining_tokens_selected_token_set_tokens__$1$$);return $APP.$cljs$core$seq$$($remaining_tokens_selected_token_set_tokens__$1$$)}),$delete_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),
$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],function(){return function($path$jscomp$281_token$jscomp$173$$){var $id$jscomp$1008$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$281_token$jscomp$173$$),$type$jscomp$696$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$281_token$jscomp$173$$);$path$jscomp$281_token$jscomp$173$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$281_token$jscomp$173$$);var $remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$=
$app$common$types$tokens_lib$group_by_type$$($selected_token_set_tokens$$);$remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$,$type$jscomp$696$$);var $G__80208$jscomp$inline_9147$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1008$$],null);$remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$=
$remaining_tokens_of_type_in_set_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$remaining_tokens_of_type_in_set_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$,$G__80208$jscomp$inline_9147$$):$remaining_tokens_of_type_in_set_QMARK_$$($remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$,$G__80208$jscomp$inline_9147$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token$$($selected_token_set_id$jscomp$6$$,
$id$jscomp$1008$$));return $APP.$cljs$core$truth_$$($remaining_tokens_QMARK__tokens_by_type__$1_tokens_filtered_by_type$jscomp$1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($type$jscomp$696$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$281_token$jscomp$173$$)].join(""))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$close_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$($type$jscomp$696$$))}}),
$delete_node$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],function(){return function($node$jscomp$445_path$jscomp$282$$,$type$jscomp$697$$){$node$jscomp$445_path$jscomp$282$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$445_path$jscomp$282$$);var $tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$=$app$common$types$tokens_lib$group_by_type$$($selected_token_set_tokens$$),
$remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$,$type$jscomp$697$$);$tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$=$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$697$$,$node$jscomp$445_path$jscomp$282$$):$filter_tokens_by_path_ids$$($type$jscomp$697$$,$node$jscomp$445_path$jscomp$282$$);
$remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$=$remaining_tokens_of_type_in_set_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$remaining_tokens_of_type_in_set_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$,$tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$):$remaining_tokens_of_type_in_set_QMARK_$$($remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$,$tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$bulk_delete_tokens$$($selected_token_set_id$jscomp$6$$,$tokens_by_type__$1$jscomp$1_tokens_in_path_ids$jscomp$1$$));return $APP.$cljs$core$truth_$$($remaining_tokens_QMARK_$jscomp$1_tokens_filtered_by_type$jscomp$2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$([$APP.$cljs$core$name$$($type$jscomp$697$$),
".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$445_path$jscomp$282$$)].join(""))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$close_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$($type$jscomp$697$$))}}),$bulk_rename_tokens_in_path$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filter_tokens_by_path_ids$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],function($new_path$jscomp$3_node$jscomp$446$$,
$type$jscomp$698$$,$new_node_name$jscomp$2_tokens_in_path_ids$jscomp$2$$){var $old_path$jscomp$3$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($new_path$jscomp$3_node$jscomp$446$$);$new_path$jscomp$3_node$jscomp$446$$=$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$($new_path$jscomp$3_node$jscomp$446$$,null,$new_node_name$jscomp$2_tokens_in_path_ids$jscomp$2$$);$new_node_name$jscomp$2_tokens_in_path_ids$jscomp$2$$=$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$?
$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$698$$,$old_path$jscomp$3$$):$filter_tokens_by_path_ids$$($type$jscomp$698$$,$old_path$jscomp$3$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$bulk_update_tokens$$($selected_token_set_id$jscomp$6$$,$new_node_name$jscomp$2_tokens_in_path_ids$jscomp$2$$,
$type$jscomp$698$$,$old_path$jscomp$3$$,$new_path$jscomp$3_node$jscomp$446$$)]))}),$bulk_remap_tokens_in_path$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filter_tokens_by_path$$),$APP.$rumext$v2$adapt$$($filter_tokens_by_path_ids$$),$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],function($node$jscomp$447$$,$type$jscomp$699$$,$new_node_name$jscomp$3$$){var $old_path$jscomp$4$$=$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$447$$),
$tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$=$app$common$types$tokens_lib$group_by_type$$($selected_token_set_tokens$$);$tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$,$type$jscomp$699$$);$tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$=
$filter_tokens_by_path$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$,$node$jscomp$447$$):$filter_tokens_by_path$$($tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$,$node$jscomp$447$$);var $tokens_in_path_ids$jscomp$3$$=$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path_ids$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$699$$,
$old_path$jscomp$4$$):$filter_tokens_by_path_ids$$($type$jscomp$699$$,$old_path$jscomp$4$$),$new_node_path$$=$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$447$$,null,$new_node_name$jscomp$3$$),$new_tokens$jscomp$3$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($token$jscomp$174$$){var $new_token_path$jscomp$1$$=$app$common$types$tokens_lib$rename_path$cljs$0core$0IFn$0_invoke$0arity$03$$($node$jscomp$447$$,$token$jscomp$174$$,$new_node_name$jscomp$3$$);
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($token$jscomp$174$$,$APP.$cljs$cst$725$name$$,$new_token_path$jscomp$1$$)},$tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$),$undo_group$jscomp$49$$=$APP.$app$common$uuid$next$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$bulk_update_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($selected_token_set_id$jscomp$6$$,
$tokens_in_path_ids$jscomp$3$$,$type$jscomp$699$$,$old_path$jscomp$4$$,$new_node_path$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3162$undo_group$$,$undo_group$jscomp$49$$])),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$remapping$bulk_remap_tokens$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($tokens_by_type__$1$jscomp$2_tokens_filtered_by_type$jscomp$3_tokens_in_path$jscomp$2$$,$new_tokens$jscomp$3$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3162$undo_group$$,
$undo_group$jscomp$49$$])),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$(),$APP.$app$main$data$modal$hide$$()]))}),$on_remap_node_warning$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($bulk_remap_tokens_in_path$$),$APP.$rumext$v2$adapt$$($bulk_rename_tokens_in_path$$)],function($node$jscomp$448$$,$type$jscomp$700$$,$new_node_name$jscomp$4$$){var $remap_data$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5867$new_name$$,
$new_node_name$jscomp$4$$,$cljs$cst$5866$old_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$448$$),$APP.$cljs$cst$139$type$$,"node"],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5899$tokens_SLASH_remapping_confirmation$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$cljs$cst$5900$remap_data$$,$remap_data$$,$cljs$cst$5901$on_remap$$,function(){return $bulk_remap_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$?$bulk_remap_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$448$$,$type$jscomp$700$$,$new_node_name$jscomp$4$$):$bulk_remap_tokens_in_path$$($node$jscomp$448$$,$type$jscomp$700$$,$new_node_name$jscomp$4$$)},$cljs$cst$5902$on_rename$$,function(){return $bulk_rename_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$?$bulk_rename_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$448$$,
$type$jscomp$700$$,$new_node_name$jscomp$4$$):$bulk_rename_tokens_in_path$$($node$jscomp$448$$,$type$jscomp$700$$,$new_node_name$jscomp$4$$)}],null))]))}),$on_rename_node$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),$APP.$rumext$v2$adapt$$($filter_tokens_by_path$$),$APP.$rumext$v2$adapt$$($on_remap_node_warning$$),$APP.$rumext$v2$adapt$$($bulk_rename_tokens_in_path$$)],function($node$jscomp$449$$,$type$jscomp$701$$,$new_node_name$jscomp$5$$){var $state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$=
$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file_data$jscomp$121$$=$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$);$state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$=$app$common$types$tokens_lib$group_by_type$$($selected_token_set_tokens$$);$state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$,$type$jscomp$701$$);$state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$=$filter_tokens_by_path$$.$cljs$core$IFn$_invoke$arity$2$?$filter_tokens_by_path$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$,
$node$jscomp$449$$):$filter_tokens_by_path$$($state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$,$node$jscomp$449$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($count$jscomp$70$$,$token$jscomp$175$$){return $count$jscomp$70$$+$app$main$data$workspace$tokens$remapping$count_token_references$$($file_data$jscomp$121$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$175$$))},0,$state$jscomp$1217_tokens_by_type__$1$jscomp$3_tokens_filtered_by_type$jscomp$4_tokens_in_current_path$$)>
0?$on_remap_node_warning$$.$cljs$core$IFn$_invoke$arity$3$?$on_remap_node_warning$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$449$$,$type$jscomp$701$$,$new_node_name$jscomp$5$$):$on_remap_node_warning$$($node$jscomp$449$$,$type$jscomp$701$$,$new_node_name$jscomp$5$$):$bulk_rename_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$?$bulk_rename_tokens_in_path$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$449$$,$type$jscomp$701$$,$new_node_name$jscomp$5$$):$bulk_rename_tokens_in_path$$($node$jscomp$449$$,
$type$jscomp$701$$,$new_node_name$jscomp$5$$)}),$open_rename_node_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),$APP.$rumext$v2$adapt$$($on_rename_node$jscomp$1$$)],function($node$jscomp$451$$,$type$jscomp$703$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5903$tokens_SLASH_rename_node$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$3817$node$$,$node$jscomp$451$$,$cljs$cst$5904$tokens_in_active_set$$,$selected_token_set_tokens$$,$cljs$cst$5902$on_rename$$,function($p1__80192_SHARP_$$){return $on_rename_node$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$on_rename_node$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($node$jscomp$451$$,$type$jscomp$703$$,$p1__80192_SHARP_$$):$on_rename_node$jscomp$1$$($node$jscomp$451$$,$type$jscomp$703$$,$p1__80192_SHARP_$$)}],null)))}),$open_duplicate_node_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_tokens$$),
$APP.$rumext$v2$adapt$$($on_duplicate_node$jscomp$1$$)],function($node$jscomp$452$$,$type$jscomp$704$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5903$tokens_SLASH_rename_node$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5905$new_node_name$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$452$$)),
"-copy"].join(""),$APP.$cljs$cst$3817$node$$,$node$jscomp$452$$,$APP.$cljs$cst$2010$variant$$,"duplicate",$cljs$cst$5904$tokens_in_active_set$$,$selected_token_set_tokens$$,$cljs$cst$5902$on_rename$$,function($p1__80193_SHARP_$$){return $on_duplicate_node$jscomp$1$$($node$jscomp$452$$,$type$jscomp$704$$,$p1__80193_SHARP_$$)}],null)))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$46$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$6$$)],
function(){var $JSCompiler_inline_result$jscomp$1874_match$jscomp$59_or__5025__auto__$jscomp$inline_9151$$=$APP.$cljs$core$truth_$$($tokens_lib$jscomp$46$$)?($JSCompiler_inline_result$jscomp$1874_match$jscomp$59_or__5025__auto__$jscomp$inline_9151$$=$selected_token_set_id$jscomp$6$$==null)?$JSCompiler_inline_result$jscomp$1874_match$jscomp$59_or__5025__auto__$jscomp$inline_9151$$:$APP.$cljs$core$truth_$$($selected_token_set_id$jscomp$6$$)?$APP.$cljs$core$not$$($APP.$app$common$types$tokens_lib$get_set$$($tokens_lib$jscomp$46$$,
$selected_token_set_id$jscomp$6$$)):$selected_token_set_id$jscomp$6$$:$tokens_lib$jscomp$46$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1874_match$jscomp$59_or__5025__auto__$jscomp$inline_9151$$)?($JSCompiler_inline_result$jscomp$1874_match$jscomp$59_or__5025__auto__$jscomp$inline_9151$$=$APP.$cljs$core$first$$($APP.$app$common$types$tokens_lib$get_sets$$($tokens_lib$jscomp$46$$)),$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1874_match$jscomp$59_or__5025__auto__$jscomp$inline_9151$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($APP.$app$common$types$tokens_lib$get_id$$($JSCompiler_inline_result$jscomp$1874_match$jscomp$59_or__5025__auto__$jscomp$inline_9151$$))):null):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$context_menu$token_context_menu$$,{"on-delete-token":$delete_token$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$node_context_menu$token_node_context_menu_STAR_$$,{onRenameNode:$open_rename_node_modal$$,onDuplicateNode:$open_duplicate_node_modal$$,onDeleteNode:$delete_node$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$selected_set_info_STAR_$$,{tokensLib:$tokens_lib$jscomp$46$$,selectedTokenSetId:$selected_token_set_id$jscomp$6$$}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$201$$,
$JSCompiler_inline_result$jscomp$1877_type$jscomp$705$$){var $JSCompiler_temp_const$jscomp$1875$$=$out_arr__44092__auto__$jscomp$201$$.push,$tokens__$1$jscomp$inline_9153$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($tokens_by_type$jscomp$1$$,$JSCompiler_inline_result$jscomp$1877_type$jscomp$705$$);$JSCompiler_inline_result$jscomp$1877_type$jscomp$705$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$group$token_group_STAR_$$,{isSelectedInsideLayout:$is_selected_inside_layout$jscomp$6$$,
type:$JSCompiler_inline_result$jscomp$1877_type$jscomp$705$$,selectedTokenSetId:$selected_token_set_id$jscomp$6$$,selectedIds:$selected$jscomp$183$$,tokensLib:$tokens_lib$jscomp$46$$,tokens:$tokens__$1$jscomp$inline_9153$$,activeThemeTokens:$resolved_active_tokens$jscomp$1$$,selectedShapes:$selected_shapes$jscomp$29$$},$APP.$cljs$core$name$$($JSCompiler_inline_result$jscomp$1877_type$jscomp$705$$));$JSCompiler_temp_const$jscomp$1875$$.call($out_arr__44092__auto__$jscomp$201$$,$JSCompiler_inline_result$jscomp$1877_type$jscomp$705$$);
return $out_arr__44092__auto__$jscomp$201$$},[],$filled_group_vec__80197$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$202$$,$type$jscomp$706$$){$out_arr__44092__auto__$jscomp$202$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$group$token_group_STAR_$$,{tokens:$APP.$cljs$core$PersistentVector$EMPTY$$,type:$type$jscomp$706$$,selectedShapes:$selected_shapes$jscomp$29$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$6$$,
activeThemeTokens:$resolved_active_tokens$jscomp$1$$},$APP.$cljs$core$name$$($type$jscomp$706$$)));return $out_arr__44092__auto__$jscomp$202$$},[],$empty_group_props_80195$$)]})};
$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set$$=function($errors$jscomp$35_tokens_lib$jscomp$47$$,$token_set$jscomp$20$$,$name$jscomp$470_name__$1$jscomp$23$$){$name$jscomp$470_name__$1$jscomp$23$$=$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$470_name__$1$jscomp$23$$,$APP.$app$common$types$tokens_lib$get_name$$($token_set$jscomp$20$$));$errors$jscomp$35_tokens_lib$jscomp$47$$=$app$common$schema$validation_errors$$($name$jscomp$470_name__$1$jscomp$23$$,
$APP.$app$common$files$tokens$make_token_set_name_schema$$($errors$jscomp$35_tokens_lib$jscomp$47$$,$APP.$app$common$types$tokens_lib$get_id$$($token_set$jscomp$20$$)));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$());return $APP.$cljs$core$empty_QMARK_$$($errors$jscomp$35_tokens_lib$jscomp$47$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$rename_token_set$$($token_set$jscomp$20$$,
$name$jscomp$470_name__$1$jscomp$23$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.token-set-already-exists"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2364$timeout$$,9E3],null)))};
$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set_group$$=function($path$jscomp$283$$,$name$jscomp$471$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$rename_token_set_group$$($path$jscomp$283$$,$name$jscomp$471$$)]))};
$app$main$ui$workspace$tokens$sets$helpers$on_create_token_set$$=function($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$48$$,$parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9157$$,$name$jscomp$472_name__$1$jscomp$24$$){$parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9157$$=$APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$tokens_lib$get_name$$($parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9157$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,
"/"]));$name$jscomp$472_name__$1$jscomp$24$$=$APP.$cljs$core$truth_$$($parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9157$$)?$APP.$app$common$types$tokens_lib$join_set_path$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($parent_set$jscomp$1_temp__5823__auto__$jscomp$inline_9157$$,$APP.$app$common$types$tokens_lib$split_set_name$$($name$jscomp$472_name__$1$jscomp$24$$))):$APP.$app$common$types$tokens_lib$normalize_set_name$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$472_name__$1$jscomp$24$$);
$errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$48$$=$app$common$schema$validation_errors$$($name$jscomp$472_name__$1$jscomp$24$$,$APP.$app$common$files$tokens$make_token_set_name_schema$$($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$48$$,null));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-token-set",
$APP.$cljs$cst$725$name$$,$name$jscomp$472_name__$1$jscomp$24$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$clear_token_set_creation$$()]));return $APP.$cljs$core$empty_QMARK_$$($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$48$$)?($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$48$$=$APP.$app$common$types$tokens_lib$make_token_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,
$name$jscomp$472_name__$1$jscomp$24$$])),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$tokens$library_edit$create_token_set$$($errors$jscomp$36_token_set$jscomp$21_tokens_lib$jscomp$48$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$clear_tokens_paths$$(),$app$main$data$workspace$tokens$library_edit$clear_tokens_types$$()]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.token-set-already-exists"),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$,$APP.$cljs$cst$2364$timeout$$,9E3],null)))};$app$main$ui$workspace$tokens$sets$lists$on_start_creation$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$start_token_set_creation$$($APP.$cljs$core$PersistentVector$EMPTY$$))};
$app$main$ui$workspace$tokens$sets$lists$editing_label_STAR_$$=function($on_key_down$jscomp$22_props_80165$$){var $on_cancel$jscomp$8$$=$on_key_down$jscomp$22_props_80165$$.onCancel,$default_value$jscomp$6$$=$on_key_down$jscomp$22_props_80165$$.defaultValue,$on_submit$jscomp$17$$=$on_key_down$jscomp$22_props_80165$$.onSubmit,$on_submit__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel$jscomp$8$$),$APP.$rumext$v2$adapt$$($on_submit$jscomp$17$$),$APP.$rumext$v2$adapt$$($default_value$jscomp$6$$)],
function($event$jscomp$600_value$jscomp$948$$){$event$jscomp$600_value$jscomp$948$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$600_value$jscomp$948$$);return $APP.$cuerdas$core$empty_QMARK_$$($event$jscomp$600_value$jscomp$948$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$600_value$jscomp$948$$,$default_value$jscomp$6$$)?$on_cancel$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$jscomp$8$$():$on_submit$jscomp$17$$.$cljs$core$IFn$_invoke$arity$1$?
$on_submit$jscomp$17$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$600_value$jscomp$948$$):$on_submit$jscomp$17$$($event$jscomp$600_value$jscomp$948$$)});$on_key_down$jscomp$22_props_80165$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_submit__$1$$),$APP.$rumext$v2$adapt$$($on_cancel$jscomp$8$$)],function($event$jscomp$601$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$601$$))?$on_submit__$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_submit__$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$601$$):$on_submit__$1$$($event$jscomp$601$$):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$601$$))?$on_cancel$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$?$on_cancel$jscomp$8$$.$cljs$core$IFn$_invoke$arity$0$():$on_cancel$jscomp$8$$():null});return(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",onBlur:$on_submit__$1$$,onKeyDown:$on_key_down$jscomp$22_props_80165$$,maxLength:"256",autoFocus:!0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.set-edit-placeholder"),
defaultValue:$default_value$jscomp$6$$,className:"main_ui_workspace_tokens_sets_lists__editing-node"})};
$app$main$ui$workspace$tokens$sets$lists$checkbox_STAR_$$=function($checked$jscomp$2_props_80166$$){var $aria_label$jscomp$10$$=$checked$jscomp$2_props_80166$$["aria-label"],$disabled$jscomp$20$$=$checked$jscomp$2_props_80166$$.disabled,$on_click$jscomp$52$$=$checked$jscomp$2_props_80166$$.onClick;$checked$jscomp$2_props_80166$$=$checked$jscomp$2_props_80166$$.checked;var $all_QMARK__checked_QMARK_$jscomp$7$$=$checked$jscomp$2_props_80166$$===!0,$mixed_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($checked$jscomp$2_props_80166$$,
"mixed");$all_QMARK__checked_QMARK_$jscomp$7$$=$all_QMARK__checked_QMARK_$jscomp$7$$||$mixed_QMARK_$$;return(0,$APP.$rumext$v2$jsx$$)("div",{role:"checkbox","aria-checked":""+($checked$jscomp$2_props_80166$$??""),disabled:$disabled$jscomp$20$$,title:$APP.$cljs$core$truth_$$($disabled$jscomp$20$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-permisions-set"):null,tabIndex:0,onClick:$APP.$cljs$core$truth_$$($disabled$jscomp$20$$)?null:$on_click$jscomp$52$$,className:"main_ui_workspace_tokens_sets_lists__checkbox-style "+
($all_QMARK__checked_QMARK_$jscomp$7$$?"main_ui_workspace_tokens_sets_lists__checkbox-checked-style":"")+" "+($APP.$cljs$core$truth_$$($all_QMARK__checked_QMARK_$jscomp$7$$?$disabled$jscomp$20$$:$all_QMARK__checked_QMARK_$jscomp$7$$)?"main_ui_workspace_tokens_sets_lists__checkbox-disabled-checked":"")+" "+($APP.$cljs$core$truth_$$($disabled$jscomp$20$$)?"main_ui_workspace_tokens_sets_lists__checkbox-disabled":""),children:$all_QMARK__checked_QMARK_$jscomp$7$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{"aria-label":$aria_label$jscomp$10$$,className:"main_ui_workspace_tokens_sets_lists__check-icon",size:"s",iconId:$mixed_QMARK_$$?"remove":"tick"}):null})};
$app$main$ui$workspace$tokens$sets$lists$inline_add_button_STAR_$$=function(){var $can_edit_QMARK_$jscomp$6$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$);return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$6$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_sets_lists__empty-sets-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_sets_lists__empty-state-message",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-sets-yet")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$app$main$ui$workspace$tokens$sets$lists$on_start_creation$$,className:"main_ui_workspace_tokens_sets_lists__create-set-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.create-one")})]}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sets_lists__empty-sets-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_sets_lists__empty-state-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-sets-yet")})})};$app$main$ui$workspace$tokens$sets$lists$add_button_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",icon:"add",onClick:$app$main$ui$workspace$tokens$sets$lists$on_start_creation$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add set")})};
$app$main$ui$workspace$tokens$sets$lists$sets_tree_set_group_STAR_$$=function($depth$jscomp$18_props_80170$$){var $path$jscomp$284$$=$depth$jscomp$18_props_80170$$.path,$index$jscomp$548$$=$depth$jscomp$18_props_80170$$.index,$on_edit_submit$$=$depth$jscomp$18_props_80170$$.onEditSubmit,$is_selected$jscomp$7$$=$depth$jscomp$18_props_80170$$.isSelected,$on_toggle$jscomp$2$$=$depth$jscomp$18_props_80170$$.onToggle,$is_collapsed$$=$depth$jscomp$18_props_80170$$.isCollapsed,$on_drop$jscomp$16$$=$depth$jscomp$18_props_80170$$.onDrop,
$dprops$jscomp$9_is_draggable$$=$depth$jscomp$18_props_80170$$.isDraggable,$is_active$jscomp$4$$=$depth$jscomp$18_props_80170$$.isActive,$on_toggle_collapse$jscomp$1$$=$depth$jscomp$18_props_80170$$.onToggleCollapse,$on_start_edition$$=$depth$jscomp$18_props_80170$$.onStartEdition,$is_editing$jscomp$4$$=$depth$jscomp$18_props_80170$$.isEditing,$label$jscomp$59$$=$depth$jscomp$18_props_80170$$.label,$id$jscomp$1009$$=$depth$jscomp$18_props_80170$$.id,$on_reset_edition$$=$depth$jscomp$18_props_80170$$.onResetEdition;
$depth$jscomp$18_props_80170$$=$depth$jscomp$18_props_80170$$.depth;var $can_edit_QMARK_$jscomp$7$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$label_id$$=[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1009$$),"-label"].join(""),$on_context_menu$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$4$$),$APP.$rumext$v2$adapt$$($id$jscomp$1009$$),$APP.$rumext$v2$adapt$$($path$jscomp$284$$),
$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$7$$)],function($event$jscomp$602$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$602$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$602$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$7$$)?$APP.$cljs$core$not$$($is_editing$jscomp$4$$):$can_edit_QMARK_$jscomp$7$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1681$position$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$602$$),$APP.$cljs$cst$2128$is_group$$,!0,$APP.$cljs$cst$266$id$$,$id$jscomp$1009$$,$APP.$cljs$cst$296$path$$,$path$jscomp$284$$],null))):null}),$on_collapse_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$603$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$603$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$603$$);return $on_toggle_collapse$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_toggle_collapse$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$284$$):$on_toggle_collapse$jscomp$1$$($path$jscomp$284$$)}),$on_double_click$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1009$$)],function(){return $on_start_edition$$.$cljs$core$IFn$_invoke$arity$1$?$on_start_edition$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1009$$):$on_start_edition$$($id$jscomp$1009$$)}),$on_checkbox_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_toggle$jscomp$2$$),
$APP.$rumext$v2$adapt$$($path$jscomp$284$$),$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$7$$)],function(){return $on_toggle$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$284$$):$on_toggle$jscomp$2$$($path$jscomp$284$$)}),$on_edit_submit_SINGLEQUOTE_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path$jscomp$284$$),$APP.$rumext$v2$adapt$$($on_edit_submit$$),$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$7$$)],
function($p1__80169_SHARP_$$){return $on_edit_submit$$.$cljs$core$IFn$_invoke$arity$2$?$on_edit_submit$$.$cljs$core$IFn$_invoke$arity$2$($path$jscomp$284$$,$p1__80169_SHARP_$$):$on_edit_submit$$($path$jscomp$284$$,$p1__80169_SHARP_$$)}),$dref$jscomp$9_on_drop__$1_vec__80172$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$548$$),$APP.$rumext$v2$adapt$$($on_drop$jscomp$16$$)],function($position$jscomp$201$$,$data$jscomp$495$$){return $on_drop$jscomp$16$$.$cljs$core$IFn$_invoke$arity$3$?
$on_drop$jscomp$16$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$548$$,$position$jscomp$201$$,$data$jscomp$495$$):$on_drop$jscomp$16$$($index$jscomp$548$$,$position$jscomp$201$$,$data$jscomp$495$$)});$dref$jscomp$9_on_drop__$1_vec__80172$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,"penpot/token-set",$APP.$cljs$cst$2966$on_drop$$,$dref$jscomp$9_on_drop__$1_vec__80172$$,
$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1801$index$$,$index$jscomp$548$$,$APP.$cljs$cst$2128$is_group$$,!0],null),$APP.$cljs$cst$2969$detect_center_QMARK_$$,!0,$APP.$cljs$cst$2970$draggable_QMARK_$$,$APP.$cljs$core$truth_$$($dprops$jscomp$9_is_draggable$$)?$APP.$cljs$core$not$$($is_editing$jscomp$4$$):$dprops$jscomp$9_is_draggable$$]));$dprops$jscomp$9_is_draggable$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$9_on_drop__$1_vec__80172$$,
0,null);$dref$jscomp$9_on_drop__$1_vec__80172$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$9_on_drop__$1_vec__80172$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$dref$jscomp$9_on_drop__$1_vec__80172$$,"data-testid":"tokens-set-group-item",style:{"--tree-depth":$depth$jscomp$18_props_80170$$},onContextMenu:$on_context_menu$jscomp$14$$,className:"main_ui_workspace_tokens_sets_lists__set-item-container main_ui_workspace_tokens_sets_lists__set-item-group "+($APP.$cljs$core$truth_$$($is_selected$jscomp$7$$)?
"main_ui_workspace_tokens_sets_lists__selected-set":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$9_is_draggable$$),$APP.$cljs$cst$1672$center$$)?"main_ui_workspace_tokens_sets_lists__dnd-over":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$9_is_draggable$$),$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_tokens_sets_lists__dnd-over-top":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2971$over$$.$cljs$core$IFn$_invoke$arity$1$($dprops$jscomp$9_is_draggable$$),$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_tokens_sets_lists__dnd-over-bot":""),children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_sets_lists__set-item-group-collapse-button",onClick:$on_collapse_click$$,"data-testid":"tokens-set-group-collapse","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.collapse"),
icon:$APP.$cljs$core$truth_$$($is_collapsed$$)?"arrow-right":"arrow-down",variant:"action"}),$APP.$cljs$core$truth_$$($is_editing$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$editing_label_STAR_$$,{defaultValue:$label$jscomp$59$$,onCancel:$on_reset_edition$$,onSubmit:$on_edit_submit_SINGLEQUOTE_$$}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{role:"button",title:$label$jscomp$59$$,tabIndex:0,onDoubleClick:$on_double_click$jscomp$2$$,
id:$label_id$$,className:"main_ui_workspace_tokens_sets_lists__set-name",children:$label$jscomp$59$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$checkbox_STAR_$$,{onClick:$on_checkbox_click$$,disabled:$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$7$$),checked:function(){var $G__80175__$1$$=$is_active$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?$is_active$jscomp$4$$.$fqn$:null;switch($G__80175__$1$$){case "all":return!0;case "partial":return"mixed";case "none":return!1;
default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80175__$1$$)].join(""));}}(),arialLabel:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.select-set")})]})]})};
$app$main$ui$workspace$tokens$sets$lists$sets_tree_set_STAR_$$=function($depth$jscomp$19_props_80177$$){var $set$jscomp$23$$=$depth$jscomp$19_props_80177$$.set,$path$jscomp$285$$=$depth$jscomp$19_props_80177$$.path,$is_new$$=$depth$jscomp$19_props_80177$$.isNew,$index$jscomp$549$$=$depth$jscomp$19_props_80177$$.index,$on_edit_submit$jscomp$1$$=$depth$jscomp$19_props_80177$$.onEditSubmit,$is_selected$jscomp$8$$=$depth$jscomp$19_props_80177$$.isSelected,$on_toggle$jscomp$3$$=$depth$jscomp$19_props_80177$$.onToggle,
$on_drop$jscomp$17$$=$depth$jscomp$19_props_80177$$.onDrop,$dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$=$depth$jscomp$19_props_80177$$.isDraggable,$is_active$jscomp$5$$=$depth$jscomp$19_props_80177$$.isActive,$on_start_edition$jscomp$1$$=$depth$jscomp$19_props_80177$$.onStartEdition,$on_select$jscomp$5$$=$depth$jscomp$19_props_80177$$.onSelect,$is_editing$jscomp$5$$=$depth$jscomp$19_props_80177$$.isEditing,$label$jscomp$60$$=$depth$jscomp$19_props_80177$$.label,$id$jscomp$1010$$=$depth$jscomp$19_props_80177$$.id,
$on_reset_edition$jscomp$1$$=$depth$jscomp$19_props_80177$$.onResetEdition;$depth$jscomp$19_props_80177$$=$depth$jscomp$19_props_80177$$.depth;var $can_edit_QMARK_$jscomp$8$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$on_click$jscomp$53$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$5$$),$APP.$rumext$v2$adapt$$($on_select$jscomp$5$$),$APP.$rumext$v2$adapt$$($id$jscomp$1010$$)],function($event$jscomp$604$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$604$$);
return $APP.$cljs$core$truth_$$($is_editing$jscomp$5$$)?null:$APP.$cljs$core$fn_QMARK_$$($on_select$jscomp$5$$)?$on_select$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1010$$):$on_select$jscomp$5$$($id$jscomp$1010$$):null}),$on_context_menu$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$5$$),$APP.$rumext$v2$adapt$$($id$jscomp$1010$$),$APP.$rumext$v2$adapt$$($path$jscomp$285$$),
$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$8$$)],function($event$jscomp$605$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$605$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$605$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$8$$)?$APP.$cljs$core$not$$($is_editing$jscomp$5$$):$can_edit_QMARK_$jscomp$8$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1681$position$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$605$$),$APP.$cljs$cst$2128$is_group$$,!1,$APP.$cljs$cst$266$id$$,$id$jscomp$1010$$,$APP.$cljs$cst$296$path$$,$path$jscomp$285$$],null))):null}),$on_double_click$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1010$$),$APP.$rumext$v2$adapt$$($is_new$$)],function(){return $APP.$cljs$core$truth_$$($is_new$$)?null:$on_start_edition$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_start_edition$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1010$$):$on_start_edition$jscomp$1$$($id$jscomp$1010$$)}),$on_checkbox_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set$jscomp$23$$),$APP.$rumext$v2$adapt$$($on_toggle$jscomp$3$$)],function($G__80181_event$jscomp$606$$){$APP.$app$util$dom$stop_propagation$$($G__80181_event$jscomp$606$$);return $APP.$cljs$core$fn_QMARK_$$($on_toggle$jscomp$3$$)?($G__80181_event$jscomp$606$$=
$APP.$app$common$types$tokens_lib$get_name$$($set$jscomp$23$$),$on_toggle$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__80181_event$jscomp$606$$):$on_toggle$jscomp$3$$($G__80181_event$jscomp$606$$)):null}),$on_edit_submit_SINGLEQUOTE_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set$jscomp$23$$),$APP.$rumext$v2$adapt$$($on_edit_submit$jscomp$1$$)],function($p1__80176_SHARP_$$){return $on_edit_submit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$?
$on_edit_submit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$2$($set$jscomp$23$$,$p1__80176_SHARP_$$):$on_edit_submit$jscomp$1$$($set$jscomp$23$$,$p1__80176_SHARP_$$)}),$dref$jscomp$10_on_drag$jscomp$2_vec__80178$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path$jscomp$285$$)],function(){return $APP.$cljs$core$truth_$$($is_selected$jscomp$8$$)?null:$on_select$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_select$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$285$$):
$on_select$jscomp$5$$($path$jscomp$285$$)}),$on_drop__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$549$$),$APP.$rumext$v2$adapt$$($on_drop$jscomp$17$$)],function($position$jscomp$202$$,$data$jscomp$496$$){return $on_drop$jscomp$17$$.$cljs$core$IFn$_invoke$arity$3$?$on_drop$jscomp$17$$.$cljs$core$IFn$_invoke$arity$3$($index$jscomp$549$$,$position$jscomp$202$$,$data$jscomp$496$$):$on_drop$jscomp$17$$($index$jscomp$549$$,$position$jscomp$202$$,
$data$jscomp$496$$)});$dref$jscomp$10_on_drag$jscomp$2_vec__80178$$=$APP.$app$main$ui$hooks$use_sortable$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2965$data_type$$,"penpot/token-set",$APP.$cljs$cst$2967$on_drag$$,$dref$jscomp$10_on_drag$jscomp$2_vec__80178$$,$APP.$cljs$cst$2966$on_drop$$,$on_drop__$1$jscomp$1$$,$APP.$cljs$cst$142$data$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1801$index$$,$index$jscomp$549$$,
$APP.$cljs$cst$2128$is_group$$,!1],null),$APP.$cljs$cst$2970$draggable_QMARK_$$,$APP.$cljs$core$truth_$$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$)?$APP.$cljs$core$not$$($is_editing$jscomp$5$$):$dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$]));$dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$10_on_drag$jscomp$2_vec__80178$$,0,null);$dref$jscomp$10_on_drag$jscomp$2_vec__80178$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dref$jscomp$10_on_drag$jscomp$2_vec__80178$$,
1,null);$dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$,$APP.$cljs$cst$2971$over$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{onDoubleClick:$on_double_click$jscomp$3$$,role:"button",className:"main_ui_workspace_tokens_sets_lists__set-item-container "+($APP.$cljs$core$truth_$$($is_selected$jscomp$8$$)?"main_ui_workspace_tokens_sets_lists__selected-set":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$,
$APP.$cljs$cst$1672$center$$)?"main_ui_workspace_tokens_sets_lists__dnd-over":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$,$APP.$cljs$cst$1567$top$$)?"main_ui_workspace_tokens_sets_lists__dnd-over-top":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dprops$jscomp$10_drop_over_is_draggable$jscomp$1$$,$APP.$cljs$cst$2963$bot$$)?"main_ui_workspace_tokens_sets_lists__dnd-over-bot":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"document",className:"main_ui_workspace_tokens_sets_lists__icon "+($APP.$cljs$core$not$$($depth$jscomp$19_props_80177$$)?"main_ui_workspace_tokens_sets_lists__root-icon":"")}),$APP.$cljs$core$truth_$$($is_editing$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$editing_label_STAR_$$,{defaultValue:$label$jscomp$60$$,onCancel:$on_reset_edition$jscomp$1$$,onSubmit:$on_edit_submit_SINGLEQUOTE_$jscomp$1$$}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_tokens_sets_lists__set-name",children:$label$jscomp$60$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$checkbox_STAR_$$,{onClick:$on_checkbox_click$jscomp$1$$,disabled:$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$8$$),arialLabel:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.select-set"),checked:$is_active$jscomp$5$$})]})],id:["token-set-item-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("/",
$path$jscomp$285$$))].join(""),"data-testid":"tokens-set-item",onContextMenu:$on_context_menu$jscomp$15$$,style:{"--tree-depth":$depth$jscomp$19_props_80177$$},"aria-checked":$is_active$jscomp$5$$,onClick:$on_click$jscomp$53$$,ref:$dref$jscomp$10_on_drag$jscomp$2_vec__80178$$})};
$app$main$ui$workspace$tokens$sets$lists$token_sets_tree_STAR_$$=function($props_80185$$){var $on_toggle_set$$=$props_80185$$.onToggleSet,$is_token_set_active$$=$props_80185$$.isTokenSetActive,$on_edit_submit_group$$=$props_80185$$.onEditSubmitGroup,$new_path$jscomp$4$$=$props_80185$$.newPath,$selected$jscomp$184$$=$props_80185$$.selected,$edition_id$jscomp$2$$=$props_80185$$.editionId,$token_sets$$=$props_80185$$.tokenSets,$is_draggable$jscomp$2$$=$props_80185$$.isDraggable,$is_token_set_group_active$$=
$props_80185$$.isTokenSetGroupActive,$on_edit_submit_set$$=$props_80185$$.onEditSubmitSet,$on_start_edition$jscomp$2$$=$props_80185$$.onStartEdition,$on_select$jscomp$6$$=$props_80185$$.onSelect,$on_toggle_set_group$$=$props_80185$$.onToggleSetGroup,$on_reset_edition$jscomp$2$$=$props_80185$$.onResetEdition,$tokens_lib$jscomp$49$$=$props_80185$$.tokensLib,$collapsed_paths_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$collapsed_paths$jscomp$1$$=
$APP.$cljs$core$_deref$$($collapsed_paths_STAR_$$),$collapsed_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($collapsed_paths$jscomp$1$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,$collapsed_paths$jscomp$1$$)),$on_drop$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($collapsed_paths$jscomp$1$$)],function($index$jscomp$550_params$jscomp$431$$,
$position$jscomp$203$$,$data$jscomp$497$$){$index$jscomp$550_params$jscomp$431$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$4758$from_index$$,$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$497$$),$APP.$cljs$cst$4759$to_index$$,$index$jscomp$550_params$jscomp$431$$,$APP.$cljs$cst$1681$position$$,$position$jscomp$203$$,$APP.$cljs$cst$4760$collapsed_paths$$,$collapsed_paths$jscomp$1$$],null);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2128$is_group$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$497$$))?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$drop_token_set_group$$($index$jscomp$550_params$jscomp$431$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$drop_token_set$$($index$jscomp$550_params$jscomp$431$$))}),$on_toggle_collapse$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($path$jscomp$286$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_paths_STAR_$$,
function($p1__80183_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__80183_SHARP_$$,$path$jscomp$286$$)?$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($p1__80183_SHARP_$$,$path$jscomp$286$$):$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p1__80183_SHARP_$$,$path$jscomp$286$$)})});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $sub$jscomp$27$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($paths_SINGLEQUOTE_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($collapsed_paths_STAR_$$,
function($paths$jscomp$9$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$disj$$,$paths$jscomp$9$$,$paths_SINGLEQUOTE_$$)})},$APP.$beicon$v2$core$map$$($cljs$cst$5536$paths$$,$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5535$expand_token_sets$$),$APP.$app$main$store$stream$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$27$$)}});
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$203$$,$JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$){$JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$);var $JSCompiler_temp$jscomp$1880_JSCompiler_temp$jscomp$1881_token_set$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$,
$APP.$cljs$cst$2129$token_set$$),$id$jscomp$1011$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$,$APP.$cljs$cst$266$id$$),$index$jscomp$551$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$,$APP.$cljs$cst$1801$index$$),$G__80194$jscomp$inline_9159_JSCompiler_inline_result$jscomp$1882_is_new$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$,
$APP.$cljs$cst$2127$is_new$$),$is_group$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$,$APP.$cljs$cst$2128$is_group$$),$path$jscomp$287$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$,$APP.$cljs$cst$296$path$$),$depth$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$,$APP.$cljs$cst$839$depth$$);
$JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$=$out_arr__44092__auto__$jscomp$203$$.push;$is_group$$?$JSCompiler_temp$jscomp$1880_JSCompiler_temp$jscomp$1881_token_set$jscomp$22$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$sets_tree_set_group_STAR_$$,{onResetEdition:$on_reset_edition$jscomp$2$$,isCollapsed:$collapsed_QMARK_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$collapsed_QMARK_$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$287$$):$collapsed_QMARK_$jscomp$2$$($path$jscomp$287$$),
isActive:$is_token_set_group_active$$.$cljs$core$IFn$_invoke$arity$1$?$is_token_set_group_active$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$287$$):$is_token_set_group_active$$($path$jscomp$287$$),index:$index$jscomp$551$$,onStartEdition:$on_start_edition$jscomp$2$$,onToggle:$on_toggle_set_group$$,isDraggable:$is_draggable$jscomp$2$$,label:$APP.$cljs$core$peek$$($path$jscomp$287$$),path:$path$jscomp$287$$,id:$id$jscomp$1011$$,onDrop:$on_drop$jscomp$18$$,depth:$depth$jscomp$20$$,isSelected:!1,onEditSubmit:$on_edit_submit_group$$,
isEditing:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition_id$jscomp$2$$,$id$jscomp$1011$$),onToggleCollapse:$on_toggle_collapse$jscomp$2$$},$index$jscomp$551$$):$G__80194$jscomp$inline_9159_JSCompiler_inline_result$jscomp$1882_is_new$jscomp$1$$?$JSCompiler_temp$jscomp$1880_JSCompiler_temp$jscomp$1881_token_set$jscomp$22$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$sets_tree_set_STAR_$$,{onResetEdition:$on_reset_edition$jscomp$2$$,isActive:!0,index:$index$jscomp$551$$,
isDraggable:!1,label:"",path:$path$jscomp$287$$,id:$id$jscomp$1011$$,onDrop:$on_drop$jscomp$18$$,isNew:!0,depth:$depth$jscomp$20$$,isSelected:!0,onEditSubmit:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$tokens$sets$helpers$on_create_token_set$$,$tokens_lib$jscomp$49$$),set:$JSCompiler_temp$jscomp$1880_JSCompiler_temp$jscomp$1881_token_set$jscomp$22$$,isEditing:!0},$index$jscomp$551$$):($G__80194$jscomp$inline_9159_JSCompiler_inline_result$jscomp$1882_is_new$jscomp$1$$=
$APP.$app$common$types$tokens_lib$get_name$$($JSCompiler_temp$jscomp$1880_JSCompiler_temp$jscomp$1881_token_set$jscomp$22$$),$G__80194$jscomp$inline_9159_JSCompiler_inline_result$jscomp$1882_is_new$jscomp$1$$=$is_token_set_active$$.$cljs$core$IFn$_invoke$arity$1$?$is_token_set_active$$.$cljs$core$IFn$_invoke$arity$1$($G__80194$jscomp$inline_9159_JSCompiler_inline_result$jscomp$1882_is_new$jscomp$1$$):$is_token_set_active$$($G__80194$jscomp$inline_9159_JSCompiler_inline_result$jscomp$1882_is_new$jscomp$1$$),
$JSCompiler_temp$jscomp$1880_JSCompiler_temp$jscomp$1881_token_set$jscomp$22$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$sets_tree_set_STAR_$$,{onResetEdition:$on_reset_edition$jscomp$2$$,isActive:$G__80194$jscomp$inline_9159_JSCompiler_inline_result$jscomp$1882_is_new$jscomp$1$$,index:$index$jscomp$551$$,onStartEdition:$on_start_edition$jscomp$2$$,onToggle:$on_toggle_set$$,isDraggable:$is_draggable$jscomp$2$$,label:$APP.$cljs$core$peek$$($path$jscomp$287$$),path:$path$jscomp$287$$,
id:$id$jscomp$1011$$,onDrop:$on_drop$jscomp$18$$,isNew:!1,depth:$depth$jscomp$20$$,isSelected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$184$$,$id$jscomp$1011$$),onEditSubmit:$on_edit_submit_set$$,set:$JSCompiler_temp$jscomp$1880_JSCompiler_temp$jscomp$1881_token_set$jscomp$22$$,isEditing:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition_id$jscomp$2$$,$id$jscomp$1011$$),onSelect:$on_select$jscomp$6$$},$index$jscomp$551$$));$JSCompiler_temp_const$jscomp$1878_map__80191__$1_p__80190$$.call($out_arr__44092__auto__$jscomp$203$$,
$JSCompiler_temp$jscomp$1880_JSCompiler_temp$jscomp$1881_token_set$jscomp$22$$);return $out_arr__44092__auto__$jscomp$203$$},[],$app$common$types$tokens_lib$sets_tree_seq$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($token_sets$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2121$skip_children_pred$$,$collapsed_QMARK_$jscomp$2$$,$APP.$cljs$cst$2126$new_at_path$$,$new_path$jscomp$4$$],null)])))};
$app$main$ui$workspace$tokens$sets$lists$controlled_sets_list_STAR_$$=function($draggable_QMARK_$jscomp$1_props_80196$$){var $on_toggle_token_set$$=$draggable_QMARK_$jscomp$1_props_80196$$.onToggleTokenSet,$is_token_set_active$jscomp$1$$=$draggable_QMARK_$jscomp$1_props_80196$$.isTokenSetActive,$on_toggle_token_set_group$$=$draggable_QMARK_$jscomp$1_props_80196$$.onToggleTokenSetGroup,$new_path$jscomp$5$$=$draggable_QMARK_$jscomp$1_props_80196$$.newPath,$selected$jscomp$185$$=$draggable_QMARK_$jscomp$1_props_80196$$.selected,
$on_update_token_set_group$$=$draggable_QMARK_$jscomp$1_props_80196$$.onUpdateTokenSetGroup,$edition_id$jscomp$3$$=$draggable_QMARK_$jscomp$1_props_80196$$.editionId,$token_sets$jscomp$1$$=$draggable_QMARK_$jscomp$1_props_80196$$.tokenSets,$on_update_token_set$$=$draggable_QMARK_$jscomp$1_props_80196$$.onUpdateTokenSet,$is_token_set_group_active$jscomp$1$$=$draggable_QMARK_$jscomp$1_props_80196$$.isTokenSetGroupActive,$on_create_token_set$$=$draggable_QMARK_$jscomp$1_props_80196$$.onCreateTokenSet,
$on_start_edition$jscomp$3$$=$draggable_QMARK_$jscomp$1_props_80196$$.onStartEdition,$on_select$jscomp$7$$=$draggable_QMARK_$jscomp$1_props_80196$$.onSelect,$on_reset_edition$jscomp$3$$=$draggable_QMARK_$jscomp$1_props_80196$$.onResetEdition,$tokens_lib$jscomp$50$$=$draggable_QMARK_$jscomp$1_props_80196$$.tokensLib,$theme_modal_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($draggable_QMARK_$jscomp$1_props_80196$$.origin,"theme-modal"),$can_edit_QMARK_$jscomp$9$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$);
$draggable_QMARK_$jscomp$1_props_80196$$=function(){var $and__5023__auto__$jscomp$901$$=!$theme_modal_QMARK_$$;return $and__5023__auto__$jscomp$901$$?$can_edit_QMARK_$jscomp$9$$:$and__5023__auto__$jscomp$901$$}();var $empty_state_QMARK_$$=$theme_modal_QMARK_$$&&$APP.$cljs$core$empty_QMARK_$$($token_sets$jscomp$1$$)&&$APP.$cljs$core$not$$($new_path$jscomp$5$$),$on_reset_edition__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_reset_edition$jscomp$3$$)],
function($v$jscomp$678$$){return $APP.$cljs$core$fn_QMARK_$$($on_reset_edition$jscomp$3$$)?$on_reset_edition$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_reset_edition$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$678$$):$on_reset_edition$jscomp$3$$($v$jscomp$678$$):null}),$on_start_edition__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_edition$jscomp$3$$)],function($v$jscomp$679$$){return $APP.$cljs$core$fn_QMARK_$$($on_start_edition$jscomp$3$$)?
$on_start_edition$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_start_edition$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$679$$):$on_start_edition$jscomp$3$$($v$jscomp$679$$):null});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sets_lists__sets-list",children:$empty_state_QMARK_$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_sets_lists__empty-state-message-sets",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-sets-create")}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$token_sets_tree_STAR_$$,{onResetEdition:$on_reset_edition__$1$$,tokenSets:$token_sets$jscomp$1$$,onCreateTokenSet:$on_create_token_set$$,selected:$selected$jscomp$185$$,onToggleSetGroup:$on_toggle_token_set_group$$,tokensLib:$tokens_lib$jscomp$50$$,onStartEdition:$on_start_edition__$1$$,newPath:$new_path$jscomp$5$$,isDraggable:$draggable_QMARK_$jscomp$1_props_80196$$,
onEditSubmitSet:$on_update_token_set$$,isTokenSetActive:$is_token_set_active$jscomp$1$$,onToggleSet:$on_toggle_token_set$$,editionId:$edition_id$jscomp$3$$,onSelect:$on_select$jscomp$7$$,isTokenSetGroupActive:$is_token_set_group_active$jscomp$1$$,onEditSubmitGroup:$on_update_token_set_group$$})})};
$app$main$ui$workspace$tokens$sets$on_select_token_set_click$$=function($id$jscomp$1012$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$clear_tokens_paths$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$library_edit$set_selected_token_set_id$$($id$jscomp$1012$$)]))};$app$main$ui$workspace$tokens$sets$on_toggle_token_set_click$$=function($name$jscomp$473$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_set$$($name$jscomp$473$$))};
$app$main$ui$workspace$tokens$sets$on_toggle_token_set_group_click$$=function($path$jscomp$288$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$toggle_token_set_group$$($path$jscomp$288$$))};
$app$main$ui$workspace$tokens$sets$sets_list_STAR_$$=function($props_80209_token_sets$jscomp$2$$){var $new_path$jscomp$6$$=$props_80209_token_sets$jscomp$2$$.newPath,$selected$jscomp$186$$=$props_80209_token_sets$jscomp$2$$.selected,$edition_id$jscomp$4$$=$props_80209_token_sets$jscomp$2$$.editionId,$tokens_lib$jscomp$51$$=$props_80209_token_sets$jscomp$2$$.tokensLib;$props_80209_token_sets$jscomp$2$$=$tokens_lib$jscomp$51$$==null?null:$APP.$app$common$types$tokens_lib$get_set_tree$$($tokens_lib$jscomp$51$$);
var $can_edit_QMARK_$jscomp$10$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$token_set_active_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$51$$)],function($name$jscomp$474$$){return $APP.$cljs$core$truth_$$($tokens_lib$jscomp$51$$)?$APP.$app$common$types$tokens_lib$token_set_active_QMARK_$$($tokens_lib$jscomp$51$$,$name$jscomp$474$$):null}),$token_set_group_active_QMARK_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($group_path$jscomp$11$$){return $APP.$cljs$core$_deref$$($app$main$refs$token_sets_at_path_all_active$$($group_path$jscomp$11$$))}),
$on_reset_edition$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$10$$)],function(){return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$10$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$clear_token_set_edition$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$clear_token_set_creation$$()])):
null}),$on_start_edition$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$10$$)],function($id$jscomp$1013$$){return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$10$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$start_token_set_edition$$($id$jscomp$1013$$)):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$controlled_sets_list_STAR_$$,
{onResetEdition:$on_reset_edition$jscomp$4$$,tokenSets:$props_80209_token_sets$jscomp$2$$,onCreateTokenSet:$app$main$ui$workspace$tokens$sets$helpers$on_create_token_set$$,selected:$selected$jscomp$186$$,onUpdateTokenSetGroup:$app$main$ui$workspace$tokens$sets$helpers$on_update_token_set_group$$,origin:"set-panel",onToggleTokenSet:$app$main$ui$workspace$tokens$sets$on_toggle_token_set_click$$,onUpdateTokenSet:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$tokens$sets$helpers$on_update_token_set$$,
$tokens_lib$jscomp$51$$),tokensLib:$tokens_lib$jscomp$51$$,onStartEdition:$on_start_edition$jscomp$4$$,newPath:$new_path$jscomp$6$$,isTokenSetActive:$token_set_active_QMARK_$jscomp$1$$,canEdit:$can_edit_QMARK_$jscomp$10$$,onToggleTokenSetGroup:$app$main$ui$workspace$tokens$sets$on_toggle_token_set_group_click$$,editionId:$edition_id$jscomp$4$$,onSelect:$app$main$ui$workspace$tokens$sets$on_select_token_set_click$$,isTokenSetGroupActive:$token_set_group_active_QMARK_$$})};
$app$main$ui$workspace$tokens$sets$context_menu$prevent_default$$=function($event$jscomp$607$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$607$$);return $APP.$app$util$dom$stop_propagation$$($event$jscomp$607$$)};$app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$=function($props_80212$$){return(0,$APP.$rumext$v2$jsx$$)("li",{"data-value":$props_80212$$.value,onClick:$props_80212$$.onClick,className:"main_ui_workspace_tokens_sets_context_menu__context-menu-item",children:$props_80212$$.title})};
$app$main$ui$workspace$tokens$sets$context_menu$menu_STAR_$$=function($create_set_at_path_props_80213$$){var $path$jscomp$289$$=$create_set_at_path_props_80213$$.path,$is_group$jscomp$1$$=$create_set_at_path_props_80213$$.isGroup,$id$jscomp$1014$$=$create_set_at_path_props_80213$$.id;$create_set_at_path_props_80213$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path$jscomp$289$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$start_token_set_creation$$($path$jscomp$289$$))});
var $on_edit$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1014$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$start_token_set_edition$$($id$jscomp$1014$$))}),$on_duplicate$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_group$jscomp$1$$),$APP.$rumext$v2$adapt$$($id$jscomp$1014$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$duplicate_token_set$cljs$0core$0IFn$0_invoke$0arity$02$$($id$jscomp$1014$$,
null))}),$on_delete$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_group$jscomp$1$$),$APP.$rumext$v2$adapt$$($path$jscomp$289$$)],$APP.$cljs$core$truth_$$($is_group$jscomp$1$$)?function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$delete_token_set_group$$($path$jscomp$289$$))}:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_set$$($id$jscomp$1014$$))});
return(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_tokens_sets_context_menu__context-list",children:[$APP.$cljs$core$truth_$$($is_group$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add-set-to-group"),onClick:$create_set_at_path_props_80213$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"),onClick:$on_edit$jscomp$9$$}),$APP.$cljs$core$truth_$$($is_group$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.duplicate"),onClick:$on_duplicate$jscomp$3$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_entry_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete"),
onClick:$on_delete$jscomp$14$$})]})};
$app$main$ui$workspace$tokens$sets$context_menu$token_set_context_menu_STAR_$$=function(){var $map__80217_position$jscomp$204$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$tokens$sets$context_menu$ref_COLON_token_sets_context_menu$$),$map__80217__$1_path$jscomp$290$$=$APP.$cljs$core$__destructure_map$$($map__80217_position$jscomp$204$$);$map__80217_position$jscomp$204$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80217__$1_path$jscomp$290$$,$APP.$cljs$cst$1681$position$$);var $is_group$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80217__$1_path$jscomp$290$$,$APP.$cljs$cst$2128$is_group$$),$id$jscomp$1015$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80217__$1_path$jscomp$290$$,$APP.$cljs$cst$266$id$$);$map__80217__$1_path$jscomp$290$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80217__$1_path$jscomp$290$$,$APP.$cljs$cst$296$path$$);var $position_top$$=($map__80217_position$jscomp$204$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80217_position$jscomp$204$$,
$APP.$cljs$cst$1516$y$$))+5,$position_left$$=($map__80217_position$jscomp$204$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80217_position$jscomp$204$$,$APP.$cljs$cst$1515$x$$))+5,$on_close$jscomp$35$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$assign_token_set_context_menu$$(null))});return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,
{show:$map__80217_position$jscomp$204$$!=null,"on-close":$on_close$jscomp$35$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"tokens-context-menu-for-set",style:{top:$position_top$$,left:$position_left$$},onContextMenu:$app$main$ui$workspace$tokens$sets$context_menu$prevent_default$$,className:"main_ui_workspace_tokens_sets_context_menu__token-set-context-menu",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$menu_STAR_$$,{isGroup:$is_group$jscomp$2$$,id:$id$jscomp$1015$$,
path:$map__80217__$1_path$jscomp$290$$})})})};
$app$main$ui$workspace$tokens$themes$theme_selector$themes_list_STAR_$$=function($props_80224$$){var $on_close$jscomp$36$$=$props_80224$$.onClose,$active_theme_paths$jscomp$1$$=$props_80224$$.activeThemePaths,$themes$jscomp$8$$=$props_80224$$.themes,$is_grouped$$=$props_80224$$.isGrouped;return $APP.$cljs$core$seq$$($themes$jscomp$8$$)?(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_themes_theme_selector__theme-options",children:$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return function $app$main$ui$workspace$tokens$themes$theme_selector$themes_list_STAR__$_iter__80225$$($s__80226$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$407$$=
$APP.$cljs$core$seq$$($s__80226$$);if($temp__5825__auto__$jscomp$407$$){var $s__80226__$2$$=$temp__5825__auto__$jscomp$407$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__80226__$2$$)){var $c__5501__auto__$jscomp$49$$=$APP.$cljs$core$_chunked_first$$($s__80226__$2$$),$size__5502__auto__$jscomp$49$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$49$$),$b__80228$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$49$$);return function(){for(var $i__80227$$=0;;)if($i__80227$$<$size__5502__auto__$jscomp$49$$){var $vec__80229$$=
$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$49$$,$i__80227$$),$_$jscomp$3094$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80229$$,0,null),$map__80232$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80229$$,1,null),$map__80232__$1$$=$APP.$cljs$core$__destructure_map$$($map__80232$$),$theme$jscomp$16$$=$map__80232__$1$$,$id$jscomp$1017$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80232__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$476$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80232__$1$$,
$APP.$cljs$cst$725$name$$),$theme_id$jscomp$7$$=$APP.$app$common$types$tokens_lib$get_theme_path$$($theme$jscomp$16$$),$selected_QMARK_$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_paths$jscomp$1$$,$theme_id$jscomp$7$$);$APP.$cljs$core$chunk_append$$($b__80228$$,(0,$APP.$rumext$v2$jsxs$$)("li",{role:"option","aria-selected":$selected_QMARK_$jscomp$10$$,onClick:function($i__80227$jscomp$1$$,$theme_id$jscomp$8$$,$selected_QMARK_$jscomp$11$$,$vec__80229$jscomp$1$$,
$_$jscomp$3095$$,$map__80232$jscomp$1$$,$map__80232__$1$jscomp$1$$,$theme$jscomp$17$$,$id$jscomp$1018$$,$name$jscomp$477$$,$c__5501__auto__$jscomp$50$$,$size__5502__auto__$jscomp$50$$,$b__80228$jscomp$1$$,$s__80226__$2$jscomp$1$$,$temp__5825__auto__$jscomp$408$$,$on_close$jscomp$37$$){return function($e$jscomp$361$$){$APP.$app$util$dom$stop_propagation$$($e$jscomp$361$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1018$$));
return $on_close$jscomp$37$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$37$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$37$$()}}($i__80227$$,$theme_id$jscomp$7$$,$selected_QMARK_$jscomp$10$$,$vec__80229$$,$_$jscomp$3094$$,$map__80232$$,$map__80232__$1$$,$theme$jscomp$16$$,$id$jscomp$1017$$,$name$jscomp$476$$,$c__5501__auto__$jscomp$49$$,$size__5502__auto__$jscomp$49$$,$b__80228$$,$s__80226__$2$$,$temp__5825__auto__$jscomp$407$$,$on_close$jscomp$36$$,$active_theme_paths$jscomp$1$$,$themes$jscomp$8$$,
$is_grouped$$),className:"main_ui_workspace_tokens_themes_theme_selector__checked-element "+($APP.$cljs$core$truth_$$($is_grouped$$)?"main_ui_workspace_tokens_themes_theme_selector__sub-item":"")+" "+($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$10$$)?"main_ui_workspace_tokens_themes_theme_selector__is-selected":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes_theme_selector__label",
title:$name$jscomp$476$$,children:$name$jscomp$476$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick","aria-hidden":!0,className:"main_ui_workspace_tokens_themes_theme_selector__check-icon "+($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$10$$)?"main_ui_workspace_tokens_themes_theme_selector__check-icon-visible":"")})]},$theme_id$jscomp$7$$));$i__80227$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80228$$),$app$main$ui$workspace$tokens$themes$theme_selector$themes_list_STAR__$_iter__80225$$($APP.$cljs$core$_chunked_rest$$($s__80226__$2$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80228$$),null)}var $vec__80233$$=$APP.$cljs$core$first$$($s__80226__$2$$),$_$jscomp$3093$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80233$$,0,null),$map__80236$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80233$$,1,null),$map__80236__$1$$=$APP.$cljs$core$__destructure_map$$($map__80236$$),$theme$jscomp$15$$=$map__80236__$1$$,$id$jscomp$1016$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236__$1$$,
$APP.$cljs$cst$266$id$$),$name$jscomp$475$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80236__$1$$,$APP.$cljs$cst$725$name$$),$theme_id$jscomp$6$$=$APP.$app$common$types$tokens_lib$get_theme_path$$($theme$jscomp$15$$),$selected_QMARK_$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_paths$jscomp$1$$,$theme_id$jscomp$6$$);return $APP.$cljs$core$cons$$((0,$APP.$rumext$v2$jsxs$$)("li",{role:"option","aria-selected":$selected_QMARK_$jscomp$9$$,onClick:function($theme_id$jscomp$9$$,
$selected_QMARK_$jscomp$12$$,$vec__80233$jscomp$1$$,$_$jscomp$3096$$,$map__80236$jscomp$1$$,$map__80236__$1$jscomp$1$$,$theme$jscomp$18$$,$id$jscomp$1019$$,$name$jscomp$478$$,$s__80226__$2$jscomp$2$$,$temp__5825__auto__$jscomp$409$$,$on_close$jscomp$38$$){return function($e$jscomp$362$$){$APP.$app$util$dom$stop_propagation$$($e$jscomp$362$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1019$$));
return $on_close$jscomp$38$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$38$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$38$$()}}($theme_id$jscomp$6$$,$selected_QMARK_$jscomp$9$$,$vec__80233$$,$_$jscomp$3093$$,$map__80236$$,$map__80236__$1$$,$theme$jscomp$15$$,$id$jscomp$1016$$,$name$jscomp$475$$,$s__80226__$2$$,$temp__5825__auto__$jscomp$407$$,$on_close$jscomp$36$$,$active_theme_paths$jscomp$1$$,$themes$jscomp$8$$,$is_grouped$$),className:"main_ui_workspace_tokens_themes_theme_selector__checked-element "+
($APP.$cljs$core$truth_$$($is_grouped$$)?"main_ui_workspace_tokens_themes_theme_selector__sub-item":"")+" "+($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$9$$)?"main_ui_workspace_tokens_themes_theme_selector__is-selected":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes_theme_selector__label",title:$name$jscomp$475$$,children:$name$jscomp$475$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"tick","aria-hidden":!0,className:"main_ui_workspace_tokens_themes_theme_selector__check-icon "+($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$9$$)?"main_ui_workspace_tokens_themes_theme_selector__check-icon-visible":"")})]},$theme_id$jscomp$6$$),$app$main$ui$workspace$tokens$themes$theme_selector$themes_list_STAR__$_iter__80225$$($APP.$cljs$core$rest$$($s__80226__$2$$)))}return null}},null,null)}($themes$jscomp$8$$)}())}):null};
$app$main$ui$workspace$tokens$themes$theme_selector$open_tokens_theme_modal$$=function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5906$tokens_SLASH_themes$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$tokens$themes$theme_selector$theme_options_STAR_$$=function($props_80237$$){var $on_close$jscomp$39$$=$props_80237$$.onClose,$active_theme_paths$jscomp$4$$=$props_80237$$.activeThemePaths;return(0,$APP.$rumext$v2$jsxs$$)("ul",{role:"listbox",className:"main_ui_workspace_tokens_themes_theme_selector__theme-options main_ui_workspace_tokens_themes_theme_selector__custom-select-dropdown",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$204$$,
$p__80238_themes__$1$$){var $group$jscomp$54$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80238_themes__$1$$,0,null);$p__80238_themes__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80238_themes__$1$$,1,null);$out_arr__44092__auto__$jscomp$204$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{"aria-labelledby":""+($group$jscomp$54$$??"")+"-label",role:"group",children:[$APP.$cljs$core$seq$$($group$jscomp$54$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"headline-small",className:"main_ui_workspace_tokens_themes_theme_selector__group",id:""+($APP.$cuerdas$core$kebab$$($group$jscomp$54$$)??"")+"-label",title:$group$jscomp$54$$,children:$group$jscomp$54$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$theme_selector$themes_list_STAR_$$,{themes:$p__80238_themes__$1$$,activeThemePaths:$active_theme_paths$jscomp$4$$,onClose:$on_close$jscomp$39$$,isGrouped:!0})]},$group$jscomp$54$$));return $out_arr__44092__auto__$jscomp$204$$},
[],$props_80237$$.themes),(0,$APP.$rumext$v2$jsx$$)("li",{"aria-hidden":!0,className:"main_ui_workspace_tokens_themes_theme_selector__separator"}),(0,$APP.$rumext$v2$jsxs$$)("li",{role:"option",onClick:$app$main$ui$workspace$tokens$themes$theme_selector$open_tokens_theme_modal$$,className:"main_ui_workspace_tokens_themes_theme_selector__checked-element main_ui_workspace_tokens_themes_theme_selector__checked-element-button",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-small",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.edit-themes")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right","aria-hidden":!0})]})]})};
$app$main$ui$workspace$tokens$themes$theme_selector$theme_selector_STAR_$$=function(){var $active_theme_paths$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_active_theme_paths_no_hidden$$),$active_themes_count_current_label$jscomp$1$$=$APP.$cljs$core$count$$($active_theme_paths$jscomp$5$$),$themes$jscomp$12$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_theme_tree_no_hidden$$),$can_edit_QMARK_$jscomp$11$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$permissions$$));
$active_themes_count_current_label$jscomp$1$$=$active_themes_count_current_label$jscomp$1$$>1?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.active-themes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$active_themes_count_current_label$jscomp$1$$])):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_themes_count_current_label$jscomp$1$$,1)?function(){var $G__80243_G__80243__$1_G__80243__$2$$=$APP.$cljs$core$first$$($active_theme_paths$jscomp$5$$);
$G__80243_G__80243__$1_G__80243__$2$$=$G__80243_G__80243__$1_G__80243__$2$$==null?null:$APP.$app$common$path_names$split_group_name$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($G__80243_G__80243__$1_G__80243__$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,"/",$APP.$cljs$cst$2014$with_spaces_QMARK_$$,!1]));$G__80243_G__80243__$1_G__80243__$2$$=$G__80243_G__80243__$1_G__80243__$2$$==null?null:$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty_QMARK_$$,
$G__80243_G__80243__$1_G__80243__$2$$);return $G__80243_G__80243__$1_G__80243__$2$$==null?null:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" / ",$G__80243_G__80243__$1_G__80243__$2$$)}():$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-active-theme");var $state_STAR_$jscomp$24$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$(),
$APP.$cljs$cst$4630$is_open_QMARK_$$,!1,$APP.$cljs$cst$1616$rect$$,null],null)}),$rect$jscomp$47_state$jscomp$1218$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$24$$),$is_open_QMARK_$jscomp$4$$=$APP.$cljs$cst$4630$is_open_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1218$$);$rect$jscomp$47_state$jscomp$1218$$=$APP.$cljs$cst$1616$rect$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1218$$);var $on_close_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$24$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4630$is_open_QMARK_$$,!1)}),$on_open_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$11$$)],function($event$jscomp$608_rect__$1$jscomp$1_temp__5825__auto__$jscomp$410$$){return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$11$$)&&($event$jscomp$608_rect__$1$jscomp$1_temp__5825__auto__$jscomp$410$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$608_rect__$1$jscomp$1_temp__5825__auto__$jscomp$410$$),
$APP.$cljs$core$truth_$$($event$jscomp$608_rect__$1$jscomp$1_temp__5825__auto__$jscomp$410$$))?($event$jscomp$608_rect__$1$jscomp$1_temp__5825__auto__$jscomp$410$$=$APP.$app$util$dom$get_bounding_rect$$($event$jscomp$608_rect__$1$jscomp$1_temp__5825__auto__$jscomp$410$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$24$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$4630$is_open_QMARK_$$,!0,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1616$rect$$,
$event$jscomp$608_rect__$1$jscomp$1_temp__5825__auto__$jscomp$410$$]))):null}),$container$jscomp$95$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5888$popup$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{role:"combobox","aria-expanded":$is_open_QMARK_$jscomp$4$$,tabIndex:"0",className:"main_ui_workspace_tokens_themes_theme_selector__custom-select "+($APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$11$$)?"main_ui_workspace_tokens_themes_theme_selector__disabled-select":
""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes_theme_selector__current-label",children:$active_themes_count_current_label$jscomp$1$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-down",className:"main_ui_workspace_tokens_themes_theme_selector__dropdown-button","aria-hidden":!0}),$APP.$cljs$core$truth_$$($is_open_QMARK_$jscomp$4$$)?
(0,$APP.$rumext$v2$portal$$)((0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"theme-select-dropdown",style:{top:$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1218$$),left:$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1218$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$47_state$jscomp$1218$$)},className:"main_ui_workspace_tokens_themes_theme_selector__dropdown-portal",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,
{show:$is_open_QMARK_$jscomp$4$$,"on-close":$on_close_dropdown$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$theme_selector$theme_options_STAR_$$,{activeThemePaths:$active_theme_paths$jscomp$5$$,themes:$themes$jscomp$12$$,onClose:$on_close_dropdown$$})})}),$container$jscomp$95$$):null],"data-testid":"theme-select","aria-haspopup":"listbox",onClick:$on_open_dropdown$$,disabled:$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$11$$)})};
$app$main$ui$workspace$tokens$themes$themes_header_STAR_$$=function(){var $ordered_themes$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_themes_no_hidden$$),$can_edit_QMARK_$jscomp$12$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$open_modal$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$363$$){$APP.$app$util$dom$stop_propagation$$($e$jscomp$363$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5906$tokens_SLASH_themes$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes__themes-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"headline-small",className:"main_ui_workspace_tokens_themes__themes-header",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.themes")}),$APP.$cljs$core$empty_QMARK_$$($ordered_themes$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_tokens_themes__empty-theme-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes__empty-state-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-themes")}),$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$12$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$open_modal$jscomp$1$$,className:"main_ui_workspace_tokens_themes__create-theme-button",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.create-one")}):null]}):$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$12$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes__theme-selector-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$theme_selector$theme_selector_STAR_$$,{}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",className:"main_ui_workspace_tokens_themes__edit-theme-button",
onClick:$open_modal$jscomp$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.edit")})]}):(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$12$$)?null:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-permission-themes"),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$theme_selector$theme_selector_STAR_$$,{})})]})};
$app$main$ui$workspace$tokens$sidebar$token_sets_list_STAR_$$=function($props_80262_tokens_lib$jscomp$52$$){$props_80262_tokens_lib$jscomp$52$$=$props_80262_tokens_lib$jscomp$52$$.tokensLib;var $token_sets$jscomp$3$$=$props_80262_tokens_lib$jscomp$52$$==null?null:$APP.$app$common$types$tokens_lib$get_set_tree$$($props_80262_tokens_lib$jscomp$52$$),$selected_token_set_id$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$map__80263_token_set_edition_id$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_tokens$$),
$map__80263__$1_token_set_new_path$$=$APP.$cljs$core$__destructure_map$$($map__80263_token_set_edition_id$$);$map__80263_token_set_edition_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80263__$1_token_set_new_path$$,$APP.$cljs$cst$4811$token_set_edition_id$$);$map__80263__$1_token_set_new_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80263__$1_token_set_new_path$$,$APP.$cljs$cst$4813$token_set_new_path$$);return $APP.$cljs$core$empty_QMARK_$$($token_sets$jscomp$3$$)&&
$APP.$cljs$core$not$$($map__80263__$1_token_set_new_path$$)?$APP.$cljs$core$truth_$$($map__80263__$1_token_set_new_path$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$inline_add_button_STAR_$$,{}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$sets_list_STAR_$$,{tokensLib:$props_80262_tokens_lib$jscomp$52$$,newPath:$map__80263__$1_token_set_new_path$$,editionId:$map__80263_token_set_edition_id$$,
selected:$selected_token_set_id$jscomp$7$$})})};
$app$main$ui$workspace$tokens$sidebar$token_management_section_STAR_$$=function($props_80265$$){var $resize_height$$=$props_80265$$.resizeHeight,$can_edit_QMARK_$jscomp$13$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$context_menu$token_set_context_menu_STAR_$$,{}),(0,$APP.$rumext$v2$jsxs$$)("section",{"data-testid":"token-management-sidebar",
style:{"--resize-height":[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($resize_height$$),"px"].join("")},className:"main_ui_workspace_tokens_sidebar__token-management-section-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$themes_header_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sidebar__sidebar-header",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.sets"),
children:$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$13$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$add_button_STAR_$$,{}):null})}),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$sidebar$token_sets_list_STAR_$$,$props_80265$$)]})]})};
$app$main$ui$workspace$tokens$sidebar$import_export_button_STAR_$$=function(){var $show_menu_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_menu_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($show_menu_STAR_$jscomp$1$$),$can_edit_QMARK_$jscomp$14$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$can_edit_QMARK_$$),$open_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$609$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$609$$);
return $APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$jscomp$1$$,!0)}),$close_menu$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$610$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$610$$);return $APP.$cljs$core$reset_BANG_$$($show_menu_STAR_$jscomp$1$$,!1)}),$on_export$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5907$tokens_SLASH_export$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}),$on_modal_show$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5908$tokens_SLASH_import$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)}),$open_settings_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$611$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$611$$);return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5909$tokens_SLASH_settings$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_sidebar__import-export-button-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$open_menu$$,type:"button",icon:"import-export",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.tools")}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:$show_menu_QMARK_$jscomp$4$$,onClose:$close_menu$jscomp$2$$,id:"tokens-menu",className:"main_ui_workspace_tokens_sidebar__import-export-menu",children:[$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$14$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_tokens_sidebar__import-export-menu-item",onClick:$on_modal_show$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sidebar__import-menu-item",
children:(0,$APP.$rumext$v2$jsx$$)("div",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.import")})})}):null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_tokens_sidebar__import-export-menu-item",onClick:$on_export$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.export")})]}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$14$$)?$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,
$APP.$cljs$cst$1212$token_base_font_size$$):$can_edit_QMARK_$jscomp$14$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"secondary",icon:"settings","aria-label":"Settings",onClick:$open_settings_modal$$}):null]})};
$app$main$ui$workspace$tokens$sidebar$tokens_sidebar_tab_STAR_$$=function($props_80267$$){var $tokens_lib$jscomp$53$$=$props_80267$$.tokensLib,$map__80268_on_pointer_down_pages$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$2108$tokens$$,200,38,"0.6",$APP.$cljs$cst$1516$y$$,!1,null,null),$map__80268__$1_size_pages_opened$$=$APP.$cljs$core$__destructure_map$$($map__80268_on_pointer_down_pages$$);$map__80268_on_pointer_down_pages$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80268__$1_size_pages_opened$$,
$APP.$cljs$cst$4610$on_pointer_down$$);var $on_lost_pointer_capture_pages$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80268__$1_size_pages_opened$$,$APP.$cljs$cst$4611$on_lost_pointer_capture$$),$on_pointer_move_pages$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80268__$1_size_pages_opened$$,$APP.$cljs$cst$4612$on_pointer_move$$);$map__80268__$1_size_pages_opened$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80268__$1_size_pages_opened$$,$APP.$cljs$cst$874$size$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_sidebar__sidebar-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sidebar$token_management_section_STAR_$$,{resizeHeight:$map__80268__$1_size_pages_opened$$,tokensLib:$tokens_lib$jscomp$53$$}),(0,$APP.$rumext$v2$jsxs$$)("article",{"data-testid":"tokens-sidebar",className:"main_ui_workspace_tokens_sidebar__tokens-section-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__80268_on_pointer_down_pages$$,
onLostPointerCapture:$on_lost_pointer_capture_pages$$,onPointerMove:$on_pointer_move_pages$$,className:"main_ui_workspace_tokens_sidebar__resize-area-horiz",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_sidebar__resize-handle-horiz"})}),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$tokens_section_STAR_$$,$props_80267$$)]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sidebar$import_export_button_STAR_$$,{})]})};
$app$main$ui$workspace$sidebar$collapse_button_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$app$main$ui$workspace$sidebar$toggle_collapse_left_sidebar$$,className:"main_ui_workspace_sidebar__collapse-sidebar-button",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",size:"s","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.collapse")})})};
$app$main$ui$workspace$sidebar$on_close_document_history$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3768$document_history$$))};
$app$main$ui$workspace$sidebar$right_sidebar_STAR_$$=function($props_80303$$){var $file_id$jscomp$431$$=$props_80303$$.fileId,$layout$jscomp$28$$=$props_80303$$.layout,$dbg_shape_panel_QMARK__section$jscomp$36$$=$props_80303$$.section,$page_id$jscomp$450$$=$props_80303$$.pageId,$active_tokens$jscomp$11$$=$props_80303$$.activeTokens,$is_comments_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_80303$$.drawingTool,$APP.$cljs$cst$3489$comments$$),$is_history_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$28$$,
$APP.$cljs$cst$3768$document_history$$),$can_be_expanded_QMARK__is_inspect_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dbg_shape_panel_QMARK__section$jscomp$36$$,$APP.$cljs$cst$2683$inspect$$);$dbg_shape_panel_QMARK__section$jscomp$36$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3095$shape_panel$$);var $current_section_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1161$info$$),$current_section$jscomp$1_map__80310_on_pointer_down$jscomp$6$$=
$APP.$cljs$core$_deref$$($current_section_STAR_$$);$can_be_expanded_QMARK__is_inspect_QMARK_$$=$dbg_shape_panel_QMARK__section$jscomp$36$$||!$is_comments_QMARK_$$&&!$is_history_QMARK_$$&&$can_be_expanded_QMARK__is_inspect_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_section$jscomp$1_map__80310_on_pointer_down$jscomp$6$$,$APP.$cljs$cst$273$code$$);$current_section$jscomp$1_map__80310_on_pointer_down$jscomp$6$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$273$code$$,
318,318,768,$APP.$cljs$cst$1515$x$$,!0,$APP.$cljs$cst$258$right$$,null);var $map__80310__$1_on_change_section$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($current_section$jscomp$1_map__80310_on_pointer_down$jscomp$6$$);$current_section$jscomp$1_map__80310_on_pointer_down$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80310__$1_on_change_section$jscomp$3$$,$APP.$cljs$cst$4610$on_pointer_down$$);var $on_lost_pointer_capture$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80310__$1_on_change_section$jscomp$3$$,
$APP.$cljs$cst$4611$on_lost_pointer_capture$$),$on_pointer_move$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80310__$1_on_change_section$jscomp$3$$,$APP.$cljs$cst$4612$on_pointer_move$$),$set_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80310__$1_on_change_section$jscomp$3$$,$APP.$cljs$cst$4614$set_size$$),$width$jscomp$210$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80310__$1_on_change_section$jscomp$3$$,$APP.$cljs$cst$874$size$$);
$map__80310__$1_on_change_section$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__80302_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($current_section_STAR_$$,$p1__80302_SHARP_$$)});var $on_expand$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($width$jscomp$210$$),$APP.$rumext$v2$adapt$$($set_width$$)],function(){var $G__80312$$=$width$jscomp$210$$>318?318:768;return $set_width$$.$cljs$core$IFn$_invoke$arity$1$?
$set_width$$.$cljs$core$IFn$_invoke$arity$1$($G__80312$$):$set_width$$($G__80312$$)}),$active_tokens_by_type$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$11$$)],function(){return new $APP.$cljs$core$Delay$$(function(){return $app$common$types$tokens_lib$group_by_type$$($active_tokens$jscomp$11$$)})});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$sidebar$$),{value:$APP.$cljs$cst$258$right$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$active_tokens_by_type$$),
{value:$active_tokens_by_type$$,children:(0,$APP.$rumext$v2$jsxs$$)("aside",{id:"right-sidebar-aside","data-testid":"right-sidebar","data-size":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$210$$),onContextMenu:$app$util$dom$prevent_default_context_menu$$,style:{"--right-sidebar-width":$can_be_expanded_QMARK__is_inspect_QMARK_$$?""+($width$jscomp$210$$??"")+"px":"318px"},className:"main_ui_workspace_sidebar__right-settings-bar "+($can_be_expanded_QMARK__is_inspect_QMARK_$$?"":
"main_ui_workspace_sidebar__not-expand")+" "+($width$jscomp$210$$>318?"main_ui_workspace_sidebar__expanded":""),children:[$can_be_expanded_QMARK__is_inspect_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$current_section$jscomp$1_map__80310_on_pointer_down$jscomp$6$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$4$$,onPointerMove:$on_pointer_move$jscomp$5$$,className:"main_ui_workspace_sidebar__resize-area"}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$right_header$right_header_STAR_$$,
{fileId:$file_id$jscomp$431$$,layout:$layout$jscomp$28$$,pageId:$page_id$jscomp$450$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar__settings-bar-inside",children:$dbg_shape_panel_QMARK__section$jscomp$36$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug_shape_info$debug_shape_info_STAR_$$,{}):$is_comments_QMARK_$$?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$workspace$comments$comments_sidebar_STAR_$$,{}):$is_history_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history_content_STAR_$$,
{}):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$options_toolbox_STAR_$$,{...$props_80303$$,onChangeSection:$map__80310__$1_on_change_section$jscomp$3$$,onExpand:$on_expand$jscomp$4$$})})]})})})};
$app$main$ui$workspace$sidebar$sidebar_STAR_$$=function($page_id$jscomp$451_props_80322$$){var $drawing_tool$jscomp$1$$=$page_id$jscomp$451_props_80322$$.drawingTool,$selected$jscomp$188$$=$page_id$jscomp$451_props_80322$$.selected,$file_id$jscomp$432$$=$page_id$jscomp$451_props_80322$$.fileId,$layout$jscomp$29$$=$page_id$jscomp$451_props_80322$$.layout,$file$jscomp$178$$=$page_id$jscomp$451_props_80322$$.file,$section$jscomp$37$$=$page_id$jscomp$451_props_80322$$.section;$page_id$jscomp$451_props_80322$$=
$page_id$jscomp$451_props_80322$$.pageId;var $tokens_lib$jscomp$55$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$),$active_tokens$jscomp$12$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$55$$)],function(){return $APP.$cljs$core$truth_$$($tokens_lib$jscomp$55$$)?$APP.$app$common$types$tokens_lib$get_tokens_in_active_sets$$($tokens_lib$jscomp$55$$):$APP.$cljs$core$PersistentArrayMap$EMPTY$$}),$selected_token_set_id$jscomp$8$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$active_tokens_force_set$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$55$$),$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$8$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($tokens_lib$jscomp$55$$)?$selected_token_set_id$jscomp$8$$:$tokens_lib$jscomp$55$$)?$app$common$types$tokens_lib$get_tokens_in_active_sets_force$$($tokens_lib$jscomp$55$$,
$selected_token_set_id$jscomp$8$$):$APP.$cljs$core$PersistentArrayMap$EMPTY$$}),$tokenscript_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$),$resolved_active_tokens$jscomp$3$$=$APP.$app$main$data$style_dictionary$use_resolved_tokens_STAR_$$($active_tokens$jscomp$12$$),$tokenscript_resolved_active_tokens$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$12$$),$APP.$rumext$v2$adapt$$($tokenscript_QMARK_$$)],
function(){return $tokenscript_QMARK_$$?$APP.$app$main$data$tokenscript$resolve_tokens$$($active_tokens$jscomp$12$$):null}),$tokenscript_resolved_active_tokens_force_set$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens_force_set$$),$APP.$rumext$v2$adapt$$($tokenscript_QMARK_$$)],function(){return $tokenscript_QMARK_$$?$APP.$app$main$data$tokenscript$resolve_tokens$$($active_tokens_force_set$$):null}),$resolved_active_tokens_force_set$$=$APP.$app$main$data$style_dictionary$use_resolved_tokens_STAR_$$($active_tokens_force_set$$);
return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($cljs$cst$5729$collapse_left_sidebar$$.$cljs$core$IFn$_invoke$arity$1$($layout$jscomp$29$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$collapsed_button_STAR_$$,{}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$left_sidebar_STAR_$$,{layout:$layout$jscomp$29$$,file:$file$jscomp$178$$,pageId:$page_id$jscomp$451_props_80322$$,tokensLib:$tokens_lib$jscomp$55$$,activeTokens:$active_tokens_force_set$$,
resolvedActiveTokens:$tokenscript_QMARK_$$?$tokenscript_resolved_active_tokens_force_set$$:$resolved_active_tokens_force_set$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$right_sidebar_STAR_$$,{pageId:$page_id$jscomp$451_props_80322$$,selected:$selected$jscomp$188$$,tokensLib:$tokens_lib$jscomp$55$$,section:$section$jscomp$37$$,activeTokens:$tokenscript_QMARK_$$?$tokenscript_resolved_active_tokens$$:$resolved_active_tokens$jscomp$3$$,layout:$layout$jscomp$29$$,drawingTool:$drawing_tool$jscomp$1$$,
file:$file$jscomp$178$$,fileId:$file_id$jscomp$432$$})]})};
$app$util$zip$writer$$=function(){var $map__80276__$1$jscomp$inline_13912_mtype$jscomp$inline_13913_stream_writer$$=$APP.$cljs$core$__destructure_map$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1732$mtype$$,"application/zip"],null)]));$map__80276__$1$jscomp$inline_13912_mtype$jscomp$inline_13913_stream_writer$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80276__$1$jscomp$inline_13912_mtype$jscomp$inline_13913_stream_writer$$,$APP.$cljs$cst$1732$mtype$$);
$map__80276__$1$jscomp$inline_13912_mtype$jscomp$inline_13913_stream_writer$$=new $shadow$js$shim$module$0$0zip_js$0zip$$.BlobWriter($APP.$cljs$core$truth_$$($map__80276__$1$jscomp$inline_13912_mtype$jscomp$inline_13913_stream_writer$$)?$map__80276__$1$jscomp$inline_13912_mtype$jscomp$inline_13913_stream_writer$$:"application/octet-stream");return new $shadow$js$shim$module$0$0zip_js$0zip$$.ZipWriter($map__80276__$1$jscomp$inline_13912_mtype$jscomp$inline_13913_stream_writer$$)};
$app$util$zip$add$$=function($writer$jscomp$174$$,$path$jscomp$291$$,$content$jscomp$253$$){if($content$jscomp$253$$ instanceof Uint8Array)$writer$jscomp$174$$.add($path$jscomp$291$$,new $shadow$js$shim$module$0$0zip_js$0zip$$.Uint8ArrayReader($content$jscomp$253$$));else if($content$jscomp$253$$ instanceof ArrayBuffer)$writer$jscomp$174$$.add($path$jscomp$291$$,new $shadow$js$shim$module$0$0zip_js$0zip$$.Uint8ArrayReader(new Uint8Array($content$jscomp$253$$)));else if($content$jscomp$253$$ instanceof
Blob)$writer$jscomp$174$$.add($path$jscomp$291$$,new $shadow$js$shim$module$0$0zip_js$0zip$$.BlobReader($content$jscomp$253$$));else if(typeof $content$jscomp$253$$==="string")$writer$jscomp$174$$.add($path$jscomp$291$$,new $shadow$js$shim$module$0$0zip_js$0zip$$.TextReader($content$jscomp$253$$));else throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("invalid data received for zip/add fn",$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,$APP.$cljs$cst$273$code$$,$APP.$cljs$cst$1760$invalid_type$$,$APP.$cljs$cst$275$hint$$,"invalid data received for zip/add fn"],null),null])),null);};$app$util$zip$read_as_text$$=function($entry$jscomp$82$$){var $writer$jscomp$175$$=new $shadow$js$shim$module$0$0zip_js$0zip$$.TextWriter;return $entry$jscomp$82$$.getData($writer$jscomp$175$$)};$app$util$zip$close$$=function($closeable$$){return $closeable$$.close()};
$app$main$ui$workspace$tokens$export$0$modal$export_tab_STAR_$$=function($children$jscomp$306_props_80284$$){var $is_disabled$jscomp$2$$=$children$jscomp$306_props_80284$$.isDisabled,$on_export$jscomp$1$$=$children$jscomp$306_props_80284$$.onExport;$children$jscomp$306_props_80284$$=$children$jscomp$306_props_80284$$.children;return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_export_modal__export-preview",children:[$APP.$cljs$core$truth_$$($is_disabled$jscomp$2$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"body-medium",className:"main_ui_workspace_tokens_export_modal__preview-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export.preview")}),$APP.$cljs$core$truth_$$($is_disabled$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export_modal__disabled-message",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export.no-tokens-themes-sets")}):$children$jscomp$306_props_80284$$,
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_export_modal__export-actions",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",disabled:$is_disabled$jscomp$2$$,onClick:$on_export$jscomp$1$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export")})]})]})};
$app$main$ui$workspace$tokens$export$0$modal$single_file_tab_STAR_$$=function(){var $is_disabled$jscomp$3_tokens_data$jscomp$1$$=function(){var $G__80287$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$tokens_lib$$);return $G__80287$$==null?null:$APP.$app$common$types$tokens_lib$export_dtcg_json$$($G__80287$$)}(),$tokens_json$$=$is_disabled$jscomp$3_tokens_data$jscomp$1$$==null?null:$APP.$app$common$json$encode$$.$cljs$core$IFn$_invoke$arity$variadic$($is_disabled$jscomp$3_tokens_data$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,
$APP.$cljs$core$identity$$,$APP.$cljs$cst$294$indent$$,2]));$is_disabled$jscomp$3_tokens_data$jscomp$1$$=$APP.$cljs$core$empty_QMARK_$$($is_disabled$jscomp$3_tokens_data$jscomp$1$$);var $on_export$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_json$$)],function(){return $APP.$cljs$core$truth_$$($tokens_json$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"export-tokens",$APP.$cljs$cst$139$type$$,"single"],null))),$APP.$app$util$dom$trigger_download$$("tokens.json",$APP.$app$util$webapi$create_blob$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($tokens_json$$)?$tokens_json$$:"{}","application/json"))):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$export_tab_STAR_$$,{isDisabled:$is_disabled$jscomp$3_tokens_data$jscomp$1$$,onExport:$on_export$jscomp$2$$,
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export_modal__json-preview",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$code_block$code_block_STAR_$$,{code:$tokens_json$$,type:"json"})})})};
$app$main$ui$workspace$tokens$export$0$modal$download_tokens_zip_BANG_$$=function($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$){var $writer$jscomp$176$$=$app$util$zip$writer$$();$G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$=$APP.$cljs$core$seq$$($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$);for(var $G__80341_chunk__80292_80327_path_80345$$=null,$G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$=
0,$i__80294_80329$$=0;;)if($i__80294_80329$$<$G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$){var $content_80332_vec__80304_80330$$=$G__80341_chunk__80292_80327_path_80345$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__80294_80329$$),$path_80331$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content_80332_vec__80304_80330$$,0,null);$content_80332_vec__80304_80330$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content_80332_vec__80304_80330$$,
1,null);$app$util$zip$add$$($writer$jscomp$176$$,$path_80331$$,$APP.$app$common$json$encode$$.$cljs$core$IFn$_invoke$arity$variadic$($content_80332_vec__80304_80330$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$identity$$,$APP.$cljs$cst$294$indent$$,2])));$i__80294_80329$$+=1}else if($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$=$APP.$cljs$core$seq$$($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$))$APP.$cljs$core$chunked_seq_QMARK_$$($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$)?
($G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$=$APP.$cljs$core$_chunked_first$$($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$),$G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$=$APP.$cljs$core$_chunked_rest$$($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$),$G__80341_chunk__80292_80327_path_80345$$=$G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$,
$G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$=$APP.$cljs$core$count$$($G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$)):($G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$=$APP.$cljs$core$first$$($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$),$G__80341_chunk__80292_80327_path_80345$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$,
0,null),$G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$,1,null),$app$util$zip$add$$($writer$jscomp$176$$,$G__80341_chunk__80292_80327_path_80345$$,$APP.$app$common$json$encode$$.$cljs$core$IFn$_invoke$arity$variadic$($G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$291$key_fn$$,
$APP.$cljs$core$identity$$,$APP.$cljs$cst$294$indent$$,2]))),$G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$=$APP.$cljs$core$next$$($G__80340_multi_file_entries_seq__80291_80326_seq__80291_80338__$1_temp__5825__auto___80337$$),$G__80341_chunk__80292_80327_path_80345$$=null,$G__80342_c__5548__auto___80339_content_80346_count__80293_80328_vec__80307_80344$$=0),$i__80294_80329$$=0;else break;return $app$util$zip$close$$($writer$jscomp$176$$).then(function($p1__80290_SHARP_$$){return $APP.$app$util$dom$trigger_download$$("tokens.zip",
$p1__80290_SHARP_$$)})};
$app$main$ui$workspace$tokens$export$0$modal$multi_file_tab_STAR_$$=function(){var $files$jscomp$30$$=function(){var $G__80313$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$tokens_lib$$);return $G__80313$$==null?null:$app$common$types$tokens_lib$export_dtcg_multi_file$$($G__80313$$)}(),$is_disabled$jscomp$4$$=$APP.$cljs$core$empty_QMARK_$$($files$jscomp$30$$)||$APP.$cljs$core$every_QMARK_$$(function($p__80314_v$jscomp$680$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80314_v$jscomp$680$$,0,
null);$p__80314_v$jscomp$680$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80314_v$jscomp$680$$,1,null);return $APP.$cljs$core$empty_QMARK_$$($p__80314_v$jscomp$680$$)},$files$jscomp$30$$),$on_export$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$30$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,
"export-tokens",$APP.$cljs$cst$139$type$$,"multiple"],null)));return $app$main$ui$workspace$tokens$export$0$modal$download_tokens_zip_BANG_$$($files$jscomp$30$$)});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$export_tab_STAR_$$,{onExport:$on_export$jscomp$3$$,isDisabled:$is_disabled$jscomp$4$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export_modal__preview-container",children:(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_export_modal__file-list",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$205$$,$p__80318_path$jscomp$293$$){$p__80318_path$jscomp$293$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80318_path$jscomp$293$$,0,null);$out_arr__44092__auto__$jscomp$205$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_tokens_export_modal__file-item",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export_modal__file-icon",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"document"})}),(0,$APP.$rumext$v2$jsx$$)("div",{title:$p__80318_path$jscomp$293$$,className:"main_ui_workspace_tokens_export_modal__file-name",children:$p__80318_path$jscomp$293$$})]},$p__80318_path$jscomp$293$$));return $out_arr__44092__auto__$jscomp$205$$},[],$files$jscomp$30$$)})})})};
$app$main$ui$workspace$tokens$export$0$modal$export_modal_body_STAR_$$=function(){var $selected_tab_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$("single"),$selected_tab$jscomp$1$$=$APP.$cljs$core$_deref$$($selected_tab_STAR_$jscomp$1$$),$on_change_tab$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__80323_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($selected_tab_STAR_$jscomp$1$$,$p1__80323_SHARP_$$)}),$tabs$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export.single-file"),$APP.$cljs$cst$266$id$$,"single"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export.multiple-files"),
$APP.$cljs$cst$266$id$$,"multiple"],null)],null)}),$JSCompiler_temp_const$jscomp$1884$$=$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_export_modal__export-modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.export-tokens")});a:switch($selected_tab$jscomp$1$$){case "single":var $JSCompiler_inline_result$jscomp$1885$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$single_file_tab_STAR_$$,
{});break a;case "multiple":$JSCompiler_inline_result$jscomp$1885$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$multi_file_tab_STAR_$$,{});break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($selected_tab$jscomp$1$$)].join(""));}return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_export_modal__export-modal-wrapper",children:[$JSCompiler_temp_const$jscomp$1884$$,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,
{tabs:$tabs$jscomp$7$$,selected:$selected_tab$jscomp$1$$,onChange:$on_change_tab$jscomp$3$$,children:$JSCompiler_inline_result$jscomp$1885$$})]})};
$app$main$ui$workspace$tokens$export$0$export_modal_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_export__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_export__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_export__close-btn",onClick:$APP.$app$main$data$modal$hide_BANG_$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
variant:"ghost",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$export$0$modal$export_modal_body_STAR_$$,{})]})})};
$app$main$data$workspace$tokens$import_export$group_by_value$$=function($m$jscomp$241$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$170$$,$p__80359_v$jscomp$681$$){var $k$jscomp$699$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80359_v$jscomp$681$$,0,null);$p__80359_v$jscomp$681$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80359_v$jscomp$681$$,1,null);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($acc$jscomp$170$$,
$p__80359_v$jscomp$681$$,$APP.$cljs$core$conj$$,$k$jscomp$699$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$m$jscomp$241$$)};
$app$main$data$workspace$tokens$import_export$show_unknown_types_warning$$=function($unknown_tokens$jscomp$1$$){var $type__GT_tokens$$=$app$main$data$workspace$tokens$import_export$group_by_value$$($unknown_tokens$jscomp$1$$);$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.workspace.tokens.import-export",$APP.$cljs$cst$1162$warn$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"unsupported token types found during import"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2108$tokens$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80364_type$jscomp$707$$){var $path$jscomp$294$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80364_type$jscomp$707$$,
0,null);$p__80364_type$jscomp$707$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80364_type$jscomp$707$$,1,null);return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$294$$)," (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p__80364_type$jscomp$707$$),")"].join("")},$unknown_tokens$jscomp$1$$))],null)],null)}),null,"app.main.data.workspace.tokens.import-export",$APP.$cljs$cst$1162$warn$$,!1);return $APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1642$content$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.unknown-token-type-message"),$APP.$cljs$cst$5446$detail$$,$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",function(){return function $app$main$data$workspace$tokens$import_export$show_unknown_types_warning_$_iter__80368$$($s__80369$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$411$$=$APP.$cljs$core$seq$$($s__80369$$);if($temp__5825__auto__$jscomp$411$$){var $s__80369__$2$$=
$temp__5825__auto__$jscomp$411$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__80369__$2$$)){var $c__5501__auto__$jscomp$51$$=$APP.$cljs$core$_chunked_first$$($s__80369__$2$$),$size__5502__auto__$jscomp$51$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$51$$),$b__80371$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$51$$);return function(){for(var $i__80370$$=0;;)if($i__80370$$<$size__5502__auto__$jscomp$51$$){var $vec__80372$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$51$$,$i__80370$$),
$token_type$jscomp$18$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80372$$,0,null),$token_paths$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80372$$,1,null);$APP.$cljs$core$chunk_append$$($b__80371$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.unknown-token-type-section",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_type$jscomp$18$$,
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.warning-count",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($token_paths$jscomp$1$$))]))]))),"\x3cul\x3e",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__80363_SHARP_$$){return["\x3cli\x3e",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__80363_SHARP_$$),
"\x3c/li\x3e"].join("")}}($i__80370$$,$vec__80372$$,$token_type$jscomp$18$$,$token_paths$jscomp$1$$,$c__5501__auto__$jscomp$51$$,$size__5502__auto__$jscomp$51$$,$b__80371$$,$s__80369__$2$$,$temp__5825__auto__$jscomp$411$$,$type__GT_tokens$$),$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($token_paths$jscomp$1$$)))),"\x3c/ul\x3e"].join(""));$i__80370$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80371$$),$app$main$data$workspace$tokens$import_export$show_unknown_types_warning_$_iter__80368$$($APP.$cljs$core$_chunked_rest$$($s__80369__$2$$))):
$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80371$$),null)}var $vec__80375$$=$APP.$cljs$core$first$$($s__80369__$2$$),$token_type$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80375$$,0,null),$token_paths$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80375$$,1,null);return $APP.$cljs$core$cons$$([$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.unknown-token-type-section",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_type$jscomp$17$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("labels.warning-count",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($token_paths$$))]))]))),"\x3cul\x3e",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function(){return function($p1__80363_SHARP_$jscomp$1$$){return["\x3cli\x3e",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($p1__80363_SHARP_$jscomp$1$$),"\x3c/li\x3e"].join("")}}($vec__80375$$,$token_type$jscomp$17$$,$token_paths$$,$s__80369__$2$$,$temp__5825__auto__$jscomp$411$$,$type__GT_tokens$$),$APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($token_paths$$)))),"\x3c/ul\x3e"].join(""),$app$main$data$workspace$tokens$import_export$show_unknown_types_warning_$_iter__80368$$($APP.$cljs$core$rest$$($s__80369__$2$$)))}return null}},null,null)}($type__GT_tokens$$)}()),
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$1161$info$$],null))};
$app$main$data$workspace$tokens$import_export$decode_json$$=function($json_string$$){try{return $APP.$app$common$json$decode$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($json_string$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$291$key_fn$$,$APP.$cljs$core$identity$$],null)]))}catch($e80378$$){if($e80378$$ instanceof Error)throw $app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4655$error_DOT_import_SLASH_json_parse_error$$,
$json_string$$,$e80378$$);throw $e80378$$;}};
$app$main$data$workspace$tokens$import_export$parse_decoded_json$$=function($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$,$e$jscomp$365_file_name$jscomp$11$$){try{var $G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$=!$APP.$cljs$core$contains_QMARK_$$($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$,"$metadata")&&
!$APP.$cljs$core$contains_QMARK_$$($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$,"$themes");var $json_format$jscomp$inline_13918$$=$app$common$types$tokens_lib$get_json_format$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$);if($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2139$json_format_SLASH_legacy$$,$json_format$jscomp$inline_13918$$))var $JSCompiler_temp$jscomp$inline_13919$$=$app$common$types$tokens_lib$parse_single_set_dtcg_json$$($e$jscomp$365_file_name$jscomp$11$$,$app$common$types$tokens_lib$legacy_json__GT_dtcg_json$$($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$));else{if($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2140$json_format_SLASH_dtcg$$,$json_format$jscomp$inline_13918$$))var $JSCompiler_temp$jscomp$inline_13920$$=$app$common$types$tokens_lib$parse_single_set_dtcg_json$$($e$jscomp$365_file_name$jscomp$11$$,$JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$);else{if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2139$json_format_SLASH_legacy$$,$json_format$jscomp$inline_13918$$)){var $sets_data$jscomp$inline_13922$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$,"$themes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["$metadata"])),$other_data$jscomp$inline_13923$$=$APP.$cljs$core$select_keys$$($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["$themes","$metadata"],null)),$dtcg_sets_data$jscomp$inline_13924$$=
$app$common$types$tokens_lib$legacy_json__GT_dtcg_json$$($sets_data$jscomp$inline_13922$$);var $JSCompiler_temp$jscomp$inline_13921$$=$APP.$app$common$types$tokens_lib$parse_multi_set_dtcg_json$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$other_data$jscomp$inline_13923$$,$dtcg_sets_data$jscomp$inline_13924$$])))}else $JSCompiler_temp$jscomp$inline_13921$$=$APP.$app$common$types$tokens_lib$parse_multi_set_dtcg_json$$($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$);
$JSCompiler_temp$jscomp$inline_13920$$=$JSCompiler_temp$jscomp$inline_13921$$}$JSCompiler_temp$jscomp$inline_13919$$=$JSCompiler_temp$jscomp$inline_13920$$}return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2147$tokens_lib$$,$JSCompiler_temp$jscomp$inline_13919$$,$cljs$cst$5914$unknown_tokens$$,$app$common$types$tokens_lib$get_tokens_of_unknown_type$$($JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)],null)}catch($e80379$$){if($e80379$$ instanceof
Error)throw $e$jscomp$365_file_name$jscomp$11$$=$e80379$$,$G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$ex_data$$($e$jscomp$365_file_name$jscomp$11$$),$APP.$cljs$cst$945$error_SLASH_code$$)?$app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$945$error_SLASH_code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$ex_data$$($e$jscomp$365_file_name$jscomp$11$$)),
$APP.$cljs$core$ex_message$$($e$jscomp$365_file_name$jscomp$11$$),$e$jscomp$365_file_name$jscomp$11$$):null,$APP.$cljs$core$truth_$$($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$)?$JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$=$G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$:
($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$=$APP.$cljs$core$ex_data$$($e$jscomp$365_file_name$jscomp$11$$),$G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$=$G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$==
null?null:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$932$app_DOT_common_DOT_schema_SLASH_explain$$,$APP.$cljs$cst$570$errors$$],null)),$G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$=
$G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$==null?null:$APP.$cljs$core$first$$($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$),$G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$297$in$$.$cljs$core$IFn$_invoke$arity$1$($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$],null))?$app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4667$error_DOT_import_SLASH_invalid_token_name$$,
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$),$e$jscomp$365_file_name$jscomp$11$$):null,$JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$=$APP.$cljs$core$truth_$$($G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$)?
$G__80358$jscomp$inline_13930_G__80358__$1$jscomp$inline_13931_or__5025__auto__$jscomp$inline_9166_or__5025__auto____$1$jscomp$inline_9167_schema_error$jscomp$inline_13929_single_set_QMARK_$jscomp$inline_13917$$:$app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$2142$error_DOT_import_SLASH_invalid_json_data$$,$JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$,$e$jscomp$365_file_name$jscomp$11$$)),$JSCompiler_inline_result$jscomp$1886_decoded_json$jscomp$8$$;throw $e80379$$;
}};
$app$main$data$workspace$tokens$import_export$validate_library$$=function($map__80381__$1_p__80380_unknown_tokens$jscomp$2$$){$map__80381__$1_p__80380_unknown_tokens$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__80381__$1_p__80380_unknown_tokens$jscomp$2$$);var $tokens_lib$jscomp$56$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80381__$1_p__80380_unknown_tokens$jscomp$2$$,$APP.$cljs$cst$2147$tokens_lib$$);$map__80381__$1_p__80380_unknown_tokens$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80381__$1_p__80380_unknown_tokens$jscomp$2$$,$cljs$cst$5914$unknown_tokens$$);
$APP.$cljs$core$truth_$$($map__80381__$1_p__80380_unknown_tokens$jscomp$2$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$import_export$show_unknown_types_warning$$($map__80381__$1_p__80380_unknown_tokens$jscomp$2$$));try{var $tokens_tree$jscomp$10$$=$APP.$app$common$types$tokens_lib$get_all_tokens_map$$($tokens_lib$jscomp$56$$),$resolved_tokens$jscomp$25$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?
(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($tokens_tree$jscomp$10$$)):$app$main$data$style_dictionary$resolve_tokens_with_verbose_errors$$($tokens_tree$jscomp$10$$);return $APP.$beicon$v2$core$catch$0$cljs$0core$0IFn$0_invoke$0arity$02$$(function($sd_error$$){var $first__80357$jscomp$inline_9172_reference_errors_vec__80355$jscomp$inline_9170$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($sd_error$$,"\n");var $first__80357__$1$jscomp$inline_9174_seq__80356$jscomp$inline_9171$$=
$APP.$cljs$core$seq$$($first__80357$jscomp$inline_9172_reference_errors_vec__80355$jscomp$inline_9170$$);$first__80357$jscomp$inline_9172_reference_errors_vec__80355$jscomp$inline_9170$$=$APP.$cljs$core$first$$($first__80357__$1$jscomp$inline_9174_seq__80356$jscomp$inline_9171$$);var $seq__80356__$1$jscomp$inline_9173_seq__80356__$2$jscomp$inline_9175$$=$APP.$cljs$core$next$$($first__80357__$1$jscomp$inline_9174_seq__80356$jscomp$inline_9171$$);$first__80357__$1$jscomp$inline_9174_seq__80356$jscomp$inline_9171$$=
$APP.$cljs$core$first$$($seq__80356__$1$jscomp$inline_9173_seq__80356__$2$jscomp$inline_9175$$);$seq__80356__$1$jscomp$inline_9173_seq__80356__$2$jscomp$inline_9175$$=$APP.$cljs$core$next$$($seq__80356__$1$jscomp$inline_9173_seq__80356__$2$jscomp$inline_9175$$);$first__80357$jscomp$inline_9172_reference_errors_vec__80355$jscomp$inline_9170$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first__80357$jscomp$inline_9172_reference_errors_vec__80355$jscomp$inline_9170$$,"Error: ")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($first__80357__$1$jscomp$inline_9174_seq__80356$jscomp$inline_9171$$,
"Reference Errors:")?$seq__80356__$1$jscomp$inline_9173_seq__80356__$2$jscomp$inline_9175$$:null;if($APP.$cljs$core$truth_$$($first__80357$jscomp$inline_9172_reference_errors_vec__80355$jscomp$inline_9170$$))return(0,$APP.$beicon$v2$core$of$$)($tokens_lib$jscomp$56$$);throw $app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4668$error_DOT_import_SLASH_style_dictionary_unknown_error$$,$sd_error$$,$sd_error$$);},$APP.$beicon$v2$core$map$$(function(){return $tokens_lib$jscomp$56$$},
$resolved_tokens$jscomp$25$$))}catch($e80382$$){if($e80382$$ instanceof Error)throw $app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4668$error_DOT_import_SLASH_style_dictionary_unknown_error$$,"",$e80382$$);throw $e80382$$;}};
$app$main$data$workspace$tokens$import_export$import_file_stream$$=function($file_path$$,$file_text$$){var $file_name$jscomp$12$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$butlast$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($file_path$$,".")));return $APP.$beicon$v2$core$mapcat$$($app$main$data$workspace$tokens$import_export$validate_library$$,$APP.$beicon$v2$core$map$$(function($p1__80383_SHARP_$$){return $app$main$data$workspace$tokens$import_export$parse_decoded_json$$($p1__80383_SHARP_$$,
$file_name$jscomp$12$$)},$APP.$beicon$v2$core$map$$($app$main$data$workspace$tokens$import_export$decode_json$$,$file_text$$)))};
$app$main$data$workspace$tokens$import_export$import_directory_stream$$=function($file_stream$$){return $APP.$beicon$v2$core$mapcat$$($app$main$data$workspace$tokens$import_export$validate_library$$,$APP.$beicon$v2$core$map$$(function($merged_json$$){return $app$main$data$workspace$tokens$import_export$parse_decoded_json$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($merged_json$$))?$APP.$cljs$core$val$$($APP.$cljs$core$first$$($merged_json$$)):$merged_json$$,
$APP.$cljs$core$ffirst$$($merged_json$$))},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($merged_json$jscomp$1$$,$decoded_json$jscomp$9$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$849$error$$.$cljs$core$IFn$_invoke$arity$1$($decoded_json$jscomp$9$$))?$merged_json$jscomp$1$$:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($merged_json$jscomp$1$$,$decoded_json$jscomp$9$$)},$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$beicon$v2$core$map$$(function($file_text$jscomp$1_p__80384$$){var $file_path$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_text$jscomp$1_p__80384$$,0,null);$file_text$jscomp$1_p__80384$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_text$jscomp$1_p__80384$$,1,null);var $path$jscomp$inline_13933_set_name$jscomp$30$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("/",$APP.$cljs$core$rest$$($APP.$app$common$path_names$split_path$$($file_path$jscomp$1$$)));$path$jscomp$inline_13933_set_name$jscomp$30$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$butlast$$($APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($path$jscomp$inline_13933_set_name$jscomp$30$$,
".")));try{return $APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$path$jscomp$inline_13933_set_name$jscomp$30$$,$app$main$data$workspace$tokens$import_export$decode_json$$($file_text$jscomp$1_p__80384$$)])}catch($e80388$$){if($e80388$$ instanceof Error)return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,$file_path$jscomp$1$$,$APP.$cljs$cst$849$error$$,$e80388$$],null);throw $e80388$$;}},$file_stream$$))))};
$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$=function($type$jscomp$708$$,$tokens_lib_stream$$){$beicon$v2$core$sub_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($tokens_lib_stream$$,function($lib$jscomp$18$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"import-tokens",$APP.$cljs$cst$139$type$$,$type$jscomp$708$$],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$import_tokens_lib$$($lib$jscomp$18$$)]));return $APP.$app$main$data$modal$hide_BANG_$$()},function($err$jscomp$52$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$notifications$show$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1642$content$$,$app$main$data$workspace$tokens$errors$humanize_errors$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$ex_data$$($err$jscomp$52$$)],null)),$APP.$cljs$cst$5446$detail$$,$app$main$data$workspace$tokens$errors$detail_errors$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$ex_data$$($err$jscomp$52$$)],null)),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2360$toast$$,$APP.$cljs$cst$284$level$$,$APP.$cljs$cst$849$error$$],null)))})};
$app$main$ui$workspace$tokens$import$0$modal$import_type_dropdown_STAR_$$=function($file_type_options_initial_option_props_80392$$){var $options$jscomp$634$$=$file_type_options_initial_option_props_80392$$.options,$button_text$jscomp$1_text_render$$=$file_type_options_initial_option_props_80392$$.textRender,$default$$jscomp$94$$=$file_type_options_initial_option_props_80392$$.default,$on_click$jscomp$55$$=$file_type_options_initial_option_props_80392$$.onClick;$file_type_options_initial_option_props_80392$$=
function(){var $or__5025__auto__$jscomp$1310$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80390_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80390_SHARP_$$),$default$$jscomp$94$$)},$options$jscomp$634$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1310$$)?$or__5025__auto__$jscomp$1310$$:$APP.$cljs$core$first$$($options$jscomp$634$$)}();var $selected_option_STAR_$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($file_type_options_initial_option_props_80392$$),$selected_option$jscomp$4$$=$APP.$cljs$core$_deref$$($selected_option_STAR_$$),$show_dropdown_QMARK_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$file_type_options_initial_option_props_80392$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$634$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($option$jscomp$24$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$266$id$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$24$$)),$APP.$cljs$cst$2296$label$$,$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$24$$),$APP.$cljs$cst$4634$aria_label$$,$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$24$$)],null)},$options$jscomp$634$$)});$button_text$jscomp$1_text_render$$=$APP.$cljs$core$truth_$$($button_text$jscomp$1_text_render$$)?
$button_text$jscomp$1_text_render$$.$cljs$core$IFn$_invoke$arity$1$?$button_text$jscomp$1_text_render$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$4$$):$button_text$jscomp$1_text_render$$($selected_option$jscomp$4$$):$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$4$$);var $toggle_dropdown$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$612$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$612$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$612$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_dropdown_QMARK_$jscomp$6$$,$APP.$cljs$core$not$$)}),$close_dropdown$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_QMARK_$jscomp$6$$,!1)}),$handle_option_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($options$jscomp$634$$)],function($event$jscomp$613_option$jscomp$25$$){var $option_id$jscomp$1$$=
$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$get_current_target$$($event$jscomp$613_option$jscomp$25$$),"id");$event$jscomp$613_option$jscomp$25$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80391_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80391_SHARP_$$)),$option_id$jscomp$1$$)},$options$jscomp$634$$));
$close_dropdown$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$close_dropdown$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$close_dropdown$jscomp$5$$();return $APP.$cljs$core$truth_$$($event$jscomp$613_option$jscomp$25$$)?$APP.$cljs$core$reset_BANG_$$($selected_option_STAR_$$,$event$jscomp$613_option$jscomp$25$$):null}),$handle_main_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$55$$),$APP.$rumext$v2$adapt$$($selected_option$jscomp$4$$)],
function($G__80393_event$jscomp$614$$){$APP.$app$util$dom$prevent_default$$($G__80393_event$jscomp$614$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($selected_option$jscomp$4$$)?$on_click$jscomp$55$$:$selected_option$jscomp$4$$)?($G__80393_event$jscomp$614$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$4$$),$on_click$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$55$$.$cljs$core$IFn$_invoke$arity$1$($G__80393_event$jscomp$614$$):$on_click$jscomp$55$$($G__80393_event$jscomp$614$$)):
null});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import_modal__dropdown-btn-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_workspace_tokens_import_modal__dropdown-btn",onClick:$handle_main_click$$,children:$button_text$jscomp$1_text_render$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",className:"main_ui_workspace_tokens_import_modal__dropdown-trigger-btn",
icon:"arrow-down",onClick:$toggle_dropdown$jscomp$4$$,"aria-label":"Show options"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$APP.$cljs$core$_deref$$($show_dropdown_QMARK_$jscomp$6$$),"on-close":$close_dropdown$jscomp$5$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$,{options:$file_type_options_initial_option_props_80392$$,selected:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($selected_option$jscomp$4$$)),
onClick:$handle_option_click$$,setRef:function(){return null}})})]})};$app$main$ui$workspace$tokens$import$0$modal$has_token_files_QMARK_$$=function($file_paths$$){var $and__5023__auto__$jscomp$905$$=$APP.$cljs$core$seq$$($file_paths$$);return $and__5023__auto__$jscomp$905$$?$APP.$cljs$core$some$$(function($p1__80394_SHARP_$$){return $APP.$cuerdas$core$ends_with_QMARK_$$($p1__80394_SHARP_$$,".json")},$file_paths$$):$and__5023__auto__$jscomp$905$$};
$app$main$ui$workspace$tokens$import$0$modal$validate_token_files$$=function($file_stream$jscomp$1$$){return $APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$identity$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($file_entries_file_paths$jscomp$1$$){$file_entries_file_paths$jscomp$1$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$file_entries_file_paths$jscomp$1$$);if($APP.$cljs$core$truth_$$($app$main$ui$workspace$tokens$import$0$modal$has_token_files_QMARK_$$($file_entries_file_paths$jscomp$1$$)))return null;
throw $app$main$data$workspace$tokens$errors$error_ex_info$$($APP.$cljs$cst$4670$error_DOT_import_SLASH_no_token_files_found$$,$file_entries_file_paths$jscomp$1$$,null);},$APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($acc$jscomp$171$$,$file_text$jscomp$2_p__80395$$){var $file_path$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_text$jscomp$2_p__80395$$,0,null);$file_text$jscomp$2_p__80395$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($file_text$jscomp$2_p__80395$$,
1,null);return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($acc$jscomp$171$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file_path$jscomp$2$$,$file_text$jscomp$2_p__80395$$],null))},$APP.$cljs$core$PersistentVector$EMPTY$$,$file_stream$jscomp$1$$)))};
$app$main$ui$workspace$tokens$import$0$modal$import_modal_body_STAR_$$=function(){var $file_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$dir_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$zip_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$on_display_file_explorer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($file_input_ref$$))}),$on_display_dir_explorer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($dir_input_ref$$))}),
$on_display_zip_explorer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($zip_input_ref$$))}),$handle_import_action$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_display_file_explorer$$),$APP.$rumext$v2$adapt$$($on_display_dir_explorer$$),$APP.$rumext$v2$adapt$$($on_display_zip_explorer$$)],function($val$jscomp$222$$){switch($val$jscomp$222$$ instanceof $APP.$cljs$core$Keyword$$?
$val$jscomp$222$$.$fqn$:null){case "file":return $on_display_file_explorer$$.$cljs$core$IFn$_invoke$arity$0$?$on_display_file_explorer$$.$cljs$core$IFn$_invoke$arity$0$():$on_display_file_explorer$$();case "folder":return $on_display_dir_explorer$$.$cljs$core$IFn$_invoke$arity$0$?$on_display_dir_explorer$$.$cljs$core$IFn$_invoke$arity$0$():$on_display_dir_explorer$$();case "zip":return $on_display_zip_explorer$$.$cljs$core$IFn$_invoke$arity$0$?$on_display_zip_explorer$$.$cljs$core$IFn$_invoke$arity$0$():
$on_display_zip_explorer$$();default:return null}}),$on_import_directory$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$615_files$jscomp$31$$){$event$jscomp$615_files$jscomp$31$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($file$jscomp$179$$){var $name$jscomp$479$$=$file$jscomp$179$$.name;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$179$$.type,"application/json")||$APP.$cuerdas$core$ends_with_QMARK_$$($name$jscomp$479$$,
".json")},$APP.$app$util$dom$get_files$$($APP.$app$util$dom$get_target$$($event$jscomp$615_files$jscomp$31$$)));$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$("multiple",$app$main$data$workspace$tokens$import_export$import_directory_stream$$($app$main$ui$workspace$tokens$import$0$modal$validate_token_files$$($APP.$beicon$v2$core$mapcat$$(function($file$jscomp$180$$){return $APP.$beicon$v2$core$map$$(function($file_text$jscomp$3$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$file$jscomp$180$$.webkitRelativePath,$file_text$jscomp$3$$],null)},$app$util$webapi$read_file_as_text$$($file$jscomp$180$$))},$APP.$beicon$v2$core$from$$($event$jscomp$615_files$jscomp$31$$)))));return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($dir_input_ref$$),"")}),$on_import_zip_file$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$616_zipfile$$){$event$jscomp$616_zipfile$$=$APP.$cljs$core$first$$($APP.$app$util$dom$get_files$$($APP.$app$util$dom$get_target$$($event$jscomp$616_zipfile$$)));
var $zipfile_name$$=$APP.$cuerdas$core$strip_suffix$$($event$jscomp$616_zipfile$$.name,".zip");$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$("zip",$app$main$data$workspace$tokens$import_export$import_directory_stream$$($app$main$ui$workspace$tokens$import$0$modal$validate_token_files$$($APP.$beicon$v2$core$mapcat$$(function($file_content_zip_reader$$){$file_content_zip_reader$$=$app$util$zip$reader$$($file_content_zip_reader$$);return $APP.$beicon$v2$core$finalize$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$util$zip$close$$,
$file_content_zip_reader$$),$APP.$beicon$v2$core$mapcat$$(function($entries$jscomp$46$$){return $APP.$beicon$v2$core$merge_map$$(function($content_promise_entry$jscomp$83$$){var $filename$jscomp$13$$=""+($zipfile_name$$??"")+"/"+($content_promise_entry$jscomp$83$$.filename??"");$content_promise_entry$jscomp$83$$=$app$util$zip$read_as_text$$($content_promise_entry$jscomp$83$$);return $APP.$beicon$v2$core$from$$($content_promise_entry$jscomp$83$$.then(function($text$jscomp$148$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$filename$jscomp$13$$,$text$jscomp$148$$],null)}))},$APP.$beicon$v2$core$filter$$(function($entry$jscomp$84$$){return $APP.$cuerdas$core$ends_with_QMARK_$$($entry$jscomp$84$$.filename,".json")},$APP.$beicon$v2$core$from$$($entries$jscomp$46$$)))},$APP.$beicon$v2$core$from$$($file_content_zip_reader$$.getEntries())))},$APP.$app$util$webapi$read_file_as_array_buffer$$($event$jscomp$616_zipfile$$)))));return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($zip_input_ref$$),
"")}),$on_import_json_file$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$617_file$jscomp$181$$){$event$jscomp$617_file$jscomp$181$$=$APP.$cljs$core$first$$($APP.$app$util$dom$get_files$$($APP.$app$util$dom$get_target$$($event$jscomp$617_file$jscomp$181$$)));$app$main$ui$workspace$tokens$import$0$modal$on_stream_imported$$("single",$app$main$data$workspace$tokens$import_export$import_file_stream$$($event$jscomp$617_file$jscomp$181$$.name,$app$util$webapi$read_file_as_text$$($event$jscomp$617_file$jscomp$181$$)));
return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($file_input_ref$$),"")}),$render_button_text$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($option$jscomp$26$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.import-button-prefix",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2296$label$$.$cljs$core$IFn$_invoke$arity$1$($option$jscomp$26$$)]))});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_tokens_import_modal__import-modal-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_import_modal__import-modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-tokens")}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"ul",typography:"body-medium",
className:"main_ui_workspace_tokens_import_modal__import-description",children:[(0,$APP.$rumext$v2$jsx$$)("li",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-single-file")}),(0,$APP.$rumext$v2$jsx$$)("li",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-multiple-files")})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{type:$APP.$cljs$cst$2320$context$$,
appearance:"neutral",level:"default",isHtml:!0,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-warning")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import_modal__import-actions",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"file",ref:$file_input_ref$$,style:{display:"none"},accept:".json",onChange:$on_import_json_file$$}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"file",ref:$zip_input_ref$$,style:{display:"none"},accept:".zip",
onChange:$on_import_zip_file$$}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"file",ref:$dir_input_ref$$,style:{display:"none"},accept:"",webkitdirectory:"true",onChange:$on_import_directory$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$import$0$modal$import_type_dropdown_STAR_$$,
{options:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-menu-json-option"),$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$208$file$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-menu-zip-option"),
$APP.$cljs$cst$260$value$$,$cljs$cst$5915$zip$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.import-menu-folder-option"),$APP.$cljs$cst$260$value$$,$cljs$cst$5916$folder$$],null)],null),onClick:$handle_import_action$$,textRender:$render_button_text$$,"default":$APP.$cljs$cst$208$file$$})]})]})};
$app$main$ui$workspace$tokens$import$0$import_modal_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_import__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_import__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_import__close-btn",onClick:$APP.$app$main$data$modal$hide_BANG_$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),
variant:"ghost",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$import$0$modal$import_modal_body_STAR_$$,{})]})})};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$resolve_value$$=function($tokens$jscomp$58_tokens__$1$jscomp$9$$,$prev_token$jscomp$2$$,$token_name$jscomp$35$$,$value$jscomp$950$$){var $valid_token_name_QMARK_$$=function(){var $and__5023__auto__$jscomp$906$$=typeof $token_name$jscomp$35$$==="string";return $and__5023__auto__$jscomp$906$$?$APP.$cljs$core$re_matches$$($APP.$app$common$types$token$token_name_validation_regex$$,$token_name$jscomp$35$$):$and__5023__auto__$jscomp$906$$}(),
$token$jscomp$176$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$950$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$not$$($valid_token_name_QMARK_$$)||$APP.$cuerdas$core$blank_QMARK_$$($token_name$jscomp$35$$)?"__PENPOT__TOKEN__NAME__PLACEHOLDER__":$token_name$jscomp$35$$],null);$tokens$jscomp$58_tokens__$1$jscomp$9$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$58_tokens__$1$jscomp$9$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$2$$)),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$176$$),function($p1__80401_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80401_SHARP_$$,$prev_token$jscomp$2$$,
$token$jscomp$176$$]))]))});return $APP.$cljs$core$truth_$$($APP.$app$common$files$tokens$token_circular_reference_QMARK_$$($tokens$jscomp$58_tokens__$1$jscomp$9$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$176$$)))?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4657$error_DOT_token_SLASH_circular_reference$$,null)],null)):$APP.$beicon$v2$core$mapcat$$(function($errors$jscomp$38_map__80403_resolved_tokens$jscomp$26$$){$errors$jscomp$38_map__80403_resolved_tokens$jscomp$26$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$38_map__80403_resolved_tokens$jscomp$26$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$176$$));var $map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$38_map__80403_resolved_tokens$jscomp$26$$);$errors$jscomp$38_map__80403_resolved_tokens$jscomp$26$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$,
$APP.$cljs$cst$570$errors$$);$map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$,$APP.$cljs$cst$4686$resolved_value$$);$map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$):
$map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$;return $APP.$cljs$core$truth_$$($map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$map__80403__$1_resolved_value$jscomp$7_resolved_value__$1$jscomp$2$$],null)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$first$$($errors$jscomp$38_map__80403_resolved_tokens$jscomp$26$$)],
null))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($tokens$jscomp$58_tokens__$1$jscomp$9$$)):$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$58_tokens__$1$jscomp$9$$))};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$hex__GT_color_obj$$=function($hex$jscomp$17_hex__$1$jscomp$3$$){var $alpha$jscomp$20_temp__5825__auto__$jscomp$414$$=$APP.$app$main$data$tinycolor$valid_color$$($hex$jscomp$17_hex__$1$jscomp$3$$);if($APP.$cljs$core$truth_$$($alpha$jscomp$20_temp__5825__auto__$jscomp$414$$)){$hex$jscomp$17_hex__$1$jscomp$3$$=$APP.$app$main$data$tinycolor$__GT_hex_string$$($alpha$jscomp$20_temp__5825__auto__$jscomp$414$$);$alpha$jscomp$20_temp__5825__auto__$jscomp$414$$=
$APP.$app$main$data$tinycolor$alpha$$($alpha$jscomp$20_temp__5825__auto__$jscomp$414$$);var $b$jscomp$363_vec__80404$$=$APP.$app$common$types$color$hex__GT_rgb$$($hex$jscomp$17_hex__$1$jscomp$3$$),$r$jscomp$141$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$363_vec__80404$$,0,null),$g$jscomp$164$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$363_vec__80404$$,1,null);$b$jscomp$363_vec__80404$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$363_vec__80404$$,
2,null);var $v$jscomp$682_vec__80408$$=$app$common$types$color$hex__GT_hsv$$($hex$jscomp$17_hex__$1$jscomp$3$$),$h$jscomp$184$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$682_vec__80408$$,0,null),$s$jscomp$592$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$682_vec__80408$$,1,null);$v$jscomp$682_vec__80408$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$682_vec__80408$$,2,null);return new $APP.$cljs$core$PersistentArrayMap$$(null,8,
[$APP.$cljs$cst$2698$hex$$,$hex$jscomp$17_hex__$1$jscomp$3$$,$APP.$cljs$cst$1749$r$$,$r$jscomp$141$$,$APP.$cljs$cst$1750$g$$,$g$jscomp$164$$,$APP.$cljs$cst$1525$b$$,$b$jscomp$363_vec__80404$$,$APP.$cljs$cst$1907$h$$,$h$jscomp$184$$,$APP.$cljs$cst$4235$s$$,$s$jscomp$592$$,$APP.$cljs$cst$3723$v$$,$v$jscomp$682_vec__80408$$,$APP.$cljs$cst$746$alpha$$,$alpha$jscomp$20_temp__5825__auto__$jscomp$414$$],null)}return null};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$ramp_STAR_$$=function($props_80411_wrapper_node_ref$$){var $on_change$jscomp$85$$=$props_80411_wrapper_node_ref$$.onChange,$color$jscomp$188$$=$props_80411_wrapper_node_ref$$.color;$props_80411_wrapper_node_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);var $dragging_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$on_start_drag$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$3$$,
!0)}),$on_finish_drag$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$3$$,!1)}),$internal_color_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$ui$workspace$tokens$management$forms$controls$color_input$hex__GT_color_obj$$($color$jscomp$188$$)}),$internal_color$jscomp$1$$=$APP.$cljs$core$_deref$$($internal_color_STAR_$jscomp$1$$),$on_change_SINGLEQUOTE_$jscomp$10$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$85$$)],function($map__80416__$1_p__80415$$){$map__80416__$1_p__80415$$=$APP.$cljs$core$__destructure_map$$($map__80416__$1_p__80415$$);var $hex$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80416__$1_p__80415$$,$APP.$cljs$cst$2698$hex$$),$alpha$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80416__$1_p__80415$$,$APP.$cljs$cst$746$alpha$$),$dragging_QMARK_$jscomp$11$$=
$APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$3$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($dragging_QMARK_$jscomp$11$$)?$hex$jscomp$18$$:$dragging_QMARK_$jscomp$11$$))return null;$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$jscomp$1$$,$map__80416__$1_p__80415$$);return $on_change$jscomp$85$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$85$$.$cljs$core$IFn$_invoke$arity$2$($hex$jscomp$18$$,$alpha$jscomp$21$$):$on_change$jscomp$85$$($hex$jscomp$18$$,$alpha$jscomp$21$$)});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$188$$)],function(){var $temp__5825__auto__$jscomp$415$$=$APP.$app$main$data$tinycolor$valid_color$$($color$jscomp$188$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$415$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$tinycolor$__GT_hex_string$$($temp__5825__auto__$jscomp$415$$),$APP.$cljs$cst$2698$hex$$.$cljs$core$IFn$_invoke$arity$1$($internal_color$jscomp$1$$))?
null:$APP.$cljs$core$reset_BANG_$$($internal_color_STAR_$jscomp$1$$,$app$main$ui$workspace$tokens$management$forms$controls$color_input$hex__GT_color_obj$$($temp__5825__auto__$jscomp$415$$)):null});$app$main$ui$workspace$colorpicker$use_color_picker_css_variables_BANG_$$($props_80411_wrapper_node_ref$$,$internal_color$jscomp$1$$);return(0,$APP.$rumext$v2$jsx$$)("div",{ref:$props_80411_wrapper_node_ref$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$ramp$ramp_selector_STAR_$$,
{color:$internal_color$jscomp$1$$,onStartDrag:$on_start_drag$jscomp$6$$,onFinishDrag:$on_finish_drag$jscomp$6$$,onChange:$on_change_SINGLEQUOTE_$jscomp$10$$})})};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$color_input_STAR_$$=function($props_80419_touched_QMARK_$jscomp$8$$){var $error$jscomp$144_name$jscomp$480$$=void 0,$token$jscomp$177$$=void 0,$tokens$jscomp$59$$=void 0,$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$=void 0;({name:$error$jscomp$144_name$jscomp$480$$,tokens:$tokens$jscomp$59$$,token:$token$jscomp$177$$,...$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$}=$props_80419_touched_QMARK_$jscomp$8$$);
var $form$jscomp$189$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$5$$=$error$jscomp$144_name$jscomp$480$$,$token_name$jscomp$36$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$props_80419_touched_QMARK_$jscomp$8$$=function(){var $and__5023__auto__$jscomp$908$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$189$$)),$input_name$jscomp$5$$);return $and__5023__auto__$jscomp$908$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$5$$],null)):$and__5023__auto__$jscomp$908$$}();$error$jscomp$144_name$jscomp$480$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$5$$],null));var $extra_error$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,
$input_name$jscomp$5$$],null)),$value$jscomp$951$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$5$$],null),""),$color_resolved$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$cljs$cst$5917$color_result$$],null),""),$hint$jscomp$22_valid_color$$=function(){var $or__5025__auto__$jscomp$1311$$=$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$951$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1311$$)?$or__5025__auto__$jscomp$1311$$:$APP.$app$main$data$tinycolor$valid_color$$($color_resolved$$)}(),$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);
a:switch($APP.$cljs$cst$3208$theme$$.$cljs$core$IFn$_invoke$arity$1$($default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$)){case "light":$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$="#eef0f2";break a;default:$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$="#2e3434"}$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$=$APP.$cljs$core$truth_$$($hint$jscomp$22_valid_color$$)?$APP.$app$main$data$tinycolor$__GT_hex_string$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$22_valid_color$$)):
$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$;var $alpha$jscomp$22_swatch$$=$APP.$cljs$core$truth_$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$22_valid_color$$))?$APP.$app$main$data$tinycolor$alpha$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$22_valid_color$$)):1,$resolve_stream$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$177$$)],function(){var $temp__5823__auto__$jscomp$236$$=
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$177$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$236$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$236$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$hint$jscomp$22_valid_color$$=$APP.$cljs$core$_deref$$($hint_STAR_$$);var $color_ramp_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$color_ramp_open_QMARK_$$=$APP.$cljs$core$_deref$$($color_ramp_open_STAR_$$),$on_change$jscomp$86_on_click_swatch$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_ramp_open_QMARK_$$)],function(){return $APP.$cljs$core$reset_BANG_$$($color_ramp_open_STAR_$$,$APP.$cljs$core$not$$($color_ramp_open_QMARK_$$))});$alpha$jscomp$22_swatch$$=$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1303$color$$,$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$,$APP.$cljs$cst$1740$opacity$$,$alpha$jscomp$22_swatch$$],null),showTooltip:!1,"data-testid":"token-form-color-bullet",className:"main_ui_workspace_tokens_management_forms_controls_color_input__slot-start",onClick:$on_change$jscomp$86_on_click_swatch$$});$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$5$$),$APP.$rumext$v2$adapt$$($value$jscomp$951$$)],function($JSCompiler_inline_result$jscomp$14344_color_value$jscomp$5_hex__$1$jscomp$4$$,$alpha__$1$$){var $G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$=$value$jscomp$951$$==null?null:$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$951$$),$prev_computed_color_to_rgba_QMARK_$$=$APP.$cljs$core$truth_$$($G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$)?
null:$value$jscomp$951$$==null?null:$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$951$$);$G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$=$APP.$cljs$core$truth_$$($G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$)?$G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$:$prev_computed_color_to_rgba_QMARK_$$;$G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$=$G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$==
null?null:$G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$.getFormat();$prev_computed_color_to_rgba_QMARK_$$=$alpha__$1$$<1&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$,"hex")||$APP.$cljs$core$not$$($G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$));var $to_hex_QMARK_$$=$APP.$cljs$core$not$$($G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($alpha__$1$$,1);$G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$=$prev_computed_color_to_rgba_QMARK_$$?"rgba":$to_hex_QMARK_$$?"hex":$APP.$cljs$core$truth_$$($G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$)?$G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$:"hex";$JSCompiler_inline_result$jscomp$14344_color_value$jscomp$5_hex__$1$jscomp$4$$=$APP.$app$main$data$tinycolor$valid_color$$($JSCompiler_inline_result$jscomp$14344_color_value$jscomp$5_hex__$1$jscomp$4$$).setAlpha($APP.$cljs$core$truth_$$($alpha__$1$$)?
$alpha__$1$$:1);$JSCompiler_inline_result$jscomp$14344_color_value$jscomp$5_hex__$1$jscomp$4$$=$app$main$data$tinycolor$__GT_string$$($JSCompiler_inline_result$jscomp$14344_color_value$jscomp$5_hex__$1$jscomp$4$$,$G__80425$jscomp$inline_13935_format$jscomp$43_prev_format_prev_input_color$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$951$$,$JSCompiler_inline_result$jscomp$14344_color_value$jscomp$5_hex__$1$jscomp$4$$)?($APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$189$$,
$input_name$jscomp$5$$,$JSCompiler_inline_result$jscomp$14344_color_value$jscomp$5_hex__$1$jscomp$4$$,!0),$resolve_stream$$.next($JSCompiler_inline_result$jscomp$14344_color_value$jscomp$5_hex__$1$jscomp$4$$)):null});$on_change$jscomp$86_on_click_swatch$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$5$$)],function($event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$){$event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$=
$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$));$event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$=$APP.$cljs$core$truth_$$($app$main$data$tinycolor$hex_without_hash_prefix_QMARK_$$($event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$))?"#"+($event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$??""):$event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$;$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$189$$,
$input_name$jscomp$5$$,$event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$,!0);return $resolve_stream$$.next($event$jscomp$618_raw_value$jscomp$2_value__$1$jscomp$62$$)});$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$={...$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$,onChange:$on_change$jscomp$86_on_click_swatch$$,value:$APP.$cljs$core$truth_$$($value$jscomp$951$$)?$value$jscomp$951$$:"",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$22_valid_color$$),
variant:"comfortable",slotStart:$alpha$jscomp$22_swatch$$,hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$22_valid_color$$)};$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error$jscomp$144_name$jscomp$480$$)?$props_80419_touched_QMARK_$jscomp$8$$:$error$jscomp$144_name$jscomp$480$$)?{...$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$144_name$jscomp$480$$)}:
$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($extra_error$jscomp$1$$)?$props_80419_touched_QMARK_$jscomp$8$$:$extra_error$jscomp$1$$)?{...$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($extra_error$jscomp$1$$)}:$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$59$$),
$APP.$rumext$v2$adapt$$($token$jscomp$177$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$5$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$36$$)],function(){var $subs$jscomp$24$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error__$1_message$jscomp$119_p__80426$$){var $map__80427__$1_value__$1$jscomp$63$$=$APP.$cljs$core$__destructure_map$$($error__$1_message$jscomp$119_p__80426$$);$error__$1_message$jscomp$119_p__80426$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80427__$1_value__$1$jscomp$63$$,
$APP.$cljs$cst$849$error$$);$map__80427__$1_value__$1$jscomp$63$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80427__$1_value__$1$jscomp$63$$,$APP.$cljs$cst$260$value$$);var $touched_QMARK___$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$189$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$5$$],null));if($APP.$cljs$core$truth_$$($touched_QMARK___$1$$)){if($APP.$cljs$core$truth_$$($error__$1_message$jscomp$119_p__80426$$)){if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error__$1_message$jscomp$119_p__80426$$,
$token_name$jscomp$36$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$189$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1_message$jscomp$119_p__80426$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$189$$,$APP.$cljs$core$assoc_in$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$input_name$jscomp$5$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1_message$jscomp$119_p__80426$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$189$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,
$cljs$cst$5917$color_result$$],null),"");return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1_message$jscomp$119_p__80426$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1_message$jscomp$119_p__80426$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($map__80427__$1_value__$1$jscomp$63$$)]));
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$189$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$5$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$189$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$cljs$cst$5917$color_result$$],
null),$map__80427__$1_value__$1$jscomp$63$$);return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1_message$jscomp$119_p__80426$$,$APP.$cljs$cst$139$type$$,"hint"],null))}return null},$APP.$beicon$v2$core$map$$(function($result$jscomp$375$$){return $APP.$app$common$data$update_when$$($result$jscomp$375$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$color_input$resolve_value$$,
$tokens$jscomp$59$$,$token$jscomp$177$$,$token_name$jscomp$36$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$24$$)}});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$349_props__$1$jscomp$88_props__$2$jscomp$6$$),$APP.$cljs$core$truth_$$($color_ramp_open_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$color_input$ramp_STAR_$$,
{color:$value$jscomp$951$$,onChange:$default_bullet_color_hex$jscomp$19_on_change_value$jscomp$2_profile$jscomp$84$$}):null]})};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$=function($form$jscomp$191$$,$field$jscomp$9$$,$index$jscomp$553$$,$value$jscomp$953$$,$value_subfield$jscomp$1$$){function $clean_errors$jscomp$1$$($errors$jscomp$39$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$39$$,$field$jscomp$9$$))}$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$191$$,
function($state$jscomp$1219$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1219$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,
$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$1$$,$index$jscomp$553$$,$field$jscomp$9$$],null),$APP.$cljs$core$truth_$$(!0)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$953$$):$value$jscomp$953$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$1$$,$index$jscomp$553$$,$field$jscomp$9$$],null),!0),$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,
$APP.$cljs$cst$260$value$$),$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$260$value$$),$APP.$cljs$cst$570$errors$$,$clean_errors$jscomp$1$$),$APP.$cljs$cst$4837$extra_errors$$,$clean_errors$jscomp$1$$),$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$main$ui$workspace$tokens$management$forms$controls$color_input$indexed_color_input_STAR_$$=function($error$jscomp$145_props_80430_touched_QMARK_$jscomp$9$$){var $index$jscomp$554$$=void 0,$hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$=void 0,$token$jscomp$178$$=void 0,$value_subfield$jscomp$2$$=void 0,$tokens$jscomp$60$$=void 0,$props$jscomp$350_props__$1$jscomp$89_props__$2$jscomp$7$$=void 0;({name:$hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$,tokens:$tokens$jscomp$60$$,
token:$token$jscomp$178$$,index:$index$jscomp$554$$,valueSubfield:$value_subfield$jscomp$2$$,...$props$jscomp$350_props__$1$jscomp$89_props__$2$jscomp$7$$}=$error$jscomp$145_props_80430_touched_QMARK_$jscomp$9$$);var $form$jscomp$192$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$6$$=$hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$,$token_name$jscomp$37$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$192$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$error$jscomp$145_props_80430_touched_QMARK_$jscomp$9$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$192$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,
$input_name$jscomp$6$$],null));var $value$jscomp$954$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$192$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$input_name$jscomp$6$$],null),"");$hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$192$$),
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$input_name$jscomp$6$$],null));var $default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$=$APP.$cuerdas$core$blank_QMARK_$$($value$jscomp$954$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.empty-field")],
null):null;$error$jscomp$145_props_80430_touched_QMARK_$jscomp$9$$=$APP.$cljs$core$truth_$$($error$jscomp$145_props_80430_touched_QMARK_$jscomp$9$$)?$APP.$cljs$core$truth_$$($hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$)?$hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$:$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$:null;var $color_resolved$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$192$$),
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$cljs$cst$5917$color_result$$],null),"");$hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1316$$=$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$954$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1316$$)?$or__5025__auto__$jscomp$1316$$:
$APP.$app$main$data$tinycolor$valid_color$$($color_resolved$jscomp$1$$)}();$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$);a:switch($APP.$cljs$cst$3208$theme$$.$cljs$core$IFn$_invoke$arity$1$($default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$)){case "light":$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$=
"#eef0f2";break a;default:$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$="#2e3434"}$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$=$APP.$cljs$core$truth_$$($hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$)?$APP.$app$main$data$tinycolor$__GT_hex_string$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$)):$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$;
var $alpha$jscomp$23_swatch$jscomp$1$$=$APP.$cljs$core$truth_$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$))?$APP.$app$main$data$tinycolor$alpha$$($APP.$app$main$data$tinycolor$valid_color$$($hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$)):1,$resolve_stream$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$178$$)],function(){var $temp__5823__auto__$jscomp$237$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$178$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$input_name$jscomp$6$$],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$237$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$237$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
$hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$1$$);var $color_ramp_open_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$color_ramp_open_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($color_ramp_open_STAR_$jscomp$1$$),$on_change$jscomp$87_on_click_swatch$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color_ramp_open_QMARK_$jscomp$1$$)],function(){return $APP.$cljs$core$reset_BANG_$$($color_ramp_open_STAR_$jscomp$1$$,
$APP.$cljs$core$not$$($color_ramp_open_QMARK_$jscomp$1$$))});$alpha$jscomp$23_swatch$jscomp$1$$=$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$,$APP.$cljs$cst$1740$opacity$$,$alpha$jscomp$23_swatch$jscomp$1$$],null),showTooltip:!1,"data-testid":"token-form-color-bullet",className:"main_ui_workspace_tokens_management_forms_controls_color_input__slot-start",
onClick:$on_change$jscomp$87_on_click_swatch$jscomp$1$$});$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$1$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$6$$),$APP.$rumext$v2$adapt$$($value$jscomp$954$$),$APP.$rumext$v2$adapt$$($index$jscomp$554$$)],function($JSCompiler_inline_result$jscomp$14345_color_value$jscomp$6_hex__$1$jscomp$5$$,$alpha__$1$jscomp$1$$){var $G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$=
$value$jscomp$954$$==null?null:$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$954$$),$prev_computed_color$jscomp$1_to_rgba_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$)?null:$value$jscomp$954$$==null?null:$APP.$app$main$data$tinycolor$valid_color$$($value$jscomp$954$$);$G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$=$APP.$cljs$core$truth_$$($G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$)?
$G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$:$prev_computed_color$jscomp$1_to_rgba_QMARK_$jscomp$1$$;$G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$=$G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$==null?null:$G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$.getFormat();$prev_computed_color$jscomp$1_to_rgba_QMARK_$jscomp$1$$=
$alpha__$1$jscomp$1$$<1&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$,"hex")||$APP.$cljs$core$not$$($G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$));var $to_hex_QMARK_$jscomp$1$$=$APP.$cljs$core$not$$($G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($alpha__$1$jscomp$1$$,
1);$G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$=$prev_computed_color$jscomp$1_to_rgba_QMARK_$jscomp$1$$?"rgba":$to_hex_QMARK_$jscomp$1$$?"hex":$APP.$cljs$core$truth_$$($G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$)?$G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$:"hex";$JSCompiler_inline_result$jscomp$14345_color_value$jscomp$6_hex__$1$jscomp$5$$=$APP.$app$main$data$tinycolor$valid_color$$($JSCompiler_inline_result$jscomp$14345_color_value$jscomp$6_hex__$1$jscomp$5$$).setAlpha($APP.$cljs$core$truth_$$($alpha__$1$jscomp$1$$)?
$alpha__$1$jscomp$1$$:1);$JSCompiler_inline_result$jscomp$14345_color_value$jscomp$6_hex__$1$jscomp$5$$=$app$main$data$tinycolor$__GT_string$$($JSCompiler_inline_result$jscomp$14345_color_value$jscomp$6_hex__$1$jscomp$5$$,$G__80434$jscomp$inline_13937_format$jscomp$44_prev_format$jscomp$1_prev_input_color$jscomp$1$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$954$$,$JSCompiler_inline_result$jscomp$14345_color_value$jscomp$6_hex__$1$jscomp$5$$)?($app$main$ui$workspace$tokens$management$forms$controls$color_input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$($form$jscomp$192$$,
$input_name$jscomp$6$$,$index$jscomp$554$$,$JSCompiler_inline_result$jscomp$14345_color_value$jscomp$6_hex__$1$jscomp$5$$,$value_subfield$jscomp$2$$),$resolve_stream$jscomp$1$$.next($JSCompiler_inline_result$jscomp$14345_color_value$jscomp$6_hex__$1$jscomp$5$$)):null});$on_change$jscomp$87_on_click_swatch$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$1$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$6$$),$APP.$rumext$v2$adapt$$($index$jscomp$554$$)],
function($event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$){$event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$));$event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$=$APP.$cljs$core$truth_$$($app$main$data$tinycolor$hex_without_hash_prefix_QMARK_$$($event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$))?"#"+($event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$??
""):$event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$;$app$main$ui$workspace$tokens$management$forms$controls$color_input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$($form$jscomp$192$$,$input_name$jscomp$6$$,$index$jscomp$554$$,$event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$,$value_subfield$jscomp$2$$);return $resolve_stream$jscomp$1$$.next($event$jscomp$619_raw_value$jscomp$3_value__$1$jscomp$65$$)});$props$jscomp$350_props__$1$jscomp$89_props__$2$jscomp$7$$=
{...$props$jscomp$350_props__$1$jscomp$89_props__$2$jscomp$7$$,onChange:$on_change$jscomp$87_on_click_swatch$jscomp$1$$,value:$APP.$cljs$core$truth_$$($value$jscomp$954$$)?$value$jscomp$954$$:"",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$),slotStart:$alpha$jscomp$23_swatch$jscomp$1$$,hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$23_indexed_error_name$jscomp$481_valid_color$jscomp$1$$)};
$props$jscomp$350_props__$1$jscomp$89_props__$2$jscomp$7$$=$APP.$cljs$core$truth_$$($error$jscomp$145_props_80430_touched_QMARK_$jscomp$9$$)?{...$props$jscomp$350_props__$1$jscomp$89_props__$2$jscomp$7$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$145_props_80430_touched_QMARK_$jscomp$9$$)}:$props$jscomp$350_props__$1$jscomp$89_props__$2$jscomp$7$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$1$$),
$APP.$rumext$v2$adapt$$($tokens$jscomp$60$$),$APP.$rumext$v2$adapt$$($token$jscomp$178$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$6$$),$APP.$rumext$v2$adapt$$($index$jscomp$554$$),$APP.$rumext$v2$adapt$$($value_subfield$jscomp$2$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$37$$)],function(){var $subs$jscomp$25$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$){$error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$=
$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$);var $error__$1$jscomp$1_message$jscomp$120$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$,$APP.$cljs$cst$849$error$$);$error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$,$APP.$cljs$cst$260$value$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error__$1$jscomp$1_message$jscomp$120$$)?$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$1_message$jscomp$120$$)):$error__$1$jscomp$1_message$jscomp$120$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$6$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,
$index$jscomp$554$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$6$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$cljs$cst$5917$color_result$$],null),""),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$])),$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);if($error__$1$jscomp$1_message$jscomp$120$$!=null){$error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$1_message$jscomp$120$$);if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$,
$token_name$jscomp$37$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$input_name$jscomp$6$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,$APP.$cljs$core$assoc_in$$,
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$cljs$cst$5917$color_result$$],null),"");return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$1_message$jscomp$120$$=
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$)]));var $input_value$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$192$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$input_name$jscomp$6$$],null),"");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$192$$,$APP.$cljs$core$update$$,
$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$192$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$2$$,$index$jscomp$554$$,$cljs$cst$5917$color_result$$],null),$APP.$app$main$data$workspace$tokens$format$format_token_value$$($error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$));
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_value$jscomp$2$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($error_SINGLEQUOTE__map__80436__$1_p__80435_value__$1$jscomp$66$$))?$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$1$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$1_message$jscomp$120$$,$APP.$cljs$cst$139$type$$,
"hint"],null))},$APP.$beicon$v2$core$map$$(function($result$jscomp$376$$){return $APP.$app$common$data$update_when$$($result$jscomp$376$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$color_input$resolve_value$$,$tokens$jscomp$60$$,$token$jscomp$178$$,$token_name$jscomp$37$$),$APP.$beicon$v2$core$debounce$$(300,
$resolve_stream$jscomp$1$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$25$$)}});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$350_props__$1$jscomp$89_props__$2$jscomp$7$$),$APP.$cljs$core$truth_$$($color_ramp_open_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$color_input$ramp_STAR_$$,{color:$value$jscomp$954$$,
onChange:$default_bullet_color$jscomp$1_empty_error_hex$jscomp$20_on_change_value$jscomp$3_profile$jscomp$85$$}):null]})};
$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$first_focusable_id$$=function($options$jscomp$635$$){return $APP.$cljs$core$some$$(function($p1__80402_SHARP_$$){var $JSCompiler_inline_result$jscomp$1887_and__5023__auto__$jscomp$inline_9180$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80402_SHARP_$$);$JSCompiler_inline_result$jscomp$1887_and__5023__auto__$jscomp$inline_9180$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1887_and__5023__auto__$jscomp$inline_9180$$)?
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$group$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__80402_SHARP_$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1477$separator$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__80402_SHARP_$$)):$JSCompiler_inline_result$jscomp$1887_and__5023__auto__$jscomp$inline_9180$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1887_and__5023__auto__$jscomp$inline_9180$$)?
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80402_SHARP_$$):null},$options$jscomp$635$$)};
$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$next_focus_id$$=function($focusables_ids$jscomp$321$$,$focused_id$jscomp$6_idx$jscomp$128$$,$G__80407__$1_direction$jscomp$29$$){$focusables_ids$jscomp$321$$=$APP.$cljs$core$vec$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$focusables_ids$jscomp$321$$));$focused_id$jscomp$6_idx$jscomp$128$$=$APP.$cljs$core$clj__GT_js$$($focusables_ids$jscomp$321$$).indexOf($focused_id$jscomp$6_idx$jscomp$128$$);
var $count$jscomp$71$$=$APP.$cljs$core$count$$($focusables_ids$jscomp$321$$);$G__80407__$1_direction$jscomp$29$$=$G__80407__$1_direction$jscomp$29$$ instanceof $APP.$cljs$core$Keyword$$?$G__80407__$1_direction$jscomp$29$$.$fqn$:null;switch($G__80407__$1_direction$jscomp$29$$){case "down":return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($focusables_ids$jscomp$321$$,$APP.$cljs$core$mod$$($focused_id$jscomp$6_idx$jscomp$128$$+1,$count$jscomp$71$$),null);case "up":return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($focusables_ids$jscomp$321$$,
$APP.$cljs$core$mod$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($focused_id$jscomp$6_idx$jscomp$128$$,-1)?0:$focused_id$jscomp$6_idx$jscomp$128$$-1,$count$jscomp$71$$),null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80407__$1_direction$jscomp$29$$)].join(""));}};
$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$use_navigation$$=function($map__80414__$1_on_key_down$jscomp$23_p__80413$$){$map__80414__$1_on_key_down$jscomp$23_p__80413$$=$APP.$cljs$core$__destructure_map$$($map__80414__$1_on_key_down$jscomp$23_p__80413$$);var $is_open$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80414__$1_on_key_down$jscomp$23_p__80413$$,$cljs$cst$5769$is_open$$),$options$jscomp$636$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80414__$1_on_key_down$jscomp$23_p__80413$$,
$APP.$cljs$cst$873$options$$),$nodes_ref$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80414__$1_on_key_down$jscomp$23_p__80413$$,$cljs$cst$5822$nodes_ref$$),$is_open_STAR_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80414__$1_on_key_down$jscomp$23_p__80413$$,$cljs$cst$5918$is_open_STAR_$$),$toggle_dropdown$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80414__$1_on_key_down$jscomp$23_p__80413$$,$cljs$cst$5919$toggle_dropdown$$),
$on_enter$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80414__$1_on_key_down$jscomp$23_p__80413$$,$cljs$cst$5823$on_enter$$),$get_selected_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80414__$1_on_key_down$jscomp$23_p__80413$$,$cljs$cst$5920$get_selected_id$$),$focused_id_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$focused_id$jscomp$7$$=$APP.$cljs$core$_deref$$($focused_id_STAR_$jscomp$5$$);$map__80414__$1_on_key_down$jscomp$23_p__80413$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$11$$),$APP.$rumext$v2$adapt$$($focused_id$jscomp$7$$)],function($event$jscomp$620_next_id$jscomp$1$$){var $focusables$jscomp$1_up_QMARK_$jscomp$6$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$620_next_id$jscomp$1$$),$down_QMARK_$jscomp$6$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$620_next_id$jscomp$1$$),$enter_QMARK_$jscomp$6$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$620_next_id$jscomp$1$$),
$esc_QMARK_$jscomp$8$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$620_next_id$jscomp$1$$),$tab_QMARK_$$=(0,$APP.$app$util$keyboard$tab_QMARK_$$)($event$jscomp$620_next_id$jscomp$1$$),$open_dropdown$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$620_next_id$jscomp$1$$.key,"{"),$close_dropdown$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$620_next_id$jscomp$1$$.key,"}"),$options__$1$jscomp$90$$=$APP.$cljs$core$delay_QMARK_$$($options$jscomp$636$$)?
$APP.$cljs$core$_deref$$($options$jscomp$636$$):$options$jscomp$636$$;if($APP.$cljs$core$truth_$$($down_QMARK_$jscomp$6$$)){$APP.$app$util$dom$prevent_default$$($event$jscomp$620_next_id$jscomp$1$$);$focusables$jscomp$1_up_QMARK_$jscomp$6$$=$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$($options__$1$jscomp$90$$);if($APP.$cljs$core$truth_$$($is_open$jscomp$11$$)){if($APP.$cljs$core$seq$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$))return $event$jscomp$620_next_id$jscomp$1$$=
$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$next_focus_id$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$,$focused_id$jscomp$7$$,$APP.$cljs$cst$1969$down$$),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,$event$jscomp$620_next_id$jscomp$1$$)}else if($APP.$cljs$core$seq$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$))return $toggle_dropdown$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$toggle_dropdown$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$620_next_id$jscomp$1$$,
!1):$toggle_dropdown$jscomp$5$$($event$jscomp$620_next_id$jscomp$1$$,!1),$APP.$cljs$core$truth_$$($get_selected_id$$)&&($get_selected_id$$.$cljs$core$IFn$_invoke$arity$0$?$get_selected_id$$.$cljs$core$IFn$_invoke$arity$0$():$get_selected_id$$()),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$first_focusable_id$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$));return null}if($APP.$cljs$core$truth_$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$))return $APP.$cljs$core$truth_$$($is_open$jscomp$11$$)?
($APP.$app$util$dom$prevent_default$$($event$jscomp$620_next_id$jscomp$1$$),$focusables$jscomp$1_up_QMARK_$jscomp$6$$=$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$($options__$1$jscomp$90$$),$event$jscomp$620_next_id$jscomp$1$$=$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$next_focus_id$$($focusables$jscomp$1_up_QMARK_$jscomp$6$$,$focused_id$jscomp$7$$,$APP.$cljs$cst$1970$up$$),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,
$event$jscomp$620_next_id$jscomp$1$$)):null;if($open_dropdown$jscomp$5$$)return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$3$$,!0),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,null);if($close_dropdown$jscomp$6$$)return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$3$$,!1);if($APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$6$$)){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_open$jscomp$11$$)?$focused_id$jscomp$7$$:$is_open$jscomp$11$$))return $focusables$jscomp$1_up_QMARK_$jscomp$6$$=
$app$main$ui$workspace$tokens$management$forms$controls$utils$focusable_options$$($options__$1$jscomp$90$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$620_next_id$jscomp$1$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__80412_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80412_SHARP_$$),$focused_id$jscomp$7$$)},$focusables$jscomp$1_up_QMARK_$jscomp$6$$))?$on_enter$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$on_enter$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($focused_id$jscomp$7$$):$on_enter$jscomp$1$$($focused_id$jscomp$7$$):null}else if($APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$8$$)){if($APP.$cljs$core$truth_$$($is_open$jscomp$11$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$620_next_id$jscomp$1$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$620_next_id$jscomp$1$$),$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$3$$,!1)}else if($APP.$cljs$core$truth_$$($tab_QMARK_$$)&&
$APP.$cljs$core$truth_$$($is_open$jscomp$11$$))return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$3$$,!1),$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,null);return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$11$$)],function(){return $APP.$cljs$core$not$$($is_open$jscomp$11$$)?$APP.$cljs$core$reset_BANG_$$($focused_id_STAR_$jscomp$5$$,null):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focused_id$jscomp$7$$),
$APP.$rumext$v2$adapt$$($nodes_ref$jscomp$7$$)],function(){if($APP.$cljs$core$truth_$$($focused_id$jscomp$7$$)){var $node$jscomp$455$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$7$$),$focused_id$jscomp$7$$);return $APP.$cljs$core$truth_$$($node$jscomp$455$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$455$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1405$block$$,
"nearest",$APP.$cljs$cst$2359$inline$$,"nearest"],null)):null}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5826$focused_id$$,$focused_id$jscomp$7$$,$cljs$cst$5828$on_key_down$$,$map__80414__$1_on_key_down$jscomp$23_p__80413$$],null)};
$app$main$ui$workspace$tokens$management$forms$controls$floating_dropdown$use_floating_dropdown$$=function($is_open$jscomp$12$$,$input_wrapper_ref$jscomp$1$$,$outer_wrapper_ref$$,$dropdown_ref$jscomp$4$$){function $calculate_position$$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$){$combobox_rect_node$jscomp$456_position__$1$jscomp$9$$=$APP.$app$util$dom$get_bounding_rect$$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$);var $dropdown_height_dropdown_node$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$4$$);
$dropdown_height_dropdown_node$$=$APP.$cljs$core$truth_$$($dropdown_height_dropdown_node$$)?$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_bounding_rect$$($dropdown_height_dropdown_node$$)):0;var $windows_height$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_window_size$$()),$space_below$$=$windows_height$$-$APP.$cljs$cst$1568$bottom$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$);
$combobox_rect_node$jscomp$456_position__$1$jscomp$9$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($dropdown_height_dropdown_node$$)?$dropdown_height_dropdown_node$$>$space_below$$:$dropdown_height_dropdown_node$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1568$bottom$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($windows_height$$-$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$)- -8),"px"].join(""),
$APP.$cljs$cst$257$left$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$)),"px"].join(""),$APP.$cljs$cst$290$width$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$)),"px"].join(""),$APP.$cljs$cst$4640$placement$$,$APP.$cljs$cst$1567$top$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1567$top$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1568$bottom$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$)+4),"px"].join(""),$APP.$cljs$cst$257$left$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$)),"px"].join(""),$APP.$cljs$cst$290$width$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($combobox_rect_node$jscomp$456_position__$1$jscomp$9$$)),
"px"].join(""),$APP.$cljs$cst$4640$placement$$,$APP.$cljs$cst$1568$bottom$$],null);$APP.$cljs$core$reset_BANG_$$($ready_STAR_$$,!0);return $APP.$cljs$core$reset_BANG_$$($position_STAR_$$,$combobox_rect_node$jscomp$456_position__$1$jscomp$9$$)}var $position_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$position$jscomp$205$$=$APP.$cljs$core$_deref$$($position_STAR_$$),$ready_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$ready$$=$APP.$cljs$core$_deref$$($ready_STAR_$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$12$$),$APP.$rumext$v2$adapt$$($dropdown_ref$jscomp$4$$),$APP.$rumext$v2$adapt$$($input_wrapper_ref$jscomp$1$$),$APP.$rumext$v2$adapt$$($outer_wrapper_ref$$)],function(){if($APP.$cljs$core$truth_$$($is_open$jscomp$12$$)){var $recalculate$$=function(){return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return $calculate_position$$($APP.$rumext$v2$ref_val$$($input_wrapper_ref$jscomp$1$$))})},
$handler$jscomp$46$$=function($event$jscomp$621_target$jscomp$161$$){var $dropdown_node$jscomp$2$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$4$$);$event$jscomp$621_target$jscomp$161$$=$APP.$app$util$dom$get_target$$($event$jscomp$621_target$jscomp$161$$);return $dropdown_node$jscomp$2$$!=null&&$event$jscomp$621_target$jscomp$161$$ instanceof Node&&!$APP.$cljs$core$not$$($dropdown_node$jscomp$2$$.contains($event$jscomp$621_target$jscomp$161$$))?null:$recalculate$$()},$resize_observer$$=new ResizeObserver(function(){return $recalculate$$()}),
$outer_node$$=$APP.$rumext$v2$ref_val$$($outer_wrapper_ref$$),$dropdown_node$jscomp$1$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$4$$);$handler$jscomp$46$$(null);window.addEventListener("resize",$handler$jscomp$46$$);window.addEventListener("scroll",$handler$jscomp$46$$,!0);$APP.$cljs$core$truth_$$($outer_node$$)&&$resize_observer$$.observe($outer_node$$);$APP.$cljs$core$truth_$$($dropdown_node$jscomp$1$$)&&$resize_observer$$.observe($dropdown_node$jscomp$1$$);return function(){window.removeEventListener("resize",
$handler$jscomp$46$$);window.removeEventListener("scroll",$handler$jscomp$46$$,!0);return $resize_observer$$.disconnect()}}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1921$style$$,$position$jscomp$205$$,$cljs$cst$5921$ready_QMARK_$$,$ready$$,$cljs$cst$5922$recalculate$$,$calculate_position$$],null)};
$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$token_at_cursor$$=function($token_name$jscomp$38_value$jscomp$956$$,$cursor$jscomp$4_last_open$jscomp$3$$){$cursor$jscomp$4_last_open$jscomp$3$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($token_name$jscomp$38_value$jscomp$956$$,0,$cursor$jscomp$4_last_open$jscomp$3$$),"{");var $last_close$jscomp$2$$=$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($token_name$jscomp$38_value$jscomp$956$$,
"}",$APP.$cljs$core$truth_$$($cursor$jscomp$4_last_open$jscomp$3$$)?$cursor$jscomp$4_last_open$jscomp$3$$:0);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($cursor$jscomp$4_last_open$jscomp$3$$)?$APP.$cljs$core$truth_$$($last_close$jscomp$2$$)?$last_close$jscomp$2$$>$cursor$jscomp$4_last_open$jscomp$3$$:$last_close$jscomp$2$$:$cursor$jscomp$4_last_open$jscomp$3$$)?($token_name$jscomp$38_value$jscomp$956$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($token_name$jscomp$38_value$jscomp$956$$,
$cursor$jscomp$4_last_open$jscomp$3$$+1,$last_close$jscomp$2$$),$APP.$cljs$core$seq$$($token_name$jscomp$38_value$jscomp$956$$)&&$APP.$cljs$core$not$$($APP.$cuerdas$core$includes_QMARK_$$($token_name$jscomp$38_value$jscomp$956$$," "))?$token_name$jscomp$38_value$jscomp$956$$:null):null};
$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$remove_self_token$$=function($filtered_options$jscomp$1_filtered_options__$1$$,$current_token$$){var $group$jscomp$55$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($current_token$$),$current_id$jscomp$9$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($current_token$$);$filtered_options$jscomp$1_filtered_options__$1$$=$APP.$cljs$core$_deref$$($filtered_options$jscomp$1_filtered_options__$1$$);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($filtered_options$jscomp$1_filtered_options__$1$$,
$group$jscomp$55$$,function($options$jscomp$637$$){return $APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80417_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80417_SHARP_$$),$current_id$jscomp$9$$)},$options$jscomp$637$$)})};
$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$select_option_by_id$$=function($id$jscomp$1021_name$jscomp$482_option$jscomp$28$$,$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$,
$JSCompiler_temp$jscomp$1546_value$jscomp$958$$){var $cursor$jscomp$6$$=$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$!=null?$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$.selectionStart:
null;$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$=$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$!=null?$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$.selectionEnd:
null;$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=$APP.$rumext$v2$ref_val$$($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$);$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$APP.$cljs$core$delay_QMARK_$$($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$)?$APP.$cljs$core$_deref$$($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$):
$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$;$id$jscomp$1021_name$jscomp$482_option$jscomp$28$$=$APP.$app$main$ui$ds$controls$select$get_option$$($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,
$id$jscomp$1021_name$jscomp$482_option$jscomp$28$$);$id$jscomp$1021_name$jscomp$482_option$jscomp$28$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1021_name$jscomp$482_option$jscomp$28$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cursor$jscomp$6$$,$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$))if($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,0,$cursor$jscomp$6$$),$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,
"{"),$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,
"}"),$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$!=null&&($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$==null||$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$<
$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$)){var $JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,0,$cursor$jscomp$6$$),
$first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,$cursor$jscomp$6$$);$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$=$app$common$data$nth_index_of_STAR_$$($JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$,
"{",$APP.$cljs$cst$271$backward$$);$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=$app$common$data$nth_index_of_STAR_$$($first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$,"}",$APP.$cljs$cst$270$forward$$);$JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$=
$app$common$data$nth_index_of_STAR_$$($JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$," ",$APP.$cljs$cst$271$backward$$);$first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$=$app$common$data$nth_index_of_STAR_$$($first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$," ",$APP.$cljs$cst$270$forward$$);if($APP.$cljs$core$boolean$0$$(typeof $G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$===
"number"&&typeof $close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$==="number"&&($JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$==null||$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$>
$JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$)&&($first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$==null||$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$<$first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$)))$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$=
$app$common$data$nth_index_of_STAR_$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,0,$cursor$jscomp$6$$),"{",$APP.$cljs$cst$271$backward$$),$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=$app$common$data$nth_index_of_STAR_$$($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,
$cursor$jscomp$6$$),"}",$APP.$cljs$cst$270$forward$$),$JSCompiler_temp$jscomp$1546_value$jscomp$958$$=$app$common$types$token$build_result$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$,typeof $close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$===
"number"?$cursor$jscomp$6$$+$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$+1:$cursor$jscomp$6$$,$id$jscomp$1021_name$jscomp$482_option$jscomp$28$$);else{$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$=
$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,0,$cursor$jscomp$6$$);b:{$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=$APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,0,$cursor$jscomp$6$$);
for($first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,"{");;)if($JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$=
$first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$,$JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$)?$first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$>0&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,$first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$-1),"{"):$JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$,
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14935_and__5023__auto__$jscomp$inline_14936_last_space_left$jscomp$inline_13953_left$jscomp$inline_13949$$))--$first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$;else{$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=
$first_space_right$jscomp$inline_13954_i$jscomp$inline_14934_right$jscomp$inline_13950$$;break b}$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$=void 0}$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$=
$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$," ");$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$=
$APP.$cljs$core$last$$($APP.$cljs$core$sort$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nil_QMARK_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$close_pos$jscomp$inline_13952_close_pos$jscomp$inline_9186_last_close$jscomp$inline_13945_left$jscomp$inline_13943_left$jscomp$inline_14933_open_pos$jscomp$inline_13959_options$jscomp$638_options__$1$jscomp$91_options_ref$jscomp$3$$,$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$==
null?null:$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$+1],null))));$JSCompiler_temp$jscomp$1546_value$jscomp$958$$=$app$common$types$token$build_result$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$,
$cursor$jscomp$6$$,$id$jscomp$1021_name$jscomp$482_option$jscomp$28$$)}}else $JSCompiler_temp$jscomp$1546_value$jscomp$958$$=$app$common$types$token$build_result$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,$cursor$jscomp$6$$,$cursor$jscomp$6$$,$id$jscomp$1021_name$jscomp$482_option$jscomp$28$$);else $JSCompiler_temp$jscomp$1546_value$jscomp$958$$=$app$common$types$token$build_result$$($JSCompiler_temp$jscomp$1546_value$jscomp$958$$,$cursor$jscomp$6$$,$G__49146$jscomp$inline_13961_JSCompiler_inline_result$jscomp$11232_input_node$jscomp$12_last_open$jscomp$inline_13944_left$jscomp$inline_13958_open_pos$jscomp$inline_13951_open_pos$jscomp$inline_9185_sel_end$jscomp$1$$,
$id$jscomp$1021_name$jscomp$482_option$jscomp$28$$);return $JSCompiler_temp$jscomp$1546_value$jscomp$958$$};
$app$main$ui$workspace$tokens$management$forms$controls$combobox$resolve_value$$=function($tokens$jscomp$61_tokens__$1$jscomp$10$$,$prev_token$jscomp$3$$,$token_name$jscomp$39$$,$value$jscomp$959$$){var $valid_token_name_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$917$$=typeof $token_name$jscomp$39$$==="string";return $and__5023__auto__$jscomp$917$$?$APP.$cljs$core$re_matches$$($APP.$app$common$types$token$token_name_validation_regex$$,$token_name$jscomp$39$$):$and__5023__auto__$jscomp$917$$}(),
$token$jscomp$179$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$959$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$not$$($valid_token_name_QMARK_$jscomp$1$$)||$APP.$cuerdas$core$blank_QMARK_$$($token_name$jscomp$39$$)?"__PENPOT__TOKEN__NAME__PLACEHOLDER__":$token_name$jscomp$39$$],null);$tokens$jscomp$61_tokens__$1$jscomp$10$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$61_tokens__$1$jscomp$10$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$3$$)),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$179$$),function($p1__80438_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80438_SHARP_$$,$prev_token$jscomp$3$$,
$token$jscomp$179$$]))]))});return $APP.$cljs$core$truth_$$($APP.$app$common$files$tokens$token_circular_reference_QMARK_$$($tokens$jscomp$61_tokens__$1$jscomp$10$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$179$$)))?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4657$error_DOT_token_SLASH_circular_reference$$,null)],null)):$APP.$beicon$v2$core$mapcat$$(function($errors$jscomp$40_map__80440_resolved_tokens$jscomp$27$$){$errors$jscomp$40_map__80440_resolved_tokens$jscomp$27$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$40_map__80440_resolved_tokens$jscomp$27$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$179$$));var $map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$40_map__80440_resolved_tokens$jscomp$27$$);$errors$jscomp$40_map__80440_resolved_tokens$jscomp$27$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$,
$APP.$cljs$cst$570$errors$$);$map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$,$APP.$cljs$cst$4686$resolved_value$$);$map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$):
$map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$;return $APP.$cljs$core$truth_$$($map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$map__80440__$1_resolved_value$jscomp$8_resolved_value__$1$jscomp$3$$],null)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$truth_$$($errors$jscomp$40_map__80440_resolved_tokens$jscomp$27$$)?
$APP.$cljs$core$first$$($errors$jscomp$40_map__80440_resolved_tokens$jscomp$27$$):$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4682$error_SLASH_unknown$$,$value$jscomp$959$$)],null))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($tokens$jscomp$61_tokens__$1$jscomp$10$$)):$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$61_tokens__$1$jscomp$10$$))};
$app$main$ui$workspace$tokens$management$forms$controls$combobox$value_combobox_STAR_$$=function($input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$){var $ref$jscomp$56$$=void 0,$name$jscomp$483$$=void 0,$token$jscomp$180$$=void 0,$empty_to_end$jscomp$4$$=void 0,$token_type$jscomp$21$$=void 0,$tokens$jscomp$62$$=void 0,$props$jscomp$351_props__$1$jscomp$90_props__$2$jscomp$8$$=void 0;({name:$name$jscomp$483$$,tokens:$tokens$jscomp$62$$,token:$token$jscomp$180$$,tokenType:$token_type$jscomp$21$$,
emptyToEnd:$empty_to_end$jscomp$4$$,ref:$ref$jscomp$56$$,...$props$jscomp$351_props__$1$jscomp$90_props__$2$jscomp$8$$}=$input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$);var $form$jscomp$193$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$token_name$jscomp$40$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,
$APP.$cljs$cst$725$name$$],null),null),$touched_QMARK_$jscomp$10$$=function(){var $and__5023__auto__$jscomp$918$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$193$$)),$name$jscomp$483$$);return $and__5023__auto__$jscomp$918$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1631$touched$$,$name$jscomp$483$$],null)):$and__5023__auto__$jscomp$918$$}(),$error$jscomp$146$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$name$jscomp$483$$],null)),$extra_error$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$name$jscomp$483$$],null)),$value$jscomp$960$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$name$jscomp$483$$],null),""),$is_open_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$is_open$jscomp$13$$=$APP.$cljs$core$_deref$$($is_open_STAR_$jscomp$4$$),
$listbox_id$jscomp$4$$=(0,$APP.$rumext$v2$use_id$$)(),$filter_term_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$filter_term$jscomp$6$$=$APP.$cljs$core$_deref$$($filter_term_STAR_$jscomp$1$$),$selected_id_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$selected_id$jscomp$8$$=$APP.$cljs$core$_deref$$($selected_id_STAR_$jscomp$3$$),$options_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dropdown_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$internal_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$nodes_ref$jscomp$8$$=(0,$APP.$rumext$v2$use_ref$$)(null),$wrapper_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null);$input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$=(0,$APP.$rumext$v2$use_ref$$)(null);var $icon_button_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$ref__$1$jscomp$3$$=function(){var $or__5025__auto__$jscomp$1322$$=$ref$jscomp$56$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1322$$)?$or__5025__auto__$jscomp$1322$$:
$internal_ref$jscomp$1$$}(),$container$jscomp$96$$=$APP.$app$main$ui$hooks$use_portal_container$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$205$default$$),$resolved_tokens_by_type$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$active_tokens_by_type$$),$filtered_tokens_by_type$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolved_tokens_by_type$$),$APP.$rumext$v2$adapt$$($token_type$jscomp$21$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$($resolved_tokens_by_type$$,
$token_type$jscomp$21$$)}),$visible_options$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($filtered_tokens_by_type$$),$APP.$rumext$v2$adapt$$($token$jscomp$180$$)],function(){return $APP.$cljs$core$truth_$$($token$jscomp$180$$)?$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$remove_self_token$$($filtered_tokens_by_type$$,$token$jscomp$180$$):$filtered_tokens_by_type$$}),$dropdown_options$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($visible_options$jscomp$1$$),
$APP.$rumext$v2$adapt$$($filter_term$jscomp$6$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$($visible_options$jscomp$1$$,["{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($filter_term$jscomp$6$$)].join(""))}),$set_option_ref$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$457_state__$2$jscomp$9$$){var $state__$1$jscomp$61$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$8$$),
{}),$id$jscomp$1022$$=$APP.$app$util$dom$get_data$$($node$jscomp$457_state__$2$jscomp$9$$,"id");$node$jscomp$457_state__$2$jscomp$9$$=$APP.$app$util$object$set_BANG_$$($state__$1$jscomp$61$$,$id$jscomp$1022$$,$node$jscomp$457_state__$2$jscomp$9$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$8$$,$node$jscomp$457_state__$2$jscomp$9$$)}),$get_selected_id$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dropdown_options$jscomp$3$$)],function(){var $input_node$jscomp$13_options$jscomp$639$$=
$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$3$$),$value__$1$jscomp$67$$=$APP.$app$util$dom$get_input_value$$($input_node$jscomp$13_options$jscomp$639$$),$token_name__$1$$=$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$token_at_cursor$$($value__$1$jscomp$67$$,$input_node$jscomp$13_options$jscomp$639$$!=null?$input_node$jscomp$13_options$jscomp$639$$.selectionStart:null);$input_node$jscomp$13_options$jscomp$639$$=$APP.$cljs$core$delay_QMARK_$$($dropdown_options$jscomp$3$$)?$APP.$cljs$core$_deref$$($dropdown_options$jscomp$3$$):
$dropdown_options$jscomp$3$$;return $APP.$cljs$core$truth_$$($token_name__$1$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80441_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__80441_SHARP_$$),$token_name__$1$$)},$input_node$jscomp$13_options$jscomp$639$$))):null}),$toggle_dropdown$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open$jscomp$13$$)],
function(){function $G__80457$$($event$jscomp$623$$,$var_args$jscomp$1469$$){var $G__80458__i_p__80447$jscomp$1$$=null;if(arguments.length>1){$G__80458__i_p__80447$jscomp$1$$=0;for(var $G__80458__a$$=Array(arguments.length-1);$G__80458__i_p__80447$jscomp$1$$<$G__80458__a$$.length;)$G__80458__a$$[$G__80458__i_p__80447$jscomp$1$$]=arguments[$G__80458__i_p__80447$jscomp$1$$+1],++$G__80458__i_p__80447$jscomp$1$$;$G__80458__i_p__80447$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__80458__a$$,0,null)}return $G__80457__delegate$$.call(this,
$event$jscomp$623$$,$G__80458__i_p__80447$jscomp$1$$)}function $G__80457__delegate$$($event$jscomp$622_input_node$jscomp$14$$,$p__80447_select_text_QMARK_$$){$p__80447_select_text_QMARK_$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80447_select_text_QMARK_$$,0,null);$APP.$app$util$dom$prevent_default$$($event$jscomp$622_input_node$jscomp$14$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($is_open_STAR_$jscomp$4$$,$APP.$cljs$core$not$$);$APP.$cljs$core$reset_BANG_$$($selected_id_STAR_$jscomp$3$$,
$get_selected_id$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$get_selected_id$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$get_selected_id$jscomp$1$$());return $APP.$cljs$core$truth_$$($p__80447_select_text_QMARK_$$)?($event$jscomp$622_input_node$jscomp$14$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$3$$),$APP.$app$util$dom$select_text_BANG_$$($event$jscomp$622_input_node$jscomp$14$$),$APP.$app$util$dom$focus_BANG_$$($event$jscomp$622_input_node$jscomp$14$$)):null}$G__80457$$.$cljs$lang$maxFixedArity$=
1;$G__80457$$.$cljs$lang$applyTo$=function($arglist__80459_p__80447$jscomp$2$$){var $event$jscomp$624$$=$APP.$cljs$core$first$$($arglist__80459_p__80447$jscomp$2$$);$arglist__80459_p__80447$jscomp$2$$=$APP.$cljs$core$rest$$($arglist__80459_p__80447$jscomp$2$$);return $G__80457__delegate$$($event$jscomp$624$$,$arglist__80459_p__80447$jscomp$2$$)};$G__80457$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__80457__delegate$$;return $G__80457$$}()),$resolve_stream$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$180$$)],
function(){return $APP.$cljs$core$contains_QMARK_$$($token$jscomp$180$$,$APP.$cljs$cst$260$value$$)?$APP.$beicon$v2$core$behavior_subject$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$180$$)):$APP.$beicon$v2$core$subject$$()}),$map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$960$$),$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$2$$),$APP.$rumext$v2$adapt$$($name$jscomp$483$$)],
function($id$jscomp$1023_map__80451_map__80451__$1$$){var $input_node$jscomp$15$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$3$$),$input_value$jscomp$3_value__$1$jscomp$68$$=$APP.$app$util$dom$get_input_value$$($input_node$jscomp$15$$);$id$jscomp$1023_map__80451_map__80451__$1$$=$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$select_option_by_id$$($id$jscomp$1023_map__80451_map__80451__$1$$,$options_ref$jscomp$4$$,$input_node$jscomp$15$$,$input_value$jscomp$3_value__$1$jscomp$68$$);
$id$jscomp$1023_map__80451_map__80451__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$1023_map__80451_map__80451__$1$$);$input_value$jscomp$3_value__$1$jscomp$68$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1023_map__80451_map__80451__$1$$,$APP.$cljs$cst$260$value$$);var $cursor$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1023_map__80451_map__80451__$1$$,$APP.$cljs$cst$2013$cursor$$);$APP.$cljs$core$truth_$$($input_value$jscomp$3_value__$1$jscomp$68$$)&&
($APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$193$$,$name$jscomp$483$$,$input_value$jscomp$3_value__$1$jscomp$68$$,!0),$resolve_stream$jscomp$2$$.next($input_value$jscomp$3_value__$1$jscomp$68$$),setTimeout(function(){$input_node$jscomp$15$$.selectionStart=$cursor$jscomp$8$$;return $input_node$jscomp$15$$.selectionEnd=$cursor$jscomp$8$$},0));$APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$jscomp$1$$,"");return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,
!1)});$map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$=$app$main$ui$workspace$tokens$management$forms$controls$combobox_navigation$use_navigation$$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$cljs$cst$5769$is_open$$,$is_open$jscomp$13$$,$cljs$cst$5822$nodes_ref$$,$nodes_ref$jscomp$8$$,$APP.$cljs$cst$873$options$$,$dropdown_options$jscomp$3$$,$cljs$cst$5919$toggle_dropdown$$,$toggle_dropdown$jscomp$6$$,$cljs$cst$5918$is_open_STAR_$$,$is_open_STAR_$jscomp$4$$,$cljs$cst$5823$on_enter$$,
$map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$,$cljs$cst$5920$get_selected_id$$,$get_selected_id$jscomp$1$$],null));$map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$);var $focused_id$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$,$cljs$cst$5826$focused_id$$);
$map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$,$cljs$cst$5828$on_key_down$$);var $on_change$jscomp$88$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$2$$),$APP.$rumext$v2$adapt$$($name$jscomp$483$$),$APP.$rumext$v2$adapt$$($form$jscomp$193$$)],function($event$jscomp$625_value__$1$jscomp$69$$){var $JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$=
$APP.$app$util$dom$get_target$$($event$jscomp$625_value__$1$jscomp$69$$);$event$jscomp$625_value__$1$jscomp$69$$=$APP.$app$util$dom$get_input_value$$($JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$);$JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$=$JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$!=null?$JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$.selectionStart:
null;var $text_before$jscomp$inline_14940$$=$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$625_value__$1$jscomp$69$$,0,$JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$),$last_open$jscomp$inline_14941$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($text_before$jscomp$inline_14940$$,"{"),$last_close$jscomp$inline_14942_or__5025__auto__$jscomp$inline_14945$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($text_before$jscomp$inline_14940$$,
"}");$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($last_open$jscomp$inline_14941$$)?$last_close$jscomp$inline_14942_or__5025__auto__$jscomp$inline_14945$$==null||$last_open$jscomp$inline_14941$$>$last_close$jscomp$inline_14942_or__5025__auto__$jscomp$inline_14945$$:$last_open$jscomp$inline_14941$$)?($last_close$jscomp$inline_14942_or__5025__auto__$jscomp$inline_14945$$=$cuerdas$core$index_of$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$625_value__$1$jscomp$69$$,"}",$last_open$jscomp$inline_14941$$),
$JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1297$start$$,$last_open$jscomp$inline_14941$$,$APP.$cljs$cst$1298$end$$,$APP.$cljs$core$truth_$$($last_close$jscomp$inline_14942_or__5025__auto__$jscomp$inline_14945$$)?$last_close$jscomp$inline_14942_or__5025__auto__$jscomp$inline_14945$$:$JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$,
$APP.$cljs$cst$2133$partial$$,$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($text_before$jscomp$inline_14940$$,$last_open$jscomp$inline_14941$$+1)],null)):$JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$=null;$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$193$$,$name$jscomp$483$$,$event$jscomp$625_value__$1$jscomp$69$$,!1);$resolve_stream$jscomp$2$$.next($event$jscomp$625_value__$1$jscomp$69$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$))return $APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,
!0),$APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$jscomp$1$$,$APP.$cljs$cst$2133$partial$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$inline_14943_cursor$jscomp$inline_14939_node$jscomp$458_token__$1$jscomp$2$$));$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,!1);return $APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$jscomp$1$$,"")}),$on_option_click$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$960$$),$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$2$$),
$APP.$rumext$v2$adapt$$($ref__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($name$jscomp$483$$)],function($event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$){var $input_node$jscomp$16$$=$APP.$rumext$v2$ref_val$$($ref__$1$jscomp$3$$);$event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$=$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$),"id");var $input_value$jscomp$4_value__$1$jscomp$70$$=$APP.$app$util$dom$get_input_value$$($input_node$jscomp$16$$);
$event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$=$app$main$ui$workspace$tokens$management$forms$controls$token_parsing$select_option_by_id$$($event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$,$options_ref$jscomp$4$$,$input_node$jscomp$16$$,$input_value$jscomp$4_value__$1$jscomp$70$$);$event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$=$APP.$cljs$core$__destructure_map$$($event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$);$input_value$jscomp$4_value__$1$jscomp$70$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$,$APP.$cljs$cst$260$value$$);var $cursor$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$626_id$jscomp$1024_map__80452_map__80452__$1$$,$APP.$cljs$cst$2013$cursor$$);$APP.$cljs$core$reset_BANG_$$($filter_term_STAR_$jscomp$1$$,"");$APP.$app$util$dom$focus_BANG_$$($input_node$jscomp$16$$);return $APP.$cljs$core$truth_$$($input_value$jscomp$4_value__$1$jscomp$70$$)?
($APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,!1),$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$193$$,$name$jscomp$483$$,$input_value$jscomp$4_value__$1$jscomp$70$$,!0),$resolve_stream$jscomp$2$$.next($input_value$jscomp$4_value__$1$jscomp$70$$),setTimeout(function(){$input_node$jscomp$16$$.selectionStart=$cursor$jscomp$9$$;return $input_node$jscomp$16$$.selectionEnd=$cursor$jscomp$9$$},0)):null}),$hint_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),
$hint$jscomp$24$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$2$$);$props$jscomp$351_props__$1$jscomp$90_props__$2$jscomp$8$$={...$props$jscomp$351_props__$1$jscomp$90_props__$2$jscomp$8$$,role:"combobox",inputWrapperRef:$input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$,onChange:$on_change$jscomp$88$$,"aria-expanded":$is_open$jscomp$13$$,hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$24$$),"data-option-focused":$APP.$cljs$core$boolean$0$$($focused_id$jscomp$8$$),
hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$24$$),value:$value$jscomp$960$$,"aria-controls":$listbox_id$jscomp$4$$,ref:$ref__$1$jscomp$3$$,slotEnd:$APP.$cljs$core$_deref$$($filtered_tokens_by_type$$)!=null?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.open-token-list-dropdown"),tabIndex:"-1",className:"main_ui_workspace_tokens_management_forms_controls_combobox__invisible-button",
onMouseDown:$APP.$app$util$dom$prevent_default$$,onClick:function($p1__80443_SHARP_$$){return $toggle_dropdown$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$?$toggle_dropdown$jscomp$6$$.$cljs$core$IFn$_invoke$arity$2$($p1__80443_SHARP_$$,!0):$toggle_dropdown$jscomp$6$$($p1__80443_SHARP_$$,!0)},ref:$icon_button_ref$$,tooltipClass:"main_ui_workspace_tokens_management_forms_controls_combobox__button-tooltip",variant:"action",icon:"arrow-down"}):null,"aria-activedescendant":$focused_id$jscomp$8$$,onKeyDown:$map__80445_map__80445__$1_on_key_down$jscomp$24_on_option_enter$jscomp$1$$,
variant:"comfortable"};$props$jscomp$351_props__$1$jscomp$90_props__$2$jscomp$8$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($extra_error$jscomp$2$$)?$extra_error$jscomp$2$$:$APP.$cljs$core$truth_$$($error$jscomp$146$$)?$touched_QMARK_$jscomp$10$$:$error$jscomp$146$$)?{...$props$jscomp$351_props__$1$jscomp$90_props__$2$jscomp$8$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($error$jscomp$146$$)?$error$jscomp$146$$:$extra_error$jscomp$2$$)}:
$props$jscomp$351_props__$1$jscomp$90_props__$2$jscomp$8$$;$input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$=$app$main$ui$workspace$tokens$management$forms$controls$floating_dropdown$use_floating_dropdown$$($is_open$jscomp$13$$,$input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$,$wrapper_ref$jscomp$4$$,$dropdown_ref$jscomp$5$$);$input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$=$APP.$cljs$core$__destructure_map$$($input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$);
var $style$jscomp$76$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$,$APP.$cljs$cst$1921$style$$),$ready_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($input_wrapper_ref$jscomp$2_map__80446_map__80446__$1_props_80444$$,$cljs$cst$5921$ready_QMARK_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$2$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$62$$),
$APP.$rumext$v2$adapt$$($token$jscomp$180$$),$APP.$rumext$v2$adapt$$($name$jscomp$483$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$40$$)],function(){var $subs$jscomp$26$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error__$1$jscomp$2_message$jscomp$121_p__80453$$){var $map__80454__$1_value__$1$jscomp$71$$=$APP.$cljs$core$__destructure_map$$($error__$1$jscomp$2_message$jscomp$121_p__80453$$);$error__$1$jscomp$2_message$jscomp$121_p__80453$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80454__$1_value__$1$jscomp$71$$,
$APP.$cljs$cst$849$error$$);$map__80454__$1_value__$1$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80454__$1_value__$1$jscomp$71$$,$APP.$cljs$cst$260$value$$);var $touched_QMARK___$1$jscomp$1$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$193$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$name$jscomp$483$$],null));if($APP.$cljs$core$truth_$$($touched_QMARK___$1$jscomp$1$$)){if($APP.$cljs$core$truth_$$($error__$1$jscomp$2_message$jscomp$121_p__80453$$)){if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error__$1$jscomp$2_message$jscomp$121_p__80453$$,
$token_name$jscomp$40$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$193$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$2_message$jscomp$121_p__80453$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$193$$,$APP.$cljs$core$assoc_in$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$name$jscomp$483$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$2_message$jscomp$121_p__80453$$],null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$2_message$jscomp$121_p__80453$$,$APP.$cljs$cst$139$type$$,
"error"],null))}$error__$1$jscomp$2_message$jscomp$121_p__80453$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80454__$1_value__$1$jscomp$71$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$193$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$name$jscomp$483$$]));
return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$2$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$2_message$jscomp$121_p__80453$$,$APP.$cljs$cst$139$type$$,"hint"],null))}return null},$APP.$beicon$v2$core$map$$(function($result$jscomp$377$$){return $APP.$app$common$data$update_when$$($result$jscomp$377$$,$APP.$cljs$cst$849$error$$,function($error__$1$jscomp$3_fexpr__80455$$){var $G__80456$$=$APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$3_fexpr__80455$$);
$error__$1$jscomp$3_fexpr__80455$$=$APP.$cljs$cst$884$error_SLASH_fn$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$3_fexpr__80455$$);return $error__$1$jscomp$3_fexpr__80455$$.$cljs$core$IFn$_invoke$arity$1$?$error__$1$jscomp$3_fexpr__80455$$.$cljs$core$IFn$_invoke$arity$1$($G__80456$$):$error__$1$jscomp$3_fexpr__80455$$($G__80456$$)})},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$combobox$resolve_value$$,
$tokens$jscomp$62$$,$token$jscomp$180$$,$token_name$jscomp$40$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$jscomp$2$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$26$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dropdown_options$jscomp$3$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($options_ref$jscomp$4$$,$dropdown_options$jscomp$3$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_open_STAR_$jscomp$4$$),
$APP.$rumext$v2$adapt$$($ref__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($wrapper_ref$jscomp$4$$)],function(){if($APP.$cljs$core$truth_$$($is_open$jscomp$13$$)){var $handler$jscomp$47$$=function($event$jscomp$627_target$jscomp$162$$){var $wrapper_node$jscomp$1$$=$APP.$rumext$v2$ref_val$$($wrapper_ref$jscomp$4$$),$dropdown_node$jscomp$3$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$5$$);$event$jscomp$627_target$jscomp$162$$=$APP.$app$util$dom$get_target$$($event$jscomp$627_target$jscomp$162$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($wrapper_node$jscomp$1$$)?
$APP.$cljs$core$truth_$$($dropdown_node$jscomp$3$$)?$APP.$cljs$core$not$$($APP.$app$util$dom$child_QMARK_$$($event$jscomp$627_target$jscomp$162$$,$wrapper_node$jscomp$1$$))&&$APP.$cljs$core$not$$($APP.$app$util$dom$child_QMARK_$$($event$jscomp$627_target$jscomp$162$$,$dropdown_node$jscomp$3$$)):$dropdown_node$jscomp$3$$:$wrapper_node$jscomp$1$$)?$APP.$cljs$core$reset_BANG_$$($is_open_STAR_$jscomp$4$$,!1):null};document.addEventListener("mousedown",$handler$jscomp$47$$);return function(){return document.removeEventListener("mousedown",
$handler$jscomp$47$$)}}return null});return(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$wrapper_ref$jscomp$4$$,children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$351_props__$1$jscomp$90_props__$2$jscomp$8$$),$is_open$jscomp$13$$?function(){var $options$jscomp$640$$=$APP.$cljs$core$delay_QMARK_$$($dropdown_options$jscomp$3$$)?$APP.$cljs$core$_deref$$($dropdown_options$jscomp$3$$):$dropdown_options$jscomp$3$$;return(0,$APP.$rumext$v2$portal$$)($APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$shared$options_dropdown$options_dropdown_STAR_$$,
{selected:$selected_id$jscomp$8$$,align:$APP.$cljs$cst$258$right$$,wrapperRef:$dropdown_ref$jscomp$5$$,className:"main_ui_workspace_tokens_management_forms_controls_combobox__dropdown",emptyToEnd:$empty_to_end$jscomp$4$$,id:$listbox_id$jscomp$4$$,style:{visibility:$APP.$cljs$core$truth_$$($ready_QMARK_$jscomp$2$$)?"visible":"hidden",left:$APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$76$$),top:function(){var $or__5025__auto__$jscomp$1325$$=$APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$76$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1325$$)?$or__5025__auto__$jscomp$1325$$:"unset"}(),bottom:function(){var $or__5025__auto__$jscomp$1326$$=$APP.$cljs$cst$1568$bottom$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$76$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1326$$)?$or__5025__auto__$jscomp$1326$$:"unset"}(),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($style$jscomp$76$$)},focused:$focused_id$jscomp$8$$,onClick:$on_option_click$jscomp$4$$,
ref:$set_option_ref$jscomp$5$$,options:$options$jscomp$640$$}),$container$jscomp$96$$)}():null]})};
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$resolve_value$$=function($tokens$jscomp$63_tokens__$1$jscomp$11$$,$prev_token$jscomp$4$$,$_token_name_tmp_value$$,$value$jscomp$961$$){$_token_name_tmp_value$$=$APP.$app$common$types$token$split_font_family$$($value$jscomp$961$$);var $token$jscomp$181$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,"__PENPOT__FONT_FAMILY__PLACEHOLDER__",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$260$value$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$4$$),$APP.$cljs$cst$1997$typography$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$4$$),$APP.$cljs$cst$1764$font_family$$,$_token_name_tmp_value$$):$_token_name_tmp_value$$],null);$tokens$jscomp$63_tokens__$1$jscomp$11$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($tokens$jscomp$63_tokens__$1$jscomp$11$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$181$$),function($p1__80460_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80460_SHARP_$$,$prev_token$jscomp$4$$,$token$jscomp$181$$]))]))});return $APP.$cljs$core$truth_$$($APP.$app$common$files$tokens$token_circular_reference_QMARK_$$($tokens$jscomp$63_tokens__$1$jscomp$11$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$181$$)))?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4657$error_DOT_token_SLASH_circular_reference$$,null)],null)):$APP.$beicon$v2$core$mapcat$$(function($errors$jscomp$41_map__80461_resolved_tokens$jscomp$28$$){$errors$jscomp$41_map__80461_resolved_tokens$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$41_map__80461_resolved_tokens$jscomp$28$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$181$$));var $map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$41_map__80461_resolved_tokens$jscomp$28$$);$errors$jscomp$41_map__80461_resolved_tokens$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$,$APP.$cljs$cst$570$errors$$);$map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$,$APP.$cljs$cst$4686$resolved_value$$);$map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$):$map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$;
return $APP.$cljs$core$truth_$$($map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$map__80461__$1_resolved_value$jscomp$9_resolved_value__$1$jscomp$4$$],null)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$truth_$$($errors$jscomp$41_map__80461_resolved_tokens$jscomp$28$$)?$APP.$cljs$core$first$$($errors$jscomp$41_map__80461_resolved_tokens$jscomp$28$$):
$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4682$error_SLASH_unknown$$,$value$jscomp$961$$)],null))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($tokens$jscomp$63_tokens__$1$jscomp$11$$)):$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$63_tokens__$1$jscomp$11$$))};
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$fonts_combobox_STAR_$$=function($font$jscomp$49_props_80464$$){var $name$jscomp$484_touched_QMARK_$jscomp$11$$=void 0,$token$jscomp$182$$=void 0,$tokens$jscomp$64$$=void 0,$props$jscomp$352_props__$1$jscomp$91_props__$2$jscomp$9$$=void 0;({token:$token$jscomp$182$$,tokens:$tokens$jscomp$64$$,name:$name$jscomp$484_touched_QMARK_$jscomp$11$$,...$props$jscomp$352_props__$1$jscomp$91_props__$2$jscomp$9$$}=$font$jscomp$49_props_80464$$);
var $form$jscomp$194$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$7$$=$name$jscomp$484_touched_QMARK_$jscomp$11$$,$token_name$jscomp$41$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$name$jscomp$484_touched_QMARK_$jscomp$11$$=function(){var $and__5023__auto__$jscomp$921$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$194$$)),$input_name$jscomp$7$$);return $and__5023__auto__$jscomp$921$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$7$$],null)):$and__5023__auto__$jscomp$921$$}();var $error$jscomp$147$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$7$$],null)),$value$jscomp$962$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$7$$],
null),"");$font$jscomp$49_props_80464$$=$APP.$app$main$fonts$find_font_family$$($value$jscomp$962$$);var $resolve_stream$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$182$$)],function(){var $temp__5823__auto__$jscomp$238$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$182$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$238$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$238$$):
$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hint$jscomp$25$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$3$$),$font_selector_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$font_selector_open_QMARK_$$=$APP.$cljs$core$_deref$$($font_selector_open_STAR_$$),$on_click_dropdown_button_on_close_font_selector$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_selector_open_QMARK_$$)],
function($e$jscomp$368$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$368$$);return $APP.$cljs$core$reset_BANG_$$($font_selector_open_STAR_$$,$APP.$cljs$core$not$$($font_selector_open_QMARK_$$))}),$font_selector_button$$=(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$on_click_dropdown_button_on_close_font_selector$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-font-family-select"),icon:"arrow-down",
variant:"action",type:"button"});$on_click_dropdown_button_on_close_font_selector$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($font_selector_open_STAR_$$,!1)});var $on_select_font$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font$jscomp$49_props_80464$$)],function($family$jscomp$8_map__80468__$1_p__80467$$){$family$jscomp$8_map__80468__$1_p__80467$$=$APP.$cljs$core$__destructure_map$$($family$jscomp$8_map__80468__$1_p__80467$$);
$family$jscomp$8_map__80468__$1_p__80467$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$8_map__80468__$1_p__80467$$,$APP.$cljs$cst$2686$family$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$962$$,$family$jscomp$8_map__80468__$1_p__80467$$)?($APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$194$$,$input_name$jscomp$7$$,$family$jscomp$8_map__80468__$1_p__80467$$,!0),$resolve_stream$jscomp$3$$.next($family$jscomp$8_map__80468__$1_p__80467$$)):
null}),$on_change$jscomp$89$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$3$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$7$$)],function($event$jscomp$628_value__$1$jscomp$73$$){$event$jscomp$628_value__$1$jscomp$73$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$628_value__$1$jscomp$73$$));$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$194$$,$input_name$jscomp$7$$,
$event$jscomp$628_value__$1$jscomp$73$$,!1);return $resolve_stream$jscomp$3$$.next($event$jscomp$628_value__$1$jscomp$73$$)});$props$jscomp$352_props__$1$jscomp$91_props__$2$jscomp$9$$={...$props$jscomp$352_props__$1$jscomp$91_props__$2$jscomp$9$$,onChange:$on_change$jscomp$89$$,value:$APP.$cljs$core$truth_$$($value$jscomp$962$$)?$value$jscomp$962$$:"",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$25$$),slotEnd:$font_selector_button$$,variant:"comfortable",
hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$25$$)};$props$jscomp$352_props__$1$jscomp$91_props__$2$jscomp$9$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error$jscomp$147$$)?$name$jscomp$484_touched_QMARK_$jscomp$11$$:$error$jscomp$147$$)?{...$props$jscomp$352_props__$1$jscomp$91_props__$2$jscomp$9$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$147$$)}:$props$jscomp$352_props__$1$jscomp$91_props__$2$jscomp$9$$;
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$3$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$64$$),$APP.$rumext$v2$adapt$$($token$jscomp$182$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$7$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$41$$)],function(){var $subs$jscomp$27$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$){var $map__80470__$1_value__$1$jscomp$74$$=
$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$);$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80470__$1_value__$1$jscomp$74$$,$APP.$cljs$cst$849$error$$);$map__80470__$1_value__$1$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80470__$1_value__$1$jscomp$74$$,$APP.$cljs$cst$260$value$$);var $touched_QMARK___$1$jscomp$2$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$194$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$7$$],null));if($APP.$cljs$core$truth_$$($touched_QMARK___$1$jscomp$2$$)){if($APP.$cljs$core$truth_$$($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$)){$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$=
$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$);if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$,$token_name$jscomp$41$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$194$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,""],null),$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$194$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$input_name$jscomp$7$$],null),$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$);
return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80470__$1_value__$1$jscomp$74$$]));
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$194$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$7$$]));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$1_error__$1$jscomp$4_message$jscomp$122_p__80469$$,$APP.$cljs$cst$139$type$$,
"hint"],null))}return null},$APP.$beicon$v2$core$map$$(function($result$jscomp$378$$){return $APP.$app$common$data$update_when$$($result$jscomp$378$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$resolve_value$$,$tokens$jscomp$64$$,$token$jscomp$182$$,$token_name$jscomp$41$$),$APP.$beicon$v2$core$debounce$$(300,
$resolve_stream$jscomp$3$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$27$$)}});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$352_props__$1$jscomp$91_props__$2$jscomp$9$$),$APP.$cljs$core$truth_$$($font_selector_open_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_controls_fonts_combobox__font-select-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$,{currentFont:$font$jscomp$49_props_80464$$,onSelect:$on_select_font$$,onClose:$on_click_dropdown_button_on_close_font_selector$$})}):null]})};
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$on_composite_combobox_token_change$cljs$0core$0IFn$0_invoke$0arity$04$$=function($form$jscomp$196$$,$field$jscomp$11$$,$value$jscomp$964$$,$trim_QMARK_$jscomp$5$$){function $clean_errors$jscomp$2$$($errors$jscomp$42$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$42$$,$field$jscomp$11$$))}$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$196$$,
function($state$jscomp$1221$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($state$jscomp$1221$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$field$jscomp$11$$],null),$APP.$cljs$core$truth_$$($trim_QMARK_$jscomp$5$$)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$964$$):
$value$jscomp$964$$),$APP.$cljs$cst$570$errors$$,$clean_errors$jscomp$2$$),$APP.$cljs$cst$4837$extra_errors$$,$clean_errors$jscomp$2$$),$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$composite_fonts_combobox_STAR_$$=function($font$jscomp$50_props_80483$$){var $error$jscomp$148_name$jscomp$485$$=void 0,$token$jscomp$183$$=void 0,$tokens$jscomp$65$$=void 0,$props$jscomp$353_props__$1$jscomp$92_props__$2$jscomp$10$$=void 0;({token:$token$jscomp$183$$,tokens:$tokens$jscomp$65$$,name:$error$jscomp$148_name$jscomp$485$$,...$props$jscomp$353_props__$1$jscomp$92_props__$2$jscomp$10$$}=$font$jscomp$50_props_80483$$);
var $form$jscomp$197$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$8$$=$error$jscomp$148_name$jscomp$485$$,$token_name$jscomp$42$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$197$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$error$jscomp$148_name$jscomp$485$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$197$$),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null));var $value$jscomp$965$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$197$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null),"");$font$jscomp$50_props_80483$$=
$APP.$app$main$fonts$find_font_family$$($value$jscomp$965$$);var $resolve_stream$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$183$$)],function(){var $temp__5823__auto__$jscomp$239$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$183$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$239$$)?
$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$239$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hint$jscomp$26$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$4$$),$font_selector_open_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$font_selector_open_QMARK_$jscomp$1$$=$APP.$cljs$core$_deref$$($font_selector_open_STAR_$jscomp$1$$),
$on_click_dropdown_button$jscomp$1_on_close_font_selector$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font_selector_open_QMARK_$jscomp$1$$)],function($e$jscomp$369$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$369$$);return $APP.$cljs$core$reset_BANG_$$($font_selector_open_STAR_$jscomp$1$$,$APP.$cljs$core$not$$($font_selector_open_QMARK_$jscomp$1$$))}),$font_selector_button$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{onClick:$on_click_dropdown_button$jscomp$1_on_close_font_selector$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-font-family-select"),icon:"arrow-down",variant:"action",type:"button"});$on_click_dropdown_button$jscomp$1_on_close_font_selector$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($font_selector_open_STAR_$jscomp$1$$,!1)});var $on_select_font$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font$jscomp$50_props_80483$$)],
function($family$jscomp$9_map__80485__$1_p__80484$$){$family$jscomp$9_map__80485__$1_p__80484$$=$APP.$cljs$core$__destructure_map$$($family$jscomp$9_map__80485__$1_p__80484$$);$family$jscomp$9_map__80485__$1_p__80484$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($family$jscomp$9_map__80485__$1_p__80484$$,$APP.$cljs$cst$2686$family$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$965$$,$family$jscomp$9_map__80485__$1_p__80484$$)?($app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$on_composite_combobox_token_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$197$$,
$input_name$jscomp$8$$,$family$jscomp$9_map__80485__$1_p__80484$$,!0),$resolve_stream$jscomp$4$$.next($family$jscomp$9_map__80485__$1_p__80484$$)):null}),$on_change$jscomp$90$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$4$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$8$$)],function($event$jscomp$629_value__$1$jscomp$76$$){$event$jscomp$629_value__$1$jscomp$76$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$629_value__$1$jscomp$76$$));
$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$on_composite_combobox_token_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$197$$,$input_name$jscomp$8$$,$event$jscomp$629_value__$1$jscomp$76$$,!1);return $resolve_stream$jscomp$4$$.next($event$jscomp$629_value__$1$jscomp$76$$)});$props$jscomp$353_props__$1$jscomp$92_props__$2$jscomp$10$$={...$props$jscomp$353_props__$1$jscomp$92_props__$2$jscomp$10$$,onChange:$on_change$jscomp$90$$,value:$APP.$cljs$core$truth_$$($value$jscomp$965$$)?
$value$jscomp$965$$:"",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$26$$),slotEnd:$font_selector_button$jscomp$1$$,variant:"comfortable",hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$26$$)};$props$jscomp$353_props__$1$jscomp$92_props__$2$jscomp$10$$=$APP.$cljs$core$truth_$$($error$jscomp$148_name$jscomp$485$$)?{...$props$jscomp$353_props__$1$jscomp$92_props__$2$jscomp$10$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$148_name$jscomp$485$$)}:
$props$jscomp$353_props__$1$jscomp$92_props__$2$jscomp$10$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$4$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$65$$),$APP.$rumext$v2$adapt$$($token$jscomp$183$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$8$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$42$$)],function(){var $subs$jscomp$28$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$){$error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$=
$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$);var $error__$1$jscomp$5_message$jscomp$123$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$,$APP.$cljs$cst$849$error$$);$error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$,
$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error__$1$jscomp$5_message$jscomp$123$$)?$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$5_message$jscomp$123$$)):$error__$1$jscomp$5_message$jscomp$123$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$8$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$8$$])),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$])),$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);if($error__$1$jscomp$5_message$jscomp$123$$!=null){$error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$5_message$jscomp$123$$);
if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$,$token_name$jscomp$42$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$197$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$197$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$],
null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$5_message$jscomp$123$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$]));
var $input_value$jscomp$5$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$197$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$8$$],null),"");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$197$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));return $APP.$cljs$core$empty_QMARK_$$($error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_value$jscomp$5$$,$error_SINGLEQUOTE_$jscomp$2_map__80491__$1_p__80490_value__$1$jscomp$77$$)?
$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$4$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$5_message$jscomp$123$$,$APP.$cljs$cst$139$type$$,"hint"],null))},$APP.$beicon$v2$core$map$$(function($result$jscomp$379$$){return $APP.$app$common$data$update_when$$($result$jscomp$379$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$)},
$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$resolve_value$$,$tokens$jscomp$65$$,$token$jscomp$183$$,$token_name$jscomp$42$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$jscomp$4$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$28$$)}});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,
$props$jscomp$353_props__$1$jscomp$92_props__$2$jscomp$10$$),$APP.$cljs$core$truth_$$($font_selector_open_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_controls_fonts_combobox__font-select-wrapper-composite",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$font_selector_STAR_$$,{currentFont:$font$jscomp$50_props_80483$$,onSelect:$on_select_font$jscomp$1$$,onClose:$on_click_dropdown_button$jscomp$1_on_close_font_selector$jscomp$1$$})}):
null]})};
$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value_tokenscript$$=function($token_result_tokens$jscomp$66$$,$prev_token$jscomp$5_token$jscomp$inline_13964$$,$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$){$prev_token$jscomp$5_token$jscomp$inline_13964$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($prev_token$jscomp$5_token$jscomp$inline_13964$$,$APP.$cljs$cst$260$value$$,$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$);
$token_result_tokens$jscomp$66$$=$APP.$app$main$data$tokenscript$process_tokens$$($token_result_tokens$jscomp$66$$).resolver.updateToken({tokenPath:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$5_token$jscomp$inline_13964$$),tokenData:$APP.$app$main$data$tokenscript$clj__GT_token__GT_tokenscript_token$$($prev_token$jscomp$5_token$jscomp$inline_13964$$)}).resolved;$token_result_tokens$jscomp$66$$ instanceof $APP.$shadow$js$shim$module$0$0penpot$0tokenscript$$.ProcessorError?
($G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$=$token_result_tokens$jscomp$66$$.dependencyChain,$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$=$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$==null?null:$APP.$cljs$core$seq$$($G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$),
$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$=$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$==null?null:$APP.$cljs$core$rest$$($G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$),$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4676$error_DOT_style_dictionary_SLASH_missing_reference$$,$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$)],null)):$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$=
$token_result_tokens$jscomp$66$$ instanceof Error?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4662$error_DOT_style_dictionary_SLASH_invalid_token_value$$,$G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$token_result_tokens$jscomp$66$$],
null);return(0,$APP.$beicon$v2$core$of$$)($G__80462$jscomp$inline_9188_G__80462__$1$jscomp$inline_9189_JSCompiler_inline_result$jscomp$1889_JSCompiler_temp$jscomp$1888_value$jscomp$966$$)};
$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$=function($tokens$jscomp$67_tokens__$1$jscomp$12$$,$prev_token$jscomp$6$$,$token_name$jscomp$43$$,$value$jscomp$967$$){var $valid_token_name_QMARK_$jscomp$2$$=function(){var $and__5023__auto__$jscomp$924$$=typeof $token_name$jscomp$43$$==="string";return $and__5023__auto__$jscomp$924$$?$APP.$cljs$core$re_matches$$($APP.$app$common$types$token$token_name_validation_regex$$,$token_name$jscomp$43$$):$and__5023__auto__$jscomp$924$$}(),
$token$jscomp$184$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$967$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$not$$($valid_token_name_QMARK_$jscomp$2$$)||$APP.$cuerdas$core$blank_QMARK_$$($token_name$jscomp$43$$)?"__PENPOT__TOKEN__NAME__PLACEHOLDER__":$token_name$jscomp$43$$],null);$tokens$jscomp$67_tokens__$1$jscomp$12$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$67_tokens__$1$jscomp$12$$,
$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$6$$)),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$184$$),function($p1__80463_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80463_SHARP_$$,$prev_token$jscomp$6$$,
$token$jscomp$184$$]))]))});return $APP.$cljs$core$truth_$$($APP.$app$common$files$tokens$token_circular_reference_QMARK_$$($tokens$jscomp$67_tokens__$1$jscomp$12$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$184$$)))?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4657$error_DOT_token_SLASH_circular_reference$$,null)],null)):$APP.$beicon$v2$core$mapcat$$(function($errors$jscomp$43_map__80465_resolved_tokens$jscomp$29$$){$errors$jscomp$43_map__80465_resolved_tokens$jscomp$29$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$43_map__80465_resolved_tokens$jscomp$29$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$184$$));var $map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($errors$jscomp$43_map__80465_resolved_tokens$jscomp$29$$);$errors$jscomp$43_map__80465_resolved_tokens$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$,
$APP.$cljs$cst$570$errors$$);$map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$,$APP.$cljs$cst$4686$resolved_value$$);$map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$($map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$):
$map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$;return $APP.$cljs$core$truth_$$($map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$)?(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,$map__80465__$1_resolved_value$jscomp$10_resolved_value__$1$jscomp$5$$],null)):(0,$APP.$beicon$v2$core$of$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$849$error$$,$APP.$cljs$core$truth_$$($errors$jscomp$43_map__80465_resolved_tokens$jscomp$29$$)?
$APP.$cljs$core$first$$($errors$jscomp$43_map__80465_resolved_tokens$jscomp$29$$):$APP.$app$main$data$workspace$tokens$errors$error_with_value$$($APP.$cljs$cst$4682$error_SLASH_unknown$$,$value$jscomp$967$$)],null))},$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($tokens$jscomp$67_tokens__$1$jscomp$12$$))};
$app$main$ui$workspace$tokens$management$forms$controls$input$input_STAR_$$=function($props_80466_touched_QMARK_$jscomp$12$$){var $error$jscomp$149_name$jscomp$486$$=void 0,$token$jscomp$185$$=void 0,$tokens$jscomp$68$$=void 0,$props$jscomp$354_props__$1$jscomp$93_props__$2$jscomp$11$$=void 0;({name:$error$jscomp$149_name$jscomp$486$$,tokens:$tokens$jscomp$68$$,token:$token$jscomp$185$$,...$props$jscomp$354_props__$1$jscomp$93_props__$2$jscomp$11$$}=$props_80466_touched_QMARK_$jscomp$12$$);var $form$jscomp$198$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$9$$=$error$jscomp$149_name$jscomp$486$$,$token_name$jscomp$44$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$198$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null);$props_80466_touched_QMARK_$jscomp$12$$=function(){var $and__5023__auto__$jscomp$925$$=$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$198$$)),
$input_name$jscomp$9$$);return $and__5023__auto__$jscomp$925$$?$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$198$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$9$$],null)):$and__5023__auto__$jscomp$925$$}();$error$jscomp$149_name$jscomp$486$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$198$$),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$input_name$jscomp$9$$],null));var $value$jscomp$968$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$198$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$input_name$jscomp$9$$],null),""),$resolve_stream$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$185$$)],
function(){return $APP.$cljs$core$contains_QMARK_$$($token$jscomp$185$$,$APP.$cljs$cst$260$value$$)?$APP.$beicon$v2$core$behavior_subject$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$185$$)):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hint$jscomp$27$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$5$$),$on_change$jscomp$91$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$5$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$9$$)],function($event$jscomp$630_value__$1$jscomp$78$$){$event$jscomp$630_value__$1$jscomp$78$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$630_value__$1$jscomp$78$$));$APP.$app$util$forms$on_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$198$$,$input_name$jscomp$9$$,$event$jscomp$630_value__$1$jscomp$78$$,!0);return $resolve_stream$jscomp$5$$.next($event$jscomp$630_value__$1$jscomp$78$$)});$props$jscomp$354_props__$1$jscomp$93_props__$2$jscomp$11$$=
{...$props$jscomp$354_props__$1$jscomp$93_props__$2$jscomp$11$$,onChange:$on_change$jscomp$91$$,defaultValue:$value$jscomp$968$$,variant:"comfortable",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$27$$),hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$27$$)};$props$jscomp$354_props__$1$jscomp$93_props__$2$jscomp$11$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error$jscomp$149_name$jscomp$486$$)?$props_80466_touched_QMARK_$jscomp$12$$:
$error$jscomp$149_name$jscomp$486$$)?{...$props$jscomp$354_props__$1$jscomp$93_props__$2$jscomp$11$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error$jscomp$149_name$jscomp$486$$)}:$props$jscomp$354_props__$1$jscomp$93_props__$2$jscomp$11$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$5$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$68$$),$APP.$rumext$v2$adapt$$($token$jscomp$185$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$9$$),
$APP.$rumext$v2$adapt$$($token_name$jscomp$44$$)],function(){var $resolve_value$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value_tokenscript$$:$app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$,$subs$jscomp$29$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error__$1$jscomp$6_message$jscomp$124_p__80471$$){var $map__80472__$1_value__$1$jscomp$79$$=
$APP.$cljs$core$__destructure_map$$($error__$1$jscomp$6_message$jscomp$124_p__80471$$);$error__$1$jscomp$6_message$jscomp$124_p__80471$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80472__$1_value__$1$jscomp$79$$,$APP.$cljs$cst$849$error$$);$map__80472__$1_value__$1$jscomp$79$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80472__$1_value__$1$jscomp$79$$,$APP.$cljs$cst$260$value$$);var $touched_QMARK___$1$jscomp$3$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$198$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$input_name$jscomp$9$$],null));if($APP.$cljs$core$truth_$$($touched_QMARK___$1$jscomp$3$$)){if($APP.$cljs$core$truth_$$($error__$1$jscomp$6_message$jscomp$124_p__80471$$)){if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error__$1$jscomp$6_message$jscomp$124_p__80471$$,$token_name$jscomp$44$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$198$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$6_message$jscomp$124_p__80471$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$198$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4837$extra_errors$$,$input_name$jscomp$9$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$6_message$jscomp$124_p__80471$$],null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$5$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$6_message$jscomp$124_p__80471$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$6_message$jscomp$124_p__80471$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80472__$1_value__$1$jscomp$79$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$198$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$9$$]));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$5$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,
$error__$1$jscomp$6_message$jscomp$124_p__80471$$,$APP.$cljs$cst$139$type$$,"hint"],null))}return null},$APP.$beicon$v2$core$map$$(function($result$jscomp$381$$){return $APP.$app$common$data$update_when$$($result$jscomp$381$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($resolve_value$$,$tokens$jscomp$68$$,$token$jscomp$185$$,$token_name$jscomp$44$$),$APP.$beicon$v2$core$debounce$$(300,
$resolve_stream$jscomp$5$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$29$$)}});return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$354_props__$1$jscomp$93_props__$2$jscomp$11$$)};
$app$main$ui$workspace$tokens$management$forms$controls$input$on_composite_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$=function($form$jscomp$200$$,$field$jscomp$13$$,$value$jscomp$970$$){function $clean_errors$jscomp$3$$($G__80481__$1_G__80481__$2_errors$jscomp$44$$){$G__80481__$1_G__80481__$2_errors$jscomp$44$$=$G__80481__$1_G__80481__$2_errors$jscomp$44$$==null?null:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__80481__$1_G__80481__$2_errors$jscomp$44$$,$APP.$cljs$cst$260$value$$,
function($p1__80474_SHARP_$$){return $APP.$cljs$core$map_QMARK_$$($p1__80474_SHARP_$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__80474_SHARP_$$,$field$jscomp$13$$):null});$G__80481__$1_G__80481__$2_errors$jscomp$44$$=$G__80481__$1_G__80481__$2_errors$jscomp$44$$==null?null:$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__80481__$1_G__80481__$2_errors$jscomp$44$$,$APP.$cljs$cst$260$value$$,function($p1__80475_SHARP_$$){return $APP.$cljs$core$seq$$($p1__80475_SHARP_$$)?
$p1__80475_SHARP_$$:null});return $G__80481__$1_G__80481__$2_errors$jscomp$44$$==null?null:$APP.$cljs$core$not_empty$$($G__80481__$1_G__80481__$2_errors$jscomp$44$$)}$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$200$$,function($state$jscomp$1222$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1222$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$field$jscomp$13$$],null),$APP.$cljs$core$truth_$$(!0)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$970$$):$value$jscomp$970$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$260$value$$,$field$jscomp$13$$],null),!0),$APP.$cljs$cst$570$errors$$,
$clean_errors$jscomp$3$$),$APP.$cljs$cst$4837$extra_errors$$,$clean_errors$jscomp$3$$),$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$=function($props_80482_value$jscomp$971$$){var $name$jscomp$487$$=void 0,$token$jscomp$186$$=void 0,$tokens$jscomp$69$$=void 0,$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$=void 0;({name:$name$jscomp$487$$,tokens:$tokens$jscomp$69$$,token:$token$jscomp$186$$,...$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$}=$props_80482_value$jscomp$971$$);var $form$jscomp$201$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$10$$=$name$jscomp$487$$,$token_name$jscomp$45$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null),$error$jscomp$150$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$201$$),
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null)),$extra_error$jscomp$3$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null));$props_80482_value$jscomp$971$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null),"");var $touched_QMARK_$jscomp$13$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null)),$resolve_stream$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$186$$)],function(){var $temp__5823__auto__$jscomp$240$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$186$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null));
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$240$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$240$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$hint$jscomp$28$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$6$$),$on_change$jscomp$92$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$6$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$10$$)],function($event$jscomp$631_value__$1$jscomp$81$$){$event$jscomp$631_value__$1$jscomp$81$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$631_value__$1$jscomp$81$$));$app$main$ui$workspace$tokens$management$forms$controls$input$on_composite_input_change$cljs$0core$0IFn$0_invoke$0arity$04$$($form$jscomp$201$$,$input_name$jscomp$10$$,$event$jscomp$631_value__$1$jscomp$81$$);return $resolve_stream$jscomp$6$$.next($event$jscomp$631_value__$1$jscomp$81$$)});
$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$={...$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$,onChange:$on_change$jscomp$92$$,defaultValue:$props_80482_value$jscomp$971$$,variant:"comfortable",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$28$$),hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$28$$)};$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$=
$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($extra_error$jscomp$3$$))return $extra_error$jscomp$3$$;var $and__5023__auto__$jscomp$927_or__5025__auto____$1$jscomp$144$$=$APP.$cljs$core$truth_$$($touched_QMARK_$jscomp$13$$)?$error$jscomp$150$$:$touched_QMARK_$jscomp$13$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$927_or__5025__auto____$1$jscomp$144$$)?$and__5023__auto__$jscomp$927_or__5025__auto____$1$jscomp$144$$:($and__5023__auto__$jscomp$927_or__5025__auto____$1$jscomp$144$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1771$line_height$$,$input_name$jscomp$10$$))?$error$jscomp$150$$:$and__5023__auto__$jscomp$927_or__5025__auto____$1$jscomp$144$$}())?{...$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$,hintType:"error",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($error$jscomp$150$$)?$error$jscomp$150$$:$extra_error$jscomp$3$$)}:$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$;
$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$=$APP.$cljs$core$not$$($error$jscomp$150$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_name$jscomp$10$$,$APP.$cljs$cst$4651$reference$$)?{...$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$,hintFormated:!0}:$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$6$$),
$APP.$rumext$v2$adapt$$($tokens$jscomp$69$$),$APP.$rumext$v2$adapt$$($token$jscomp$186$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$10$$),$APP.$rumext$v2$adapt$$($name$jscomp$487$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$45$$)],function(){var $subs$jscomp$30$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$){$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$=
$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$);var $error__$1$jscomp$7_input_value$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$,$APP.$cljs$cst$849$error$$);$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$,
$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error__$1$jscomp$7_input_value$jscomp$6$$)?$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$7_input_value$jscomp$6$$)):$error__$1$jscomp$7_input_value$jscomp$6$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$10$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$10$$])),
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$])),$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);if($error__$1$jscomp$7_input_value$jscomp$6$$!=null){$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$=
$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$7_input_value$jscomp$6$$);if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$,$token_name$jscomp$45$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$201$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4837$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$201$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$],null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$6$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$7_input_value$jscomp$6$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$input_name$jscomp$10$$],null),"");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$487$$,$APP.$cljs$cst$1771$line_height$$)){var $JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$=
$APP.$app$common$files$tokens$parse_token_value$$($error__$1$jscomp$7_input_value$jscomp$6$$);if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$)){var $map__80488__$1$jscomp$inline_13967_value__$2$jscomp$inline_13969$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$);
$JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80488__$1$jscomp$inline_13967_value__$2$jscomp$inline_13969$$,$APP.$cljs$cst$4654$unit$$);$map__80488__$1$jscomp$inline_13967_value__$2$jscomp$inline_13969$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80488__$1$jscomp$inline_13967_value__$2$jscomp$inline_13969$$,$APP.$cljs$cst$260$value$$);
var $font_size$jscomp$inline_13970$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$201$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1766$font_size$$],null),"");$JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("%",
$JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$)?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($map__80488__$1$jscomp$inline_13967_value__$2$jscomp$inline_13969$$)/100:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("px",$JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$)?
$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($map__80488__$1$jscomp$inline_13967_value__$2$jscomp$inline_13969$$)/$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($font_size$jscomp$inline_13970$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$)?$map__80488__$1$jscomp$inline_13967_value__$2$jscomp$inline_13969$$:
null;$JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$=$APP.$app$main$data$workspace$tokens$format$format_token_value$$($JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$)}else $JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$=
null}else $JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$=$APP.$app$main$data$workspace$tokens$format$format_token_value$$($error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$);$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$)?$JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$:$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$201$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($error__$1$jscomp$7_input_value$jscomp$6$$,
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11310_calculated$jscomp$inline_13971_resolved_value$jscomp$11_temp__5825__auto__$jscomp$inline_13966_unit$jscomp$inline_13968$$))?$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$6$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$3_map__80487__$1_message$jscomp$125_p__80486_value__$1$jscomp$82$$,
$APP.$cljs$cst$139$type$$,"hint"],null))},$APP.$beicon$v2$core$map$$(function($result$jscomp$382$$){return $APP.$app$common$data$update_when$$($result$jscomp$382$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$,$tokens$jscomp$69$$,$token$jscomp$186$$,$token_name$jscomp$45$$),$APP.$beicon$v2$core$debounce$$(300,
$resolve_stream$jscomp$6$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$30$$)}});return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$355_props__$1$jscomp$94_props__$2$jscomp$12_props__$3$jscomp$1$$)};
$app$main$ui$workspace$tokens$management$forms$controls$input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$=function($form$jscomp$203$$,$field$jscomp$15$$,$index$jscomp$556$$,$value$jscomp$973$$,$value_subfield$jscomp$4$$){function $clean_errors$jscomp$4$$($errors$jscomp$45$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($errors$jscomp$45$$,$field$jscomp$15$$))}$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($form$jscomp$203$$,
function($state$jscomp$1223$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc_in$$($APP.$cljs$core$assoc_in$$($state$jscomp$1223$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,
$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$4$$,$index$jscomp$556$$,$field$jscomp$15$$],null),$APP.$cljs$core$truth_$$(!0)?$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$973$$):$value$jscomp$973$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$4$$,$index$jscomp$556$$,$field$jscomp$15$$],null),!0),$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,
$APP.$cljs$cst$260$value$$),$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$260$value$$),$APP.$cljs$cst$570$errors$$,$clean_errors$jscomp$4$$),$APP.$cljs$cst$4837$extra_errors$$,$clean_errors$jscomp$4$$),$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,"")})};
$app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$=function($props_80498_value_from_form$$){var $index$jscomp$557$$=void 0,$hint$jscomp$29_name$jscomp$488_touched_QMARK_$jscomp$14$$=void 0,$token$jscomp$187$$=void 0,$value_subfield$jscomp$5$$=void 0,$tokens$jscomp$70$$=void 0,$indexed_error$jscomp$1_nillable$jscomp$2_on_change$jscomp$93$$=void 0,$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$=void 0;({name:$hint$jscomp$29_name$jscomp$488_touched_QMARK_$jscomp$14$$,
tokens:$tokens$jscomp$70$$,token:$token$jscomp$187$$,index:$index$jscomp$557$$,valueSubfield:$value_subfield$jscomp$5$$,nillable:$indexed_error$jscomp$1_nillable$jscomp$2_on_change$jscomp$93$$,...$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$}=$props_80498_value_from_form$$);var $form$jscomp$204$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$11$$=$hint$jscomp$29_name$jscomp$488_touched_QMARK_$jscomp$14$$,$token_name$jscomp$46$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$204$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$725$name$$],null),null),$empty_error$jscomp$1_nillable__$1$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($indexed_error$jscomp$1_nillable$jscomp$2_on_change$jscomp$93$$,!1);$hint$jscomp$29_name$jscomp$488_touched_QMARK_$jscomp$14$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$204$$),
new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$557$$,$input_name$jscomp$11$$],null));var $extra_error$jscomp$4$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$204$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$260$value$$,
$value_subfield$jscomp$5$$,$index$jscomp$557$$,$input_name$jscomp$11$$],null));$props_80498_value_from_form$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$204$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$557$$,$input_name$jscomp$11$$],null),"");$indexed_error$jscomp$1_nillable$jscomp$2_on_change$jscomp$93$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$204$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$557$$,$input_name$jscomp$11$$],null));$empty_error$jscomp$1_nillable__$1$jscomp$1$$=$APP.$cljs$core$not$$($empty_error$jscomp$1_nillable__$1$jscomp$1$$)&&$APP.$cuerdas$core$blank_QMARK_$$($props_80498_value_from_form$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.empty-field")],null):null;var $error$jscomp$151$$=$APP.$cljs$core$truth_$$($hint$jscomp$29_name$jscomp$488_touched_QMARK_$jscomp$14$$)?$APP.$cljs$core$truth_$$($indexed_error$jscomp$1_nillable$jscomp$2_on_change$jscomp$93$$)?$indexed_error$jscomp$1_nillable$jscomp$2_on_change$jscomp$93$$:$empty_error$jscomp$1_nillable__$1$jscomp$1$$:null,$resolve_stream$jscomp$7$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$187$$),$APP.$rumext$v2$adapt$$($index$jscomp$557$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$11$$)],function(){var $temp__5823__auto__$jscomp$241$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$187$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$557$$,$input_name$jscomp$11$$],
null));return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$241$$)?$APP.$beicon$v2$core$behavior_subject$$($temp__5823__auto__$jscomp$241$$):$APP.$beicon$v2$core$subject$$()}),$hint_STAR_$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);$hint$jscomp$29_name$jscomp$488_touched_QMARK_$jscomp$14$$=$APP.$cljs$core$_deref$$($hint_STAR_$jscomp$7$$);$indexed_error$jscomp$1_nillable$jscomp$2_on_change$jscomp$93$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$7$$),
$APP.$rumext$v2$adapt$$($input_name$jscomp$11$$),$APP.$rumext$v2$adapt$$($index$jscomp$557$$)],function($event$jscomp$632_value$jscomp$975$$){$event$jscomp$632_value$jscomp$975$$=$APP.$app$util$dom$get_input_value$$($APP.$app$util$dom$get_target$$($event$jscomp$632_value$jscomp$975$$));$app$main$ui$workspace$tokens$management$forms$controls$input$on_indexed_input_change$cljs$0core$0IFn$0_invoke$0arity$06$$($form$jscomp$204$$,$input_name$jscomp$11$$,$index$jscomp$557$$,$event$jscomp$632_value$jscomp$975$$,
$value_subfield$jscomp$5$$);return $resolve_stream$jscomp$7$$.next($event$jscomp$632_value$jscomp$975$$)});$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$={...$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$,onChange:$indexed_error$jscomp$1_nillable$jscomp$2_on_change$jscomp$93$$,value:$props_80498_value_from_form$$,variant:"comfortable",hintMessage:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$29_name$jscomp$488_touched_QMARK_$jscomp$14$$),
hintType:$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($hint$jscomp$29_name$jscomp$488_touched_QMARK_$jscomp$14$$)};$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error$jscomp$151$$)?$error$jscomp$151$$:$extra_error$jscomp$4$$)?{...$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$,hintType:"error",hintMessage:function(){var $or__5025__auto__$jscomp$1334$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($error$jscomp$151$$)?
$error$jscomp$151$$:$extra_error$jscomp$4$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1334$$)?$or__5025__auto__$jscomp$1334$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.field-missing")}()}:$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$;$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$=$APP.$cljs$core$not$$($error$jscomp$151$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_name$jscomp$11$$,
$APP.$cljs$cst$4651$reference$$)?{...$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$,hintFormated:!0}:$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$;$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolve_stream$jscomp$7$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$70$$),$APP.$rumext$v2$adapt$$($token$jscomp$187$$),$APP.$rumext$v2$adapt$$($input_name$jscomp$11$$),$APP.$rumext$v2$adapt$$($index$jscomp$557$$),
$APP.$rumext$v2$adapt$$($value_subfield$jscomp$5$$),$APP.$rumext$v2$adapt$$($token_name$jscomp$46$$)],function(){var $subs$jscomp$31$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$){$error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$=$APP.$cljs$core$__destructure_map$$($error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$);var $error__$1$jscomp$8_message$jscomp$126$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$,$APP.$cljs$cst$849$error$$);$error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$,$APP.$cljs$cst$260$value$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($error__$1$jscomp$8_message$jscomp$126$$)?$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$4684$error_SLASH_value$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$8_message$jscomp$126$$)):
$error__$1$jscomp$8_message$jscomp$126$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$557$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$11$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,
$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$557$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$input_name$jscomp$11$$])),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$])),$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$7$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$);if($error__$1$jscomp$8_message$jscomp$126$$!=null){$error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$=$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($error__$1$jscomp$8_message$jscomp$126$$);if($app$main$ui$workspace$tokens$management$forms$controls$utils$group_name_conflict_error_QMARK_$$($error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$,
$token_name$jscomp$46$$))return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$204$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,""],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$],null));$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$204$$,
$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$557$$,$input_name$jscomp$11$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$],null));return $APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$7$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$141$message$$,$error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$,$APP.$cljs$cst$139$type$$,"error"],null))}$error__$1$jscomp$8_message$jscomp$126$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$)]));var $input_value$jscomp$7$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$204$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$5$$,$index$jscomp$557$$,$input_name$jscomp$11$$],null),"");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$204$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$]));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($input_value$jscomp$7$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($error_SINGLEQUOTE_$jscomp$4_map__80506__$1_p__80505_value$jscomp$976$$))?$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$7$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$):$APP.$cljs$core$reset_BANG_$$($hint_STAR_$jscomp$7$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$141$message$$,$error__$1$jscomp$8_message$jscomp$126$$,$APP.$cljs$cst$139$type$$,"hint"],null))},$APP.$beicon$v2$core$map$$(function($result$jscomp$383$$){return $APP.$app$common$data$update_when$$($result$jscomp$383$$,$APP.$cljs$cst$849$error$$,$app$main$data$workspace$tokens$errors$resolve_error_assoc_message$$)},$APP.$beicon$v2$core$mapcat$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$04$$($app$main$ui$workspace$tokens$management$forms$controls$input$resolve_value$$,
$tokens$jscomp$70$$,$token$jscomp$187$$,$token_name$jscomp$46$$),$APP.$beicon$v2$core$debounce$$(300,$resolve_stream$jscomp$7$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$31$$)}});return(0,$APP.$rumext$v2$create_element$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,$props$jscomp$356_props__$1$jscomp$95_props__$2$jscomp$13_props__$3$jscomp$2$$)};
$app$main$ui$workspace$tokens$management$forms$controls$select$select_indexed_STAR_$$=function($props_80473_value$jscomp$977$$){var $index$jscomp$558$$=void 0,$name$jscomp$489_on_change$jscomp$94$$=void 0,$indexed_type$$=void 0,$props$jscomp$357$$=void 0;({name:$name$jscomp$489_on_change$jscomp$94$$,index:$index$jscomp$558$$,indexedType:$indexed_type$$,...$props$jscomp$357$$}=$props_80473_value$jscomp$977$$);var $form$jscomp$205$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$input_name$jscomp$12$$=
$name$jscomp$489_on_change$jscomp$94$$;$props_80473_value$jscomp$977$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$_deref$$($form$jscomp$205$$),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$indexed_type$$,$index$jscomp$558$$,$input_name$jscomp$12$$],null),!1);$name$jscomp$489_on_change$jscomp$94$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($input_name$jscomp$12$$)],
function($id$jscomp$1025_is_inner_QMARK_$$){$id$jscomp$1025_is_inner_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1025_is_inner_QMARK_$$,"inner");$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$205$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$indexed_type$$,$index$jscomp$558$$,$input_name$jscomp$12$$],null),$id$jscomp$1025_is_inner_QMARK_$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$205$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([""]))});return $APP.$rumext$v2$create_element$$($APP.$app$main$ui$ds$controls$select$select_STAR_$$,{...$props$jscomp$357$$,defaultSelected:$APP.$cljs$core$truth_$$($props_80473_value$jscomp$977$$)?"inner":"drop",variant:"ghost",onChange:$name$jscomp$489_on_change$jscomp$94$$})};
$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$=function($token_name$jscomp$47$$,$token_value$jscomp$11$$){return $APP.$app$common$types$token$token_value_self_reference_QMARK_$$($token_name$jscomp$47$$,$token_value$jscomp$11$$)?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4672$error_DOT_token_SLASH_direct_self_reference$$):null};
$app$main$ui$workspace$tokens$management$forms$validators$validate_resolve_token$$=function($token$jscomp$189_tokens_SINGLEQUOTE_$jscomp$2$$,$prev_token$jscomp$7$$,$tokens$jscomp$71$$){var $token__$1$jscomp$3$$=$APP.$cljs$core$not$$($app$common$schema$valid_QMARK_$$($APP.$app$common$types$token$schema_COLON_token_name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$189_tokens_SINGLEQUOTE_$jscomp$2$$)))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($token$jscomp$189_tokens_SINGLEQUOTE_$jscomp$2$$,
$APP.$cljs$cst$725$name$$,"__PENPOT__TOKEN__NAME__PLACEHOLDER__"):$token$jscomp$189_tokens_SINGLEQUOTE_$jscomp$2$$;$token$jscomp$189_tokens_SINGLEQUOTE_$jscomp$2$$=function(){var $G__80496__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$3$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$7$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($tokens$jscomp$71$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($prev_token$jscomp$7$$)):
$tokens$jscomp$71$$;return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__80496__$1$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$3$$),function($p1__80494_SHARP_$$){return $APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__80494_SHARP_$$,
$prev_token$jscomp$7$$,$token__$1$jscomp$3$$]))]))})}();return $APP.$beicon$v2$core$mapcat$$(function($resolved_tokens$jscomp$30$$){var $resolved_token$jscomp$23$$=function(){var $G__80497$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($resolved_tokens$jscomp$30$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$3$$));return $APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($G__80497$$,
$APP.$cljs$cst$4686$resolved_value$$,$APP.$app$main$data$tokenscript$tokenscript_symbols__GT_penpot_unit$$):$G__80497$$}();return $APP.$cljs$core$truth_$$($APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$23$$))?(0,$APP.$beicon$v2$core$of$$)($resolved_token$jscomp$23$$):$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,function(){var $or__5025__auto__$jscomp$1336$$=$APP.$cljs$core$seq$$($APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$23$$));
return $or__5025__auto__$jscomp$1336$$?$or__5025__auto__$jscomp$1336$$:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($cljs$cst$5923$error_SLASH_unknown_error$$)],null)}()],null))},$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$tokenscript$resolve_tokens$$($token$jscomp$189_tokens_SINGLEQUOTE_$jscomp$2$$)):
$APP.$app$main$data$style_dictionary$resolve_tokens_interactive$$($token$jscomp$189_tokens_SINGLEQUOTE_$jscomp$2$$))};
$app$main$ui$workspace$tokens$management$forms$validators$validate_token_with$$=function($token$jscomp$190$$,$temp__5823__auto__$jscomp$242_validators$jscomp$9$$){$temp__5823__auto__$jscomp$242_validators$jscomp$9$$=$APP.$cljs$core$some$$(function($validate$jscomp$5$$){return $validate$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$validate$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$190$$):$validate$jscomp$5$$($token$jscomp$190$$)},$temp__5823__auto__$jscomp$242_validators$jscomp$9$$);
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$242_validators$jscomp$9$$)?$APP.$beicon$v2$core$throw$0$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$570$errors$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$temp__5823__auto__$jscomp$242_validators$jscomp$9$$],null)],null)):(0,$APP.$beicon$v2$core$of$$)($token$jscomp$190$$)};
$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$=function($map__80502__$1_p__80501_token$jscomp$191$$){$map__80502__$1_p__80501_token$jscomp$191$$=$APP.$cljs$core$__destructure_map$$($map__80502__$1_p__80501_token$jscomp$191$$);var $token_name$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80502__$1_p__80501_token$jscomp$191$$,$APP.$cljs$cst$4253$token_name$$),$token_value$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80502__$1_p__80501_token$jscomp$191$$,
$cljs$cst$5924$token_value$$),$token_description$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80502__$1_p__80501_token$jscomp$191$$,$cljs$cst$5925$token_description$$),$prev_token$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80502__$1_p__80501_token$jscomp$191$$,$cljs$cst$5926$prev_token$$),$tokens$jscomp$72$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80502__$1_p__80501_token$jscomp$191$$,$APP.$cljs$cst$2108$tokens$$),$validators$jscomp$10$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__80502__$1_p__80501_token$jscomp$191$$,$APP.$cljs$cst$4836$validators$$,$app$main$ui$workspace$tokens$management$forms$validators$default_validators$$);$map__80502__$1_p__80501_token$jscomp$191$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$token_name$jscomp$48$$,$APP.$cljs$cst$260$value$$,$token_value$jscomp$12$$,$APP.$cljs$cst$936$description$$,
$token_description$$],null));return $APP.$beicon$v2$core$mapcat$$(function($p1__80500_SHARP_$$){return $app$main$ui$workspace$tokens$management$forms$validators$validate_resolve_token$$($p1__80500_SHARP_$$,$prev_token$jscomp$8$$,$tokens$jscomp$72$$)},$APP.$beicon$v2$core$mapcat$$(function($p1__80499_SHARP_$$){return $app$main$ui$workspace$tokens$management$forms$validators$validate_token_with$$($p1__80499_SHARP_$$,$validators$jscomp$10$$)},(0,$APP.$beicon$v2$core$of$$)($map__80502__$1_p__80501_token$jscomp$191$$)))};
$app$main$ui$workspace$tokens$management$forms$validators$check_coll_self_reference$$=function($token_name$jscomp$49$$,$token_vals$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$some$$(function($p1__80503_SHARP_$$){return $APP.$app$common$types$token$token_value_self_reference_QMARK_$$($token_name$jscomp$49$$,$p1__80503_SHARP_$$)},$token_vals$$))?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4672$error_DOT_token_SLASH_direct_self_reference$$):null};
$app$main$ui$workspace$tokens$management$forms$generic_form$scroll_token_type_section_on_create$$=function($token_id$jscomp$25$$){return $APP.$cljs$core$truth_$$($token_id$jscomp$25$$)?requestAnimationFrame(function(){var $JSCompiler_temp$jscomp$11217_temp__5825__auto__$jscomp$417$$=$APP.$app$util$dom$get_element$$(["token-pill-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($token_id$jscomp$25$$)].join(""));if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11217_temp__5825__auto__$jscomp$417$$)){var $options$jscomp$inline_13974$$=
{block:"center",behavior:"smooth"};$JSCompiler_temp$jscomp$11217_temp__5825__auto__$jscomp$417$$=$JSCompiler_temp$jscomp$11217_temp__5825__auto__$jscomp$417$$!=null?$JSCompiler_temp$jscomp$11217_temp__5825__auto__$jscomp$417$$.scrollIntoView($options$jscomp$inline_13974$$):null}else $JSCompiler_temp$jscomp$11217_temp__5825__auto__$jscomp$417$$=null;return $JSCompiler_temp$jscomp$11217_temp__5825__auto__$jscomp$417$$}):null};
$app$main$ui$workspace$tokens$management$forms$generic_form$get_value_for_validator$$=function($active_tab$$,$value$jscomp$978$$,$value_subfield$jscomp$6$$,$value_type$$){switch($value_type$$ instanceof $APP.$cljs$core$Keyword$$?$value_type$$.$fqn$:null){case "indexed":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_tab$$,$APP.$cljs$cst$4651$reference$$)?$APP.$cljs$cst$4651$reference$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$978$$):$value_subfield$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?
$value_subfield$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$978$$):$value_subfield$jscomp$6$$($value$jscomp$978$$);case "composite":return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_tab$$,$APP.$cljs$cst$4651$reference$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$978$$,$APP.$cljs$cst$4651$reference$$):$value$jscomp$978$$;default:return $value$jscomp$978$$}};
$app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$=function($props_80511_token_properties_token_title$$){var $is_create$$=$props_80511_token_properties_token_title$$.isCreate,$value_type$jscomp$1$$=$props_80511_token_properties_token_title$$.valueType,$make_schema$$=$props_80511_token_properties_token_title$$.makeSchema,$active_tokens_by_type$jscomp$1_validator$jscomp$35$$=$props_80511_token_properties_token_title$$.validator,$input_value_placeholder$$=$props_80511_token_properties_token_title$$.inputValuePlaceholder,
$tokens_tree_in_selected_set$$=$props_80511_token_properties_token_title$$.tokensTreeInSelectedSet,$selected_token_set_id$jscomp$9$$=$props_80511_token_properties_token_title$$.selectedTokenSetId,$general_errors_input_component_schema$jscomp$245$$=$props_80511_token_properties_token_title$$.inputComponent,$token$jscomp$192$$=$props_80511_token_properties_token_title$$.token,$initial_errors$jscomp$2$$=$props_80511_token_properties_token_title$$.initialErrors,$token_type$jscomp$22$$=$props_80511_token_properties_token_title$$.tokenType,
$value_subfield$jscomp$7$$=$props_80511_token_properties_token_title$$.valueSubfield,$initial$jscomp$37$$=$props_80511_token_properties_token_title$$.initial,$current_token_path$jscomp$1$$=$props_80511_token_properties_token_title$$.currentTokenPath,$action$jscomp$8$$=$props_80511_token_properties_token_title$$.action,$make_schema__$1$$=function(){return $APP.$cljs$core$truth_$$($make_schema$$)?$make_schema$$:function($p1__80510_SHARP_$$){return $APP.$app$common$schema$dissoc_key$$($APP.$app$common$files$tokens$make_token_schema$$($p1__80510_SHARP_$$,
$token_type$jscomp$22$$,$current_token_path$jscomp$1$$))}}(),$input_component__$1$$=$APP.$cljs$core$truth_$$($general_errors_input_component_schema$jscomp$245$$)?$general_errors_input_component_schema$jscomp$245$$:$app$main$ui$workspace$tokens$management$forms$controls$input$input_STAR_$$,$validate_token$$=$APP.$cljs$core$truth_$$($active_tokens_by_type$jscomp$1_validator$jscomp$35$$)?$active_tokens_by_type$jscomp$1_validator$jscomp$35$$:$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$,
$active_tab_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$192$$),"{"))?$APP.$cljs$cst$4651$reference$$:$cljs$cst$5927$composite$$}),$active_tab$jscomp$1$$=$APP.$cljs$core$_deref$$($active_tab_STAR_$$),$token__$1$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$192$$)],
function(){return $APP.$cljs$core$truth_$$($token$jscomp$192$$)?$token$jscomp$192$$:new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$22$$],null)});$props_80511_token_properties_token_title$$=$app$main$data$workspace$tokens$application$get_token_properties$$($token__$1$jscomp$4$$);$props_80511_token_properties_token_title$$=$APP.$cuerdas$core$lower$$($APP.$cljs$cst$939$title$$.$cljs$core$IFn$_invoke$arity$1$($props_80511_token_properties_token_title$$));
var $tokens_tree$jscomp$11$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_map$$),$tokens_in_selected_set$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_in_selected_set$$),$tokens$jscomp$73$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_tree$jscomp$11$$),$APP.$rumext$v2$adapt$$($tokens_in_selected_set$$),$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$)],function(){var $G__80512$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$tokens_tree$jscomp$11$$,
$tokens_in_selected_set$$]));var $JSCompiler_inline_result$jscomp$1890_and__5023__auto__$jscomp$inline_9191$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$);$JSCompiler_inline_result$jscomp$1890_and__5023__auto__$jscomp$inline_9191$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1890_and__5023__auto__$jscomp$inline_9191$$)?$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$):$JSCompiler_inline_result$jscomp$1890_and__5023__auto__$jscomp$inline_9191$$;
return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1890_and__5023__auto__$jscomp$inline_9191$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80512$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$),$token__$1$jscomp$4$$):$G__80512$$}),$tokenscript_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$),$resolved_active_tokens$jscomp$4$$=$APP.$app$main$data$style_dictionary$use_resolved_tokens_STAR_$$($tokens_tree$jscomp$11$$),
$tokenscript_resolved_active_tokens$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_tree$jscomp$11$$),$APP.$rumext$v2$adapt$$($tokenscript_QMARK_$jscomp$1$$)],function(){return $tokenscript_QMARK_$jscomp$1$$?$APP.$app$main$data$tokenscript$resolve_tokens$$($tokens_tree$jscomp$11$$):null});$active_tokens_by_type$jscomp$1_validator$jscomp$35$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($resolved_active_tokens$jscomp$4$$),
$APP.$rumext$v2$adapt$$($tokenscript_resolved_active_tokens$jscomp$1$$),$APP.$rumext$v2$adapt$$($tokenscript_QMARK_$jscomp$1$$)],function(){return new $APP.$cljs$core$Delay$$(function(){return $app$common$types$tokens_lib$group_by_type$$($tokenscript_QMARK_$jscomp$1$$?$tokenscript_resolved_active_tokens$jscomp$1$$:$resolved_active_tokens$jscomp$4$$)})});$general_errors_input_component_schema$jscomp$245$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_tree_in_selected_set$$),
$APP.$rumext$v2$adapt$$($active_tab$jscomp$1$$)],function(){return $make_schema__$1$$.$cljs$core$IFn$_invoke$arity$2$?$make_schema__$1$$.$cljs$core$IFn$_invoke$arity$2$($tokens_tree_in_selected_set$$,$active_tab$jscomp$1$$):$make_schema__$1$$($tokens_tree_in_selected_set$$,$active_tab$jscomp$1$$)});var $handle_key_down_delete_initial__$1$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($initial$jscomp$37$$)],
function(){return $APP.$cljs$core$truth_$$($initial$jscomp$37$$)?$initial$jscomp$37$$:new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$22$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$4$$,""),$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$4$$,""),$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$4$$,
"")],null)}),$handle_key_down_cancel_initial_general_errors$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($handle_key_down_delete_initial__$1$jscomp$3$$),$APP.$rumext$v2$adapt$$($initial_errors$jscomp$2$$)],function(){return $APP.$cljs$core$truth_$$($initial_errors$jscomp$2$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4676$error_DOT_style_dictionary_SLASH_missing_reference$$,$APP.$cljs$cst$945$error_SLASH_code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($initial_errors$jscomp$2$$)))?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value_type$jscomp$1$$,$cljs$cst$5927$composite$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value_type$jscomp$1$$,$cljs$cst$5928$indexed$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4651$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($initial_errors$jscomp$2$$))],
null)],null)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($initial_errors$jscomp$2$$))],null)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,["",new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($initial_errors$jscomp$2$$))],
null)],null):null}),$form$jscomp$206$$=$APP.$app$util$forms$use_form$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$298$schema$$,$general_errors_input_component_schema$jscomp$245$$,$APP.$cljs$cst$4841$initial_errors$$,$handle_key_down_cancel_initial_general_errors$$,$APP.$cljs$cst$4840$initial$$,$handle_key_down_delete_initial__$1$jscomp$3$$]));$general_errors_input_component_schema$jscomp$245$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$206$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,""],null));var $on_toggle_tab$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$206$$)],function($new_tab_new_tab__$1$$){$new_tab_new_tab__$1$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($new_tab_new_tab__$1$$);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_tab_new_tab__$1$$,$APP.$cljs$cst$4651$reference$$)?
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$206$$,$APP.$cljs$core$assoc_in$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$570$errors$$,$APP.$cljs$cst$4651$reference$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,"Need valid reference"],null)):$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$206$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$570$errors$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4651$reference$$]));return $APP.$cljs$core$reset_BANG_$$($active_tab_STAR_$$,$new_tab_new_tab__$1$$)}),$on_cancel$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$370$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$370$$);return $APP.$app$main$data$modal$hide_BANG_$$()}),$on_delete_token$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_token_set_id$jscomp$9$$),
$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$)],function($e$jscomp$371$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$371$$);$APP.$app$main$data$modal$hide_BANG_$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token$$($selected_token_set_id$jscomp$9$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$)))});$handle_key_down_delete_initial__$1$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_delete_token$jscomp$3$$)],
function($e$jscomp$372$$){var $JSCompiler_inline_result$jscomp$1891_or__5025__auto__$jscomp$inline_9193$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($e$jscomp$372$$);$JSCompiler_inline_result$jscomp$1891_or__5025__auto__$jscomp$inline_9193$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1891_or__5025__auto__$jscomp$inline_9193$$)?$JSCompiler_inline_result$jscomp$1891_or__5025__auto__$jscomp$inline_9193$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($e$jscomp$372$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1891_or__5025__auto__$jscomp$inline_9193$$)?
$on_delete_token$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete_token$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$372$$):$on_delete_token$jscomp$3$$($e$jscomp$372$$):null});$handle_key_down_cancel_initial_general_errors$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_cancel$jscomp$9$$)],function($e$jscomp$373$$){var $JSCompiler_inline_result$jscomp$1892_or__5025__auto__$jscomp$inline_9195$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($e$jscomp$373$$);
$JSCompiler_inline_result$jscomp$1892_or__5025__auto__$jscomp$inline_9195$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1892_or__5025__auto__$jscomp$inline_9195$$)?$JSCompiler_inline_result$jscomp$1892_or__5025__auto__$jscomp$inline_9195$$:(0,$APP.$app$util$keyboard$space_QMARK_$$)($e$jscomp$373$$);return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1892_or__5025__auto__$jscomp$inline_9195$$)?$on_cancel$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$?$on_cancel$jscomp$9$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$373$$):
$on_cancel$jscomp$9$$($e$jscomp$373$$):null});var $on_remap_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($token_type$jscomp$22$$)],function($valid_token$$,$new_name$jscomp$38$$,$old_name$jscomp$2$$,$description$jscomp$19$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$($token_type$jscomp$22$$,$new_name$jscomp$38$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$new_name$jscomp$38$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($valid_token$$),$APP.$cljs$cst$936$description$$,$description$jscomp$19$$],null)),
$app$main$data$workspace$tokens$remapping$remap_tokens$$($old_name$jscomp$2$$,$new_name$jscomp$38$$),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$(),$APP.$app$main$data$modal$hide_BANG_$$()]))}),$on_rename_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($token_type$jscomp$22$$)],function($valid_token$jscomp$1$$,$name$jscomp$490$$,$description$jscomp$20$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$($token_type$jscomp$22$$,
$name$jscomp$490$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$name$jscomp$490$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($valid_token$jscomp$1$$),$APP.$cljs$cst$936$description$$,$description$jscomp$20$$],
null)),$APP.$app$main$data$modal$hide_BANG_$$()]))}),$on_submit$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($validate_token$$),$APP.$rumext$v2$adapt$$($token__$1$jscomp$4$$),$APP.$rumext$v2$adapt$$($tokens$jscomp$73$$),$APP.$rumext$v2$adapt$$($token_type$jscomp$22$$),$APP.$rumext$v2$adapt$$($value_subfield$jscomp$7$$),$APP.$rumext$v2$adapt$$($value_type$jscomp$1$$),$APP.$rumext$v2$adapt$$($active_tab$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_remap_token$$),
$APP.$rumext$v2$adapt$$($on_rename_token$$),$APP.$rumext$v2$adapt$$($is_create$$)],function($form__$1$jscomp$20$$,$event$jscomp$633$$){var $name$jscomp$491$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$20$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4838$clean_data$$,$APP.$cljs$cst$725$name$$],null)),$description$jscomp$21$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$20$$),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4838$clean_data$$,$APP.$cljs$cst$936$description$$],null)),$value$jscomp$979$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form__$1$jscomp$20$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4838$clean_data$$,$APP.$cljs$cst$260$value$$],null)),$value_for_validation$$=$app$main$ui$workspace$tokens$management$forms$generic_form$get_value_for_validator$$($active_tab$jscomp$1$$,
$value$jscomp$979$$,$value_subfield$jscomp$7$$,$value_type$jscomp$1$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$633$$);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$(function($valid_token$jscomp$2$$){function $on_rename$jscomp$3$$(){return $on_rename_token$$.$cljs$core$IFn$_invoke$arity$3$?$on_rename_token$$.$cljs$core$IFn$_invoke$arity$3$($valid_token$jscomp$2$$,$name$jscomp$491$$,$description$jscomp$21$$):$on_rename_token$$($valid_token$jscomp$2$$,$name$jscomp$491$$,
$description$jscomp$21$$)}function $on_remap$$(){return $on_remap_token$$.$cljs$core$IFn$_invoke$arity$4$?$on_remap_token$$.$cljs$core$IFn$_invoke$arity$4$($valid_token$jscomp$2$$,$name$jscomp$491$$,$old_name$jscomp$3$$,$description$jscomp$21$$):$on_remap_token$$($valid_token$jscomp$2$$,$name$jscomp$491$$,$old_name$jscomp$3$$,$description$jscomp$21$$)}var $is_rename_new_token$jscomp$2_state$jscomp$1224$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$file_data$jscomp$122_references_count$$=
$APP.$app$main$data$helpers$lookup_file_data$$.$cljs$core$IFn$_invoke$arity$1$($is_rename_new_token$jscomp$2_state$jscomp$1224$$),$old_name$jscomp$3$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$);$is_rename_new_token$jscomp$2_state$jscomp$1224$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$8$$,"edit")&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$491$$,$old_name$jscomp$3$$);$file_data$jscomp$122_references_count$$=
$app$main$data$workspace$tokens$remapping$count_token_references$$($file_data$jscomp$122_references_count$$,$old_name$jscomp$3$$);var $remap_data$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5867$new_name$$,$name$jscomp$491$$,$cljs$cst$5866$old_name$$,$old_name$jscomp$3$$,$APP.$cljs$cst$139$type$$,"token"],null);if($is_rename_new_token$jscomp$2_state$jscomp$1224$$&&$file_data$jscomp$122_references_count$$>0)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($cljs$cst$5899$tokens_SLASH_remapping_confirmation$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5900$remap_data$$,$remap_data$jscomp$1$$,$cljs$cst$5901$on_remap$$,$on_remap$$,$cljs$cst$5902$on_rename$$,$on_rename$jscomp$3$$],null)));$is_rename_new_token$jscomp$2_state$jscomp$1224$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$library_edit$toggle_nested_token_path$$($token_type$jscomp$22$$,$name$jscomp$491$$));$is_rename_new_token$jscomp$2_state$jscomp$1224$$=$APP.$cljs$core$truth_$$($is_create$$)?
$APP.$app$common$types$tokens_lib$make_token$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$725$name$$,$name$jscomp$491$$,$APP.$cljs$cst$139$type$$,$token_type$jscomp$22$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($valid_token$jscomp$2$$),$APP.$cljs$cst$936$description$$,$description$jscomp$21$$],null)])):null;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$truth_$$($is_create$$)?
$APP.$app$main$data$workspace$tokens$library_edit$create_token$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$is_rename_new_token$jscomp$2_state$jscomp$1224$$):$app$main$data$workspace$tokens$library_edit$update_token$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$name$jscomp$491$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($valid_token$jscomp$2$$),
$APP.$cljs$cst$936$description$$,$description$jscomp$21$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$library_edit$open_token_type$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$4$$)),$APP.$app$main$data$workspace$tokens$propagation$propagate_workspace_tokens$$(),$APP.$cljs$core$truth_$$($is_create$$)?$app$main$ui$workspace$tokens$management$forms$generic_form$scroll_token_type_section_on_create$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($is_rename_new_token$jscomp$2_state$jscomp$1224$$)):
null,$APP.$app$main$data$modal$hide_BANG_$$()]))},function($error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$){$error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$=$APP.$cljs$core$__destructure_map$$($error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$);$error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$,
$APP.$cljs$cst$570$errors$$);$error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$=$app$main$data$workspace$tokens$errors$humanize_errors$$($error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$);$error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$=$APP.$cljs$core$first$$($error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form__$1$jscomp$20$$,$APP.$cljs$core$assoc_in$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4837$extra_errors$$,$APP.$cljs$cst$260$value$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$141$message$$,$error_message_error_messages_errors$jscomp$46_map__80514__$1_p__80513$$],null))},function(){var $G__80515$$=new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$cljs$cst$5924$token_value$$,$value_for_validation$$,$APP.$cljs$cst$4253$token_name$$,$name$jscomp$491$$,
$cljs$cst$5925$token_description$$,$description$jscomp$21$$,$cljs$cst$5926$prev_token$$,$token__$1$jscomp$4$$,$APP.$cljs$cst$2108$tokens$$,$tokens$jscomp$73$$],null);return $validate_token$$.$cljs$core$IFn$_invoke$arity$1$?$validate_token$$.$cljs$core$IFn$_invoke$arity$1$($G__80515$$):$validate_token$$($G__80515$$)}())});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$active_tokens_by_type$$),{value:$active_tokens_by_type$jscomp$1_validator$jscomp$35$$,children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_STAR_$$,
{className:"main_ui_workspace_tokens_management_forms_generic_form__form-wrapper",form:$form$jscomp$206$$,onSubmit:$on_submit$jscomp$18$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__token-rows",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_management_forms_generic_form__form-modal-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$8$$,
"edit")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.edit-token",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_type$jscomp$22$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.create-token",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$token_type$jscomp$22$$]))}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__input-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_input_STAR_$$,
{id:"token-name",name:$APP.$cljs$cst$725$name$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name"),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.enter-token-name",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$props_80511_token_properties_token_title$$])),maxLength:255,variant:"comfortable",trim:!0,autoFocus:!0})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__input-row",
children:function(){switch($value_type$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$value_type$jscomp$1$$.$fqn$:null){case "indexed":return(0,$APP.$rumext$v2$jsx$$)($input_component__$1$$,{token:$token__$1$jscomp$4$$,tokens:$tokens$jscomp$73$$,tab:$active_tab$jscomp$1$$,valueSubfield:$value_subfield$jscomp$7$$,handleToggle:$on_toggle_tab$$});case "composite":return(0,$APP.$rumext$v2$jsx$$)($input_component__$1$$,{token:$token__$1$jscomp$4$$,tokens:$tokens$jscomp$73$$,tab:$active_tab$jscomp$1$$,
handleToggle:$on_toggle_tab$$});default:return(0,$APP.$rumext$v2$jsx$$)($input_component__$1$$,{placeholder:$APP.$cljs$core$truth_$$($input_value_placeholder$$)?$input_value_placeholder$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-value-enter"),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-value"),name:$APP.$cljs$cst$260$value$$,token:$token__$1$jscomp$4$$,tokenType:$token_type$jscomp$22$$,tokens:$tokens$jscomp$73$$})}}()}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__input-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_input_STAR_$$,{id:"token-description",name:$APP.$cljs$cst$936$description$$,label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-description"),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-description"),maxLength:255,variant:"comfortable",isOptional:!0})}),
$general_errors_input_component_schema$jscomp$245$$!=null?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$notifications$context_notification$context_notification_STAR_$$,{level:$APP.$cljs$cst$2354$warning$$,appearance:$APP.$cljs$cst$5103$ghost$$,children:$APP.$cljs$cst$141$message$$.$cljs$core$IFn$_invoke$arity$1$($general_errors_input_component_schema$jscomp$245$$)}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_generic_form__button-row "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$8$$,
"edit")?"main_ui_workspace_tokens_management_forms_generic_form__with-delete":""),children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($action$jscomp$8$$,"edit")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$on_delete_token$jscomp$3$$,onKeyDown:$handle_key_down_delete_initial__$1$jscomp$3$$,className:"main_ui_workspace_tokens_management_forms_generic_form__delete-btn",type:"button",icon:"delete",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")}):
null,$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$on_cancel$jscomp$9$$,onKeyDown:$handle_key_down_cancel_initial_general_errors$$,type:"button",id:"token-modal-cancel",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_submit_STAR_$$,{variant:"primary",onSubmit:$on_submit$jscomp$18$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.save")})]})]})})})};
$app$main$ui$workspace$tokens$management$forms$color$form_STAR_$$=function($props_80520$$){var $token$jscomp$193$$=$props_80520$$.token,$token_type$jscomp$23$$=$props_80520$$.tokenType,$current_token_path$jscomp$2$$=$props_80520$$.currentTokenPath,$initial$jscomp$38$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_type$jscomp$23$$),$APP.$rumext$v2$adapt$$($token$jscomp$193$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$139$type$$,
$token_type$jscomp$23$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$193$$,""),$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$193$$,""),$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$193$$,""),$cljs$cst$5917$color_result$$,""],null)});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,
{...$props_80520$$,makeSchema:function($p1__80519_SHARP__s$jscomp$inline_9197$$){$p1__80519_SHARP__s$jscomp$inline_9197$$=$APP.$app$common$schema$dissoc_key$$($APP.$app$common$files$tokens$make_token_schema$$($p1__80519_SHARP__s$jscomp$inline_9197$$,$token_type$jscomp$23$$,$current_token_path$jscomp$2$$));return $app$common$schema$assoc_key$cljs$0core$0IFn$0_invoke$0arity$04$$($p1__80519_SHARP__s$jscomp$inline_9197$$,$cljs$cst$5917$color_result$$,$APP.$cljs$cst$198$string$$)},initial:$initial$jscomp$38$$,
inputComponent:$app$main$ui$workspace$tokens$management$forms$controls$color_input$color_input_STAR_$$})};$app$main$ui$workspace$tokens$management$forms$font_family$check_font_family_token_self_reference$$=function($token$jscomp$194$$){return $app$main$ui$workspace$tokens$management$forms$validators$check_coll_self_reference$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$194$$),$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$194$$))};
$app$main$ui$workspace$tokens$management$forms$font_family$validate_font_family_token$$=function($props$jscomp$360$$){return $app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($props$jscomp$360$$,$cljs$cst$5924$token_value$$,$APP.$app$common$types$token$split_font_family$$),$APP.$cljs$cst$4836$validators$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($token$jscomp$195$$){return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$195$$))?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4660$error_DOT_token_SLASH_empty_input$$):null},$app$main$ui$workspace$tokens$management$forms$font_family$check_font_family_token_self_reference$$],null)))};
$app$main$ui$workspace$tokens$management$forms$font_family$form_STAR_$$=function($props_80522_token__$1$jscomp$5$$){var $token$jscomp$196$$=void 0,$token_type$jscomp$24$$=void 0,$current_token_path$jscomp$3$$=void 0,$props$jscomp$361$$=void 0;({token:$token$jscomp$196$$,tokenType:$token_type$jscomp$24$$,currentTokenPath:$current_token_path$jscomp$3$$,...$props$jscomp$361$$}=$props_80522_token__$1$jscomp$5$$);$props_80522_token__$1$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$196$$)],
function(){return $APP.$cljs$core$truth_$$($token$jscomp$196$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($token$jscomp$196$$,$APP.$cljs$cst$260$value$$,$app$common$types$token$join_font_family$$):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$24$$],null)});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,{...$props$jscomp$361$$,token:$props_80522_token__$1$jscomp$5$$,tokenType:$token_type$jscomp$24$$,
makeSchema:function($p1__80521_SHARP__s$jscomp$inline_9201$$){$p1__80521_SHARP__s$jscomp$inline_9201$$=$APP.$app$common$schema$dissoc_key$$($APP.$app$common$files$tokens$make_token_schema$$($p1__80521_SHARP__s$jscomp$inline_9201$$,$token_type$jscomp$24$$,$current_token_path$jscomp$3$$));return $app$common$schema$assoc_key$cljs$0core$0IFn$0_invoke$0arity$04$$($p1__80521_SHARP__s$jscomp$inline_9201$$,$APP.$cljs$cst$260$value$$,$APP.$app$common$files$tokens$schema_COLON_token_value_generic$$)},validator:$app$main$ui$workspace$tokens$management$forms$font_family$validate_font_family_token$$,
inputComponent:$app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$fonts_combobox_STAR_$$})};
$app$main$ui$workspace$tokens$management$forms$shadow$check_shadow_token_self_reference$$=function($shadow_values$jscomp$1_token$jscomp$197$$){var $token_name$jscomp$50$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shadow_values$jscomp$1_token$jscomp$197$$);$shadow_values$jscomp$1_token$jscomp$197$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($shadow_values$jscomp$1_token$jscomp$197$$);return $APP.$cljs$core$some$$(function($p__80523_shadow_map$jscomp$2$$){var $shadow_idx$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80523_shadow_map$jscomp$2$$,0,null);$p__80523_shadow_map$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80523_shadow_map$jscomp$2$$,1,null);return $APP.$cljs$core$some$$(function($p__80527_temp__5825__auto__$jscomp$418_v$jscomp$683$$){var $k$jscomp$700$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80527_temp__5825__auto__$jscomp$418_v$jscomp$683$$,0,null);$p__80527_temp__5825__auto__$jscomp$418_v$jscomp$683$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80527_temp__5825__auto__$jscomp$418_v$jscomp$683$$,1,null);$p__80527_temp__5825__auto__$jscomp$418_v$jscomp$683$$=$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$($token_name$jscomp$50$$,$p__80527_temp__5825__auto__$jscomp$418_v$jscomp$683$$);return $APP.$cljs$core$truth_$$($p__80527_temp__5825__auto__$jscomp$418_v$jscomp$683$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p__80527_temp__5825__auto__$jscomp$418_v$jscomp$683$$,
$APP.$cljs$cst$4703$shadow_key$$,$k$jscomp$700$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4704$shadow_index$$,$shadow_idx$$])):null},$p__80523_shadow_map$jscomp$2$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($shadow_values$jscomp$1_token$jscomp$197$$))};
$app$main$ui$workspace$tokens$management$forms$shadow$check_empty_shadow_token$$=function($token$jscomp$198$$){return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1345$$=$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$198$$));return $or__5025__auto__$jscomp$1345$$?$or__5025__auto__$jscomp$1345$$:$APP.$cljs$core$some$$(function($shadow__$1$jscomp$22$$){return $cljs$core$not_every_QMARK_$$(function($p1__80531_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($shadow__$1$jscomp$22$$,
$p1__80531_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1655$offset_x$$,$APP.$cljs$cst$1656$offset_y$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1657$spread$$,$APP.$cljs$cst$1303$color$$],null))},$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$198$$))}())?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4660$error_DOT_token_SLASH_empty_input$$):null};
$app$main$ui$workspace$tokens$management$forms$shadow$validate_shadow_token$$=function($map__80536__$1_p__80535_params__$1$jscomp$58$$){$map__80536__$1_p__80535_params__$1$jscomp$58$$=$APP.$cljs$core$__destructure_map$$($map__80536__$1_p__80535_params__$1$jscomp$58$$);var $token_value$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80536__$1_p__80535_params__$1$jscomp$58$$,$cljs$cst$5924$token_value$$);if($token_value$jscomp$13$$==null)return(0,$APP.$beicon$v2$core$of$$)(null);
if(typeof $token_value$jscomp$13$$==="string")return $app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($map__80536__$1_p__80535_params__$1$jscomp$58$$);$map__80536__$1_p__80535_params__$1$jscomp$58$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($map__80536__$1_p__80535_params__$1$jscomp$58$$,$cljs$cst$5924$token_value$$,function($value$jscomp$980$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($shadow__$1$jscomp$23$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$update_when$$($shadow__$1$jscomp$23$$,
$APP.$cljs$cst$2141$inset$$,function($p1__80532_SHARP_$$){return $APP.$cljs$core$boolean_QMARK_$$($p1__80532_SHARP_$$)?$p1__80532_SHARP_$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("true",$p1__80532_SHARP_$$)?!0:!1}),$APP.$cljs$cst$1658$blur$$,function($p1__80533_SHARP_$$){return $APP.$cuerdas$core$blank_QMARK_$$($p1__80533_SHARP_$$)?"0":$p1__80533_SHARP_$$}),$APP.$cljs$cst$1657$spread$$,function($p1__80534_SHARP_$$){return $APP.$cuerdas$core$blank_QMARK_$$($p1__80534_SHARP_$$)?"0":$p1__80534_SHARP_$$})},
$APP.$cljs$core$truth_$$($value$jscomp$980$$)?$value$jscomp$980$$:$APP.$cljs$core$PersistentVector$EMPTY$$)}),$APP.$cljs$cst$4836$validators$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$ui$workspace$tokens$management$forms$shadow$check_empty_shadow_token$$,$app$main$ui$workspace$tokens$management$forms$shadow$check_shadow_token_self_reference$$],null));return $app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($map__80536__$1_p__80535_params__$1$jscomp$58$$)};
$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$=function($token$jscomp$199_value$jscomp$981$$,$index$jscomp$559$$,$prop$jscomp$40$$,$value_subfield$jscomp$8$$){$token$jscomp$199_value$jscomp$981$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$199_value$jscomp$981$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$8$$,$index$jscomp$559$$,$prop$jscomp$40$$],null));
return $APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$40$$,$APP.$cljs$cst$1303$color$$)?$APP.$cljs$cst$1303$color$$:$APP.$cljs$cst$1996$dimensions$$,$APP.$cljs$cst$260$value$$,$token$jscomp$199_value$jscomp$981$$],null))};
$app$main$ui$workspace$tokens$management$forms$shadow$shadow_formset_STAR_$$=function($props_80537_tokens$jscomp$74$$){var $index$jscomp$560$$=$props_80537_tokens$jscomp$74$$.index,$show_button$$=$props_80537_tokens$jscomp$74$$.showButton,$spread_token_spread_token__$1_token$jscomp$200$$=$props_80537_tokens$jscomp$74$$.token,$remove_shadow_block$$=$props_80537_tokens$jscomp$74$$.removeShadowBlock,$value_subfield$jscomp$9$$=$props_80537_tokens$jscomp$74$$.valueSubfield;$props_80537_tokens$jscomp$74$$=
$props_80537_tokens$jscomp$74$$.tokens;var $inset_token_inset_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$200$$,$index$jscomp$560$$,$APP.$cljs$cst$2141$inset$$,$value_subfield$jscomp$9$$);$inset_token_inset_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($inset_token_inset_token__$1$$);var $color_token_color_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$200$$,
$index$jscomp$560$$,$APP.$cljs$cst$1303$color$$,$value_subfield$jscomp$9$$);$color_token_color_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($color_token_color_token__$1$$);var $offset_x_token_offset_x_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$200$$,$index$jscomp$560$$,$APP.$cljs$cst$1655$offset_x$$,$value_subfield$jscomp$9$$);$offset_x_token_offset_x_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($offset_x_token_offset_x_token__$1$$);
var $offset_y_token_offset_y_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$200$$,$index$jscomp$560$$,$APP.$cljs$cst$1656$offset_y$$,$value_subfield$jscomp$9$$);$offset_y_token_offset_y_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($offset_y_token_offset_y_token__$1$$);var $blur_token_blur_token__$1$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$200$$,
$index$jscomp$560$$,$APP.$cljs$cst$1658$blur$$,$value_subfield$jscomp$9$$);$blur_token_blur_token__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($blur_token_blur_token__$1$$);$spread_token_spread_token__$1_token$jscomp$200$$=$app$main$ui$workspace$tokens$management$forms$shadow$get_subtoken$$($spread_token_spread_token__$1_token$jscomp$200$$,$index$jscomp$560$$,$APP.$cljs$cst$1657$spread$$,$value_subfield$jscomp$9$$);$spread_token_spread_token__$1_token$jscomp$200$$=$APP.$app$main$ui$hooks$use_equal_memo$$($spread_token_spread_token__$1_token$jscomp$200$$);
var $on_button_click$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$560$$)],function($event$jscomp$634$$){return $remove_shadow_block$$.$cljs$core$IFn$_invoke$arity$2$?$remove_shadow_block$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$560$$,$event$jscomp$634$$):$remove_shadow_block$$($index$jscomp$560$$,$event$jscomp$634$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":["shadow-input-fields-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$560$$)].join(""),
className:"main_ui_workspace_tokens_management_forms_shadow__shadow-block",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__select-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$select$select_indexed_STAR_$$,{options:new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"drop",
$APP.$cljs$cst$2296$label$$,"drop shadow",$APP.$cljs$cst$1727$icon$$,"drop-shadow"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$266$id$$,"inner",$APP.$cljs$cst$2296$label$$,"inner shadow",$APP.$cljs$cst$1727$icon$$,"inner-shadow"],null)],null),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-inset"),token:$inset_token_inset_token__$1$$,tokens:$props_80537_tokens$jscomp$74$$,index:$index$jscomp$560$$,indexedType:$value_subfield$jscomp$9$$,
name:$APP.$cljs$cst$2141$inset$$}),$APP.$cljs$core$truth_$$($show_button$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",type:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-remove-shadow"),onClick:$on_button_click$jscomp$1$$,icon:"remove"}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__inputs-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$color_input$indexed_color_input_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-value-enter"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.color"),name:$APP.$cljs$cst$1303$color$$,token:$color_token_color_token__$1$$,valueSubfield:$value_subfield$jscomp$9$$,
index:$index$jscomp$560$$,tokens:$props_80537_tokens$jscomp$74$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-x"),icon:"character-x",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-x"),
name:$APP.$cljs$cst$1655$offset_x$$,token:$offset_x_token_offset_x_token__$1$$,index:$index$jscomp$560$$,valueSubfield:$value_subfield$jscomp$9$$,tokens:$props_80537_tokens$jscomp$74$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-y"),
icon:"character-y",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-y"),name:$APP.$cljs$cst$1656$offset_y$$,token:$offset_y_token_offset_y_token__$1$$,index:$index$jscomp$560$$,valueSubfield:$value_subfield$jscomp$9$$,tokens:$props_80537_tokens$jscomp$74$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,
{token:$blur_token_blur_token__$1$$,index:$index$jscomp$560$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-blur"),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-blur"),name:$APP.$cljs$cst$1658$blur$$,slotStart:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_forms_shadow__visible-label",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-blur")),
":"].join("")}),nillable:!0,valueSubfield:$value_subfield$jscomp$9$$,tokens:$props_80537_tokens$jscomp$74$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_indexed_STAR_$$,{token:$spread_token_spread_token__$1_token$jscomp$200$$,index:$index$jscomp$560$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-spread"),
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-spread"),name:$APP.$cljs$cst$1657$spread$$,slotStart:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_forms_shadow__visible-label",children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-spread")),":"].join("")}),nillable:!0,valueSubfield:$value_subfield$jscomp$9$$,tokens:$props_80537_tokens$jscomp$74$$})})]})]})};
$app$main$ui$workspace$tokens$management$forms$shadow$composite_form_STAR_$$=function($props_80538$$){var $token$jscomp$201$$=$props_80538$$.token,$remove_shadow_block$jscomp$1$$=$props_80538$$.removeShadowBlock,$value_subfield$jscomp$10$$=$props_80538$$.valueSubfield,$tokens$jscomp$75$$=$props_80538$$.tokens,$form$jscomp$207$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$),$length$jscomp$61$$=$APP.$cljs$core$count$$(function(){var $G__80539$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$207$$)));
return $value_subfield$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$value_subfield$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($G__80539$$):$value_subfield$jscomp$10$$($G__80539$$)}());return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$206$$,$index$jscomp$561$$){$out_arr__44092__auto__$jscomp$206$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$shadow$shadow_formset_STAR_$$,{index:$index$jscomp$561$$,token:$token$jscomp$201$$,
tokens:$tokens$jscomp$75$$,valueSubfield:$value_subfield$jscomp$10$$,removeShadowBlock:$remove_shadow_block$jscomp$1$$,showButton:$length$jscomp$61$$>1},$index$jscomp$561$$));return $out_arr__44092__auto__$jscomp$206$$},[],$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$01$$($length$jscomp$61$$))};
$app$main$ui$workspace$tokens$management$forms$shadow$reference_form_STAR_$$=function($props_80540_tokens$jscomp$76$$){var $token$jscomp$202$$=$props_80540_tokens$jscomp$76$$.token;$props_80540_tokens$jscomp$76$$=$props_80540_tokens$jscomp$76$$.tokens;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__input-row-reference",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.reference-composite-shadow"),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.reference"),icon:"drop-shadow",name:$APP.$cljs$cst$4651$reference$$,token:$token$jscomp$202$$,tokens:$props_80540_tokens$jscomp$76$$})})};
$app$main$ui$workspace$tokens$management$forms$shadow$tabs_wrapper_STAR_$$=function($on_add_shadow_block_props_80542$$){var $tab$jscomp$9$$=void 0,$handle_toggle$jscomp$1$$=void 0,$token$jscomp$203$$=void 0,$value_subfield$jscomp$11$$=void 0,$tokens$jscomp$77$$=void 0;({token:$token$jscomp$203$$,tokens:$tokens$jscomp$77$$,tab:$tab$jscomp$9$$,handleToggle:$handle_toggle$jscomp$1$$,valueSubfield:$value_subfield$jscomp$11$$}=$on_add_shadow_block_props_80542$$);var $form$jscomp$208$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$forms$context$$);
$on_add_shadow_block_props_80542$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value_subfield$jscomp$11$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($form$jscomp$208$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,$value_subfield$jscomp$11$$],null),$APP.$cljs$core$conj$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$workspace$tokens$management$forms$shadow$default_token_shadow$$]))});
var $remove_shadow_block$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value_subfield$jscomp$11$$)],function($index$jscomp$562$$,$event$jscomp$635$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$635$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($form$jscomp$208$$,$APP.$cljs$core$update_in$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$260$value$$,
$value_subfield$jscomp$11$$],null),function($p1__80541_SHARP_$$){return $APP.$app$common$data$remove_at_index$$($p1__80541_SHARP_$$,$index$jscomp$562$$)})});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__title-bar",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_shadow__title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.shadow")}),
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",type:"button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-add-shadow"),onClick:$on_add_shadow_block_props_80542$$,icon:"add"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_tokens_management_forms_shadow__listing-options",selected:$APP.$app$common$data$name$$($tab$jscomp$9$$),"on-change":$handle_toggle$jscomp$1$$,
name:"reference-composite-tab",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"layers",value:"composite",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.individual-tokens"),id:"composite-opt"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"tokens",value:"reference",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.use-reference"),id:"reference-opt"})]})]}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tab$jscomp$9$$,$cljs$cst$5927$composite$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$shadow$composite_form_STAR_$$,{token:$token$jscomp$203$$,tokens:$tokens$jscomp$77$$,removeShadowBlock:$remove_shadow_block$jscomp$2$$,valueSubfield:$value_subfield$jscomp$11$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$shadow$reference_form_STAR_$$,{token:$token$jscomp$203$$,tokens:$tokens$jscomp$77$$})]})};
$app$main$ui$workspace$tokens$management$forms$shadow$make_schema$$=function($current_token_path$jscomp$4$$,$tokens_tree$jscomp$12$$,$active_tab$jscomp$2$$){return $APP.$app$common$schema$schema$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$338$min$$,1,$APP.$cljs$cst$339$max$$,255,$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80549_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80549_SHARP_$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name-length-validation-error"))].join("")}],null)],null),$APP.$app$common$schema$update_properties$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$common$types$token$schema_COLON_token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80550_SHARP_$$){return[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80550_SHARP_$$)),
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name-validation-error"))].join("")}])),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,function($p1__80552_SHARP_$$){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.token-name-duplication-validation-error",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__80552_SHARP_$$)]))}],null),function($p1__80553_SHARP_$$){return!$APP.$app$common$types$tokens_lib$token_name_path_exists_QMARK_$$($p1__80553_SHARP_$$,$APP.$app$common$data$dissoc_in$$($tokens_tree$jscomp$12$$,$current_token_path$jscomp$4$$))}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1659$shadow$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$200$vector$$,new $APP.$cljs$core$PersistentVector$$(null,8,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1655$offset_x$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,
$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1656$offset_y$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$blur$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$884$error_SLASH_fn$$,
function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.shadow-token-blur-value-error")}],null),function($blur$jscomp$13_n$jscomp$306$$){$blur$jscomp$13_n$jscomp$306$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($blur$jscomp$13_n$jscomp$306$$);return $blur$jscomp$13_n$jscomp$306$$==null||!($blur$jscomp$13_n$jscomp$306$$<0)}],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1657$spread$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1303$color$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5917$color_result$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),$APP.$cljs$cst$974$app_DOT_common_DOT_schema_SLASH_any$$],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2141$inset$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$421$boolean$$],null)],null)],null)],null)],null),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_tab$jscomp$2$$,$APP.$cljs$cst$4651$reference$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4651$reference$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!1],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4651$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],
null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2048,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.field-max-length",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([2048]))}],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3441$error_SLASH_field$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$4651$reference$$],null),$APP.$cljs$cst$884$error_SLASH_fn$$,
function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.self-reference")}],null),function($name$jscomp$492_p__80555$$){var $map__80556__$1_reference$jscomp$1_value$jscomp$982$$=$APP.$cljs$core$__destructure_map$$($name$jscomp$492_p__80555$$);$name$jscomp$492_p__80555$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80556__$1_reference$jscomp$1_value$jscomp$982$$,$APP.$cljs$cst$725$name$$);$map__80556__$1_reference$jscomp$1_value$jscomp$982$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80556__$1_reference$jscomp$1_value$jscomp$982$$,
$APP.$cljs$cst$260$value$$);$map__80556__$1_reference$jscomp$1_value$jscomp$982$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80556__$1_reference$jscomp$1_value$jscomp$982$$,$APP.$cljs$cst$4651$reference$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__80556__$1_reference$jscomp$1_value$jscomp$982$$)?$name$jscomp$492_p__80555$$:$map__80556__$1_reference$jscomp$1_value$jscomp$982$$)?!$APP.$app$common$types$token$token_value_self_reference_QMARK_$$($name$jscomp$492_p__80555$$,
$map__80556__$1_reference$jscomp$1_value$jscomp$982$$):!0}],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return"Must be a valid shadow or reference"},$APP.$cljs$cst$3441$error_SLASH_field$$,$APP.$cljs$cst$260$value$$],null),function($map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$){$map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$=
$APP.$cljs$core$__destructure_map$$($map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$);var $shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$983$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$,$APP.$cljs$cst$260$value$$);$map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$983$$,$APP.$cljs$cst$4651$reference$$);
$map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$=$APP.$cljs$core$truth_$$($map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$)?!$APP.$cuerdas$core$blank_QMARK_$$($map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$):$map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$;$shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$983$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$983$$,
$APP.$cljs$cst$1659$shadow$$);$shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$983$$=$APP.$cljs$core$seq$$($shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$983$$)&&$APP.$cljs$core$every_QMARK_$$(function($offset_x$jscomp$14_p__80560$$){var $color$jscomp$189_map__80561__$1$$=$APP.$cljs$core$__destructure_map$$($offset_x$jscomp$14_p__80560$$);$offset_x$jscomp$14_p__80560$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$189_map__80561__$1$$,$APP.$cljs$cst$1655$offset_x$$);
var $offset_y$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$189_map__80561__$1$$,$APP.$cljs$cst$1656$offset_y$$);$color$jscomp$189_map__80561__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$189_map__80561__$1$$,$APP.$cljs$cst$1303$color$$);return!$APP.$cuerdas$core$blank_QMARK_$$($offset_x$jscomp$14_p__80560$$)&&!$APP.$cuerdas$core$blank_QMARK_$$($offset_y$jscomp$14$$)&&!$APP.$cuerdas$core$blank_QMARK_$$($color$jscomp$189_map__80561__$1$$)},
$shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$983$$);return $APP.$cljs$core$truth_$$($map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$)?$map__80559__$1_p__80558_ref_valid_QMARK__reference$jscomp$2$$:$shadows$jscomp$5_valid_composite_shadow_QMARK__value$jscomp$983$$}],null)],null))};
$app$main$ui$workspace$tokens$management$forms$shadow$make_default_value$$=function($value$jscomp$984$$){return typeof $value$jscomp$984$$==="string"?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4651$reference$$,$value$jscomp$984$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null):$APP.$cljs$core$vector_QMARK_$$($value$jscomp$984$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4651$reference$$,null,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($shadow__$1$jscomp$24$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shadow__$1$jscomp$24$$,
$APP.$cljs$cst$1658$blur$$,function($p1__80562_SHARP_$$){return $APP.$cuerdas$core$blank_QMARK_$$($p1__80562_SHARP_$$)?"0":$p1__80562_SHARP_$$}),$APP.$cljs$cst$1657$spread$$,function($p1__80563_SHARP_$$){return $APP.$cuerdas$core$blank_QMARK_$$($p1__80563_SHARP_$$)?"0":$p1__80563_SHARP_$$})},$value$jscomp$984$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4651$reference$$,null,$APP.$cljs$cst$1659$shadow$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$app$main$ui$workspace$tokens$management$forms$shadow$default_token_shadow$$],null)],null)};
$app$main$ui$workspace$tokens$management$forms$shadow$form_STAR_$$=function($props_80564$$){var $token$jscomp$204$$=$props_80564$$.token,$token_type$jscomp$25$$=$props_80564$$.tokenType,$current_token_path$jscomp$5$$=$props_80564$$.currentTokenPath,$token__$1$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$204$$)],function(){if($APP.$cljs$core$truth_$$($token$jscomp$204$$))return $token$jscomp$204$$;var $temp__5823__auto__$jscomp$243$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$204$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$243$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$25$$,$APP.$cljs$cst$260$value$$,$app$main$ui$workspace$tokens$management$forms$shadow$make_default_value$$($temp__5823__auto__$jscomp$243$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$token_type$jscomp$25$$,
$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$4651$reference$$,null,$APP.$cljs$cst$1659$shadow$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$ui$workspace$tokens$management$forms$shadow$default_token_shadow$$],null)],null)],null)}),$initial$jscomp$39$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token__$1$jscomp$6$$)],function(){var $raw_value$jscomp$4_value$jscomp$986$$=
$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token__$1$jscomp$6$$);$raw_value$jscomp$4_value$jscomp$986$$=$app$main$ui$workspace$tokens$management$forms$shadow$make_default_value$$($raw_value$jscomp$4_value$jscomp$986$$);return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$6$$,""),$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$2$($token__$1$jscomp$6$$,
""),$APP.$cljs$cst$260$value$$,$raw_value$jscomp$4_value$jscomp$986$$],null)});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,{...$props_80564$$,token:$token__$1$jscomp$6$$,tokenType:$token_type$jscomp$25$$,initial:$initial$jscomp$39$$,makeSchema:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$tokens$management$forms$shadow$make_schema$$,$current_token_path$jscomp$5$$),valueType:$cljs$cst$5928$indexed$$,
valueSubfield:$APP.$cljs$cst$1659$shadow$$,inputComponent:$app$main$ui$workspace$tokens$management$forms$shadow$tabs_wrapper_STAR_$$,validator:$app$main$ui$workspace$tokens$management$forms$shadow$validate_shadow_token$$})};
$app$main$ui$workspace$tokens$management$forms$typography$check_typography_token_self_reference$$=function($token$jscomp$205_token_values$$){var $token_name$jscomp$51$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$205_token_values$$);$token$jscomp$205_token_values$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$205_token_values$$);return $APP.$cljs$core$some$$(function($p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$){var $k$jscomp$701$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$,0,null);$p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$,1,null);a:switch($k$jscomp$701$$ instanceof $APP.$cljs$core$Keyword$$?$k$jscomp$701$$.$fqn$:null){case "font-family":$p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$=$app$main$ui$workspace$tokens$management$forms$validators$check_coll_self_reference$$($token_name$jscomp$51$$,
$p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$);break a;default:$p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$=$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$($token_name$jscomp$51$$,$p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$)}return $APP.$cljs$core$truth_$$($p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p__80543_temp__5825__auto__$jscomp$419_v$jscomp$684$$,$APP.$cljs$cst$4702$typography_key$$,
$k$jscomp$701$$):null},$token$jscomp$205_token_values$$)};$app$main$ui$workspace$tokens$management$forms$typography$check_empty_typography_token$$=function($token$jscomp$206$$){return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$206$$))?$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4660$error_DOT_token_SLASH_empty_input$$):null};
$app$main$ui$workspace$tokens$management$forms$typography$validate_typography_token$$=function($map__80554__$1_p__80551$$){$map__80554__$1_p__80551$$=$APP.$cljs$core$__destructure_map$$($map__80554__$1_p__80551$$);var $token_value$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80554__$1_p__80551$$,$cljs$cst$5924$token_value$$);return $token_value$jscomp$14$$==null?(0,$APP.$beicon$v2$core$of$$)(null):typeof $token_value$jscomp$14$$==="string"?$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($map__80554__$1_p__80551$$):
$app$main$ui$workspace$tokens$management$forms$validators$default_validate_token$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($map__80554__$1_p__80551$$,$cljs$cst$5924$token_value$$,function($v$jscomp$685$$){return $APP.$app$common$data$update_when$$($APP.$cljs$core$truth_$$($v$jscomp$685$$)?$v$jscomp$685$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$cst$1764$font_family$$,function($p1__80548_SHARP_$$){return typeof $p1__80548_SHARP_$$===
"string"?$APP.$app$common$types$token$split_font_family$$($p1__80548_SHARP_$$):$p1__80548_SHARP_$$})}),$APP.$cljs$cst$4836$validators$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$app$main$ui$workspace$tokens$management$forms$typography$check_empty_typography_token$$,$app$main$ui$workspace$tokens$management$forms$typography$check_typography_token_self_reference$$],null)))};
$app$main$ui$workspace$tokens$management$forms$typography$composite_form_STAR_$$=function($props_80557_tokens$jscomp$78$$){var $token$jscomp$207$$=$props_80557_tokens$jscomp$78$$.token;$props_80557_tokens$jscomp$78$$=$props_80557_tokens$jscomp$78$$.tokens;var $letter_spacing_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$207$$)],function(){var $temp__5823__auto__$jscomp$244$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$207$$,
$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$244$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1772$letter_spacing$$,$APP.$cljs$cst$260$value$$,$app$common$types$token$join_font_family$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$244$$,$APP.$cljs$cst$1772$letter_spacing$$))],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1772$letter_spacing$$],
null)}),$font_family_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$207$$)],function(){var $temp__5823__auto__$jscomp$245$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$207$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$245$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$245$$,
$APP.$cljs$cst$1764$font_family$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1764$font_family$$],null)}),$font_size_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$207$$)],function(){var $temp__5823__auto__$jscomp$246$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$207$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$246$$)?
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1766$font_size$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$246$$,$APP.$cljs$cst$1766$font_size$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1766$font_size$$],null)}),$font_weight_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$207$$)],
function(){var $temp__5823__auto__$jscomp$247$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$207$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$247$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1767$font_weight$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$247$$,$APP.$cljs$cst$1767$font_weight$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1767$font_weight$$],null)}),$line_height_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$207$$)],function(){var $temp__5823__auto__$jscomp$248$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$207$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$248$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1996$dimensions$$,
$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$248$$,$APP.$cljs$cst$1771$line_height$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1996$dimensions$$],null)}),$text_case_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$207$$)],function(){var $temp__5823__auto__$jscomp$249$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$207$$,
$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$249$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1995$text_case$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$249$$,$APP.$cljs$cst$1995$text_case$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1995$text_case$$],null)}),$text_decoration_sub_token$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$207$$)],
function(){var $temp__5823__auto__$jscomp$250$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$207$$,$APP.$cljs$cst$260$value$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$250$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1774$text_decoration$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$250$$,$APP.$cljs$cst$1774$text_decoration$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1774$text_decoration$$],null)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$fonts_combobox$composite_fonts_combobox_STAR_$$,{icon:"text-font-family",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-font-family-value-enter"),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-font-family-value"),name:$APP.$cljs$cst$1764$font_family$$,token:$font_family_sub_token$$,tokens:$props_80557_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Font Size",icon:"text-font-size",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.font-size-value-enter"),name:$APP.$cljs$cst$1766$font_size$$,token:$font_size_sub_token$$,tokens:$props_80557_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Font Weight",icon:"text-font-weight",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.font-weight-value-enter"),name:$APP.$cljs$cst$1767$font_weight$$,token:$font_weight_sub_token$$,tokens:$props_80557_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Line Height",icon:"text-lineheight",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.line-height-value-enter"),name:$APP.$cljs$cst$1771$line_height$$,token:$line_height_sub_token$$,tokens:$props_80557_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Letter Spacing",icon:"text-letterspacing",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.letter-spacing-value-enter-composite"),name:$APP.$cljs$cst$1772$letter_spacing$$,token:$letter_spacing_sub_token$$,tokens:$props_80557_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Text Case",
icon:"text-mixed",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.text-case-value-enter"),name:$APP.$cljs$cst$1995$text_case$$,token:$text_case_sub_token$$,tokens:$props_80557_tokens$jscomp$78$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{"aria-label":"Text Decoration",icon:"text-underlined",
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.text-decoration-value-enter"),name:$APP.$cljs$cst$1774$text_decoration$$,token:$text_decoration_sub_token$$,tokens:$props_80557_tokens$jscomp$78$$})})]})};
$app$main$ui$workspace$tokens$management$forms$typography$reference_form_STAR_$$=function($props_80565_tokens$jscomp$79$$){var $token$jscomp$208$$=$props_80565_tokens$jscomp$79$$.token;$props_80565_tokens$jscomp$79$$=$props_80565_tokens$jscomp$79$$.tokens;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__input-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$controls$input$input_composite_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.reference-composite"),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.reference"),icon:"text-typography",name:$APP.$cljs$cst$4651$reference$$,token:$token$jscomp$208$$,tokens:$props_80565_tokens$jscomp$79$$})})};
$app$main$ui$workspace$tokens$management$forms$typography$tabs_wrapper_STAR_$$=function($props_80566$$){var $tab$jscomp$10$$=void 0,$handle_toggle$jscomp$2$$=void 0,$token$jscomp$209$$=void 0,$tokens$jscomp$80$$=void 0;({token:$token$jscomp$209$$,tokens:$tokens$jscomp$80$$,tab:$tab$jscomp$10$$,handleToggle:$handle_toggle$jscomp$2$$}=$props_80566$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__title-bar",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.typography")}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{"class":"main_ui_workspace_tokens_management_forms_typography__listing-options",selected:$APP.$app$common$data$name$$($tab$jscomp$10$$),"on-change":$handle_toggle$jscomp$2$$,name:"reference-composite-tab",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{icon:"layers",value:"composite",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.individual-tokens"),id:"composite-opt"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"tokens",value:"reference",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.use-reference"),id:"reference-opt"})]})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_management_forms_typography__inputs-wrapper",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($tab$jscomp$10$$,$cljs$cst$5927$composite$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$typography$composite_form_STAR_$$,{token:$token$jscomp$209$$,tokens:$tokens$jscomp$80$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$typography$reference_form_STAR_$$,{token:$token$jscomp$209$$,tokens:$tokens$jscomp$80$$})})]})};
$app$main$ui$workspace$tokens$management$forms$typography$make_schema$$=function($current_token_path$jscomp$6$$,$tokens_tree$jscomp$13$$,$active_tab$jscomp$3$$){return $APP.$app$common$schema$schema$$(new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$429$and$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$725$name$$,$APP.$app$common$files$tokens$make_token_name_schema$$($APP.$app$common$data$dissoc_in$$($tokens_tree$jscomp$13$$,$current_token_path$jscomp$6$$))],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1764$font_family$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1766$font_size$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1767$font_weight$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,
$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1771$line_height$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1772$letter_spacing$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1995$text_case$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],
null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1774$text_decoration$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,
$APP.$cljs$cst$198$string$$],null)],null),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($active_tab$jscomp$3$$,$APP.$cljs$cst$4651$reference$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4651$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!1],null),$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4651$reference$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$522$maybe$$,$APP.$cljs$cst$198$string$$],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$936$description$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$450$optional$$,
!0],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$198$string$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$339$max$$,2048,$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("errors.field-max-length",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([2048]))}],null)],null)],null)],null),new $APP.$cljs$core$PersistentVector$$(null,3,
5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3441$error_SLASH_field$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$4651$reference$$],null),$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.self-reference")}],null),function($name$jscomp$493_p__80567$$){var $map__80568__$1_reference$jscomp$3_value$jscomp$994$$=
$APP.$cljs$core$__destructure_map$$($name$jscomp$493_p__80567$$);$name$jscomp$493_p__80567$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80568__$1_reference$jscomp$3_value$jscomp$994$$,$APP.$cljs$cst$725$name$$);$map__80568__$1_reference$jscomp$3_value$jscomp$994$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80568__$1_reference$jscomp$3_value$jscomp$994$$,$APP.$cljs$cst$260$value$$);$map__80568__$1_reference$jscomp$3_value$jscomp$994$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80568__$1_reference$jscomp$3_value$jscomp$994$$,
$APP.$cljs$cst$4651$reference$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__80568__$1_reference$jscomp$3_value$jscomp$994$$)?$name$jscomp$493_p__80567$$:$map__80568__$1_reference$jscomp$3_value$jscomp$994$$)?!$APP.$app$common$types$token$token_value_self_reference_QMARK_$$($name$jscomp$493_p__80567$$,$map__80568__$1_reference$jscomp$3_value$jscomp$994$$):!0}],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$3441$error_SLASH_field$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1771$line_height$$],null),$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.tokens.composite-line-height-needs-font-size")}],null),function($line_heigh_map__80570__$1_p__80569$$){$line_heigh_map__80570__$1_p__80569$$=
$APP.$cljs$core$__destructure_map$$($line_heigh_map__80570__$1_p__80569$$);var $font_size$jscomp$15_value$jscomp$995$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_heigh_map__80570__$1_p__80569$$,$APP.$cljs$cst$260$value$$);$line_heigh_map__80570__$1_p__80569$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_size$jscomp$15_value$jscomp$995$$,$APP.$cljs$cst$1771$line_height$$);$font_size$jscomp$15_value$jscomp$995$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($font_size$jscomp$15_value$jscomp$995$$,
$APP.$cljs$cst$1766$font_size$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($line_heigh_map__80570__$1_p__80569$$)?$APP.$cljs$core$not$$($font_size$jscomp$15_value$jscomp$995$$):$line_heigh_map__80570__$1_p__80569$$)?!1:!0}],null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$516$fn$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$884$error_SLASH_fn$$,function(){return"At least one composite field must be set"},
$APP.$cljs$cst$3441$error_SLASH_field$$,$APP.$cljs$cst$260$value$$],null),function($attrs$jscomp$184$$){return $APP.$cljs$core$reduce_kv$$(function($_$jscomp$3103$$,$___$1$jscomp$2105$$,$v$jscomp$686$$){return $APP.$cuerdas$core$empty_QMARK_$$($v$jscomp$686$$)?!1:$APP.$cljs$core$reduced$$(!0)},!1,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($attrs$jscomp$184$$,$APP.$cljs$cst$260$value$$))}],null)],null))};
$app$main$ui$workspace$tokens$management$forms$typography$form_STAR_$$=function($props_80571$$){var $token$jscomp$210$$=$props_80571$$.token,$current_token_path$jscomp$7$$=$props_80571$$.currentTokenPath,$initial$jscomp$40$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$210$$)],function(){var $JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$210$$);
typeof $JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$==="string"?$JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4651$reference$$,$JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$],null):$APP.$cljs$core$map_QMARK_$$($JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$)?
($JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$,
$APP.$cljs$cst$1764$font_family$$,$app$common$types$token$join_font_family$$):$JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$,$JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$=$APP.$cljs$core$select_keys$$($JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$,new $APP.$cljs$core$PersistentVector$$(null,
7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$1766$font_size$$,$APP.$cljs$cst$1767$font_weight$$,$APP.$cljs$cst$1771$line_height$$,$APP.$cljs$cst$1772$letter_spacing$$,$APP.$cljs$cst$1995$text_case$$,$APP.$cljs$cst$1774$text_decoration$$],null))):$JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$210$$,""),$APP.$cljs$cst$260$value$$,$JSCompiler_temp$jscomp$11311_JSCompiler_temp$jscomp$11312_processed_value_value$jscomp$996_value__$1$jscomp$inline_13976$$,$APP.$cljs$cst$936$description$$,$APP.$cljs$cst$936$description$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$210$$,"")],null)});return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,
{...$props_80571$$,initial:$initial$jscomp$40$$,makeSchema:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$tokens$management$forms$typography$make_schema$$,$current_token_path$jscomp$7$$),token:$token$jscomp$210$$,validator:$app$main$ui$workspace$tokens$management$forms$typography$validate_typography_token$$,valueType:$cljs$cst$5927$composite$$,inputComponent:$app$main$ui$workspace$tokens$management$forms$typography$tabs_wrapper_STAR_$$})};
$app$main$ui$workspace$tokens$management$forms$form_container$form_container_STAR_$$=function($props_80574_token_type__$1$$){var $token$jscomp$211$$=void 0,$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$=void 0,$token_type$jscomp$26$$=void 0,$props$jscomp$372_text_case_props$$=void 0;({token:$token$jscomp$211$$,tokenType:$token_type$jscomp$26$$,initialErrors:$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$,...$props$jscomp$372_text_case_props$$}=$props_80574_token_type__$1$$);
$props_80574_token_type__$1$$=function(){var $or__5025__auto__$jscomp$1350$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$211$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1350$$)?$or__5025__auto__$jscomp$1350$$:$token_type$jscomp$26$$}();var $selected_token_set_id$jscomp$10_text_decoration_props$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_token_set_id$$),$tokens_in_selected_set$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_all_tokens_in_selected_set$$),
$font_weight_props_token_path$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token$jscomp$211$$)],function(){return $APP.$app$common$types$tokens_lib$get_token_path$$($token$jscomp$211$$)}),$tokens_tree_in_selected_set$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_in_selected_set$jscomp$1$$)],function(){return $APP.$app$common$types$tokens_lib$tokens_tree$$($tokens_in_selected_set$jscomp$1$$)});
$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$={...$props$jscomp$372_text_case_props$$,tokenType:$props_80574_token_type__$1$$,initialErrors:$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$,tokensTreeInSelectedSet:$tokens_tree_in_selected_set$jscomp$1$$,selectedTokenSetId:$selected_token_set_id$jscomp$10_text_decoration_props$$,currentTokenPath:$font_weight_props_token_path$jscomp$2$$,token:$token$jscomp$211$$};$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1240$token_combobox$$)?{...$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$,inputComponent:$app$main$ui$workspace$tokens$management$forms$controls$combobox$value_combobox_STAR_$$}:$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$;$props$jscomp$372_text_case_props$$={...$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$,inputValuePlaceholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.text-case-value-enter")};
$selected_token_set_id$jscomp$10_text_decoration_props$$={...$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$,inputValuePlaceholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.text-decoration-value-enter")};$font_weight_props_token_path$jscomp$2$$={...$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$,inputValuePlaceholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.font-weight-value-enter")};switch($props_80574_token_type__$1$$ instanceof
$APP.$cljs$core$Keyword$$?$props_80574_token_type__$1$$.$fqn$:null){case "color":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$color$form_STAR_$$,$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$);case "typography":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$typography$form_STAR_$$,$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$);case "shadow":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$shadow$form_STAR_$$,
$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$);case "font-family":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$font_family$form_STAR_$$,$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$);case "text-case":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,$props$jscomp$372_text_case_props$$);case "text-decoration":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,
$selected_token_set_id$jscomp$10_text_decoration_props$$);case "font-weight":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,$font_weight_props_token_path$jscomp$2$$);default:return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$generic_form$form_STAR_$$,$initial_errors$jscomp$3_props__$1$jscomp$101_props__$2$jscomp$14$$)}};
$app$main$ui$workspace$tokens$management$forms$modals$calculate_position$$=function($map__80581__$1_max_y$jscomp$3_p__80580$$,$position$jscomp$206$$,$x$jscomp$1261$$,$y$jscomp$482$$,$token_type$jscomp$27$$){$map__80581__$1_max_y$jscomp$3_p__80580$$=$APP.$cljs$core$__destructure_map$$($map__80581__$1_max_y$jscomp$3_p__80580$$);var $vh$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80581__$1_max_y$jscomp$3_p__80580$$,$APP.$cljs$cst$1527$height$$),$modal_height$jscomp$1$$=function(){switch($token_type$jscomp$27$$ instanceof
$APP.$cljs$core$Keyword$$?$token_type$jscomp$27$$.$fqn$:null){case "color":return 500;case "typography":return 660;case "shadow":return 660;default:return 400}}();$map__80581__$1_max_y$jscomp$3_p__80580$$=$vh$jscomp$5$$-$modal_height$jscomp$1$$;var $overflow_fix$$=function(){var $y__5111__auto__$jscomp$144$$=$y$jscomp$482$$+-50+$modal_height$jscomp$1$$+-$vh$jscomp$5$$;return 0>$y__5111__auto__$jscomp$144$$?0:$y__5111__auto__$jscomp$144$$}(),$max_height_top$jscomp$1$$=["calc(100vh - ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(""+
($y$jscomp$482$$-70)+"px")].join(""),$left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$rulers_QMARK_$$);$left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$=$APP.$cljs$core$truth_$$($left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$)?80:58;var $left_position$$=""+($x$jscomp$1261$$-325)+"px";return $x$jscomp$1261$$==null||$y$jscomp$482$$==null?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,"auto",$APP.$cljs$cst$258$right$$,"16rem",$APP.$cljs$cst$1567$top$$,
"4rem"],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$206$$,$APP.$cljs$cst$257$left$$)?$y$jscomp$482$$>$map__80581__$1_max_y$jscomp$3_p__80580$$?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,$left_position$$,$APP.$cljs$cst$1568$bottom$$,"1rem",$APP.$cljs$cst$5929$maxHeight$$,"calc(100vh -1rem"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,$left_position$$,$APP.$cljs$cst$5929$maxHeight$$,$max_height_top$jscomp$1$$,
$APP.$cljs$cst$1567$top$$,""+($y$jscomp$482$$-50-$overflow_fix$$)+"px"],null):$y$jscomp$482$$>$map__80581__$1_max_y$jscomp$3_p__80580$$?new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,""+($x$jscomp$1261$$+$left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$??"")+"px",$APP.$cljs$cst$1568$bottom$$,"1rem",$APP.$cljs$cst$5929$maxHeight$$,"calc(100vh -1rem"],null):new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$257$left$$,""+($x$jscomp$1261$$+$left_offset$jscomp$1_rulers_QMARK_$jscomp$3$$??
"")+"px",$APP.$cljs$cst$1567$top$$,""+($y$jscomp$482$$-70-$overflow_fix$$)+"px",$APP.$cljs$cst$5929$maxHeight$$,$max_height_top$jscomp$1$$],null)};
$app$main$ui$workspace$tokens$management$forms$modals$use_viewport_position_style$$=function($x$jscomp$1262$$,$y$jscomp$483$$,$position$jscomp$207$$,$token_type$jscomp$28$$){var $vport$jscomp$10$$=$APP.$rumext$v2$deref$$($APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2211$vport$$,$APP.$app$main$refs$workspace_local$$));return $APP.$cljs$core$clj__GT_js$$($app$main$ui$workspace$tokens$management$forms$modals$calculate_position$$($vport$jscomp$10$$,$position$jscomp$207$$,
$x$jscomp$1262$$,$y$jscomp$483$$,$token_type$jscomp$28$$))};
$app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$=function($props_80583_wrapper_style$$){var $selected_token_set_id$jscomp$11$$=$props_80583_wrapper_style$$["selected-token-set-id"],$token$jscomp$212$$=$props_80583_wrapper_style$$.token,$initial_errors$jscomp$4$$=$props_80583_wrapper_style$$["initial-errors"],$token_type$jscomp$29$$=$props_80583_wrapper_style$$["token-type"],$action$jscomp$9$$=$props_80583_wrapper_style$$.action;$props_80583_wrapper_style$$=$app$main$ui$workspace$tokens$management$forms$modals$use_viewport_position_style$$($props_80583_wrapper_style$$.x,
$props_80583_wrapper_style$$.y,$props_80583_wrapper_style$$.position,$token_type$jscomp$29$$);var $modal_size_large_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_type$jscomp$29$$,$APP.$cljs$cst$1997$typography$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_type$jscomp$29$$,$APP.$cljs$cst$1303$color$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($token_type$jscomp$29$$,$APP.$cljs$cst$1659$shadow$$)),
$modal_size_large_QMARK_$$=$APP.$cljs$core$_deref$$($modal_size_large_STAR_$$),$close_modal$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$data$modal$hide_BANG_$$()}),$update_modal_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($visible$jscomp$3$$){return $APP.$cljs$core$reset_BANG_$$($modal_size_large_STAR_$$,$visible$jscomp$3$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:$props_80583_wrapper_style$$,"data-testid":"token-update-create-modal",
className:"main_ui_workspace_tokens_management_forms_modals__token-modal-wrapper "+($APP.$cljs$core$truth_$$($modal_size_large_QMARK_$$)?"main_ui_workspace_tokens_management_forms_modals__token-modal-large":""),children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$close_modal$$,className:"main_ui_workspace_tokens_management_forms_modals__close-btn",icon:"close",variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$form_container$form_container_STAR_$$,{isCreate:!$APP.$app$common$types$tokens_lib$token_QMARK_$$($token$jscomp$212$$),token:$token$jscomp$212$$,action:$action$jscomp$9$$,selectedTokenSetId:$selected_token_set_id$jscomp$11$$,tokenType:$token_type$jscomp$29$$,initialErrors:$initial_errors$jscomp$4$$,onDisplayColorpicker:$update_modal_size$$})]})};
$app$main$ui$workspace$tokens$management$forms$modals$boolean_modal$$=function($properties$jscomp$109_props_80584$$){$properties$jscomp$109_props_80584$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$109_props_80584$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$109_props_80584$$))};
$app$main$ui$workspace$tokens$management$forms$modals$border_radius_modal$$=function($properties$jscomp$110_props_80585$$){$properties$jscomp$110_props_80585$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$110_props_80585$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$110_props_80585$$))};
$app$main$ui$workspace$tokens$management$forms$modals$box_shadow_modal$$=function($properties$jscomp$111_props_80586$$){$properties$jscomp$111_props_80586$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$111_props_80586$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$111_props_80586$$))};
$app$main$ui$workspace$tokens$management$forms$modals$color_modal$$=function($properties$jscomp$112_props_80587$$){$properties$jscomp$112_props_80587$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$112_props_80587$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$112_props_80587$$))};
$app$main$ui$workspace$tokens$management$forms$modals$dimensions_modal$$=function($properties$jscomp$113_props_80588$$){$properties$jscomp$113_props_80588$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$113_props_80588$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$113_props_80588$$))};
$app$main$ui$workspace$tokens$management$forms$modals$font_familiy_modal$$=function($properties$jscomp$114_props_80589$$){$properties$jscomp$114_props_80589$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$114_props_80589$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$114_props_80589$$))};
$app$main$ui$workspace$tokens$management$forms$modals$font_size_modal$$=function($properties$jscomp$115_props_80590$$){$properties$jscomp$115_props_80590$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$115_props_80590$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$115_props_80590$$))};
$app$main$ui$workspace$tokens$management$forms$modals$font_weight_modal$$=function($properties$jscomp$116_props_80591$$){$properties$jscomp$116_props_80591$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$116_props_80591$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$116_props_80591$$))};
$app$main$ui$workspace$tokens$management$forms$modals$letter_spacing_modal$$=function($properties$jscomp$117_props_80592$$){$properties$jscomp$117_props_80592$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$117_props_80592$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$117_props_80592$$))};
$app$main$ui$workspace$tokens$management$forms$modals$number_modal$$=function($properties$jscomp$118_props_80593$$){$properties$jscomp$118_props_80593$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$118_props_80593$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$118_props_80593$$))};
$app$main$ui$workspace$tokens$management$forms$modals$opacity_modal$$=function($properties$jscomp$119_props_80594$$){$properties$jscomp$119_props_80594$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$119_props_80594$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$119_props_80594$$))};
$app$main$ui$workspace$tokens$management$forms$modals$other_modal$$=function($properties$jscomp$120_props_80595$$){$properties$jscomp$120_props_80595$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$120_props_80595$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$120_props_80595$$))};
$app$main$ui$workspace$tokens$management$forms$modals$rotation_modal$$=function($properties$jscomp$121_props_80596$$){$properties$jscomp$121_props_80596$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$121_props_80596$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$121_props_80596$$))};
$app$main$ui$workspace$tokens$management$forms$modals$sizing_modal$$=function($properties$jscomp$122_props_80597$$){$properties$jscomp$122_props_80597$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$122_props_80597$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$122_props_80597$$))};
$app$main$ui$workspace$tokens$management$forms$modals$spacing_modal$$=function($properties$jscomp$123_props_80598$$){$properties$jscomp$123_props_80598$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$123_props_80598$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$123_props_80598$$))};
$app$main$ui$workspace$tokens$management$forms$modals$string_modal$$=function($properties$jscomp$124_props_80599$$){$properties$jscomp$124_props_80599$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$124_props_80599$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$124_props_80599$$))};
$app$main$ui$workspace$tokens$management$forms$modals$stroke_width_modal$$=function($properties$jscomp$125_props_80600$$){$properties$jscomp$125_props_80600$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$125_props_80600$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$125_props_80600$$))};
$app$main$ui$workspace$tokens$management$forms$modals$text_case_modal$$=function($properties$jscomp$126_props_80601$$){$properties$jscomp$126_props_80601$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$126_props_80601$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$126_props_80601$$))};
$app$main$ui$workspace$tokens$management$forms$modals$text_decoration_modal$$=function($properties$jscomp$127_props_80602$$){$properties$jscomp$127_props_80602$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$127_props_80602$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$127_props_80602$$))};
$app$main$ui$workspace$tokens$management$forms$modals$typography_modal$$=function($properties$jscomp$128_props_80603$$){$properties$jscomp$128_props_80603$$=$APP.$rumext$v2$util$wrap_props$$($properties$jscomp$128_props_80603$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$forms$modals$token_update_create_modal$$,$APP.$rumext$v2$util$map__GT_obj$$($properties$jscomp$128_props_80603$$))};
$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_form_STAR_$$=function($on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$){var $variant$jscomp$27$$=$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$.variant,$on_close$jscomp$40$$=$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$.onClose,$new_node_name$jscomp$7$$=$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$.newNodeName,$node$jscomp$460$$=$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$.node,
$active_tokens$jscomp$13$$=$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$.activeTokens,$tokens_tree$jscomp$14$$=$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$.tokensTree,$on_submit$jscomp$19$$=$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$.onSubmit;$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$13$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,$app$common$files$tokens$make_node_token_name_schema$$($active_tokens$jscomp$13$$,$tokens_tree$jscomp$14$$,$node$jscomp$460$$)],null)],null)});var $initial$jscomp$41_is_disabled_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($node$jscomp$460$$),$APP.$rumext$v2$adapt$$($new_node_name$jscomp$7$$)],
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$725$name$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($new_node_name$jscomp$7$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$460$$))],null)}),$form$jscomp$209$$=$APP.$app$util$forms$use_form$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$298$schema$$,$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$,
$APP.$cljs$cst$4840$initial$$,$initial$jscomp$41_is_disabled_QMARK_$$]));$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($form$jscomp$209$$),$APP.$rumext$v2$adapt$$($on_submit$jscomp$19$$)],function(){var $name$jscomp$494$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$209$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$4838$clean_data$$,$APP.$cljs$cst$725$name$$],null));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$494$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$460$$))?$on_submit$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$on_submit$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($name$jscomp$494$$):$on_submit$jscomp$19$$($name$jscomp$494$$):null});$initial$jscomp$41_is_disabled_QMARK_$$=$APP.$cljs$core$not$$($APP.$cljs$cst$4839$valid$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($form$jscomp$209$$)))||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$209$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4838$clean_data$$,$APP.$cljs$cst$725$name$$],null)),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$460$$));var $hint_path$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($form$jscomp$209$$)),
$APP.$rumext$v2$adapt$$($node$jscomp$460$$)],function(){var $new_name$jscomp$39_new_path$jscomp$7$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$209$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4838$clean_data$$,$APP.$cljs$cst$725$name$$],null)),$path$jscomp$298$$=$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$460$$));
$new_name$jscomp$39_new_path$jscomp$7$$=$APP.$cuerdas$core$replace$$($path$jscomp$298$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$460$$),$new_name$jscomp$39_new_path$jscomp$7$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($form$jscomp$209$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1631$touched$$,$APP.$cljs$cst$725$name$$],null)))?
$new_name$jscomp$39_new_path$jscomp$7$$:$path$jscomp$298$$});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$forms$form_STAR_$$,{className:"main_ui_workspace_tokens_management_forms_rename_node_modal__form-wrapper",form:$form$jscomp$209$$,onSubmit:$on_submit__$1$jscomp$1_props_80577_schema$jscomp$246$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_management_forms_rename_node_modal__form-modal-title",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$27$$,"rename")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.rename-group"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.duplicate-group")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_input_STAR_$$,{placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name"),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.token-name"),
hintType:"hint",hintMessage:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$27$$,"rename")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.rename-group-name-hint",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$hint_path$$])):null,id:"rename-node",maxLength:255,name:$APP.$cljs$cst$725$name$$,variant:"comfortable",autoFocus:!0}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_rename_node_modal__form-actions",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",name:"cancel",onClick:$on_close$jscomp$40$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$forms$form_submit_STAR_$$,{variant:"primary",disabled:$initial$jscomp$41_is_disabled_QMARK_$$,name:"rename",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($variant$jscomp$27$$,"rename")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.rename"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.duplicate")})]})]})};
$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_modal$$=function($map__80579_new_node_name$jscomp$8_props_80578$$){$map__80579_new_node_name$jscomp$8_props_80578$$=$APP.$rumext$v2$util$wrap_props$$($map__80579_new_node_name$jscomp$8_props_80578$$);var $map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$=$APP.$cljs$core$__destructure_map$$($map__80579_new_node_name$jscomp$8_props_80578$$);$map__80579_new_node_name$jscomp$8_props_80578$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$,
$cljs$cst$5905$new_node_name$$);var $node$jscomp$461$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$,$APP.$cljs$cst$3817$node$$),$tokens_in_active_set$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$,$cljs$cst$5904$tokens_in_active_set$$),$on_rename$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$,
$cljs$cst$5902$on_rename$$);$map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$,$APP.$cljs$cst$2010$variant$$);$map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$,"rename");var $tokens_tree_in_selected_set$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($tokens_in_active_set$$),
$APP.$rumext$v2$adapt$$($node$jscomp$461$$)],function(){return $APP.$app$common$data$dissoc_in$$($APP.$app$common$types$tokens_lib$tokens_tree$$($tokens_in_active_set$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$461$$))}),$close_modal$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$rename$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_rename$jscomp$4$$)],
function($new_name$jscomp$40$$){return $on_rename$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$on_rename$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($new_name$jscomp$40$$):$on_rename$jscomp$4$$($new_name$jscomp$40$$)}),$on_key_down$jscomp$25$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$close_modal$jscomp$1$$],null))],function($event$jscomp$636$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$636$$))?
$close_modal$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$close_modal$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$close_modal$jscomp$1$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{onKeyDown:$on_key_down$jscomp$25$$,"data-testid":"token-rename-node-modal",className:"main_ui_workspace_tokens_management_forms_rename_node_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_management_forms_rename_node_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{className:"main_ui_workspace_tokens_management_forms_rename_node_modal__close-btn",onClick:$close_modal$jscomp$1$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),variant:"ghost",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_form_STAR_$$,{newNodeName:$map__80579_new_node_name$jscomp$8_props_80578$$,node:$node$jscomp$461$$,variant:$map__80579__$1_variant$jscomp$28_variant__$1$jscomp$8$$,activeTokens:$tokens_in_active_set$$,
tokensTree:$tokens_tree_in_selected_set$jscomp$2$$,onClose:$close_modal$jscomp$1$$,onSubmit:$rename$jscomp$4$$})]})})};
$app$main$ui$workspace$tokens$remapping_modal$token_remapping_modal$$=function($map__80609_props_80608_remap_data$jscomp$2$$){$map__80609_props_80608_remap_data$jscomp$2$$=$APP.$rumext$v2$util$wrap_props$$($map__80609_props_80608_remap_data$jscomp$2$$);var $map__80609__$1_old_name$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__80609_props_80608_remap_data$jscomp$2$$);$map__80609_props_80608_remap_data$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80609__$1_old_name$jscomp$4$$,
$cljs$cst$5900$remap_data$$);var $on_remap$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80609__$1_old_name$jscomp$4$$,$cljs$cst$5901$on_remap$$),$on_rename$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80609__$1_old_name$jscomp$4$$,$cljs$cst$5902$on_rename$$);$map__80609__$1_old_name$jscomp$4$$=$cljs$cst$5866$old_name$$.$cljs$core$IFn$_invoke$arity$1$($map__80609_props_80608_remap_data$jscomp$2$$);var $new_name$jscomp$41$$=$cljs$cst$5867$new_name$$.$cljs$core$IFn$_invoke$arity$1$($map__80609_props_80608_remap_data$jscomp$2$$),
$confirm_remap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_remap$jscomp$1$$),$APP.$rumext$v2$adapt$$($map__80609__$1_old_name$jscomp$4$$),$APP.$rumext$v2$adapt$$($new_name$jscomp$41$$)],function(){return $APP.$cljs$core$fn_QMARK_$$($on_remap$jscomp$1$$)?$on_remap$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_remap$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_remap$jscomp$1$$():null}),$rename_token$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_rename$jscomp$5$$)],
function(){return $APP.$cljs$core$fn_QMARK_$$($on_rename$jscomp$5$$)?$on_rename$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$?$on_rename$jscomp$5$$.$cljs$core$IFn$_invoke$arity$0$():$on_rename$jscomp$5$$():null}),$cancel_action$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$on_key_down$jscomp$26$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cancel_action$$)],
function($event$jscomp$637$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$637$$))?$cancel_action$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_action$$.$cljs$core$IFn$_invoke$arity$0$():$cancel_action$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{onKeyDown:$on_key_down$jscomp$26$$,role:"alertdialog","aria-modal":"true","aria-labelledby":"modal-title",className:"main_ui_workspace_tokens_remapping_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",
{"data-testid":"token-remapping-modal",className:"main_ui_workspace_tokens_remapping_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$cancel_action$$,className:"main_ui_workspace_tokens_remapping_modal__close-btn",icon:"close",variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_remapping_modal__modal-header",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,id:"modal-title",typography:"headline-large",className:"main_ui_workspace_tokens_remapping_modal__modal-title",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($map__80609_props_80608_remap_data$jscomp$2$$),"token")?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.remap-token-references-title",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80609__$1_old_name$jscomp$4$$,$new_name$jscomp$41$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.remap-node-references-title",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$map__80609__$1_old_name$jscomp$4$$,$new_name$jscomp$41$$]))})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_remapping_modal__modal-content",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($map__80609_props_80608_remap_data$jscomp$2$$),
"token")?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"p",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.remap-token-warning-effects")}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"p",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.remap-node-warning-effects")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"p",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.remap-warning-time")})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_remapping_modal__modal-footer",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_remapping_modal__action-buttons",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$rename_token$$,type:"button",variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.not-remap")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$confirm_remap$$,type:"button",variant:"primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.remap")})]})})]})})};
$app$main$data$workspace$tokens$typography$set_base_font_size$$=function($base_font_size$jscomp$2$$){typeof $app$main$data$workspace$tokens$typography$set_base_font_size_80605$$==="undefined"&&($app$main$data$workspace$tokens$typography$set_base_font_size_80605$$=function($base_font_size$jscomp$3$$,$meta80606$$){this.$base_font_size$=$base_font_size$jscomp$3$$;this.$meta80606$=$meta80606$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$tokens$typography$set_base_font_size_80605$$.prototype.$potok$v2$core$Event$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$typography$set_base_font_size_80605$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$5933$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_typography_SLASH_set_base_font_size$$},$app$main$data$workspace$tokens$typography$set_base_font_size_80605$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_80607$$,$meta80606__$1$$){return new $app$main$data$workspace$tokens$typography$set_base_font_size_80605$$(this.$base_font_size$,
$meta80606__$1$$)},$app$main$data$workspace$tokens$typography$set_base_font_size_80605$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta80606$},$app$main$data$workspace$tokens$typography$set_base_font_size_80605$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$tokens$typography$set_base_font_size_80605$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($file_id$jscomp$433_it$jscomp$279_new_base_font_size$jscomp$inline_9207$$,
$changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$){$file_id$jscomp$433_it$jscomp$279_new_base_font_size$jscomp$inline_9207$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$,$APP.$cljs$cst$2543$workspace$$),$APP.$cljs$cst$1934$current_file_id$$);$changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$,$APP.$cljs$cst$1933$files$$),$file_id$jscomp$433_it$jscomp$279_new_base_font_size$jscomp$inline_9207$$),$APP.$cljs$cst$142$data$$);$changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$=$APP.$app$common$files$changes_builder$with_file_data$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$01$$(this),
$changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$);$file_id$jscomp$433_it$jscomp$279_new_base_font_size$jscomp$inline_9207$$=this.$base_font_size$;var $file_data$jscomp$inline_9208_previous_font_size$jscomp$inline_9209$$=$APP.$cljs$cst$3193$app_DOT_common_DOT_files_DOT_changes_builder_SLASH_file_data$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$));$file_data$jscomp$inline_9208_previous_font_size$jscomp$inline_9209$$=
$app$common$types$file$get_base_font_size$$($file_data$jscomp$inline_9208_previous_font_size$jscomp$inline_9209$$);$changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$=$APP.$app$common$files$changes_builder$apply_changes_local$$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$,$APP.$cljs$cst$3157$redo_changes$$,
$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2670$set_base_font_size$$,$APP.$cljs$cst$2587$base_font_size$$,$file_id$jscomp$433_it$jscomp$279_new_base_font_size$jscomp$inline_9207$$],null)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$conj$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2670$set_base_font_size$$,$APP.$cljs$cst$2587$base_font_size$$,$file_data$jscomp$inline_9208_previous_font_size$jscomp$inline_9209$$],
null)));return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$changes$commit_changes$$($changes$jscomp$336_changes$jscomp$inline_9206_file_data$jscomp$123_state$jscomp$1225$$))});return new $app$main$data$workspace$tokens$typography$set_base_font_size_80605$$($base_font_size$jscomp$2$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$tokens$settings$menu$token_settings_STAR_$$=function(){var $file_data$jscomp$124$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_data$$),$base_font_size_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$common$types$file$get_base_font_size$$($file_data$jscomp$124$$)}),$base_font_size$jscomp$4$$=$APP.$cljs$core$_deref$$($base_font_size_STAR_$$),$valid_QMARK__STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),
$is_valid$$=$APP.$cljs$core$_deref$$($valid_QMARK__STAR_$$),$hint_message$jscomp$1$$=$APP.$cljs$core$truth_$$($is_valid$$)?["1rem \x3d ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($base_font_size$jscomp$4$$)].join(""):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.base-font-size.error"),$on_change_base_font_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_font_size_STAR_$$)],function($e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$){$e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$=
(0,$APP.$app$util$dom$get_target_val$$)($e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$);$APP.$cljs$core$reset_BANG_$$($valid_QMARK__STAR_$$,$APP.$cljs$core$boolean$0$$($APP.$cljs$core$re_matches$$(/^\d+(\.\d+)?(px)?$/,$e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$)));return $APP.$cljs$core$boolean$0$$($APP.$cljs$core$re_matches$$(/^\d+(\.\d+)?(px)?$/,$e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$))?($e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$=$APP.$cuerdas$core$ends_with_QMARK_$$($e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$,
"px")?$e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$),"px"].join(""),$APP.$cljs$core$reset_BANG_$$($base_font_size_STAR_$$,$e$jscomp$374_unit_value$jscomp$1_value$jscomp$998$$)):null}),$on_set_font$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_font_size$jscomp$4$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$tokens$typography$set_base_font_size$$($base_font_size$jscomp$4$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$hide$$()]))}),$handle_key_down$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_font_size$jscomp$4$$),$APP.$rumext$v2$adapt$$($is_valid$$)],function($and__5023__auto__$jscomp$inline_9211_e$jscomp$375$$){$and__5023__auto__$jscomp$inline_9211_e$jscomp$375$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($and__5023__auto__$jscomp$inline_9211_e$jscomp$375$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9211_e$jscomp$375$$)?
$is_valid$$:$and__5023__auto__$jscomp$inline_9211_e$jscomp$375$$)?$on_set_font$$.$cljs$core$IFn$_invoke$arity$0$?$on_set_font$$.$cljs$core$IFn$_invoke$arity$0$():$on_set_font$$():null});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"token-font-settings-modal",className:"main_ui_workspace_tokens_settings_menu__setting-modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_settings_menu__setting-modal",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{onClick:$APP.$app$main$data$modal$hide_BANG_$$,className:"main_ui_workspace_tokens_settings_menu__close-btn",icon:"close",variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_settings_menu__settings-modal-layout",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_settings_menu__settings-modal-title",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.settings")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_settings_menu__settings-modal-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_settings_menu__settings-modal-subtitle-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-large",className:"main_ui_workspace_tokens_settings_menu__settings-subtitle",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.base-font-size")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",className:"main_ui_workspace_tokens_settings_menu__settings-modal-description",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.setting-description")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{type:"text",
placeholder:"16",defaultValue:$base_font_size$jscomp$4$$,hintMessage:$hint_message$jscomp$1$$,hintType:$APP.$cljs$core$truth_$$($is_valid$$)?"hint":"error",onKeyDown:$handle_key_down$jscomp$10$$,onChange:$on_change_base_font_size$$}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_settings_menu__settings-modal-actions",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$APP.$app$main$data$modal$hide_BANG_$$,type:"button",variant:"secondary",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$on_set_font$$,type:"button",disabled:$APP.$cljs$core$not$$($is_valid$$),variant:"primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.save")})]})]})]})]})})};
$app$main$ui$workspace$tokens$settings$token_settings_modal_STAR_$$=function(){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$settings$menu$token_settings_STAR_$$,{})};
$app$main$ui$workspace$tokens$themes$create_modal$empty_themes$$=function($create_theme_map__80613_map__80613__$1_props_80612$$){$create_theme_map__80613_map__80613__$1_props_80612$$=$APP.$rumext$v2$util$wrap_props$$($create_theme_map__80613_map__80613__$1_props_80612$$);$create_theme_map__80613_map__80613__$1_props_80612$$=$APP.$cljs$core$__destructure_map$$($create_theme_map__80613_map__80613__$1_props_80612$$);var $change_view$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($create_theme_map__80613_map__80613__$1_props_80612$$,
$cljs$cst$5934$change_view$$);$create_theme_map__80613_map__80613__$1_props_80612$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_view$$)],function(){return $change_view$$.$cljs$core$IFn$_invoke$arity$1$?$change_view$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5935$create_theme$$):$change_view$$($cljs$cst$5935$create_theme$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,
{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.themes-list")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__empty-themes-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__empty-themes-message",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"span",typography:"title-medium",className:"main_ui_workspace_tokens_themes_create_modal__empty-theme-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-themes-currently")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",className:"main_ui_workspace_tokens_themes_create_modal__empty-theme-subtitle",typography:"body-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.create-new-theme")})]}),
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__button-footer",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",onClick:$create_theme_map__80613_map__80613__$1_props_80612$$,
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add-new-theme")})]})]})]})};
$app$main$ui$workspace$tokens$themes$create_modal$themes_overview$$=function($props_80614$$){var $map__80615$$=$APP.$rumext$v2$util$wrap_props$$($props_80614$$),$map__80615__$1$$=$APP.$cljs$core$__destructure_map$$($map__80615$$),$change_view$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80615__$1$$,$cljs$cst$5934$change_view$$),$active_theme_paths$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_active_theme_paths$$),$themes_groups$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_theme_tree_no_hidden$$),
$create_theme$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_view$jscomp$1$$)],function($e$jscomp$376$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$376$$);$APP.$app$util$dom$stop_propagation$$($e$jscomp$376$$);return $change_view$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$change_view$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5935$create_theme$$):$change_view$jscomp$1$$($cljs$cst$5935$create_theme$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-title",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.themes-list")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"div",typography:"body-medium",
className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-description",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.themes-description")}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_themes_create_modal__theme-group-wrapper",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$207$$,$p__80616$$){var $group$jscomp$56$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80616$$,
0,null),$themes$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80616$$,1,null);$out_arr__44092__auto__$jscomp$207$$.push((0,$APP.$rumext$v2$jsxs$$)("li",{children:[$APP.$cljs$core$seq$$($group$jscomp$56$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:3,className:"main_ui_workspace_tokens_themes_create_modal__theme-group-label",typography:"body-large",children:(0,$APP.$rumext$v2$jsxs$$)("div",{title:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.group-name")),
": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($group$jscomp$56$$)].join(""),className:"main_ui_workspace_tokens_themes_create_modal__group-title",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"group",className:"main_ui_workspace_tokens_themes_create_modal__group-title-icon"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",className:"main_ui_workspace_tokens_themes_create_modal__group-title-name",
children:$group$jscomp$56$$})]})}):null,(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_themes_create_modal__theme-group-rows-wrapper",children:$APP.$cljs$core$into_array$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return function $app$main$ui$workspace$tokens$themes$create_modal$themes_overview_$_iter__80620$$($s__80621$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $temp__5825__auto__$jscomp$420$$=$APP.$cljs$core$seq$$($s__80621$$);if($temp__5825__auto__$jscomp$420$$){var $s__80621__$2$$=
$temp__5825__auto__$jscomp$420$$;if($APP.$cljs$core$chunked_seq_QMARK_$$($s__80621__$2$$)){var $c__5501__auto__$jscomp$53$$=$APP.$cljs$core$_chunked_first$$($s__80621__$2$$),$size__5502__auto__$jscomp$53$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$53$$),$b__80623$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$53$$);return function(){for(var $i__80622$$=0;;)if($i__80622$$<$size__5502__auto__$jscomp$53$$){var $vec__80625$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$53$$,$i__80622$$),
$_$jscomp$3106$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80625$$,0,null),$map__80628$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80625$$,1,null),$map__80628__$1$$=$APP.$cljs$core$__destructure_map$$($map__80628$$),$theme$jscomp$20$$=$map__80628__$1$$,$id$jscomp$1027$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80628__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$496$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80628__$1$$,
$APP.$cljs$cst$725$name$$),$theme_path$jscomp$2$$=$APP.$app$common$types$tokens_lib$get_theme_path$$($theme$jscomp$20$$),$selected_QMARK_$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_paths$jscomp$6$$,$theme_path$jscomp$2$$)!=null,$delete_theme$jscomp$1$$=function($i__80622$jscomp$1$$,$theme_path$jscomp$3$$,$selected_QMARK_$jscomp$15$$,$vec__80625$jscomp$1$$,$_$jscomp$3107$$,$map__80628$jscomp$1$$,$map__80628__$1$jscomp$1$$,$theme$jscomp$21$$,$id$jscomp$1028$$){return function($e$jscomp$377$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$377$$);
$APP.$app$util$dom$stop_propagation$$($e$jscomp$377$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$($id$jscomp$1028$$))}}($i__80622$$,$theme_path$jscomp$2$$,$selected_QMARK_$jscomp$14$$,$vec__80625$$,$_$jscomp$3106$$,$map__80628$$,$map__80628__$1$$,$theme$jscomp$20$$,$id$jscomp$1027$$,$name$jscomp$496$$,$c__5501__auto__$jscomp$53$$,$size__5502__auto__$jscomp$53$$,$b__80623$$,$s__80621__$2$$,$temp__5825__auto__$jscomp$420$$,
$p__80616$$,$group$jscomp$56$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80615$$,$map__80615__$1$$,$change_view$jscomp$1$$),$on_switch_theme$jscomp$1$$=function($i__80622$jscomp$2$$,$theme_path$jscomp$4$$,$selected_QMARK_$jscomp$16$$,$delete_theme$jscomp$2$$,$vec__80625$jscomp$2$$,$_$jscomp$3108$$,$map__80628$jscomp$2$$,$map__80628__$1$jscomp$2$$,$theme$jscomp$22$$,$id$jscomp$1029$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1029$$))}}($i__80622$$,
$theme_path$jscomp$2$$,$selected_QMARK_$jscomp$14$$,$delete_theme$jscomp$1$$,$vec__80625$$,$_$jscomp$3106$$,$map__80628$$,$map__80628__$1$$,$theme$jscomp$20$$,$id$jscomp$1027$$,$name$jscomp$496$$,$c__5501__auto__$jscomp$53$$,$size__5502__auto__$jscomp$53$$,$b__80623$$,$s__80621__$2$$,$temp__5825__auto__$jscomp$420$$,$p__80616$$,$group$jscomp$56$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80615$$,$map__80615__$1$$,$change_view$jscomp$1$$),$on_edit_theme$jscomp$1$$=
function($i__80622$jscomp$3$$,$theme_path$jscomp$5$$,$selected_QMARK_$jscomp$17$$,$delete_theme$jscomp$3$$,$on_switch_theme$jscomp$2$$,$vec__80625$jscomp$3$$,$_$jscomp$3109$$,$map__80628$jscomp$3$$,$map__80628__$1$jscomp$3$$,$theme$jscomp$23$$,$id$jscomp$1030$$,$name$jscomp$499$$,$c__5501__auto__$jscomp$56$$,$size__5502__auto__$jscomp$56$$,$b__80623$jscomp$3$$,$s__80621__$2$jscomp$3$$,$temp__5825__auto__$jscomp$423$$,$vec__80617$jscomp$3$$,$group$jscomp$59$$,$themes$jscomp$16$$,$active_theme_paths$jscomp$9$$,
$themes_groups$jscomp$3$$,$create_theme$jscomp$4$$,$map__80615$jscomp$3$$,$map__80615__$1$jscomp$3$$,$change_view$jscomp$4$$){return function($G__80631_e$jscomp$378$$){$APP.$app$util$dom$prevent_default$$($G__80631_e$jscomp$378$$);$APP.$app$util$dom$stop_propagation$$($G__80631_e$jscomp$378$$);$G__80631_e$jscomp$378$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5937$theme_info$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$23$$),
$APP.$cljs$cst$1613$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$23$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$23$$)],null)],null);return $change_view$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$?$change_view$jscomp$4$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5936$edit_theme$$,$G__80631_e$jscomp$378$$):$change_view$jscomp$4$$($cljs$cst$5936$edit_theme$$,$G__80631_e$jscomp$378$$)}}($i__80622$$,$theme_path$jscomp$2$$,$selected_QMARK_$jscomp$14$$,$delete_theme$jscomp$1$$,
$on_switch_theme$jscomp$1$$,$vec__80625$$,$_$jscomp$3106$$,$map__80628$$,$map__80628__$1$$,$theme$jscomp$20$$,$id$jscomp$1027$$,$name$jscomp$496$$,$c__5501__auto__$jscomp$53$$,$size__5502__auto__$jscomp$53$$,$b__80623$$,$s__80621__$2$$,$temp__5825__auto__$jscomp$420$$,$p__80616$$,$group$jscomp$56$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80615$$,$map__80615__$1$$,$change_view$jscomp$1$$);$APP.$cljs$core$chunk_append$$($b__80623$$,(0,$APP.$rumext$v2$jsxs$$)("li",
{className:"main_ui_workspace_tokens_themes_create_modal__theme-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__theme-switch-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$,{label:$name$jscomp$496$$,onChange:$on_switch_theme$jscomp$1$$,defaultChecked:$selected_QMARK_$jscomp$14$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__theme-actions-row",children:[function(){var $G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$=
$theme$jscomp$20$$;$G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$=$G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$==null?null:$APP.$cljs$cst$2116$sets$$.$cljs$core$IFn$_invoke$arity$1$($G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$);$G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$=
$G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$==null?null:$APP.$cljs$core$seq$$($G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$);$G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$=$G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$==null?null:$APP.$cljs$core$count$$($G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$);
return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:($APP.$cljs$core$truth_$$($G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$)?"main_ui_workspace_tokens_themes_create_modal__sets-count-button":"")+" "+($APP.$cljs$core$not$$($G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$)?"main_ui_workspace_tokens_themes_create_modal__sets-count-empty-button":""),
variant:"secondary",type:"button",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.sets-hint"),onClick:$on_edit_theme$jscomp$1$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__label-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",children:$APP.$cljs$core$truth_$$($G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$)?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.num-active-sets",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__80632$jscomp$inline_9213_G__80632__$1$jscomp$inline_9214_G__80632__$2$jscomp$inline_9215_sets_count$$])):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-active-sets")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right"})]})})}(),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{onClick:$delete_theme$jscomp$1$$,variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.delete-theme-title"),icon:"delete"})]})]},$theme_path$jscomp$2$$));$i__80622$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80623$$),$app$main$ui$workspace$tokens$themes$create_modal$themes_overview_$_iter__80620$$($APP.$cljs$core$_chunked_rest$$($s__80621__$2$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80623$$),
null)}var $vec__80633$$=$APP.$cljs$core$first$$($s__80621__$2$$),$_$jscomp$3105$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80633$$,0,null),$map__80636$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__80633$$,1,null),$map__80636__$1$$=$APP.$cljs$core$__destructure_map$$($map__80636$$),$theme$jscomp$19$$=$map__80636__$1$$,$id$jscomp$1026$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80636__$1$$,$APP.$cljs$cst$266$id$$),$name$jscomp$495$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80636__$1$$,
$APP.$cljs$cst$725$name$$),$theme_path$jscomp$1$$=$APP.$app$common$types$tokens_lib$get_theme_path$$($theme$jscomp$19$$),$selected_QMARK_$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_paths$jscomp$6$$,$theme_path$jscomp$1$$)!=null,$delete_theme$$=function($theme_path$jscomp$6$$,$selected_QMARK_$jscomp$18$$,$vec__80633$jscomp$1$$,$_$jscomp$3110$$,$map__80636$jscomp$1$$,$map__80636__$1$jscomp$1$$,$theme$jscomp$24$$,$id$jscomp$1031$$){return function($e$jscomp$379$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$379$$);
$APP.$app$util$dom$stop_propagation$$($e$jscomp$379$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$($id$jscomp$1031$$))}}($theme_path$jscomp$1$$,$selected_QMARK_$jscomp$13$$,$vec__80633$$,$_$jscomp$3105$$,$map__80636$$,$map__80636__$1$$,$theme$jscomp$19$$,$id$jscomp$1026$$,$name$jscomp$495$$,$s__80621__$2$$,$temp__5825__auto__$jscomp$420$$,$p__80616$$,$group$jscomp$56$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,
$themes_groups$$,$create_theme$jscomp$1$$,$map__80615$$,$map__80615__$1$$,$change_view$jscomp$1$$),$on_switch_theme$$=function($theme_path$jscomp$7$$,$selected_QMARK_$jscomp$19$$,$delete_theme$jscomp$4$$,$vec__80633$jscomp$2$$,$_$jscomp$3111$$,$map__80636$jscomp$2$$,$map__80636__$1$jscomp$2$$,$theme$jscomp$25$$,$id$jscomp$1032$$){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_theme_active$$($id$jscomp$1032$$))}}($theme_path$jscomp$1$$,
$selected_QMARK_$jscomp$13$$,$delete_theme$$,$vec__80633$$,$_$jscomp$3105$$,$map__80636$$,$map__80636__$1$$,$theme$jscomp$19$$,$id$jscomp$1026$$,$name$jscomp$495$$,$s__80621__$2$$,$temp__5825__auto__$jscomp$420$$,$p__80616$$,$group$jscomp$56$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80615$$,$map__80615__$1$$,$change_view$jscomp$1$$),$on_edit_theme$$=function($theme_path$jscomp$8$$,$selected_QMARK_$jscomp$20$$,$delete_theme$jscomp$5$$,$on_switch_theme$jscomp$3$$,
$vec__80633$jscomp$3$$,$_$jscomp$3112$$,$map__80636$jscomp$3$$,$map__80636__$1$jscomp$3$$,$theme$jscomp$26$$,$id$jscomp$1033$$,$name$jscomp$502$$,$s__80621__$2$jscomp$6$$,$temp__5825__auto__$jscomp$426$$,$vec__80617$jscomp$6$$,$group$jscomp$62$$,$themes$jscomp$19$$,$active_theme_paths$jscomp$12$$,$themes_groups$jscomp$6$$,$create_theme$jscomp$7$$,$map__80615$jscomp$6$$,$map__80615__$1$jscomp$6$$,$change_view$jscomp$7$$){return function($G__80638_e$jscomp$380$$){$APP.$app$util$dom$prevent_default$$($G__80638_e$jscomp$380$$);
$APP.$app$util$dom$stop_propagation$$($G__80638_e$jscomp$380$$);$G__80638_e$jscomp$380$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5937$theme_info$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$26$$),$APP.$cljs$cst$1613$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$26$$),$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$26$$)],null)],
null);return $change_view$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$?$change_view$jscomp$7$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5936$edit_theme$$,$G__80638_e$jscomp$380$$):$change_view$jscomp$7$$($cljs$cst$5936$edit_theme$$,$G__80638_e$jscomp$380$$)}}($theme_path$jscomp$1$$,$selected_QMARK_$jscomp$13$$,$delete_theme$$,$on_switch_theme$$,$vec__80633$$,$_$jscomp$3105$$,$map__80636$$,$map__80636__$1$$,$theme$jscomp$19$$,$id$jscomp$1026$$,$name$jscomp$495$$,$s__80621__$2$$,$temp__5825__auto__$jscomp$420$$,
$p__80616$$,$group$jscomp$56$$,$themes$jscomp$13$$,$active_theme_paths$jscomp$6$$,$themes_groups$$,$create_theme$jscomp$1$$,$map__80615$$,$map__80615__$1$$,$change_view$jscomp$1$$);return $APP.$cljs$core$cons$$((0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_tokens_themes_create_modal__theme-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__theme-switch-row",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$switch$0$switch_STAR_$$,
{label:$name$jscomp$495$$,onChange:$on_switch_theme$$,defaultChecked:$selected_QMARK_$jscomp$13$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__theme-actions-row",children:[function(){var $G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$=$theme$jscomp$19$$;$G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$=$G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$==
null?null:$APP.$cljs$cst$2116$sets$$.$cljs$core$IFn$_invoke$arity$1$($G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$);$G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$=$G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$==null?null:$APP.$cljs$core$seq$$($G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$);
$G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$=$G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$==null?null:$APP.$cljs$core$count$$($G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$);return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{className:($APP.$cljs$core$truth_$$($G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$)?
"main_ui_workspace_tokens_themes_create_modal__sets-count-button":"")+" "+($APP.$cljs$core$not$$($G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$)?"main_ui_workspace_tokens_themes_create_modal__sets-count-empty-button":""),variant:"secondary",type:"button",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.sets-hint"),onClick:$on_edit_theme$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__label-wrapper",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-medium",children:$APP.$cljs$core$truth_$$($G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.num-active-sets",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__80639$jscomp$inline_9217_G__80639__$1$jscomp$inline_9218_G__80639__$2$jscomp$inline_9219_sets_count$jscomp$1$$])):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.no-active-sets")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow-right"})]})})}(),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{onClick:$delete_theme$$,variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.delete-theme-title"),icon:"delete"})]})]},$theme_path$jscomp$1$$),$app$main$ui$workspace$tokens$themes$create_modal$themes_overview_$_iter__80620$$($APP.$cljs$core$rest$$($s__80621__$2$$)))}return null}},
null,null)}($themes$jscomp$13$$)}())})]},"token-theme-group"+($group$jscomp$56$$??"")));return $out_arr__44092__auto__$jscomp$207$$},[],$themes_groups$$)}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__button-footer",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$APP.$app$main$data$modal$hide_BANG_$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"button",onClick:$create_theme$jscomp$1$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add-new-theme")})]})]})};
$app$main$ui$workspace$tokens$themes$create_modal$theme_inputs_STAR_$$=function($options$jscomp$641_props_80640_theme_groups$$){var $theme$jscomp$27$$=$options$jscomp$641_props_80640_theme_groups$$.theme,$on_change_field$$=$options$jscomp$641_props_80640_theme_groups$$.onChangeField,$tokens_lib$jscomp$57$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$);$options$jscomp$641_props_80640_theme_groups$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_theme_groups$$);var $theme_name_ref$$=
(0,$APP.$rumext$v2$use_ref$$)($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$27$$));$options$jscomp$641_props_80640_theme_groups$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($group$jscomp$63$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$group$jscomp$63$$,$APP.$cljs$cst$266$id$$,$group$jscomp$63$$],null)},$options$jscomp$641_props_80640_theme_groups$$);var $current_group_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1613$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$27$$)),
$current_group$$=$APP.$cljs$core$_deref$$($current_group_STAR_$$),$current_name_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$27$$)),$current_name$jscomp$2$$=$APP.$cljs$core$_deref$$($current_name_STAR_$$),$group_errors_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$group_errors$$=$APP.$cljs$core$_deref$$($group_errors_STAR_$$),$name_errors_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$name_errors$$=$APP.$cljs$core$_deref$$($name_errors_STAR_$$),$on_update_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_field$$),$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$57$$),$APP.$rumext$v2$adapt$$($current_name$jscomp$2$$)],function($value$jscomp$999$$){var $errors$jscomp$47$$=$app$common$schema$validation_errors$$($value$jscomp$999$$,$APP.$app$common$files$tokens$make_token_theme_group_schema$$($tokens_lib$jscomp$57$$,$current_name$jscomp$2$$,
$APP.$app$common$types$tokens_lib$get_id$$($theme$jscomp$27$$)));$APP.$cljs$core$reset_BANG_$$($group_errors_STAR_$$,$errors$jscomp$47$$);return $APP.$cljs$core$empty_QMARK_$$($errors$jscomp$47$$)?($APP.$cljs$core$reset_BANG_$$($current_group_STAR_$$,$value$jscomp$999$$),$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$group$$,$value$jscomp$999$$):$on_change_field$$($APP.$cljs$cst$1613$group$$,$value$jscomp$999$$)):$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$?
$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$group$$,""):$on_change_field$$($APP.$cljs$cst$1613$group$$,"")}),$on_update_name$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change_field$$),$APP.$rumext$v2$adapt$$($tokens_lib$jscomp$57$$),$APP.$rumext$v2$adapt$$($current_group$$)],function($event$jscomp$638_value$jscomp$1000$$){$event$jscomp$638_value$jscomp$1000$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$638_value$jscomp$1000$$));
var $errors$jscomp$48$$=$app$common$schema$validation_errors$$($event$jscomp$638_value$jscomp$1000$$,$APP.$app$common$files$tokens$make_token_theme_name_schema$$($tokens_lib$jscomp$57$$,$current_group$$,$APP.$app$common$types$tokens_lib$get_id$$($theme$jscomp$27$$)));$APP.$cljs$core$reset_BANG_$$($name_errors_STAR_$$,$errors$jscomp$48$$);$APP.$rumext$v2$set_ref_val_BANG_$$($theme_name_ref$$,$event$jscomp$638_value$jscomp$1000$$);return $APP.$cljs$core$empty_QMARK_$$($errors$jscomp$48$$)?($APP.$cljs$core$reset_BANG_$$($current_name_STAR_$$,
$event$jscomp$638_value$jscomp$1000$$),$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,$event$jscomp$638_value$jscomp$1000$$):$on_change_field$$($APP.$cljs$cst$725$name$$,$event$jscomp$638_value$jscomp$1000$$)):$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$?$on_change_field$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$725$name$$,""):$on_change_field$$($APP.$cljs$cst$725$name$$,"")});return(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_tokens_themes_create_modal__edit-theme-inputs-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__group-input-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$utilities$label$label_STAR_$$,{htmlFor:"groups-dropdown",isOptional:!0,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.label.group")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$controls$combobox$combobox_STAR_$$,
{id:"groups-dropdown",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.label.group-placeholder"),defaultSelected:$APP.$cljs$cst$1613$group$$.$cljs$core$IFn$_invoke$arity$1$($theme$jscomp$27$$),options:$APP.$cljs$core$clj__GT_js$$($options$jscomp$641_props_80640_theme_groups$$),hasError:$APP.$app$common$data$not_empty_QMARK_$$($group_errors$$),onChange:$on_update_group$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__group-input-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$controls$input$input_STAR_$$,{onChange:$on_update_name$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.label.theme-placeholder"),label:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.label.theme"),hintType:$APP.$cljs$core$empty_QMARK_$$($name_errors$$)?null:"error",hintMessage:$APP.$cljs$core$first$$($name_errors$$),maxLength:255,defaultValue:$APP.$rumext$v2$ref_val$$($theme_name_ref$$),
variant:"comfortable",autoFocus:!0})})]})};
$app$main$ui$workspace$tokens$themes$create_modal$theme_modal_buttons_STAR_$$=function($handle_key_down_cancel$jscomp$1_props_80641$$){var $disabled_QMARK_$jscomp$9$$=$handle_key_down_cancel$jscomp$1_props_80641$$["disabled?"],$close_modal$jscomp$2$$=$handle_key_down_cancel$jscomp$1_props_80641$$.closeModal,$on_save_form$$=$handle_key_down_cancel$jscomp$1_props_80641$$.onSaveForm;$handle_key_down_cancel$jscomp$1_props_80641$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($close_modal$jscomp$2$$)],function($event$jscomp$639$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$639$$))?
$close_modal$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$close_modal$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$639$$):$close_modal$jscomp$2$$($event$jscomp$639$$):null});var $handle_key_down_save$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_save_form$$)],function($event$jscomp$640$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$640$$))?$on_save_form$$.$cljs$core$IFn$_invoke$arity$1$?$on_save_form$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$640$$):
$on_save_form$$($event$jscomp$640$$):null});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",onClick:$close_modal$jscomp$2$$,onKeyDown:$handle_key_down_cancel$jscomp$1_props_80641$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.cancel")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",type:"submit",
onClick:$on_save_form$$,onKeyDown:$handle_key_down_save$jscomp$1$$,disabled:$disabled_QMARK_$jscomp$9$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.save-theme")})]})};
$app$main$ui$workspace$tokens$themes$create_modal$make_lib_with_theme$$=function($theme$jscomp$28$$,$sets$jscomp$23_tlib__$1$$){var $tlib$jscomp$2$$=$APP.$app$common$types$tokens_lib$make_tokens_lib$$().$app$common$types$tokens_lib$ITokenThemes$add_theme$arity$2$(null,$theme$jscomp$28$$);$sets$jscomp$23_tlib__$1$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$types$tokens_lib$add_set$$,$tlib$jscomp$2$$,$sets$jscomp$23_tlib__$1$$);return $APP.$app$common$types$tokens_lib$activate_theme$$($sets$jscomp$23_tlib__$1$$,
$APP.$app$common$types$tokens_lib$get_id$$($theme$jscomp$28$$))};
$app$main$ui$workspace$tokens$themes$create_modal$edit_create_theme_STAR_$$=function($is_editing$jscomp$6_props_80644$$){var $has_prev_view$$=$is_editing$jscomp$6_props_80644$$.hasPrevView,$change_view$jscomp$8$$=$is_editing$jscomp$6_props_80644$$.changeView,$on_save$jscomp$1$$=$is_editing$jscomp$6_props_80644$$.onSave,$disabled_QMARK_$jscomp$10_theme$jscomp$29$$=$is_editing$jscomp$6_props_80644$$.theme;$is_editing$jscomp$6_props_80644$$=$is_editing$jscomp$6_props_80644$$.isEditing;var $ordered_token_sets$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_ordered_token_sets$$),$tokens_lib$jscomp$58$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$tokens_lib$$),$token_sets$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_sets_tree$$),$current_theme_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_QMARK_$jscomp$10_theme$jscomp$29$$),$current_theme$$=$APP.$cljs$core$_deref$$($current_theme_STAR_$$),$lib$jscomp$19$$=$app$main$ui$workspace$tokens$themes$create_modal$make_lib_with_theme$$($current_theme$$,
$ordered_token_sets$$),$on_back$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_view$jscomp$8$$)],function(){return $change_view$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$change_view$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5938$themes_overview$$):$change_view$jscomp$8$$($cljs$cst$5938$themes_overview$$)});$disabled_QMARK_$jscomp$10_theme$jscomp$29$$=$APP.$cuerdas$core$empty_QMARK_$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($current_theme$$)));
var $on_change_field$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($field$jscomp$16$$,$value$jscomp$1001$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($current_theme_STAR_$$,function($p1__80642_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80642_SHARP_$$,$field$jscomp$16$$,$value$jscomp$1001$$)})}),$on_save_form$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$),
$APP.$rumext$v2$adapt$$($on_save$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_back$$)],function($e$jscomp$381_theme_SINGLEQUOTE_$jscomp$1$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$381_theme_SINGLEQUOTE_$jscomp$1$$);$e$jscomp$381_theme_SINGLEQUOTE_$jscomp$1$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($current_theme$$,$APP.$cljs$cst$725$name$$,$APP.$cuerdas$core$trim$$),
$APP.$cljs$cst$1613$group$$,$APP.$cuerdas$core$trim$$),$APP.$cljs$cst$936$description$$,$APP.$cuerdas$core$trim$$);$APP.$cuerdas$core$empty_QMARK_$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$381_theme_SINGLEQUOTE_$jscomp$1$$))||($on_save$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_save$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$381_theme_SINGLEQUOTE_$jscomp$1$$):$on_save$jscomp$1$$($e$jscomp$381_theme_SINGLEQUOTE_$jscomp$1$$));return $on_back$$.$cljs$core$IFn$_invoke$arity$0$?
$on_back$$.$cljs$core$IFn$_invoke$arity$0$():$on_back$$()}),$close_modal$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$382$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$382$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$hide$$())}),$on_delete_theme$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$),$APP.$rumext$v2$adapt$$($on_back$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$delete_token_theme$$($APP.$app$common$types$tokens_lib$get_id$$($current_theme$$)));
return $on_back$$.$cljs$core$IFn$_invoke$arity$0$?$on_back$$.$cljs$core$IFn$_invoke$arity$0$():$on_back$$()}),$token_set_group_active_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$)],function($group_path$jscomp$12$$){return $app$common$types$tokens_lib$sets_at_path_all_active_QMARK_$$($lib$jscomp$19$$,$group_path$jscomp$12$$)}),$token_set_active_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$)],
function($name$jscomp$503$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$cst$2116$sets$$.$cljs$core$IFn$_invoke$arity$1$($current_theme$$),$name$jscomp$503$$)}),$on_toggle_token_set$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$)],function($set_name$jscomp$31$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($current_theme_STAR_$$,function($p1__80643_SHARP_$$){return $APP.$app$common$types$tokens_lib$toggle_set$$($p1__80643_SHARP_$$,
$set_name$jscomp$31$$)})}),$on_toggle_token_set_group$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_theme$$),$APP.$rumext$v2$adapt$$($ordered_token_sets$$)],function($group_path$jscomp$13$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($current_theme_STAR_$$,function($theme_SINGLEQUOTE_$jscomp$2$$){var $lib_SINGLEQUOTE_$jscomp$4$$=$app$main$ui$workspace$tokens$themes$create_modal$make_lib_with_theme$$($theme_SINGLEQUOTE_$jscomp$2$$,
$ordered_token_sets$$);return $app$common$logic$tokens$toggle_token_set_group$$($group_path$jscomp$13$$,$lib_SINGLEQUOTE_$jscomp$4$$,$theme_SINGLEQUOTE_$jscomp$2$$)})}),$on_click_token_set$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_toggle_token_set$jscomp$1$$)],function($G__80645_set$jscomp$24_set_id$jscomp$45$$){$G__80645_set$jscomp$24_set_id$jscomp$45$$=$APP.$app$common$types$tokens_lib$get_set$$($lib$jscomp$19$$,$G__80645_set$jscomp$24_set_id$jscomp$45$$);
$G__80645_set$jscomp$24_set_id$jscomp$45$$=$APP.$app$common$types$tokens_lib$get_name$$($G__80645_set$jscomp$24_set_id$jscomp$45$$);return $on_toggle_token_set$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle_token_set$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80645_set$jscomp$24_set_id$jscomp$45$$):$on_toggle_token_set$jscomp$1$$($G__80645_set$jscomp$24_set_id$jscomp$45$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-wrapper",
children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"headline-medium",className:"main_ui_workspace_tokens_themes_create_modal__themes-modal-title",children:$APP.$cljs$core$truth_$$($is_editing$jscomp$6_props_80644$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.edit-theme-title"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.add-new-theme")}),(0,$APP.$rumext$v2$jsx$$)("form",
{onSubmit:$on_save_form$jscomp$1$$,className:"main_ui_workspace_tokens_themes_create_modal__edit-theme-form",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__edit-theme-wrapper",children:[$APP.$cljs$core$truth_$$($has_prev_view$$)?(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$on_back$$,type:"button",className:"main_ui_workspace_tokens_themes_create_modal__back-btn",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-left","aria-hidden":!0}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.back-to-themes")]}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$theme_inputs_STAR_$$,{theme:$current_theme$$,onChangeField:$on_change_field$jscomp$1$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"span",typography:"body-small",className:"main_ui_workspace_tokens_themes_create_modal__select-sets-message",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.set-selection-theme")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__sets-list-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sets$lists$controlled_sets_list_STAR_$$,{tokenSets:$token_sets$jscomp$4$$,origin:"theme-modal",onToggleTokenSet:$on_toggle_token_set$jscomp$1$$,tokensLib:$tokens_lib$jscomp$58$$,isTokenSetActive:$token_set_active_QMARK_$jscomp$2$$,
canEdit:!1,onToggleTokenSetGroup:$on_toggle_token_set_group$jscomp$1$$,onSelect:$on_click_token_set$$,isTokenSetGroupActive:$token_set_group_active_QMARK_$jscomp$1$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__edit-theme-footer",children:[$APP.$cljs$core$truth_$$($is_editing$jscomp$6_props_80644$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",type:"button",icon:"delete",onClick:$on_delete_theme$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.delete")}):
null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__button-footer",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$theme_modal_buttons_STAR_$$,{closeModal:$close_modal$jscomp$3$$,onSaveForm:$on_save_form$jscomp$1$$,"disabled?":$disabled_QMARK_$jscomp$10_theme$jscomp$29$$})})]})]})})]})};
$app$main$ui$workspace$tokens$themes$create_modal$has_prev_view$$=function($prev_view_type$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5938$themes_overview$$,null,$cljs$cst$5939$empty_themes$$,null],null),null),$prev_view_type$$)};
$app$main$ui$workspace$tokens$themes$create_modal$edit_theme$$=function($change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$){$change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$=$APP.$rumext$v2$util$wrap_props$$($change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$);$change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$=$APP.$cljs$core$__destructure_map$$($change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$);var $has_prev_view$jscomp$1_state$jscomp$1226$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$,$APP.$cljs$cst$769$state$$);$change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$,$cljs$cst$5934$change_view$$);var $map__80648__$1_on_save$jscomp$2_vec__80649$$=$APP.$cljs$core$__destructure_map$$($has_prev_view$jscomp$1_state$jscomp$1226$$);$map__80648__$1_on_save$jscomp$2_vec__80649$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80648__$1_on_save$jscomp$2_vec__80649$$,$cljs$cst$5937$theme_info$$);var $theme_id$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80648__$1_on_save$jscomp$2_vec__80649$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80648__$1_on_save$jscomp$2_vec__80649$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80648__$1_on_save$jscomp$2_vec__80649$$,2,null);var $theme$jscomp$30$$=
$APP.$rumext$v2$deref$$($app$main$refs$workspace_token_theme$$($theme_id$jscomp$10$$));$has_prev_view$jscomp$1_state$jscomp$1226$$=$app$main$ui$workspace$tokens$themes$create_modal$has_prev_view$$($cljs$cst$5940$prev_type$$.$cljs$core$IFn$_invoke$arity$1$($has_prev_view$jscomp$1_state$jscomp$1226$$));$map__80648__$1_on_save$jscomp$2_vec__80649$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($theme$jscomp$30$$)],function($theme_SINGLEQUOTE_$jscomp$3$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$update_token_theme$$($APP.$app$common$types$tokens_lib$get_id$$($theme$jscomp$30$$),
$theme_SINGLEQUOTE_$jscomp$3$$))});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$edit_create_theme_STAR_$$,{changeView:$change_view$jscomp$9_map__80647_map__80647__$1_props_80646$$,theme:$theme$jscomp$30$$,onSave:$map__80648__$1_on_save$jscomp$2_vec__80649$$,isEditing:!0,hasPrevView:$has_prev_view$jscomp$1_state$jscomp$1226$$})};
$app$main$ui$workspace$tokens$themes$create_modal$create_theme$$=function($has_prev_view$jscomp$2_map__80653_props_80652_state$jscomp$1227$$){$has_prev_view$jscomp$2_map__80653_props_80652_state$jscomp$1227$$=$APP.$rumext$v2$util$wrap_props$$($has_prev_view$jscomp$2_map__80653_props_80652_state$jscomp$1227$$);var $change_view$jscomp$10_map__80653__$1$$=$APP.$cljs$core$__destructure_map$$($has_prev_view$jscomp$2_map__80653_props_80652_state$jscomp$1227$$);$has_prev_view$jscomp$2_map__80653_props_80652_state$jscomp$1227$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_view$jscomp$10_map__80653__$1$$,$APP.$cljs$cst$769$state$$);$change_view$jscomp$10_map__80653__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($change_view$jscomp$10_map__80653__$1$$,$cljs$cst$5934$change_view$$);var $theme$jscomp$31$$=$APP.$app$common$types$tokens_lib$make_token_theme$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$725$name$$,""])),$on_save$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($theme__$1$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"create-tokens-theme"],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$library_edit$create_token_theme$$($theme__$1$$)]))});$has_prev_view$jscomp$2_map__80653_props_80652_state$jscomp$1227$$=
$app$main$ui$workspace$tokens$themes$create_modal$has_prev_view$$($cljs$cst$5940$prev_type$$.$cljs$core$IFn$_invoke$arity$1$($has_prev_view$jscomp$2_map__80653_props_80652_state$jscomp$1227$$));return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$edit_create_theme_STAR_$$,{changeView:$change_view$jscomp$10_map__80653__$1$$,theme:$theme$jscomp$31$$,onSave:$on_save$jscomp$3$$,hasPrevView:$has_prev_view$jscomp$2_map__80653_props_80652_state$jscomp$1227$$})};
$app$main$ui$workspace$tokens$themes$create_modal$themes_modal_body_STAR_$$=function(){var $themes$jscomp$20$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_token_themes_no_hidden$$),$state_STAR_$jscomp$25$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$empty_QMARK_$$($themes$jscomp$20$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5935$create_theme$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5938$themes_overview$$],null)}),$state$jscomp$1228$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$25$$),$change_view$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){function $G__80662$$($type$jscomp$711$$,$var_args$jscomp$1473$$){var $G__80663__i_p__80655$jscomp$1$$=null;if(arguments.length>1){$G__80663__i_p__80655$jscomp$1$$=0;for(var $G__80663__a$$=Array(arguments.length-1);$G__80663__i_p__80655$jscomp$1$$<$G__80663__a$$.length;)$G__80663__a$$[$G__80663__i_p__80655$jscomp$1$$]=
arguments[$G__80663__i_p__80655$jscomp$1$$+1],++$G__80663__i_p__80655$jscomp$1$$;$G__80663__i_p__80655$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__80663__a$$,0,null)}return $G__80662__delegate$$.call(this,$type$jscomp$711$$,$G__80663__i_p__80655$jscomp$1$$)}function $G__80662__delegate$$($type$jscomp$710$$,$map__80656__$1_p__80655$$){$map__80656__$1_p__80655$$=$APP.$cljs$core$__destructure_map$$($map__80656__$1_p__80655$$);var $theme_info$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80656__$1_p__80655$$,
$cljs$cst$5937$theme_info$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$25$$,function($G__80657__$1_current_state$$){$G__80657__$1_current_state$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__80657__$1_current_state$$,$APP.$cljs$cst$139$type$$,$type$jscomp$710$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5940$prev_type$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__80657__$1_current_state$$)]));
return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80657__$1_current_state$$,$cljs$cst$5937$theme_info$$,$theme_info$jscomp$1$$)})}$G__80662$$.$cljs$lang$maxFixedArity$=1;$G__80662$$.$cljs$lang$applyTo$=function($arglist__80664_p__80655$jscomp$2$$){var $type$jscomp$712$$=$APP.$cljs$core$first$$($arglist__80664_p__80655$jscomp$2$$);$arglist__80664_p__80655$jscomp$2$$=$APP.$cljs$core$rest$$($arglist__80664_p__80655$jscomp$2$$);return $G__80662__delegate$$($type$jscomp$712$$,$arglist__80664_p__80655$jscomp$2$$)};
$G__80662$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__80662__delegate$$;return $G__80662$$}()),$component$jscomp$135$$=function(){var $G__80658_G__80658__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$1228$$);$G__80658_G__80658__$1$$=$G__80658_G__80658__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__80658_G__80658__$1$$.$fqn$:null;switch($G__80658_G__80658__$1$$){case "empty-themes":return $app$main$ui$workspace$tokens$themes$create_modal$empty_themes$$;case "themes-overview":return $APP.$cljs$core$empty_QMARK_$$($themes$jscomp$20$$)?
$app$main$ui$workspace$tokens$themes$create_modal$empty_themes$$:$app$main$ui$workspace$tokens$themes$create_modal$themes_overview$$;case "edit-theme":return $app$main$ui$workspace$tokens$themes$create_modal$edit_theme$$;case "create-theme":return $app$main$ui$workspace$tokens$themes$create_modal$create_theme$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80658_G__80658__$1$$)].join(""));}}();return(0,$APP.$rumext$v2$jsx$$)($component$jscomp$135$$,
{state:$state$jscomp$1228$$,"change-view":$change_view$jscomp$11$$})};
$app$main$ui$workspace$tokens$themes$create_modal$token_themes_modal$$=function(){return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_tokens_themes_create_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"token-theme-update-create-modal",className:"main_ui_workspace_tokens_themes_create_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:"main_ui_workspace_tokens_themes_create_modal__close-btn",
onClick:$APP.$app$main$data$modal$hide_BANG_$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),variant:"action",icon:"close"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$themes$create_modal$themes_modal_body_STAR_$$,{})]})})};
$app$main$ui$flex_controls$common$flex_display_pill$$=function($map__80629_props_80624_x$jscomp$1264$$){$map__80629_props_80624_x$jscomp$1264$$=$APP.$rumext$v2$util$wrap_props$$($map__80629_props_80624_x$jscomp$1264$$);var $color$jscomp$190_map__80629__$1$$=$APP.$cljs$core$__destructure_map$$($map__80629_props_80624_x$jscomp$1264$$);$map__80629_props_80624_x$jscomp$1264$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$190_map__80629__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$485$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$190_map__80629__$1$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$211$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$190_map__80629__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$190_map__80629__$1$$,$APP.$cljs$cst$1527$height$$),$font_size$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$190_map__80629__$1$$,
$APP.$cljs$cst$1766$font_size$$),$border_radius$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$190_map__80629__$1$$,$APP.$cljs$cst$1998$border_radius$$),$value$jscomp$1002$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$190_map__80629__$1$$,$APP.$cljs$cst$260$value$$);$color$jscomp$190_map__80629__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$190_map__80629__$1$$,$APP.$cljs$cst$1303$color$$);return(0,$APP.$rumext$v2$jsxs$$)("g",
{className:"distance-pill",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__80629_props_80624_x$jscomp$1264$$,y:$y$jscomp$485$$,width:$width$jscomp$211$$,height:$height$jscomp$179$$,rx:$border_radius$jscomp$1$$,ry:$border_radius$jscomp$1$$,style:{fill:$color$jscomp$190_map__80629__$1$$}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$map__80629_props_80624_x$jscomp$1264$$+$width$jscomp$211$$/2,y:$y$jscomp$485$$+$height$jscomp$179$$/2,textAnchor:"middle",dominantBaseline:"central",style:{fill:"var(--app-white)",
fontSize:$font_size$jscomp$16$$},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$truth_$$($value$jscomp$1002$$)?$value$jscomp$1002$$:0)})]})};
$app$main$ui$workspace$viewport$viewport_ref$init_observer$$=function($node$jscomp$462$$){var $observer$jscomp$7$$=new ResizeObserver($app$main$ui$workspace$viewport$viewport_ref$on_change_bounds$$);$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$current_observer$$)!=null&&$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$current_observer$$).disconnect();$APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$viewport$viewport_ref$current_observer$$,$observer$jscomp$7$$);
return $node$jscomp$462$$!=null?$observer$jscomp$7$$.observe($node$jscomp$462$$):null};
$app$main$ui$workspace$viewport$viewport_ref$on_change_bounds$$=function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$))){var $brect_brect__$1$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$));$brect_brect__$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$257$left$$.$cljs$core$IFn$_invoke$arity$1$($brect_brect__$1$$)),$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1567$top$$.$cljs$core$IFn$_invoke$arity$1$($brect_brect__$1$$)));
return $APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$viewport$viewport_ref$viewport_brect$$,$brect_brect__$1$$)}return null};
$app$main$ui$workspace$viewport$viewport_ref$create_viewport_ref$$=function(){var $ref$jscomp$57$$=(0,$APP.$rumext$v2$use_ref$$)(null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ref$jscomp$57$$,$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return function($node$jscomp$463$$){$APP.$rumext$v2$set_ref_val_BANG_$$($ref$jscomp$57$$,$node$jscomp$463$$);$APP.$cljs$core$reset_BANG_$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$,
$node$jscomp$463$$);$node$jscomp$463$$!=null&&$APP.$goog$events$listen$$($node$jscomp$463$$,"mouseleave",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$BlurEvent$$(null,null,null))});return $app$main$ui$workspace$viewport$viewport_ref$init_observer$$($node$jscomp$463$$)}})],null)};
$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$=function($pt$jscomp$26$$){var $zoom$jscomp$70_zoom__$1$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),$APP.$cljs$cst$1937$workspace_local$$),$APP.$cljs$cst$2204$zoom$$,1);if($APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$)!=null&&$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_brect$$)!=
null){var $box_vbox$jscomp$40$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$).viewBox.baseVal,$brect$jscomp$1$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_brect$$);$box_vbox$jscomp$40$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($box_vbox$jscomp$40$$.x,$box_vbox$jscomp$40$$.y);$zoom$jscomp$70_zoom__$1$jscomp$1$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$70_zoom__$1$jscomp$1$$);
return $APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$divide$$($APP.$app$common$geom$point$subtract$$($pt$jscomp$26$$,$brect$jscomp$1$$),$zoom$jscomp$70_zoom__$1$jscomp$1$$),$box_vbox$jscomp$40$$)}return null};
$app$main$ui$flex_controls$gap$gap_display_STAR_$$=function($props_80661$$){var $on_change$jscomp$95$$=$props_80661$$.onChange,$zoom$jscomp$71$$=$props_80661$$.zoom,$on_pointer_leave$jscomp$7$$=$props_80661$$.onPointerLeave,$gap_type$$=$props_80661$$.gapType,$is_selected$jscomp$9$$=$props_80661$$.isSelected,$on_pointer_enter$jscomp$7$$=$props_80661$$.onPointerEnter,$mouse_pos$$=$props_80661$$.mousePos,$on_context_menu$jscomp$16$$=$props_80661$$.onContextMenu,$on_move_selected$$=$props_80661$$.onMoveSelected,
$hover_value$jscomp$1$$=$props_80661$$.hoverValue,$rect_data$$=$props_80661$$.rectData,$gap$jscomp$7$$=$props_80661$$.gap,$is_hover$$=$props_80661$$.isHover,$frame_id$jscomp$152$$=$props_80661$$.frameId,$resizing$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$start$jscomp$248$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$original_value$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$last_pos$jscomp$2$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$negate_QMARK_$jscomp$3$$=$cljs$cst$5941$resize_negate_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),$axis$jscomp$40$$=$cljs$cst$5942$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),$on_pointer_down$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$152$$),$APP.$rumext$v2$adapt$$($gap_type$$),$APP.$rumext$v2$adapt$$($gap$jscomp$7$$)],function($event$jscomp$641$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$641$$);
$APP.$cljs$core$reset_BANG_$$($resizing$$,$gap_type$$);$APP.$cljs$core$reset_BANG_$$($start$jscomp$248$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$641$$));return $APP.$cljs$core$reset_BANG_$$($original_value$$,$cljs$cst$5943$initial_value$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$))}),$calc_modifiers$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$152$$),$APP.$rumext$v2$adapt$$($gap_type$$),$APP.$rumext$v2$adapt$$($gap$jscomp$7$$)],
function($pos$jscomp$151$$){var $delta$jscomp$65$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__80666$$=$APP.$app$common$geom$point$to_vec$$($APP.$cljs$core$_deref$$($start$jscomp$248$$),$pos$jscomp$151$$);return $APP.$cljs$core$truth_$$($negate_QMARK_$jscomp$3$$)?$APP.$app$common$geom$point$negate$$($G__80666$$):$G__80666$$}(),$axis$jscomp$40$$),$val$jscomp$223$$=function(){var $x__5110__auto__$jscomp$145$$=$APP.$cljs$core$_deref$$($original_value$$)+$delta$jscomp$65$$/
$zoom$jscomp$71$$;return $x__5110__auto__$jscomp$145$$>0?$x__5110__auto__$jscomp$145$$:0}()|0,$layout_gap$jscomp$4$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($gap$jscomp$7$$,$gap_type$$,$val$jscomp$223$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val$jscomp$223$$,$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$152$$],
null),$APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1685$layout_gap$$,$layout_gap$jscomp$4$$))],null)}),$on_lost_pointer_capture$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$$)],function($G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$){$APP.$app$util$dom$release_pointer$$($G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$);
$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($resizing$$),$gap_type$$)&&($G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$=$APP.$cljs$core$_deref$$($last_pos$jscomp$2$$),$G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$=$calc_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$):
$calc_modifiers$$($G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$,0,null),$G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$,1,null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($G__80670$jscomp$inline_9221_event$jscomp$642_modifiers_80695_vec__80667_80693$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()])));$APP.$cljs$core$reset_BANG_$$($resizing$$,null);$APP.$cljs$core$reset_BANG_$$($start$jscomp$248$$,null);$APP.$cljs$core$reset_BANG_$$($original_value$$,0);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}),
$on_pointer_move$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$95$$)],function($event$jscomp$643_pos$jscomp$152_val$jscomp$224$$){$event$jscomp$643_pos$jscomp$152_val$jscomp$224$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$643_pos$jscomp$152_val$jscomp$224$$);$APP.$cljs$core$reset_BANG_$$($last_pos$jscomp$2$$,$event$jscomp$643_pos$jscomp$152_val$jscomp$224$$);$APP.$cljs$core$reset_BANG_$$($mouse_pos$$,
$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$643_pos$jscomp$152_val$jscomp$224$$));if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($resizing$$),$gap_type$$)){var $modifiers$jscomp$116_vec__80671$$=$calc_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$643_pos$jscomp$152_val$jscomp$224$$):$calc_modifiers$$($event$jscomp$643_pos$jscomp$152_val$jscomp$224$$);$event$jscomp$643_pos$jscomp$152_val$jscomp$224$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$116_vec__80671$$,0,null);$modifiers$jscomp$116_vec__80671$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$116_vec__80671$$,1,null);$APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$1$$,$event$jscomp$643_pos$jscomp$152_val$jscomp$224$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modifiers$jscomp$116_vec__80671$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modifiers$jscomp$116_vec__80671$$,!1,!1,null));return $APP.$cljs$core$truth_$$($on_change$jscomp$95$$)?$on_change$jscomp$95$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$95$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$116_vec__80671$$):$on_change$jscomp$95$$($modifiers$jscomp$116_vec__80671$$):null}return null});return(0,$APP.$rumext$v2$jsxs$$)("g",
{className:"gap-rect",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),className:"info-area",x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),onContextMenu:$on_context_menu$jscomp$16$$,style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$$)?$is_hover$$:$is_selected$jscomp$9$$)?"var(--color-accent-quaternary)":
"none",opacity:$APP.$cljs$core$truth_$$($is_selected$jscomp$9$$)?.5:.25},y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),onPointerMove:$on_pointer_move$jscomp$6$$,onPointerDown:$on_move_selected$$,onPointerLeave:$on_pointer_leave$jscomp$7$$,onPointerEnter:$on_pointer_enter$jscomp$7$$}),function(){var $handle_width$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$40$$,$APP.$cljs$cst$1515$x$$)?2/$zoom$jscomp$71$$:function(){var $x__5113__auto__$jscomp$80$$=
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)*.5,$y__5114__auto__$jscomp$80$$=20/$zoom$jscomp$71$$;return $x__5113__auto__$jscomp$80$$<$y__5114__auto__$jscomp$80$$?$x__5113__auto__$jscomp$80$$:$y__5114__auto__$jscomp$80$$}(),$handle_height$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$40$$,$APP.$cljs$cst$1516$y$$)?2/$zoom$jscomp$71$$:function(){var $x__5113__auto__$jscomp$81$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)*
.5,$y__5114__auto__$jscomp$81$$=30/$zoom$jscomp$71$$;return $x__5113__auto__$jscomp$81$$<$y__5114__auto__$jscomp$81$$?$x__5113__auto__$jscomp$81$$:$y__5114__auto__$jscomp$81$$}();return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$handle_width$$,height:$handle_height$$,className:"handle "+(($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$$)?$is_hover$$:$is_selected$jscomp$9$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5942$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$),
$APP.$cljs$cst$1515$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",0):$app$main$ui$css_cursors$get_dynamic$$("resize-ew",90):null)??""),x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)+($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)-$handle_width$$)/2,onContextMenu:$on_context_menu$jscomp$16$$,style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$$)?$is_hover$$:$is_selected$jscomp$9$$)?"var(--color-accent-quaternary)":"none",
opacity:$APP.$cljs$core$truth_$$($is_selected$jscomp$9$$)?0:1},onLostPointerCapture:$on_lost_pointer_capture$jscomp$5$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)+($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$$)-$handle_height$$)/2,onPointerMove:$on_pointer_move$jscomp$6$$,onPointerDown:$on_pointer_down$jscomp$7$$,onPointerLeave:$on_pointer_leave$jscomp$7$$,onPointerEnter:$on_pointer_enter$jscomp$7$$})}()]})};
$app$main$ui$flex_controls$gap$gap_rects_STAR_$$=function($pill_width_props_80680$$){function $create_rgdd_block$$($block$jscomp$9_y$jscomp$491$$){var $x$jscomp$1270$$=$APP.$cljs$core$truth_$$($flip_x$jscomp$9$$)?$x1$jscomp$40$$+$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$):$x1$jscomp$40$$+$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$);$block$jscomp$9_y$jscomp$491$$=$APP.$cljs$core$truth_$$($flip_y$jscomp$9$$)?$APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$9_y$jscomp$491$$)-
$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$):$APP.$cljs$cst$1531$y2$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$9_y$jscomp$491$$);var $w$jscomp$45$$=$width$jscomp$212$$-($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$)+$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$));return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,
$cljs$cst$5945$gap_type$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$block$jscomp$9_y$jscomp$491$$,$APP.$cljs$cst$1568$bottom$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($negate$$),$is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1687$column_gap$$:$APP.$cljs$cst$1686$row_gap$$,$w$jscomp$45$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$),$x$jscomp$1270$$,
$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$)])}function $create_rgdd$$($shape$jscomp$1048_y$jscomp$490$$){var $block$jscomp$8_w$jscomp$44$$=$get_container_block$$($shape$jscomp$1048_y$jscomp$490$$),$x$jscomp$1269$$=$APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$8_w$jscomp$44$$);$shape$jscomp$1048_y$jscomp$490$$=$APP.$cljs$core$truth_$$($flip_y$jscomp$9$$)?$APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1048_y$jscomp$490$$))-
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1048_y$jscomp$490$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1704$layout_item_margin$$,$APP.$cljs$cst$1707$m3$$],null))-$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$):$APP.$cljs$cst$1531$y2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1048_y$jscomp$490$$))+$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1048_y$jscomp$490$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1704$layout_item_margin$$,$APP.$cljs$cst$1707$m3$$],null));$block$jscomp$8_w$jscomp$44$$=$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$8_w$jscomp$44$$)-$APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$8_w$jscomp$44$$);return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,
$cljs$cst$5945$gap_type$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$shape$jscomp$1048_y$jscomp$490$$,$APP.$cljs$cst$1568$bottom$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($negate$$),$is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1686$row_gap$$:$APP.$cljs$cst$1687$column_gap$$,$block$jscomp$8_w$jscomp$44$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$),
$x$jscomp$1269$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1686$row_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$)])}function $create_cgdd_block$$($block$jscomp$7_x$jscomp$1268$$){$block$jscomp$7_x$jscomp$1268$$=$APP.$cljs$core$truth_$$($flip_x$jscomp$9$$)?$APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$7_x$jscomp$1268$$)-$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$):$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$7_x$jscomp$1268$$);
var $y$jscomp$489$$=$APP.$cljs$core$truth_$$($flip_y$jscomp$9$$)?$y1$jscomp$42$$+$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$):$y1$jscomp$42$$+$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$),$h$jscomp$186$$=$height$jscomp$180$$-($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$)+$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$11$$));return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,
$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$cljs$cst$5945$gap_type$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$y$jscomp$489$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($negate$$),$is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1687$column_gap$$:$APP.$cljs$cst$1686$row_gap$$,$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$),
$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$),$block$jscomp$7_x$jscomp$1268$$,$APP.$cljs$cst$1515$x$$,$h$jscomp$186$$])}function $create_cgdd$$($shape$jscomp$1047_x$jscomp$1267$$){var $block$jscomp$6_h$jscomp$185$$=$get_container_block$$($shape$jscomp$1047_x$jscomp$1267$$);$shape$jscomp$1047_x$jscomp$1267$$=$APP.$cljs$core$truth_$$($flip_x$jscomp$9$$)?$APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1047_x$jscomp$1267$$))-
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1047_x$jscomp$1267$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1704$layout_item_margin$$,$APP.$cljs$cst$1706$m2$$],null))-$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$):$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1047_x$jscomp$1267$$))+$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1047_x$jscomp$1267$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1704$layout_item_margin$$,$APP.$cljs$cst$1706$m2$$],null));var $y$jscomp$488$$=$APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$6_h$jscomp$185$$);$block$jscomp$6_h$jscomp$185$$=$APP.$cljs$cst$1531$y2$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$6_h$jscomp$185$$)-$APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($block$jscomp$6_h$jscomp$185$$);return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,
$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$cljs$cst$5945$gap_type$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$y$jscomp$488$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($negate$$),$is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1686$row_gap$$:$APP.$cljs$cst$1687$column_gap$$,$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$),
$APP.$cljs$cst$1687$column_gap$$.$cljs$core$IFn$_invoke$arity$1$($gap$jscomp$8$$),$shape$jscomp$1047_x$jscomp$1267$$,$APP.$cljs$cst$1515$x$$,$block$jscomp$6_h$jscomp$185$$])}function $get_container_block$$($selrect$jscomp$84_shape$jscomp$1046$$){$selrect$jscomp$84_shape$jscomp$1046$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$84_shape$jscomp$1046$$);var $x$jscomp$1266$$=($APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$84_shape$jscomp$1046$$)+
$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$84_shape$jscomp$1046$$))/2,$y$jscomp$487$$=($APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$84_shape$jscomp$1046$$)+$APP.$cljs$cst$1531$y2$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$84_shape$jscomp$1046$$))/2;return $APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80679_SHARP_$$){return $is_col_QMARK_$jscomp$2$$?$APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($p1__80679_SHARP_$$)<=
$x$jscomp$1266$$&&$x$jscomp$1266$$<=$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($p1__80679_SHARP_$$):$APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($p1__80679_SHARP_$$)<=$y$jscomp$487$$&&$y$jscomp$487$$<=$APP.$cljs$cst$1531$y2$$.$cljs$core$IFn$_invoke$arity$1$($p1__80679_SHARP_$$)},$wrap_blocks$$))}function $on_pointer_leave$jscomp$8$$(){return $APP.$cljs$core$reset_BANG_$$($hover$jscomp$2$$,null)}function $on_pointer_enter$jscomp$8$$($hover_type$$,$val$jscomp$225$$){$APP.$cljs$core$reset_BANG_$$($hover$jscomp$2$$,
$hover_type$$);return $APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$2$$,$val$jscomp$225$$)}var $zoom$jscomp$72$$=$pill_width_props_80680$$.zoom,$children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$=$pill_width_props_80680$$.frame,$on_context_menu$jscomp$17$$=$pill_width_props_80680$$.onContextMenu,$on_move_selected$jscomp$1$$=$pill_width_props_80680$$.onMoveSelected,$frame_id$jscomp$153$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$),
$display_blocks_saved_dir$jscomp$1$$=$APP.$cljs$cst$1684$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$),$is_col_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$display_blocks_saved_dir$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$column_reverse$$,$display_blocks_saved_dir$jscomp$1$$),$flip_x$jscomp$9$$=$APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$),
$flip_y$jscomp$9$$=$APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$);$pill_width_props_80680$$=40/$zoom$jscomp$72$$;var $pill_height$$=20/$zoom$jscomp$72$$,$workspace_modifiers$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$),$workspace_wasm_modifiers$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_modifiers$$),$gap_selected$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_gap_selected$$),
$hover$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_value$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$mouse_pos$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$current_modifiers$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$frame__$1$jscomp$7$$=$APP.$app$common$types$modifiers$apply_structure_modifiers$$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($current_modifiers$jscomp$1$$),$frame_id$jscomp$153$$),$APP.$cljs$cst$1816$modifiers$$)),$padding$jscomp$11$$=$APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$),$gap$jscomp$8$$=$APP.$cljs$cst$1685$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$);$children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$=
$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$);$children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$=$APP.$cljs$core$__destructure_map$$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$);var $width$jscomp$212$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$,$APP.$cljs$cst$290$width$$),$height$jscomp$180$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$,$APP.$cljs$cst$1527$height$$),$x1$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$,$APP.$cljs$cst$1528$x1$$),$y1$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$,
$APP.$cljs$cst$1529$y1$$),$on_change$jscomp$96$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifiers$jscomp$117$$){return $APP.$cljs$core$reset_BANG_$$($current_modifiers$jscomp$1$$,$modifiers$jscomp$117$$)}),$negate$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1687$column_gap$$,$APP.$cljs$core$truth_$$($flip_x$jscomp$9$$)?!0:!1,$APP.$cljs$cst$1686$row_gap$$,$APP.$cljs$core$truth_$$($flip_y$jscomp$9$$)?!0:!1],null),$objects$jscomp$816$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$)),
$children$jscomp$307$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$layout$position_absolute_QMARK_$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$816$$,$frame_id$jscomp$153$$)),$children_to_display$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1666$row_reverse$$,$display_blocks_saved_dir$jscomp$1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$column_reverse$$,
$display_blocks_saved_dir$jscomp$1$$)?$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($children$jscomp$307$$):$APP.$cljs$core$rest$$($children$jscomp$307$$);$children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?function(){var $modifiers$jscomp$118$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$workspace_wasm_modifiers$$);return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape$jscomp$1045$$){return $APP.$app$common$geom$shapes$apply_transform$$($shape$jscomp$1045$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$118$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1045$$)))},$children_to_display$$)}():$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80674_SHARP_$$){return $APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($p1__80674_SHARP_$$,
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($workspace_modifiers$jscomp$1$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80674_SHARP_$$),$APP.$cljs$cst$1816$modifiers$$],null)))},$children_to_display$$);var $wrap_blocks$$=function(){var $block_children_layout_data$jscomp$17$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80675_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__80675_SHARP_$$),$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$)),$p1__80675_SHARP_$$],null)},$children$jscomp$307$$),$bounds$jscomp$84$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$816$$),function($p1__80676_SHARP_$$){return $APP.$app$common$geom$shapes$shape__GT_points$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$816$$,
$p1__80676_SHARP_$$))});$block_children_layout_data$jscomp$17$$=$APP.$app$common$geom$shapes$flex_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($frame__$1$jscomp$7$$,$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$7$$),$block_children_layout_data$jscomp$17$$,$bounds$jscomp$84$$,$objects$jscomp$816$$);var $layout_bounds$jscomp$11$$=$APP.$cljs$cst$3719$layout_bounds$$.$cljs$core$IFn$_invoke$arity$1$($block_children_layout_data$jscomp$17$$);return function $app$main$ui$flex_controls$gap$gap_rects_STAR__$_iter__80682$$($s__80683$$){return new $APP.$cljs$core$LazySeq$$(null,
function(){for(;;){var $s__80683__$2_temp__5825__auto__$jscomp$427$$=$APP.$cljs$core$seq$$($s__80683$$);if($s__80683__$2_temp__5825__auto__$jscomp$427$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__80683__$2_temp__5825__auto__$jscomp$427$$)){var $c__5501__auto__$jscomp$57$$=$APP.$cljs$core$_chunked_first$$($s__80683__$2_temp__5825__auto__$jscomp$427$$),$size__5502__auto__$jscomp$57$$=$APP.$cljs$core$count$$($c__5501__auto__$jscomp$57$$),$b__80685$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$57$$);
return function(){for(var $i__80684$$=0;;)if($i__80684$$<$size__5502__auto__$jscomp$57$$){var $map__80686_map__80686__$1$$=$APP.$cljs$core$_nth$$($c__5501__auto__$jscomp$57$$,$i__80684$$);$map__80686_map__80686__$1$$=$APP.$cljs$core$__destructure_map$$($map__80686_map__80686__$1$$);var $start_p$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80686_map__80686__$1$$,$APP.$cljs$cst$3716$start_p$$),$line_width$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80686_map__80686__$1$$,
$APP.$cljs$cst$3865$line_width$$),$line_height$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80686_map__80686__$1$$,$APP.$cljs$cst$1771$line_height$$),$layout_gap_row$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80686_map__80686__$1$$,$APP.$cljs$cst$3867$layout_gap_row$$),$layout_gap_col$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80686_map__80686__$1$$,$APP.$cljs$cst$3868$layout_gap_col$$),$num_children$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80686_map__80686__$1$$,
$APP.$cljs$cst$3866$num_children$$);$APP.$cljs$core$chunk_append$$($b__80685$$,function(){var $line_height__$1$jscomp$7$$=$is_col_QMARK_$jscomp$2$$?$line_height$jscomp$23$$+($num_children$jscomp$7$$-1)*$layout_gap_col$jscomp$12$$:$line_height$jscomp$23$$,$end_p$jscomp$3$$=$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($start_p$jscomp$11$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$11$$,$is_col_QMARK_$jscomp$2$$?$line_width$jscomp$10$$:$line_width$jscomp$10$$+
($num_children$jscomp$7$$-1)*$layout_gap_row$jscomp$12$$)),$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$11$$,$line_height__$1$jscomp$7$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1528$x1$$,function(){var $x__5113__auto__$jscomp$82$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$11$$),$y__5114__auto__$jscomp$82$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$3$$);return $x__5113__auto__$jscomp$82$$<
$y__5114__auto__$jscomp$82$$?$x__5113__auto__$jscomp$82$$:$y__5114__auto__$jscomp$82$$}(),$APP.$cljs$cst$1529$y1$$,function(){var $x__5113__auto__$jscomp$83$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$11$$),$y__5114__auto__$jscomp$83$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$3$$);return $x__5113__auto__$jscomp$83$$<$y__5114__auto__$jscomp$83$$?$x__5113__auto__$jscomp$83$$:$y__5114__auto__$jscomp$83$$}(),$APP.$cljs$cst$1530$x2$$,function(){var $x__5110__auto__$jscomp$146$$=
$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$11$$),$y__5111__auto__$jscomp$146$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$3$$);return $x__5110__auto__$jscomp$146$$>$y__5111__auto__$jscomp$146$$?$x__5110__auto__$jscomp$146$$:$y__5111__auto__$jscomp$146$$}(),$APP.$cljs$cst$1531$y2$$,function(){var $x__5110__auto__$jscomp$147$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$11$$),$y__5111__auto__$jscomp$147$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$3$$);
return $x__5110__auto__$jscomp$147$$>$y__5111__auto__$jscomp$147$$?$x__5110__auto__$jscomp$147$$:$y__5111__auto__$jscomp$147$$}()],null)}());$i__80684$$+=1}else return!0}()?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80685$$),$app$main$ui$flex_controls$gap$gap_rects_STAR__$_iter__80682$$($APP.$cljs$core$_chunked_rest$$($s__80683__$2_temp__5825__auto__$jscomp$427$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__80685$$),null)}var $map__80687_map__80687__$1$$=$APP.$cljs$core$first$$($s__80683__$2_temp__5825__auto__$jscomp$427$$);
$map__80687_map__80687__$1$$=$APP.$cljs$core$__destructure_map$$($map__80687_map__80687__$1$$);var $start_p$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80687_map__80687__$1$$,$APP.$cljs$cst$3716$start_p$$),$line_width$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80687_map__80687__$1$$,$APP.$cljs$cst$3865$line_width$$),$line_height$jscomp$22$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80687_map__80687__$1$$,$APP.$cljs$cst$1771$line_height$$),
$layout_gap_row$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80687_map__80687__$1$$,$APP.$cljs$cst$3867$layout_gap_row$$),$layout_gap_col$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80687_map__80687__$1$$,$APP.$cljs$cst$3868$layout_gap_col$$),$num_children$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80687_map__80687__$1$$,$APP.$cljs$cst$3866$num_children$$);return $APP.$cljs$core$cons$$(function(){var $line_height__$1$jscomp$8$$=
$is_col_QMARK_$jscomp$2$$?$line_height$jscomp$22$$+($num_children$jscomp$6$$-1)*$layout_gap_col$jscomp$11$$:$line_height$jscomp$22$$,$end_p$jscomp$4$$=$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($start_p$jscomp$10$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$11$$,$is_col_QMARK_$jscomp$2$$?$line_width$jscomp$9$$:$line_width$jscomp$9$$+($num_children$jscomp$6$$-1)*$layout_gap_row$jscomp$11$$)),$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$11$$,
$line_height__$1$jscomp$8$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1528$x1$$,function(){var $x__5113__auto__$jscomp$84$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$10$$),$y__5114__auto__$jscomp$84$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$4$$);return $x__5113__auto__$jscomp$84$$<$y__5114__auto__$jscomp$84$$?$x__5113__auto__$jscomp$84$$:$y__5114__auto__$jscomp$84$$}(),$APP.$cljs$cst$1529$y1$$,function(){var $x__5113__auto__$jscomp$85$$=
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$10$$),$y__5114__auto__$jscomp$85$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$4$$);return $x__5113__auto__$jscomp$85$$<$y__5114__auto__$jscomp$85$$?$x__5113__auto__$jscomp$85$$:$y__5114__auto__$jscomp$85$$}(),$APP.$cljs$cst$1530$x2$$,function(){var $x__5110__auto__$jscomp$148$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$10$$),$y__5111__auto__$jscomp$148$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$4$$);
return $x__5110__auto__$jscomp$148$$>$y__5111__auto__$jscomp$148$$?$x__5110__auto__$jscomp$148$$:$y__5111__auto__$jscomp$148$$}(),$APP.$cljs$cst$1531$y2$$,function(){var $x__5110__auto__$jscomp$149$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($start_p$jscomp$10$$),$y__5111__auto__$jscomp$149$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$4$$);return $x__5110__auto__$jscomp$149$$>$y__5111__auto__$jscomp$149$$?$x__5110__auto__$jscomp$149$$:$y__5111__auto__$jscomp$149$$}()],
null)}(),$app$main$ui$flex_controls$gap$gap_rects_STAR__$_iter__80682$$($APP.$cljs$core$rest$$($s__80683__$2_temp__5825__auto__$jscomp$427$$)))}return null}},null,null)}($APP.$cljs$cst$3075$layout_lines$$.$cljs$core$IFn$_invoke$arity$1$($block_children_layout_data$jscomp$17$$))}();$display_blocks_saved_dir$jscomp$1$$=$is_col_QMARK_$jscomp$2$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($create_cgdd_block$$,$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($wrap_blocks$$)):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($create_rgdd_block$$,
$APP.$cljs$core$drop_last$cljs$0core$0IFn$0_invoke$0arity$01$$($wrap_blocks$$));$children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$=$is_col_QMARK_$jscomp$2$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($create_rgdd$$,$children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$):$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($create_cgdd$$,$children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$);
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"gaps",pointerEvents:"visible",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$208$$,$JSCompiler_temp_const$jscomp$1895_p__80688$$){var $JSCompiler_inline_result$jscomp$1897_index$jscomp$563$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1895_p__80688$$,0,null),$display_item$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1895_p__80688$$,
1,null);$JSCompiler_temp_const$jscomp$1895_p__80688$$=$out_arr__44092__auto__$jscomp$208$$.push;var $gap_type$jscomp$inline_9227$$=$cljs$cst$5945$gap_type$$.$cljs$core$IFn$_invoke$arity$1$($display_item$$);$JSCompiler_inline_result$jscomp$1897_index$jscomp$563$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$gap$gap_display_STAR_$$,{hoverValue:$hover_value$jscomp$2$$,gap:$gap$jscomp$8$$,isHover:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$2$$),
$gap_type$jscomp$inline_9227$$),onChange:$on_change$jscomp$96$$,zoom:$zoom$jscomp$72$$,onContextMenu:$on_context_menu$jscomp$17$$,frameId:$frame_id$jscomp$153$$,gapType:$gap_type$jscomp$inline_9227$$,isSelected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($gap_selected$jscomp$2$$,$gap_type$jscomp$inline_9227$$),onMoveSelected:$on_move_selected$jscomp$1$$,onPointerLeave:$on_pointer_leave$jscomp$8$$,rectData:$display_item$$,onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_pointer_enter$jscomp$8$$,
$gap_type$jscomp$inline_9227$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gap$jscomp$8$$,$gap_type$jscomp$inline_9227$$)),mousePos:$mouse_pos$jscomp$1$$},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$153$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1897_index$jscomp$563$$)].join(""));$JSCompiler_temp_const$jscomp$1895_p__80688$$.call($out_arr__44092__auto__$jscomp$208$$,$JSCompiler_inline_result$jscomp$1897_index$jscomp$563$$);
return $out_arr__44092__auto__$jscomp$208$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($display_blocks_saved_dir$jscomp$1$$,$children_to_display__$1_display_children_frame$jscomp$77_map__80681_map__80681__$1$$))),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover$jscomp$2$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$common$flex_display_pill$$,{height:$pill_height$$,width:$pill_width_props_80680$$,
"font-size":11/$zoom$jscomp$72$$,"border-radius":4/$zoom$jscomp$72$$,color:"var(--color-accent-quaternary)",x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$1$$)),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$1$$))-$pill_width_props_80680$$,value:$APP.$cljs$core$_deref$$($hover_value$jscomp$2$$)}):null]})};
$app$main$ui$flex_controls$gap$gap_control_STAR_$$=function($on_move_selected$jscomp$2_props_80692$$){var $zoom$jscomp$73$$=$on_move_selected$jscomp$2_props_80692$$.zoom,$frame$jscomp$78$$=$on_move_selected$jscomp$2_props_80692$$.frame,$on_context_menu$jscomp$18$$=$on_move_selected$jscomp$2_props_80692$$.onContextMenu;$on_move_selected$jscomp$2_props_80692$$=$on_move_selected$jscomp$2_props_80692$$.onMoveSelected;return $APP.$cljs$core$truth_$$($frame$jscomp$78$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"measurement-gaps",
pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)("g",{className:"hover-shapes",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$gap$gap_rects_STAR_$$,{frame:$frame$jscomp$78$$,zoom:$zoom$jscomp$73$$,onMoveSelected:$on_move_selected$jscomp$2_props_80692$$,onContextMenu:$on_context_menu$jscomp$18$$})})}):null};
$app$main$ui$flex_controls$margin$margin_display_STAR_$$=function($is_hover$jscomp$1_props_80696$$){var $on_change$jscomp$97$$=$is_hover$jscomp$1_props_80696$$.onChange,$margin$jscomp$6$$=$is_hover$jscomp$1_props_80696$$.margin,$zoom$jscomp$74$$=$is_hover$jscomp$1_props_80696$$.zoom,$is_hover_h$$=$is_hover$jscomp$1_props_80696$$.isHoverH,$on_pointer_leave$jscomp$9$$=$is_hover$jscomp$1_props_80696$$.onPointerLeave,$margin_num$$=$is_hover$jscomp$1_props_80696$$.marginNum,$is_selected$jscomp$10$$=$is_hover$jscomp$1_props_80696$$.isSelected,
$on_pointer_enter$jscomp$9$$=$is_hover$jscomp$1_props_80696$$.onPointerEnter,$mouse_pos$jscomp$2$$=$is_hover$jscomp$1_props_80696$$.mousePos,$is_hover_all$$=$is_hover$jscomp$1_props_80696$$.isHoverAll,$is_hover_v$$=$is_hover$jscomp$1_props_80696$$.isHoverV,$shape_id$jscomp$168$$=$is_hover$jscomp$1_props_80696$$.shapeId,$hover_value$jscomp$3$$=$is_hover$jscomp$1_props_80696$$.hoverValue,$rect_data$jscomp$1$$=$is_hover$jscomp$1_props_80696$$.rectData;$is_hover$jscomp$1_props_80696$$=$is_hover$jscomp$1_props_80696$$.isHover;
var $resizing_QMARK_$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$start$jscomp$249$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$original_value$jscomp$1$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$last_pos$jscomp$3$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$negate_QMARK_$jscomp$4$$=$cljs$cst$5941$resize_negate_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$)===!0,$axis$jscomp$41$$=$cljs$cst$5942$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$),
$on_pointer_down$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$168$$),$APP.$rumext$v2$adapt$$($margin_num$$),$APP.$rumext$v2$adapt$$($margin$jscomp$6$$)],function($event$jscomp$644$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$644$$);$APP.$cljs$core$reset_BANG_$$($resizing_QMARK_$$,!0);$APP.$cljs$core$reset_BANG_$$($start$jscomp$249$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$644$$));return $APP.$cljs$core$reset_BANG_$$($original_value$jscomp$1$$,
$cljs$cst$5943$initial_value$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$))}),$calc_modifiers$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$168$$),$APP.$rumext$v2$adapt$$($margin_num$$),$APP.$rumext$v2$adapt$$($margin$jscomp$6$$),$APP.$rumext$v2$adapt$$($is_hover_all$$),$APP.$rumext$v2$adapt$$($is_hover_v$$),$APP.$rumext$v2$adapt$$($is_hover_h$$)],function($pos$jscomp$153$$){var $delta$jscomp$66$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__80697$$=
$APP.$app$common$geom$point$to_vec$$($APP.$cljs$core$_deref$$($start$jscomp$249$$),$pos$jscomp$153$$);return $negate_QMARK_$jscomp$4$$?$APP.$app$common$geom$point$negate$$($G__80697$$):$G__80697$$}(),$axis$jscomp$41$$),$val$jscomp$226$$=function(){var $x__5110__auto__$jscomp$150$$=$APP.$cljs$core$_deref$$($original_value$jscomp$1$$)+$delta$jscomp$66$$/$zoom$jscomp$74$$;return $x__5110__auto__$jscomp$150$$>0?$x__5110__auto__$jscomp$150$$:0}()|0,$layout_item_margin$jscomp$6$$=$APP.$cljs$core$truth_$$($is_hover_all$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($margin$jscomp$6$$,$APP.$cljs$cst$1705$m1$$,$val$jscomp$226$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1706$m2$$,$val$jscomp$226$$,$APP.$cljs$cst$1707$m3$$,$val$jscomp$226$$,$APP.$cljs$cst$1708$m4$$,$val$jscomp$226$$])):$APP.$cljs$core$truth_$$($is_hover_v$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($margin$jscomp$6$$,$APP.$cljs$cst$1705$m1$$,$val$jscomp$226$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1707$m3$$,
$val$jscomp$226$$])):$APP.$cljs$core$truth_$$($is_hover_h$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($margin$jscomp$6$$,$APP.$cljs$cst$1706$m2$$,$val$jscomp$226$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1708$m4$$,$val$jscomp$226$$])):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($margin$jscomp$6$$,$margin_num$$,$val$jscomp$226$$),$layout_item_margin_type$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$6$$),
$APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$6$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$6$$),$APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$6$$)]))?$APP.$cljs$cst$1668$simple$$:$APP.$cljs$cst$1621$multiple$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val$jscomp$226$$,$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$168$$],null),$APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1704$layout_item_margin$$,$layout_item_margin$jscomp$6$$),$APP.$cljs$cst$1703$layout_item_margin_type$$,$layout_item_margin_type$jscomp$2$$))],null)}),$on_lost_pointer_capture$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$jscomp$1$$)],
function($G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$){$APP.$app$util$dom$release_pointer$$($G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&($G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$=$APP.$cljs$core$_deref$$($last_pos$jscomp$3$$),$G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$=
$calc_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$):$calc_modifiers$jscomp$1$$($G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$,0,null),$G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$,1,null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($G__80701$jscomp$inline_9229_event$jscomp$645_modifiers_80715_vec__80698_80713$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()])));$APP.$cljs$core$reset_BANG_$$($resizing_QMARK_$$,
!1);$APP.$cljs$core$reset_BANG_$$($start$jscomp$249$$,null);$APP.$cljs$core$reset_BANG_$$($original_value$jscomp$1$$,0);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}),$on_pointer_move$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$jscomp$1$$),
$APP.$rumext$v2$adapt$$($on_change$jscomp$97$$)],function($event$jscomp$646_pos$jscomp$154_val$jscomp$227$$){$event$jscomp$646_pos$jscomp$154_val$jscomp$227$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$646_pos$jscomp$154_val$jscomp$227$$);$APP.$cljs$core$reset_BANG_$$($mouse_pos$jscomp$2$$,$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$646_pos$jscomp$154_val$jscomp$227$$));$APP.$cljs$core$reset_BANG_$$($last_pos$jscomp$3$$,$event$jscomp$646_pos$jscomp$154_val$jscomp$227$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($resizing_QMARK_$$))){var $modifiers$jscomp$119_vec__80702$$=$calc_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$646_pos$jscomp$154_val$jscomp$227$$):$calc_modifiers$jscomp$1$$($event$jscomp$646_pos$jscomp$154_val$jscomp$227$$);$event$jscomp$646_pos$jscomp$154_val$jscomp$227$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$119_vec__80702$$,
0,null);$modifiers$jscomp$119_vec__80702$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$119_vec__80702$$,1,null);$APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$3$$,$event$jscomp$646_pos$jscomp$154_val$jscomp$227$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modifiers$jscomp$119_vec__80702$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modifiers$jscomp$119_vec__80702$$,!1,!1,null));return $APP.$cljs$core$truth_$$($on_change$jscomp$97$$)?$on_change$jscomp$97$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$97$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$119_vec__80702$$):$on_change$jscomp$97$$($modifiers$jscomp$119_vec__80702$$):null}return null});return(0,$APP.$rumext$v2$jsx$$)("rect",
{width:function(){var $y__5111__auto__$jscomp$151$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$);return 0>$y__5111__auto__$jscomp$151$$?0:$y__5111__auto__$jscomp$151$$}(),height:function(){var $y__5111__auto__$jscomp$152$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$);return 0>$y__5111__auto__$jscomp$152$$?0:$y__5111__auto__$jscomp$152$$}(),className:"margin-rect "+(($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$1_props_80696$$)?
$is_hover$jscomp$1_props_80696$$:$is_selected$jscomp$10$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5942$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$),$APP.$cljs$cst$1515$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",0):$app$main$ui$css_cursors$get_dynamic$$("resize-ew",90):null)??""),x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$),style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$1_props_80696$$)?
$is_hover$jscomp$1_props_80696$$:$is_selected$jscomp$10$$)?"var(--status-color-warning-500)":"none",opacity:$APP.$cljs$core$truth_$$($is_selected$jscomp$10$$)?.5:.25},onLostPointerCapture:$on_lost_pointer_capture$jscomp$6$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$1$$),onPointerMove:$on_pointer_move$jscomp$7$$,onPointerDown:$on_pointer_down$jscomp$8$$,onPointerLeave:$on_pointer_leave$jscomp$9$$,onPointerEnter:$on_pointer_enter$jscomp$9$$})};
$app$main$ui$flex_controls$margin$margin_rects_STAR_$$=function($pill_width$jscomp$1_props_80705$$){function $hover_QMARK_$jscomp$8$$($value$jscomp$1003$$){if($APP.$cljs$core$truth_$$($hover_all_QMARK_$$))return $hover_all_QMARK_$$;var $or__5025__auto____$1$jscomp$145_or__5025__auto____$2$jscomp$33$$=function(){var $and__5023__auto__$jscomp$940$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1003$$,$APP.$cljs$cst$1705$m1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1003$$,
$APP.$cljs$cst$1707$m3$$);return $and__5023__auto__$jscomp$940$$?$hover_v_QMARK_$$:$and__5023__auto__$jscomp$940$$}();if($APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$145_or__5025__auto____$2$jscomp$33$$))return $or__5025__auto____$1$jscomp$145_or__5025__auto____$2$jscomp$33$$;$or__5025__auto____$1$jscomp$145_or__5025__auto____$2$jscomp$33$$=function(){var $and__5023__auto__$jscomp$941$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1003$$,$APP.$cljs$cst$1706$m2$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1003$$,$APP.$cljs$cst$1708$m4$$);return $and__5023__auto__$jscomp$941$$?$hover_h_QMARK_$$:$and__5023__auto__$jscomp$941$$}();return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$145_or__5025__auto____$2$jscomp$33$$)?$or__5025__auto____$1$jscomp$145_or__5025__auto____$2$jscomp$33$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$value$jscomp$1003$$)}var $is_shift$$=$pill_width$jscomp$1_props_80705$$.isShift,
$zoom$jscomp$75$$=$pill_width$jscomp$1_props_80705$$.zoom,$frame$jscomp$79_margin_display_data$$=$pill_width$jscomp$1_props_80705$$.frame,$is_alt$$=$pill_width$jscomp$1_props_80705$$.isAlt,$map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$=$pill_width$jscomp$1_props_80705$$.shape,$shape_id$jscomp$169$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$);$pill_width$jscomp$1_props_80705$$=40/$zoom$jscomp$75$$;
var $pill_height$jscomp$1$$=20/$zoom$jscomp$75$$,$margins_selected$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_margins_selected$$),$current_modifiers$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$=$APP.$app$common$types$modifiers$apply_structure_modifiers$$($map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($current_modifiers$jscomp$2$$),
$shape_id$jscomp$169$$),$APP.$cljs$cst$1816$modifiers$$));var $hover_value$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$mouse_pos$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_all_QMARK_$$=function(){var $and__5023__auto__$jscomp$937$$=$APP.$cljs$core$_deref$$($hover$jscomp$3$$)!=null;return $and__5023__auto__$jscomp$937$$?$is_alt$$:$and__5023__auto__$jscomp$937$$}(),
$hover_v_QMARK_$$=function(){var $and__5023__auto__$jscomp$938$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$APP.$cljs$cst$1705$m1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$APP.$cljs$cst$1707$m3$$);return $and__5023__auto__$jscomp$938$$?$is_shift$$:$and__5023__auto__$jscomp$938$$}(),$hover_h_QMARK_$$=function(){var $and__5023__auto__$jscomp$939$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),
$APP.$cljs$cst$1706$m2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$3$$),$APP.$cljs$cst$1708$m4$$);return $and__5023__auto__$jscomp$939$$?$is_shift$$:$and__5023__auto__$jscomp$939$$}(),$margin$jscomp$7$$=$APP.$cljs$cst$1704$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$);$map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$);
var $map__80707__$1_y2$jscomp$40$$=$APP.$cljs$core$__destructure_map$$($map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$);$map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80707__$1_y2$jscomp$40$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80707__$1_y2$jscomp$40$$,$APP.$cljs$cst$1527$height$$),$x1$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80707__$1_y2$jscomp$40$$,
$APP.$cljs$cst$1528$x1$$),$x2$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80707__$1_y2$jscomp$40$$,$APP.$cljs$cst$1530$x2$$),$y1$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80707__$1_y2$jscomp$40$$,$APP.$cljs$cst$1529$y1$$);$map__80707__$1_y2$jscomp$40$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80707__$1_y2$jscomp$40$$,$APP.$cljs$cst$1531$y2$$);var $on_pointer_enter$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($hover_type$jscomp$1$$,
$val$jscomp$228$$){$APP.$cljs$core$reset_BANG_$$($hover$jscomp$3$$,$hover_type$jscomp$1$$);return $APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$4$$,$val$jscomp$228$$)}),$on_pointer_leave$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($hover$jscomp$3$$,null)}),$on_change$jscomp$98$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifiers$jscomp$120$$){return $APP.$cljs$core$reset_BANG_$$($current_modifiers$jscomp$2$$,
$modifiers$jscomp$120$$)});$frame$jscomp$79_margin_display_data$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1705$m1$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$79_margin_display_data$$))?
$map__80707__$1_y2$jscomp$40$$:$y1$jscomp$43$$-$APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$cst$1567$top$$,$APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$79_margin_display_data$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$169$$),"-m1"].join(""),$map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$,$APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$x1$jscomp$41$$,
$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1705$m1$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$)]),$APP.$cljs$cst$1706$m2$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$y1$jscomp$43$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$79_margin_display_data$$),
[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$169$$),"-m2"].join(""),$APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$79_margin_display_data$$))?$x1$jscomp$41$$-$APP.$cljs$cst$1706$m2$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$):$x2$jscomp$38$$,$APP.$cljs$cst$1515$x$$,
$height$jscomp$181$$]),$APP.$cljs$cst$1707$m3$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$79_margin_display_data$$))?$y1$jscomp$43$$-$APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$):
$map__80707__$1_y2$jscomp$40$$,$APP.$cljs$cst$1567$top$$,$APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$79_margin_display_data$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$169$$),"-m3"].join(""),$map__80707_shape$jscomp$1049_shape__$1$jscomp$110_width$jscomp$213$$,$APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$x1$jscomp$41$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1707$m3$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$)]),
$APP.$cljs$cst$1708$m4$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$y1$jscomp$43$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$79_margin_display_data$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$169$$),
"-m4"].join(""),$APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$79_margin_display_data$$))?$x2$jscomp$38$$:$x1$jscomp$41$$-$APP.$cljs$cst$1708$m4$$.$cljs$core$IFn$_invoke$arity$1$($margin$jscomp$7$$),$APP.$cljs$cst$1515$x$$,$height$jscomp$181$$])],null);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"margins",
pointerEvents:"visible",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$209$$,$p__80708_rect_data$jscomp$2$$){var $margin_num$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80708_rect_data$jscomp$2$$,0,null);$p__80708_rect_data$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80708_rect_data$jscomp$2$$,1,null);$out_arr__44092__auto__$jscomp$209$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$margin$margin_display_STAR_$$,
{hoverValue:$hover_value$jscomp$4$$,isHover:$hover_QMARK_$jscomp$8$$($margin_num$jscomp$1$$),onChange:$on_change$jscomp$98$$,margin:$margin$jscomp$7$$,shapeId:$shape_id$jscomp$169$$,zoom:$zoom$jscomp$75$$,marginNum:$margin_num$jscomp$1$$,isHoverH:$hover_h_QMARK_$$,isHoverAll:$hover_all_QMARK_$$,isSelected:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margins_selected$jscomp$2$$,$margin_num$jscomp$1$$),onPointerLeave:$on_pointer_leave$jscomp$10$$,rectData:$p__80708_rect_data$jscomp$2$$,onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_pointer_enter$jscomp$10$$,
$margin_num$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($margin$jscomp$7$$,$margin_num$jscomp$1$$)),isHoverV:$hover_v_QMARK_$$,mousePos:$mouse_pos$jscomp$3$$},$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($p__80708_rect_data$jscomp$2$$)));return $out_arr__44092__auto__$jscomp$209$$},[],$frame$jscomp$79_margin_display_data$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover$jscomp$3$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$common$flex_display_pill$$,
{height:$pill_height$jscomp$1$$,width:$pill_width$jscomp$1_props_80705$$,"font-size":11/$zoom$jscomp$75$$,"border-radius":4/$zoom$jscomp$75$$,color:"var(--status-color-warning-500)",x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$3$$)),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$3$$))-$pill_width$jscomp$1_props_80705$$,value:$APP.$cljs$core$_deref$$($hover_value$jscomp$4$$)}):null]})};
$app$main$ui$flex_controls$margin$margin_control_STAR_$$=function($props_80712_shape$jscomp$1050$$){var $is_shift$jscomp$1$$=$props_80712_shape$jscomp$1050$$.isShift,$zoom$jscomp$76$$=$props_80712_shape$jscomp$1050$$.zoom,$parent$jscomp$301$$=$props_80712_shape$jscomp$1050$$.parent,$is_alt$jscomp$1$$=$props_80712_shape$jscomp$1050$$.isAlt;$props_80712_shape$jscomp$1050$$=$props_80712_shape$jscomp$1050$$.shape;return $APP.$cljs$core$truth_$$($props_80712_shape$jscomp$1050$$)?(0,$APP.$rumext$v2$jsx$$)("g",
{className:"measurement-gaps",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)("g",{className:"hover-shapes",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$margin$margin_rects_STAR_$$,{shape:$props_80712_shape$jscomp$1050$$,frame:$parent$jscomp$301$$,zoom:$zoom$jscomp$76$$,isAlt:$is_alt$jscomp$1$$,isShift:$is_shift$jscomp$1$$})})}):null};
$app$main$ui$flex_controls$padding$padding_display_STAR_$$=function($props_80716$$){var $on_change$jscomp$99$$=$props_80716$$.onChange,$zoom$jscomp$77$$=$props_80716$$.zoom,$is_hover_h$jscomp$1$$=$props_80716$$.isHoverH,$on_pointer_leave$jscomp$11$$=$props_80716$$.onPointerLeave,$is_selected$jscomp$11$$=$props_80716$$.isSelected,$on_pointer_enter$jscomp$11$$=$props_80716$$.onPointerEnter,$mouse_pos$jscomp$4$$=$props_80716$$.mousePos,$is_hover_all$jscomp$1$$=$props_80716$$.isHoverAll,$padding_num$$=
$props_80716$$.paddingNum,$is_hover_v$jscomp$1$$=$props_80716$$.isHoverV,$on_context_menu$jscomp$19$$=$props_80716$$.onContextMenu,$on_move_selected$jscomp$3$$=$props_80716$$.onMoveSelected,$hover_value$jscomp$5$$=$props_80716$$.hoverValue,$padding$jscomp$12$$=$props_80716$$.padding,$rect_data$jscomp$3$$=$props_80716$$.rectData,$is_hover$jscomp$2$$=$props_80716$$.isHover,$frame_id$jscomp$154$$=$props_80716$$.frameId,$resizing_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$start$jscomp$250$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$original_value$jscomp$2$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$last_pos$jscomp$4$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$negate_QMARK_$jscomp$5$$=$cljs$cst$5941$resize_negate_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)===!0,$axis$jscomp$42$$=$cljs$cst$5942$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$),$on_pointer_down$jscomp$9$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$154$$),$APP.$rumext$v2$adapt$$($rect_data$jscomp$3$$),$APP.$rumext$v2$adapt$$($padding_num$$)],function($event$jscomp$647$$){$APP.$app$util$dom$capture_pointer$$($event$jscomp$647$$);$APP.$cljs$core$reset_BANG_$$($resizing_QMARK_$jscomp$1$$,!0);$APP.$cljs$core$reset_BANG_$$($start$jscomp$250$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$647$$));return $APP.$cljs$core$reset_BANG_$$($original_value$jscomp$2$$,
$cljs$cst$5943$initial_value$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$))}),$calc_modifiers$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$154$$),$APP.$rumext$v2$adapt$$($padding_num$$),$APP.$rumext$v2$adapt$$($padding$jscomp$12$$),$APP.$rumext$v2$adapt$$($is_hover_all$jscomp$1$$),$APP.$rumext$v2$adapt$$($is_hover_v$jscomp$1$$),$APP.$rumext$v2$adapt$$($is_hover_h$jscomp$1$$)],function($pos$jscomp$155$$){var $delta$jscomp$67$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$(function(){var $G__80717$$=$APP.$app$common$geom$point$to_vec$$($APP.$cljs$core$_deref$$($start$jscomp$250$$),$pos$jscomp$155$$);return $negate_QMARK_$jscomp$5$$?$APP.$app$common$geom$point$negate$$($G__80717$$):$G__80717$$}(),$axis$jscomp$42$$),$val$jscomp$229$$=function(){var $x__5110__auto__$jscomp$153$$=$APP.$cljs$core$_deref$$($original_value$jscomp$2$$)+$delta$jscomp$67$$/$zoom$jscomp$77$$;return $x__5110__auto__$jscomp$153$$>0?$x__5110__auto__$jscomp$153$$:
0}()|0,$layout_padding$jscomp$11$$=$APP.$cljs$core$truth_$$($is_hover_all$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($padding$jscomp$12$$,$APP.$cljs$cst$1093$p1$$,$val$jscomp$229$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1091$p2$$,$val$jscomp$229$$,$APP.$cljs$cst$1692$p3$$,$val$jscomp$229$$,$APP.$cljs$cst$1693$p4$$,$val$jscomp$229$$])):$APP.$cljs$core$truth_$$($is_hover_v$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($padding$jscomp$12$$,
$APP.$cljs$cst$1093$p1$$,$val$jscomp$229$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1692$p3$$,$val$jscomp$229$$])):$APP.$cljs$core$truth_$$($is_hover_h$jscomp$1$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($padding$jscomp$12$$,$APP.$cljs$cst$1091$p2$$,$val$jscomp$229$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1693$p4$$,$val$jscomp$229$$])):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($padding$jscomp$12$$,
$padding_num$$,$val$jscomp$229$$),$layout_padding_type$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$12$$),$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$12$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$12$$),$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$12$$)]))?
$APP.$cljs$cst$1668$simple$$:$APP.$cljs$cst$1621$multiple$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$val$jscomp$229$$,$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$154$$],null),$APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),
$APP.$cljs$cst$1691$layout_padding$$,$layout_padding$jscomp$11$$),$APP.$cljs$cst$1690$layout_padding_type$$,$layout_padding_type$jscomp$4$$))],null)}),$on_lost_pointer_capture$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$jscomp$2$$)],function($G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$){$APP.$app$util$dom$release_pointer$$($G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$);
$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")&&($G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$=$APP.$cljs$core$_deref$$($last_pos$jscomp$4$$),$G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$=$calc_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$):
$calc_modifiers$jscomp$2$$($G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$),$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$,0,null),$G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$,1,null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($G__80721$jscomp$inline_9231_event$jscomp$648_modifiers_80741_vec__80718_80739$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()])));$APP.$cljs$core$reset_BANG_$$($resizing_QMARK_$jscomp$1$$,!1);$APP.$cljs$core$reset_BANG_$$($start$jscomp$250$$,null);$APP.$cljs$core$reset_BANG_$$($original_value$jscomp$2$$,0);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}),
$on_pointer_move$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calc_modifiers$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$99$$)],function($event$jscomp$649_pos$jscomp$156_val$jscomp$230$$){$event$jscomp$649_pos$jscomp$156_val$jscomp$230$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$649_pos$jscomp$156_val$jscomp$230$$);$APP.$cljs$core$reset_BANG_$$($mouse_pos$jscomp$4$$,$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$649_pos$jscomp$156_val$jscomp$230$$));
$APP.$cljs$core$reset_BANG_$$($last_pos$jscomp$4$$,$event$jscomp$649_pos$jscomp$156_val$jscomp$230$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($resizing_QMARK_$jscomp$1$$))){var $modifiers$jscomp$121_vec__80722$$=$calc_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$calc_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$649_pos$jscomp$156_val$jscomp$230$$):$calc_modifiers$jscomp$2$$($event$jscomp$649_pos$jscomp$156_val$jscomp$230$$);$event$jscomp$649_pos$jscomp$156_val$jscomp$230$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$121_vec__80722$$,0,null);$modifiers$jscomp$121_vec__80722$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers$jscomp$121_vec__80722$$,1,null);$APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$5$$,$event$jscomp$649_pos$jscomp$156_val$jscomp$230$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modifiers$jscomp$121_vec__80722$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modifiers$jscomp$121_vec__80722$$,!1,!1,null));return $APP.$cljs$core$truth_$$($on_change$jscomp$99$$)?$on_change$jscomp$99$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$99$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$121_vec__80722$$):$on_change$jscomp$99$$($modifiers$jscomp$121_vec__80722$$):null}return null});return(0,$APP.$rumext$v2$jsxs$$)("g",
{className:"padding-rect",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{width:function(){var $y__5111__auto__$jscomp$154$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$);return 0>$y__5111__auto__$jscomp$154$$?0:$y__5111__auto__$jscomp$154$$}(),height:function(){var $y__5111__auto__$jscomp$155$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$);return 0>$y__5111__auto__$jscomp$155$$?0:$y__5111__auto__$jscomp$155$$}(),className:"info-area",
x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$),onContextMenu:$on_context_menu$jscomp$19$$,style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$2$$)?$is_hover$jscomp$2$$:$is_selected$jscomp$11$$)?"var(--color-accent-quaternary)":"none",opacity:$APP.$cljs$core$truth_$$($is_selected$jscomp$11$$)?.5:.25},y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$),onPointerMove:$on_pointer_move$jscomp$8$$,onPointerDown:$on_move_selected$jscomp$3$$,
onPointerLeave:$on_pointer_leave$jscomp$11$$,onPointerEnter:$on_pointer_enter$jscomp$11$$}),function(){var $handle_width$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$42$$,$APP.$cljs$cst$1515$x$$)?2/$zoom$jscomp$77$$:function(){var $x__5113__auto__$jscomp$86$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)*.5,$y__5114__auto__$jscomp$86$$=20/$zoom$jscomp$77$$;return $x__5113__auto__$jscomp$86$$<$y__5114__auto__$jscomp$86$$?$x__5113__auto__$jscomp$86$$:
$y__5114__auto__$jscomp$86$$}(),$handle_height$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$42$$,$APP.$cljs$cst$1516$y$$)?2/$zoom$jscomp$77$$:function(){var $x__5113__auto__$jscomp$87$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)*.5,$y__5114__auto__$jscomp$87$$=30/$zoom$jscomp$77$$;return $x__5113__auto__$jscomp$87$$<$y__5114__auto__$jscomp$87$$?$x__5113__auto__$jscomp$87$$:$y__5114__auto__$jscomp$87$$}();return(0,$APP.$rumext$v2$jsx$$)("rect",
{width:$handle_width$jscomp$1$$,height:$handle_height$jscomp$1$$,className:"handle "+(($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$2$$)?$is_hover$jscomp$2$$:$is_selected$jscomp$11$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5942$resize_axis$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$),$APP.$cljs$cst$1515$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",0):$app$main$ui$css_cursors$get_dynamic$$("resize-ew",90):null)??""),x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)+
($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)-$handle_width$jscomp$1$$)/2,onContextMenu:$on_context_menu$jscomp$19$$,style:{fill:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_hover$jscomp$2$$)?$is_hover$jscomp$2$$:$is_selected$jscomp$11$$)?"var(--color-accent-quaternary)":"none",opacity:$APP.$cljs$core$truth_$$($is_selected$jscomp$11$$)?0:1},onLostPointerCapture:$on_lost_pointer_capture$jscomp$7$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)+
($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect_data$jscomp$3$$)-$handle_height$jscomp$1$$)/2,onPointerMove:$on_pointer_move$jscomp$8$$,onPointerDown:$on_pointer_down$jscomp$9$$,onPointerLeave:$on_pointer_leave$jscomp$11$$,onPointerEnter:$on_pointer_enter$jscomp$11$$})}()]})};
$app$main$ui$flex_controls$padding$padding_rects_STAR_$$=function($map__80726_padding_rect_data_props_80725_width$jscomp$214$$){function $hover_QMARK_$jscomp$9$$($value$jscomp$1004$$){if($APP.$cljs$core$truth_$$($hover_all_QMARK_$jscomp$1$$))return $hover_all_QMARK_$jscomp$1$$;var $or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$34$$=function(){var $and__5023__auto__$jscomp$945$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1004$$,$APP.$cljs$cst$1093$p1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1004$$,
$APP.$cljs$cst$1692$p3$$);return $and__5023__auto__$jscomp$945$$?$hover_v_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$945$$}();if($APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$34$$))return $or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$34$$;$or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$34$$=function(){var $and__5023__auto__$jscomp$946$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1004$$,$APP.$cljs$cst$1091$p2$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$1004$$,$APP.$cljs$cst$1693$p4$$);return $and__5023__auto__$jscomp$946$$?$hover_h_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$946$$}();return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$34$$)?$or__5025__auto____$1$jscomp$146_or__5025__auto____$2$jscomp$34$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$value$jscomp$1004$$)}var $is_shift$jscomp$2$$=
$map__80726_padding_rect_data_props_80725_width$jscomp$214$$.isShift,$zoom$jscomp$78$$=$map__80726_padding_rect_data_props_80725_width$jscomp$214$$.zoom,$frame$jscomp$80_height$jscomp$182$$=$map__80726_padding_rect_data_props_80725_width$jscomp$214$$.frame,$is_alt$jscomp$2$$=$map__80726_padding_rect_data_props_80725_width$jscomp$214$$.isAlt,$on_context_menu$jscomp$20$$=$map__80726_padding_rect_data_props_80725_width$jscomp$214$$.onContextMenu,$on_move_selected$jscomp$4$$=$map__80726_padding_rect_data_props_80725_width$jscomp$214$$.onMoveSelected,
$frame_id$jscomp$155$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$80_height$jscomp$182$$),$paddings_selected$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_paddings_selected$$),$current_modifiers$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$frame__$1$jscomp$8$$=$APP.$app$common$types$modifiers$apply_structure_modifiers$$($frame$jscomp$80_height$jscomp$182$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($current_modifiers$jscomp$3$$),
$frame_id$jscomp$155$$),$APP.$cljs$cst$1816$modifiers$$)),$hover_value$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$mouse_pos$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_all_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$942$$=$APP.$cljs$core$_deref$$($hover$jscomp$4$$)!=null;return $and__5023__auto__$jscomp$942$$?$is_alt$jscomp$2$$:
$and__5023__auto__$jscomp$942$$}(),$hover_v_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$943$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$APP.$cljs$cst$1093$p1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$APP.$cljs$cst$1692$p3$$);return $and__5023__auto__$jscomp$943$$?$is_shift$jscomp$2$$:$and__5023__auto__$jscomp$943$$}(),$hover_h_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$944$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$APP.$cljs$cst$1091$p2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover$jscomp$4$$),$APP.$cljs$cst$1693$p4$$);return $and__5023__auto__$jscomp$944$$?$is_shift$jscomp$2$$:$and__5023__auto__$jscomp$944$$}(),$padding$jscomp$13$$=$APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$);$map__80726_padding_rect_data_props_80725_width$jscomp$214$$=
$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$);var $map__80726__$1_pill_width$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__80726_padding_rect_data_props_80725_width$jscomp$214$$);$map__80726_padding_rect_data_props_80725_width$jscomp$214$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80726__$1_pill_width$jscomp$2$$,$APP.$cljs$cst$290$width$$);$frame$jscomp$80_height$jscomp$182$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80726__$1_pill_width$jscomp$2$$,
$APP.$cljs$cst$1527$height$$);var $x1$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80726__$1_pill_width$jscomp$2$$,$APP.$cljs$cst$1528$x1$$),$x2$jscomp$39$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80726__$1_pill_width$jscomp$2$$,$APP.$cljs$cst$1530$x2$$),$y1$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80726__$1_pill_width$jscomp$2$$,$APP.$cljs$cst$1529$y1$$),$y2$jscomp$41$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80726__$1_pill_width$jscomp$2$$,
$APP.$cljs$cst$1531$y2$$);$map__80726__$1_pill_width$jscomp$2$$=40/$zoom$jscomp$78$$;var $pill_height$jscomp$2$$=20/$zoom$jscomp$78$$,$negate$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?!0:!1,$APP.$cljs$cst$1091$p2$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?!0:!1,$APP.$cljs$cst$1692$p3$$,
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?!0:!1,$APP.$cljs$cst$1693$p4$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?!0:!1],null),$negate__$1$$=function(){var $G__80728__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1677$auto$$,$APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($negate$jscomp$1$$,
$APP.$cljs$cst$1091$p2$$,$APP.$cljs$core$not$$($APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($negate$jscomp$1$$))):$negate$jscomp$1$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1677$auto$$,$APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80728__$1$$,$APP.$cljs$cst$1692$p3$$,$APP.$cljs$core$not$$($APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($negate$jscomp$1$$))):
$G__80728__$1$$}();$map__80726_padding_rect_data_props_80725_width$jscomp$214$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?
$y2$jscomp$41$$-$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$):$y1$jscomp$44$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?$APP.$cljs$cst$1568$bottom$$:$APP.$cljs$cst$1567$top$$,$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($negate__$1$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$155$$),"-p1"].join(""),$map__80726_padding_rect_data_props_80725_width$jscomp$214$$,
$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$x1$jscomp$42$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1093$p1$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$)]),$APP.$cljs$cst$1091$p2$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],
[$y1$jscomp$44$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($negate__$1$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$155$$),"-p2"].join(""),$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?$x1$jscomp$42$$:$x2$jscomp$39$$-
$APP.$cljs$cst$1091$p2$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$cst$1515$x$$,$frame$jscomp$80_height$jscomp$182$$]),$APP.$cljs$cst$1692$p3$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$APP.$cljs$core$truth_$$($APP.$cljs$cst$1888$flip_y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?
$y1$jscomp$44$$:$y2$jscomp$41$$-$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$cst$1568$bottom$$,$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($negate__$1$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$155$$),"-p3"].join(""),$map__80726_padding_rect_data_props_80725_width$jscomp$214$$,$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$x1$jscomp$42$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1692$p3$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$)]),
$APP.$cljs$cst$1693$p4$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$cljs$cst$5944$resize_type$$,$cljs$cst$5941$resize_negate_QMARK_$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$290$width$$,$cljs$cst$5943$initial_value$$,$APP.$cljs$cst$1515$x$$,$cljs$cst$5942$resize_axis$$,$APP.$cljs$cst$1527$height$$],[$y1$jscomp$44$$,$APP.$cljs$core$truth_$$($APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$257$left$$,
$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($negate__$1$$),[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$155$$),"-p4"].join(""),$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1887$flip_x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$8$$))?$x2$jscomp$39$$-$APP.$cljs$cst$1693$p4$$.$cljs$core$IFn$_invoke$arity$1$($padding$jscomp$13$$):
$x1$jscomp$42$$,$APP.$cljs$cst$1515$x$$,$frame$jscomp$80_height$jscomp$182$$])],null);var $on_pointer_enter$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($hover_type$jscomp$2$$,$val$jscomp$231$$){$APP.$cljs$core$reset_BANG_$$($hover$jscomp$4$$,$hover_type$jscomp$2$$);return $APP.$cljs$core$reset_BANG_$$($hover_value$jscomp$6$$,$val$jscomp$231$$)}),$on_pointer_leave$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($hover$jscomp$4$$,
null)}),$on_change$jscomp$100$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifiers$jscomp$122$$){return $APP.$cljs$core$reset_BANG_$$($current_modifiers$jscomp$3$$,$modifiers$jscomp$122$$)});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"paddings",pointerEvents:"visible",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$210$$,$p__80730_rect_data$jscomp$4$$){var $padding_num$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80730_rect_data$jscomp$4$$,
0,null);$p__80730_rect_data$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80730_rect_data$jscomp$4$$,1,null);$out_arr__44092__auto__$jscomp$210$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$padding$padding_display_STAR_$$,{hoverValue:$hover_value$jscomp$6$$,isHover:$hover_QMARK_$jscomp$9$$($padding_num$jscomp$1$$),onChange:$on_change$jscomp$100$$,zoom:$zoom$jscomp$78$$,padding:$padding$jscomp$13$$,onContextMenu:$on_context_menu$jscomp$20$$,frameId:$frame_id$jscomp$155$$,
isHoverH:$hover_h_QMARK_$jscomp$1$$,isHoverAll:$hover_all_QMARK_$jscomp$1$$,isSelected:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($paddings_selected$jscomp$2$$,$padding_num$jscomp$1$$),onMoveSelected:$on_move_selected$jscomp$4$$,onPointerLeave:$on_pointer_leave$jscomp$12$$,rectData:$p__80730_rect_data$jscomp$4$$,onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_pointer_enter$jscomp$12$$,$padding_num$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($padding$jscomp$13$$,
$padding_num$jscomp$1$$)),isHoverV:$hover_v_QMARK_$jscomp$1$$,mousePos:$mouse_pos$jscomp$5$$,paddingNum:$padding_num$jscomp$1$$},$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($p__80730_rect_data$jscomp$4$$)));return $out_arr__44092__auto__$jscomp$210$$},[],$map__80726_padding_rect_data_props_80725_width$jscomp$214$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover$jscomp$4$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$common$flex_display_pill$$,{height:$pill_height$jscomp$2$$,
width:$map__80726__$1_pill_width$jscomp$2$$,"font-size":11/$zoom$jscomp$78$$,"border-radius":4/$zoom$jscomp$78$$,color:"var(--color-accent-quaternary)",x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$5$$)),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($mouse_pos$jscomp$5$$))-$map__80726__$1_pill_width$jscomp$2$$,value:$APP.$cljs$core$_deref$$($hover_value$jscomp$6$$)}):null]})};
$app$main$ui$flex_controls$padding$padding_control_STAR_$$=function($on_move_selected$jscomp$5_props_80734$$){var $is_shift$jscomp$3$$=$on_move_selected$jscomp$5_props_80734$$.isShift,$zoom$jscomp$79$$=$on_move_selected$jscomp$5_props_80734$$.zoom,$frame$jscomp$81$$=$on_move_selected$jscomp$5_props_80734$$.frame,$is_alt$jscomp$3$$=$on_move_selected$jscomp$5_props_80734$$.isAlt,$on_context_menu$jscomp$21$$=$on_move_selected$jscomp$5_props_80734$$.onContextMenu;$on_move_selected$jscomp$5_props_80734$$=
$on_move_selected$jscomp$5_props_80734$$.onMoveSelected;return $APP.$cljs$core$truth_$$($frame$jscomp$81$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"measurement-gaps",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)("g",{className:"hover-shapes",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$padding$padding_rects_STAR_$$,{frame:$frame$jscomp$81$$,zoom:$zoom$jscomp$79$$,isAlt:$is_alt$jscomp$3$$,isShift:$is_shift$jscomp$3$$,onMoveSelected:$on_move_selected$jscomp$5_props_80734$$,
onContextMenu:$on_context_menu$jscomp$21$$})})}):null};
$app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$=function($props_80727_x$jscomp$1271$$){var $is_last$$=$props_80727_x$jscomp$1271$$.isLast,$edit_mode_is_active$jscomp$6$$=$props_80727_x$jscomp$1271$$.editMode,$is_new$jscomp$2$$=$props_80727_x$jscomp$1271$$.isNew,$zoom$jscomp$80$$=$props_80727_x$jscomp$1271$$.zoom,$is_selected$jscomp$12$$=$props_80727_x$jscomp$1271$$.isSelected,$is_start_path$$=$props_80727_x$jscomp$1271$$.isStartPath,$is_curve$$=$props_80727_x$jscomp$1271$$.isCurve,$is_preview$$=
$props_80727_x$jscomp$1271$$.isPreview,$is_hover$jscomp$3_on_enter$jscomp$2$$=$props_80727_x$jscomp$1271$$.isHover,$position$jscomp$209$$=$props_80727_x$jscomp$1271$$.position,$map__80729__$1_y$jscomp$492$$=$APP.$cljs$core$__destructure_map$$($position$jscomp$209$$);$props_80727_x$jscomp$1271$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80729__$1_y$jscomp$492$$,$APP.$cljs$cst$1515$x$$);$map__80729__$1_y$jscomp$492$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80729__$1_y$jscomp$492$$,
$APP.$cljs$cst$1516$y$$);var $is_draw$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode_is_active$jscomp$6$$,$APP.$cljs$cst$4291$draw$$),$is_move$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode_is_active$jscomp$6$$,$APP.$cljs$cst$1804$move$$);$edit_mode_is_active$jscomp$6$$=$is_selected$jscomp$12$$||$is_hover$jscomp$3_on_enter$jscomp$2$$;$is_hover$jscomp$3_on_enter$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$path_pointer_enter$$($position$jscomp$209$$))});
var $on_leave$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$path_pointer_leave$$($position$jscomp$209$$))});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"path-point",children:[(0,$APP.$rumext$v2$jsx$$)("circle",{className:"path-point",cx:$props_80727_x$jscomp$1271$$,cy:$map__80729__$1_y$jscomp$492$$,r:$edit_mode_is_active$jscomp$6$$?5/$zoom$jscomp$80$$:
4/$zoom$jscomp$80$$,style:{strokeWidth:1/$zoom$jscomp$80$$,stroke:$edit_mode_is_active$jscomp$6$$?"var(--app-black)":$is_preview$$?"var(--color-accent-quaternary)":"var(--color-accent-tertiary)",fill:$APP.$cljs$core$truth_$$($is_selected$jscomp$12$$)?"var(--color-accent-tertiary)":"var(--app-white)"}}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:$map__80729__$1_y$jscomp$492$$,className:$is_draw$$?$APP.$app$main$ui$css_cursors$get_static$$("pen-node"):$is_move$$?$APP.$app$main$ui$css_cursors$get_static$$("pointer-node"):
null,style:{strokeWidth:0,fill:"none"},r:15/$zoom$jscomp$80$$,onPointerDown:function($JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$){if($app$util$dom$left_mouse_QMARK_$$($JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$)){$APP.$app$util$dom$stop_propagation$$($JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$);$APP.$app$util$dom$prevent_default$$($JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_new$jscomp$2$$)?$APP.$cljs$core$meta$$($position$jscomp$209$$)!=null:$is_new$jscomp$2$$)){var $JSCompiler_temp_const$jscomp$11279_is_shift$jscomp$4$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;$JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$=$APP.$cljs$core$meta$$($position$jscomp$209$$);$JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$=
$app$main$data$workspace$path$edition$create_node_at_position$$($JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$);return $JSCompiler_temp_const$jscomp$11279_is_shift$jscomp$4$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$)}$JSCompiler_temp_const$jscomp$11279_is_shift$jscomp$4$$=$JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$.shiftKey;
$JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$=$APP.$app$util$keyboard$mod_QMARK_$$($JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$);return $APP.$cljs$core$truth_$$($is_last$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$drawing$reset_last_handler$$()):$is_move$$&&$JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$&&
$APP.$cljs$core$not$$($is_curve$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_curve$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$209$$)):$APP.$cljs$core$truth_$$($is_move$$?$JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$?$is_curve$$:$JSCompiler_inline_result$jscomp$11281_event$jscomp$650_is_mod_param70242$jscomp$inline_13978$$:$is_move$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_corner$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$209$$)):
$is_move$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$start_move_path_point$$($position$jscomp$209$$,$JSCompiler_temp_const$jscomp$11279_is_shift$jscomp$4$$)):$APP.$cljs$core$truth_$$($is_draw$$?$is_start_path$$:$is_draw$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$drawing$start_path_from_point$$($position$jscomp$209$$)):$is_draw$$&&$APP.$cljs$core$not$$($is_start_path$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$drawing$close_path_drag_start$$($position$jscomp$209$$)):
null}return null},onPointerLeave:$on_leave$jscomp$2$$,cx:$props_80727_x$jscomp$1271$$,onPointerEnter:$is_hover$jscomp$3_on_enter$jscomp$2$$,pointerEvents:$is_preview$$?null:"visible"})]})};
$app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$=function($point$jscomp$80_props_80735$$){var $handler$jscomp$48_y$jscomp$493$$=$point$jscomp$80_props_80735$$.handler,$edit_mode$jscomp$1_is_active$jscomp$7$$=$point$jscomp$80_props_80735$$.editMode,$zoom$jscomp$81$$=$point$jscomp$80_props_80735$$.zoom,$index$jscomp$564$$=$point$jscomp$80_props_80735$$.index,$is_selected$jscomp$13$$=$point$jscomp$80_props_80735$$.isSelected,$prefix$jscomp$73$$=$point$jscomp$80_props_80735$$.prefix,$is_hover$jscomp$4$$=
$point$jscomp$80_props_80735$$.isHover,$snap_angle$$=$point$jscomp$80_props_80735$$.snapAngle;$point$jscomp$80_props_80735$$=$point$jscomp$80_props_80735$$.point;var $x$jscomp$1272$$=$handler$jscomp$48_y$jscomp$493$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$48_y$jscomp$493$$,$APP.$cljs$cst$1515$x$$);$handler$jscomp$48_y$jscomp$493$$=$handler$jscomp$48_y$jscomp$493$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handler$jscomp$48_y$jscomp$493$$,$APP.$cljs$cst$1516$y$$);
var $is_draw$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$1_is_active$jscomp$7$$,$APP.$cljs$cst$4291$draw$$),$is_move$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$1_is_active$jscomp$7$$,$APP.$cljs$cst$1804$move$$);$edit_mode$jscomp$1_is_active$jscomp$7$$=$is_selected$jscomp$13$$||$is_hover$jscomp$4$$;var $on_enter$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$564$$),
$APP.$rumext$v2$adapt$$($prefix$jscomp$73$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$path_handler_enter$$($index$jscomp$564$$,$prefix$jscomp$73$$))}),$on_leave$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$564$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$73$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$path_handler_leave$$($index$jscomp$564$$,
$prefix$jscomp$73$$))}),$on_pointer_down$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($index$jscomp$564$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$73$$),$APP.$rumext$v2$adapt$$($is_move$jscomp$1$$)],function($event$jscomp$651$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$651$$)?($APP.$app$util$dom$stop_propagation$$($event$jscomp$651$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$651$$),$is_move$jscomp$1$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$edition$start_move_handler$$($index$jscomp$564$$,
$prefix$jscomp$73$$)):null):null});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"handler",pointerEvents:$is_draw$jscomp$1$$?"none":"visible",children:[(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$80_props_80735$$),y1:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$80_props_80735$$),x2:$x$jscomp$1272$$,y2:$handler$jscomp$48_y$jscomp$493$$,style:{stroke:$is_hover$jscomp$4$$?"var(--app-black)":"var(--df-secondary)",
strokeWidth:1/$zoom$jscomp$81$$}}),$snap_angle$$?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$80_props_80735$$),y1:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$80_props_80735$$),x2:$x$jscomp$1272$$,y2:$handler$jscomp$48_y$jscomp$493$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:1/$zoom$jscomp$81$$}}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1272$$-3/$zoom$jscomp$81$$,y:$handler$jscomp$48_y$jscomp$493$$-
3/$zoom$jscomp$81$$,width:6/$zoom$jscomp$81$$,height:6/$zoom$jscomp$81$$,style:{strokeWidth:1/$zoom$jscomp$81$$,stroke:$edit_mode$jscomp$1_is_active$jscomp$7$$?"var(--app-black)":"var(--color-accent-tertiary)",fill:$is_selected$jscomp$13$$?"var(--color-accent-tertiary)":"var(--app-white)"}}),(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$x$jscomp$1272$$,cy:$handler$jscomp$48_y$jscomp$493$$,r:15/$zoom$jscomp$81$$,onPointerDown:$on_pointer_down$jscomp$11$$,onPointerEnter:$on_enter$jscomp$3$$,onPointerLeave:$on_leave$jscomp$3$$,
style:{fill:"none",strokeWidth:0},className:$is_move$jscomp$1$$?$APP.$app$main$ui$css_cursors$get_static$$("pointer-move"):null})]})};
$app$main$ui$workspace$shapes$path$editor$path_preview_STAR_$$=function($path$jscomp$299_props_80742$$){var $zoom$jscomp$82$$=$path$jscomp$299_props_80742$$.zoom,$from$jscomp$30$$=$path$jscomp$299_props_80742$$.from,$segment$jscomp$60$$=$path$jscomp$299_props_80742$$.segment;$path$jscomp$299_props_80742$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1819$move_to$$,$APP.$cljs$cst$1818$command$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$60$$))?function(){var $segments__$1$jscomp$4$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1818$command$$,$APP.$cljs$cst$1819$move_to$$,$APP.$cljs$cst$1435$params$$,$from$jscomp$30$$],null)],null),$segment$jscomp$60$$);return $APP.$app$common$types$path$impl$path_data$$($segments__$1$jscomp$4$$)}():null;var $position$jscomp$210$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($segment$jscomp$60$$)],
function(){return $APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($segment$jscomp$60$$))});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"preview",style:{pointerEvents:"none"},children:[$path$jscomp$299_props_80742$$!=null?(0,$APP.$rumext$v2$jsx$$)("path",{style:{fill:"none",stroke:"var(--app-black)",strokeWidth:1/$zoom$jscomp$82$$,strokeDasharray:4/$zoom$jscomp$82$$},d:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($path$jscomp$299_props_80742$$)}):
null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$,{position:$position$jscomp$210$$,isPreview:!0,zoom:$zoom$jscomp$82$$})]})};
$app$main$ui$workspace$shapes$path$editor$path_snap_STAR_$$=function($matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$){var $zoom$jscomp$83$$=$matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$.zoom,$selected$jscomp$189$$=$matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$.selected,$points$jscomp$103$$=$matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$.points;$matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$189$$),
$APP.$rumext$v2$adapt$$($points$jscomp$103$$)],function(){return $APP.$app$main$snap$create_ranges$$.$cljs$core$IFn$_invoke$arity$2$($points$jscomp$103$$,$selected$jscomp$189$$)});$matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$=$APP.$app$main$snap$get_snap_delta_match$$($selected$jscomp$189$$,$matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$,1/$zoom$jscomp$83$$);$matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$)),
$APP.$cljs$core$second$$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$)));return(0,$APP.$rumext$v2$jsx$$)("g",{className:"snap-paths",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$211$$,$from$jscomp$31_p__80755$$){var $idx$jscomp$129$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from$jscomp$31_p__80755$$,0,null),$to$jscomp$27_vec__80759$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($from$jscomp$31_p__80755$$,
1,null);$from$jscomp$31_p__80755$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($to$jscomp$27_vec__80759$$,0,null);$to$jscomp$27_vec__80759$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($to$jscomp$27_vec__80759$$,1,null);$out_arr__44092__auto__$jscomp$211$$.push((0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$31_p__80755$$),y1:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($from$jscomp$31_p__80755$$),x2:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$27_vec__80759$$),
y2:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($to$jscomp$27_vec__80759$$),style:{stroke:"var(--color-accent-quaternary)",strokeWidth:1/$zoom$jscomp$83$$}},"snap-"+($idx$jscomp$129$$??"")+"-"+($from$jscomp$31_p__80755$$??"")+"-"+($to$jscomp$27_vec__80759$$??"")));return $out_arr__44092__auto__$jscomp$211$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($matches$jscomp$11_props_80744_ranges$jscomp$9_snap_matches$$))})};
$app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$=function($editor_ref_props_80788$$){var $zoom$jscomp$84$$=$editor_ref_props_80788$$.zoom,$prev_handler$jscomp$6_state$jscomp$1229$$=$editor_ref_props_80788$$.state,$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$=$editor_ref_props_80788$$.shape,$hover_point$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$editor_ref_props_80788$$=(0,$APP.$rumext$v2$use_ref$$)(null);var $map__80790__$1_show_snap_QMARK_$$=
$APP.$cljs$core$__destructure_map$$($prev_handler$jscomp$6_state$jscomp$1229$$);$prev_handler$jscomp$6_state$jscomp$1229$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$3607$prev_handler$$);var $edit_mode$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4290$edit_mode$$),$moving_handler$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,
$APP.$cljs$cst$4316$moving_handler$$),$hover_points$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4302$hover_points$$),$snap_toggled$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4269$snap_toggled$$),$moving_nodes$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4318$moving_nodes$$),$hover_handlers$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,
$APP.$cljs$cst$4305$hover_handlers$$),$last_point$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$3606$last_point$$),$selected_points$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$4308$selected_points$$),$content_modifiers$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$1941$content_modifiers$$),$preview$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$3609$preview$$),$drag_handler$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80790__$1_show_snap_QMARK_$$,$APP.$cljs$cst$3608$drag_handler$$),$selected_points__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($selected_points$jscomp$7$$)?$selected_points$jscomp$7$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$,$base_content$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$,
$APP.$cljs$cst$1642$content$$);$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_content$jscomp$1$$)],function(){return $APP.$app$common$types$path$get_points$$($base_content$jscomp$1$$)});var $content$jscomp$255$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_content$jscomp$1$$),$APP.$rumext$v2$adapt$$($content_modifiers$jscomp$5$$)],function(){return $APP.$app$common$types$path$apply_content_modifiers$$($base_content$jscomp$1$$,
$content_modifiers$jscomp$5$$)}),$content_points$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$255$$)],function(){return $APP.$app$common$types$path$get_points$$($content$jscomp$255$$)}),$point__GT_base$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$hash_map$$,$content_points$$,$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$)),
$base__GT_point$$=$APP.$clojure$set$map_invert$$($point__GT_base$$),$points$jscomp$104$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content_points$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$content_points$$)});$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$=$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$last$$($content$jscomp$255$$));
var $handlers$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$255$$)],function(){return $app$common$types$path$get_handlers$$($content$jscomp$255$$)}),$is_path_start$$=$last_point$jscomp$4$$==null;$map__80790__$1_show_snap_QMARK_$$=function(){if($snap_toggled$jscomp$3$$){var $or__5025__auto__$jscomp$1363_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$35$$=$drag_handler$$!=null;return $or__5025__auto__$jscomp$1363_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$35$$||
($or__5025__auto__$jscomp$1363_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$35$$=$preview$jscomp$5$$!=null)?$or__5025__auto__$jscomp$1363_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$35$$:($or__5025__auto__$jscomp$1363_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$35$$=$moving_handler$$!=null)?$or__5025__auto__$jscomp$1363_or__5025__auto____$1$jscomp$147_or__5025__auto____$2$jscomp$35$$:$moving_nodes$$}return $snap_toggled$jscomp$3$$}();$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($edit_mode$jscomp$2$$)],
function(){var $key$jscomp$422$$=$APP.$goog$events$listen$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$globals$document$$,"#app"),"dblclick",function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$2$$,$APP.$cljs$cst$1804$move$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2177$interrupt$$):null});return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$422$$)}});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$main$streams$mouse_position$$,
[$APP.$rumext$v2$adapt$$($base_content$jscomp$1$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$84$$)],function($position$jscomp$211$$){var $precision$jscomp$inline_9235_temp__5825__auto__$jscomp$428$$=.01/$zoom$jscomp$84$$;var $content__$1$jscomp$inline_9236$$=$APP.$app$common$types$path$impl$path_data$$($base_content$jscomp$1$$);$precision$jscomp$inline_9235_temp__5825__auto__$jscomp$428$$=$APP.$cljs$core$count$$($content__$1$jscomp$inline_9236$$)>0?$app$common$types$path$segment$closest_point$$($content__$1$jscomp$inline_9236$$,
$position$jscomp$211$$,$precision$jscomp$inline_9235_temp__5825__auto__$jscomp$428$$):null;return $APP.$cljs$core$truth_$$($precision$jscomp$inline_9235_temp__5825__auto__$jscomp$428$$)?$APP.$cljs$core$reset_BANG_$$($hover_point$$,$APP.$app$common$geom$point$distance$$($position$jscomp$211$$,$precision$jscomp$inline_9235_temp__5825__auto__$jscomp$428$$)<10/$zoom$jscomp$84$$?$precision$jscomp$inline_9235_temp__5825__auto__$jscomp$428$$:null):null});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"path-editor",
ref:$editor_ref_props_80788$$,children:[(0,$APP.$rumext$v2$jsx$$)("path",{d:$content$jscomp$255$$.toString(),style:{fill:"none",stroke:"var(--color-accent-tertiary)",strokeWidth:1/$zoom$jscomp$84$$}}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($preview$jscomp$5$$)?$APP.$cljs$core$not$$($drag_handler$$):$preview$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_preview_STAR_$$,{segment:$preview$jscomp$5$$,from:$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$,
zoom:$zoom$jscomp$84$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($drag_handler$$)?$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$:$drag_handler$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"drag-handler",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$,{point:$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$,handler:$drag_handler$$,editMode:$edit_mode$jscomp$2$$,zoom:$zoom$jscomp$84$$})}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($hover_point$$))?
(0,$APP.$rumext$v2$jsx$$)("g",{className:"hover-point",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$,{position:$APP.$cljs$core$_deref$$($hover_point$$),editMode:$edit_mode$jscomp$2$$,isNew:!0,isStartPath:$is_path_start$$,zoom:$zoom$jscomp$84$$})}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$212$$,$position$jscomp$212$$){$out_arr__44092__auto__$jscomp$212$$.push(function(){var $pos_x$jscomp$5$$=
$position$jscomp$212$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$212$$,$APP.$cljs$cst$1515$x$$),$pos_y$jscomp$5$$=$position$jscomp$212$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$212$$,$APP.$cljs$cst$1516$y$$),$position_handlers$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80793_prefix$jscomp$74$$){var $handler_position$jscomp$1_index$jscomp$565$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80793_prefix$jscomp$74$$,
0,null);$p__80793_prefix$jscomp$74$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80793_prefix$jscomp$74$$,1,null);$handler_position$jscomp$1_index$jscomp$565$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$255$$,$handler_position$jscomp$1_index$jscomp$565$$,$p__80793_prefix$jscomp$74$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$212$$,$handler_position$jscomp$1_index$jscomp$565$$)},$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handlers$jscomp$7$$,
$position$jscomp$212$$))),$point_selected_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($selected_points__$1$jscomp$3$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point__GT_base$$,$position$jscomp$212$$)),$point_hover_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($hover_points$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point__GT_base$$,$position$jscomp$212$$)),$is_last$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($last_point$jscomp$4$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point__GT_base$$,
$position$jscomp$212$$)),$is_curve$jscomp$1$$=$APP.$cljs$core$boolean$0$$($position_handlers$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"path-node",children:[(0,$APP.$rumext$v2$jsx$$)("g",{className:"point-handlers",pointerEvents:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$2$$,$APP.$cljs$cst$4291$draw$$)?"none":null,children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$21$$,$JSCompiler_temp_const$jscomp$11313_p__80797$$){var $JSCompiler_inline_result$jscomp$11315_hindex$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11313_p__80797$$,0,null),$prefix$jscomp$75$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$11313_p__80797$$,1,null);$JSCompiler_temp_const$jscomp$11313_p__80797$$=$out_arr__44092__auto____$1$jscomp$21$$.push;var $handler_position$jscomp$inline_13980$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$255$$,$JSCompiler_inline_result$jscomp$11315_hindex$$,$prefix$jscomp$75$$),
$handler_hover_QMARK_$jscomp$inline_13981$$=$APP.$cljs$core$contains_QMARK_$$($hover_handlers$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$11315_hindex$$,$prefix$jscomp$75$$],null)),$moving_handler_QMARK_$jscomp$inline_13982$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($handler_position$jscomp$inline_13980$$,$moving_handler$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,$APP.$cljs$core$count$$($position_handlers$$))){var $i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($position_handlers$$,0,null);var $i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$,0,null);var $p1$jscomp$inline_14952$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$,
1,null),$p2$jscomp$inline_14955_vec__80771$jscomp$inline_14953$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($position_handlers$$,1,null);$i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$inline_14955_vec__80771$jscomp$inline_14953$$,0,null);$p2$jscomp$inline_14955_vec__80771$jscomp$inline_14953$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p2$jscomp$inline_14955_vec__80771$jscomp$inline_14953$$,
1,null);$i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$255$$,$i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$,$p1$jscomp$inline_14952$$);$i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$=$APP.$app$common$types$path$get_handler_point$$($content$jscomp$255$$,
$i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$,$p2$jscomp$inline_14955_vec__80771$jscomp$inline_14953$$);$i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$=$APP.$app$common$geom$point$subtract$$($i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$,$position$jscomp$212$$);$i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$=
$APP.$app$common$geom$point$subtract$$($i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$,$position$jscomp$212$$);$i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$=180-$APP.$app$common$geom$point$angle_with_other$$($i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$,$i2$jscomp$inline_14954_p2__$1$jscomp$inline_14957_v2$jscomp$inline_14959_vec__80768$jscomp$inline_14950$$)<=
.1}else $i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$=null;$JSCompiler_inline_result$jscomp$11315_hindex$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($position$jscomp$212$$)?$handler_position$jscomp$inline_13980$$:$position$jscomp$212$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$,{editMode:$edit_mode$jscomp$2$$,zoom:$zoom$jscomp$84$$,index:$JSCompiler_inline_result$jscomp$11315_hindex$$,
prefix:$prefix$jscomp$75$$,isHover:$handler_hover_QMARK_$jscomp$inline_13981$$,point:$position$jscomp$212$$,snapAngle:$moving_handler_QMARK_$jscomp$inline_13982$$?$i1$jscomp$inline_14951_matching_handler_QMARK_$jscomp$inline_13983_p1__$1$jscomp$inline_14956_v1$jscomp$inline_14958$$:$moving_handler_QMARK_$jscomp$inline_13982$$,handler:$handler_position$jscomp$inline_13980$$},""+($JSCompiler_inline_result$jscomp$11315_hindex$$??"")+"-"+($APP.$app$common$data$name$$($prefix$jscomp$75$$)??"")):null;$JSCompiler_temp_const$jscomp$11313_p__80797$$.call($out_arr__44092__auto____$1$jscomp$21$$,
$JSCompiler_inline_result$jscomp$11315_hindex$$);return $out_arr__44092__auto____$1$jscomp$21$$},[],$position_handlers$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_point_STAR_$$,{position:$position$jscomp$212$$,zoom:$zoom$jscomp$84$$,editMode:$edit_mode$jscomp$2$$,isSelected:$point_selected_QMARK_$$,isHover:$point_hover_QMARK_$$,isLast:$is_last$jscomp$1$$,isStartPath:$is_path_start$$,isCurve:$is_curve$jscomp$1$$})]},""+($pos_x$jscomp$5$$??"")+"-"+($pos_y$jscomp$5$$??
""))}());return $out_arr__44092__auto__$jscomp$212$$},[],$points$jscomp$104$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($prev_handler$jscomp$6_state$jscomp$1229$$)?$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$:$prev_handler$jscomp$6_state$jscomp$1229$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"prev-handler",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_handler_STAR_$$,{point:$base_points$jscomp$1_last_p$jscomp$1_shape$jscomp$1051$$,
editMode:$edit_mode$jscomp$2$$,handler:$prev_handler$jscomp$6_state$jscomp$1229$$,zoom:$zoom$jscomp$84$$})}):null,$map__80790__$1_show_snap_QMARK_$$?function(){var $snap_points$jscomp$1_vec__80802$$=$drag_handler$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$drag_handler$$]),$points$jscomp$104$$],null):$preview$jscomp$5$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$app$common$types$path$helpers$segment__GT_point$$.$cljs$core$IFn$_invoke$arity$1$($preview$jscomp$5$$)]),$points$jscomp$104$$],null):$moving_handler$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$moving_handler$$]),$points$jscomp$104$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($base__GT_point$$,$selected_points__$1$jscomp$3$$)),$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($selected_points__$1$jscomp$3$$,$points$jscomp$104$$))],null),$snap_selected$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($snap_points$jscomp$1_vec__80802$$,
0,null);$snap_points$jscomp$1_vec__80802$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($snap_points$jscomp$1_vec__80802$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"path-snap",pointerEvents:"none",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_snap_STAR_$$,{selected:$snap_selected$$,points:$snap_points$jscomp$1_vec__80802$$,zoom:$zoom$jscomp$84$$})})}():null]})};
$app$main$ui$workspace$shapes$text$editor$block_component$$=function($props_80736$$){var $bprops_style$jscomp$77$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80736$$,"blockProps"),$data$jscomp$498_dir$jscomp$9$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($bprops_style$jscomp$77$$,"data");$bprops_style$jscomp$77$$=$APP.$app$main$ui$shapes$text$styles$generate_paragraph_styles$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($bprops_style$jscomp$77$$,
"data"));$data$jscomp$498_dir$jscomp$9$$=$APP.$cljs$cst$1770$text_direction$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$498_dir$jscomp$9$$,"auto");return(0,$APP.$rumext$v2$jsx$$)("div",{style:$bprops_style$jscomp$77$$,dir:$data$jscomp$498_dir$jscomp$9$$,children:(0,$APP.$rumext$v2$create_element$$)($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.EditorBlock,$props_80736$$)})};
$app$main$ui$workspace$shapes$text$editor$styles_fn$$=function($shape$jscomp$1053$$,$data$jscomp$499_styles$jscomp$28$$,$content$jscomp$256$$){$data$jscomp$499_styles$jscomp$28$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$256$$.getText(),"")?$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($content$jscomp$256$$.getData().toJS(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!0])):$APP.$app$common$text$styles_to_attrs$$($data$jscomp$499_styles$jscomp$28$$);
return $APP.$app$main$ui$shapes$text$styles$generate_text_styles$cljs$0core$0IFn$0_invoke$0arity$03$$($shape$jscomp$1053$$,$data$jscomp$499_styles$jscomp$28$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2696$show_text_QMARK_$$,!1],null))};
$app$main$ui$workspace$shapes$text$editor$get_blocks_to_setup$$=function($block_changes$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80743_v$jscomp$687$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80743_v$jscomp$687$$,0,null);$p__80743_v$jscomp$687$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80743_v$jscomp$687$$,1,null);return $APP.$cljs$cst$4067$old$$.$cljs$core$IFn$_invoke$arity$1$($p__80743_v$jscomp$687$$)==
null},$block_changes$$))};
$app$main$ui$workspace$shapes$text$editor$get_blocks_to_add_styles$$=function($block_changes$jscomp$1$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__80748_v$jscomp$688$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80748_v$jscomp$688$$,0,null);$p__80748_v$jscomp$688$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80748_v$jscomp$688$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4067$old$$.$cljs$core$IFn$_invoke$arity$1$($p__80748_v$jscomp$688$$),
$APP.$cljs$cst$4068$new$$.$cljs$core$IFn$_invoke$arity$1$($p__80748_v$jscomp$688$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4067$old$$.$cljs$core$IFn$_invoke$arity$1$($p__80748_v$jscomp$688$$),"")},$block_changes$jscomp$1$$))};
$app$main$ui$workspace$shapes$text$editor$shape__GT_justify$$=function($content$jscomp$257_map__80753__$1_p__80752$$){$content$jscomp$257_map__80753__$1_p__80752$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$257_map__80753__$1_p__80752$$);$content$jscomp$257_map__80753__$1_p__80752$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$257_map__80753__$1_p__80752$$,$APP.$cljs$cst$1642$content$$);switch($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$257_map__80753__$1_p__80752$$),
"top")){case "center":return"center";case "top":return"flex-start";case "bottom":return"flex-end";default:return null}};
$app$main$ui$workspace$shapes$text$editor$text_editor_svg$$=function($clip_id$jscomp$2_props_80805$$){var $modifiers$jscomp$123_text_modifier_ref$jscomp$2_width$jscomp$215$$=$clip_id$jscomp$2_props_80805$$.modifiers,$shape$jscomp$1055$$=$clip_id$jscomp$2_props_80805$$.shape,$shape_id$jscomp$170$$=$shape$jscomp$1055$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1055$$,$APP.$cljs$cst$266$id$$),$modifiers__$1$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$123_text_modifier_ref$jscomp$2_width$jscomp$215$$,
$shape_id$jscomp$170$$),$APP.$cljs$cst$1816$modifiers$$);$clip_id$jscomp$2_props_80805$$="text-edition-clip"+($shape_id$jscomp$170$$??"");$modifiers$jscomp$123_text_modifier_ref$jscomp$2_width$jscomp$215$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$170$$)],function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($shape_id$jscomp$170$$)});var $text_modifier$jscomp$4$$=$APP.$rumext$v2$deref$$($modifiers$jscomp$123_text_modifier_ref$jscomp$2_width$jscomp$215$$),
$maybe_zoom$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1352$safari_16$$)?$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$):null,$shape__$1$jscomp$112$$=function(){var $G__80806__$1$$=$text_modifier$jscomp$4$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($shape$jscomp$1055$$,$text_modifier$jscomp$4$$):$shape$jscomp$1055$$;return $modifiers__$1$jscomp$17$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__80806__$1$$,
$modifiers__$1$jscomp$17$$):$G__80806__$1$$}(),$bounds$jscomp$85_height$jscomp$183$$=$APP.$app$common$geom$shapes$text$shape__GT_rect$$($shape__$1$jscomp$112$$),$x$jscomp$1273$$=Math.min($bounds$jscomp$85_height$jscomp$183$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$85_height$jscomp$183$$,$APP.$cljs$cst$1515$x$$),$shape__$1$jscomp$112$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1515$x$$)),$y$jscomp$494$$=Math.min($bounds$jscomp$85_height$jscomp$183$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$85_height$jscomp$183$$,$APP.$cljs$cst$1516$y$$),$shape__$1$jscomp$112$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1516$y$$));$modifiers$jscomp$123_text_modifier_ref$jscomp$2_width$jscomp$215$$=Math.max($bounds$jscomp$85_height$jscomp$183$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$85_height$jscomp$183$$,$APP.$cljs$cst$290$width$$),$shape__$1$jscomp$112$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$290$width$$));$bounds$jscomp$85_height$jscomp$183$$=Math.max($bounds$jscomp$85_height$jscomp$183$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$85_height$jscomp$183$$,$APP.$cljs$cst$1527$height$$),$shape__$1$jscomp$112$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1527$height$$));var $style$jscomp$78$$=function(){var $G__80807_G__80807__$1_G__80807__$2$$=
{pointerEvents:"all"};$G__80807_G__80807__$1_G__80807__$2$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1351$safari$$)?$G__80807_G__80807__$1_G__80807__$2$$:$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80807_G__80807__$1_G__80807__$2$$,{transform:"translate("+(($shape__$1$jscomp$112$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1515$x$$))-$x$jscomp$1273$$)+"px, "+(($shape__$1$jscomp$112$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,
$APP.$cljs$cst$1516$y$$))-$y$jscomp$494$$)+"px)"});$G__80807_G__80807__$1_G__80807__$2$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1357$safari_17$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80807_G__80807__$1_G__80807__$2$$,{height:"100%",display:"flex",flexDirection:"column",justifyContent:$app$main$ui$workspace$shapes$text$editor$shape__GT_justify$$($shape__$1$jscomp$112$$)}):$G__80807_G__80807__$1_G__80807__$2$$;return $APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1352$safari_16$$)?
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80807_G__80807__$1_G__80807__$2$$,{position:"fixed",left:0,top:($shape__$1$jscomp$112$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$112$$,$APP.$cljs$cst$1516$y$$))-$y$jscomp$494$$,"transform-origin":"top left",transform:$maybe_zoom$$!=null?"scale("+($maybe_zoom$$??"")+")":null}):$G__80807_G__80807__$1_G__80807__$2$$}();return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"text-editor",clipPath:"url(#"+
($clip_id$jscomp$2_props_80805$$??"")+")",transform:""+($APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$112$$)??""),children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$2_props_80805$$,children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1273$$,y:$y$jscomp$494$$,width:$modifiers$jscomp$123_text_modifier_ref$jscomp$2_width$jscomp$215$$,height:$bounds$jscomp$85_height$jscomp$183$$})})}),(0,$APP.$rumext$v2$jsx$$)("foreignObject",
{x:$x$jscomp$1273$$,y:$y$jscomp$494$$,width:$modifiers$jscomp$123_text_modifier_ref$jscomp$2_width$jscomp$215$$,height:$bounds$jscomp$85_height$jscomp$183$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{style:$style$jscomp$78$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$editor$text_shape_edit_html$$,{shape:$shape__$1$jscomp$112$$},""+($shape_id$jscomp$170$$??""))})})]})};
$app$main$ui$workspace$shapes$text$text_edition_outline$text_edition_outline_STAR_$$=function($props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$){var $zoom$jscomp$86$$=$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$.zoom,$modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$=$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$.modifiers,
$shape$jscomp$1056$$=$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$.shape;if($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")){$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$=
$app$main$data$helpers$get_selrect$$($props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$,$shape$jscomp$1056$$);var $selrect$jscomp$85$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$,0,null);$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$,
1,null);var $sr_height$jscomp$4_vec__80778_y$jscomp$495$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1364$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$85$$),.01);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1364$$)?$or__5025__auto__$jscomp$1364$$:$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$85$$),
.01)}())?function(){var $map__80782_width$jscomp$217$$=$APP.$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1056$$)),$height$jscomp$185_map__80782__$1$$=$APP.$cljs$core$__destructure_map$$($map__80782_width$jscomp$217$$);$map__80782_width$jscomp$217$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$185_map__80782__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$185_map__80782__$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$185_map__80782__$1$$,$APP.$cljs$cst$1527$height$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$map__80782_width$jscomp$217$$,$height$jscomp$185_map__80782__$1$$],null)}():new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$85$$),$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$85$$)],
null);$modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($sr_height$jscomp$4_vec__80778_y$jscomp$495$$,0,null);$sr_height$jscomp$4_vec__80778_y$jscomp$495$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($sr_height$jscomp$4_vec__80778_y$jscomp$495$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("rect",{className:"main viewport-selrect",x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$85$$),
y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$85$$),width:$modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$,height:$sr_height$jscomp$4_vec__80778_y$jscomp$495$$,transform:$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$,style:{stroke:"var(--color-accent-tertiary)",strokeWidth:1/$zoom$jscomp$86$$,fill:"none"}})}var $modifiers__$1$jscomp$18$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1056$$),$APP.$cljs$cst$1816$modifiers$$],null));$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1056$$))],function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1056$$))});
var $text_modifier$jscomp$5$$=$APP.$rumext$v2$deref$$($props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$);$modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$=function(){var $G__80789__$1$$=$modifiers__$1$jscomp$18$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1056$$,$modifiers__$1$jscomp$18$$):$shape$jscomp$1056$$;return $text_modifier$jscomp$5$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($G__80789__$1$$,
$text_modifier$jscomp$5$$):$G__80789__$1$$}();$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$);var $height$jscomp$184_map__80783__$1$$=$APP.$cljs$core$__destructure_map$$($modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$);$modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$184_map__80783__$1$$,$APP.$cljs$cst$1515$x$$);$sr_height$jscomp$4_vec__80778_y$jscomp$495$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$184_map__80783__$1$$,$APP.$cljs$cst$1516$y$$);var $width$jscomp$216$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$184_map__80783__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$184_map__80783__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$184_map__80783__$1$$,
$APP.$cljs$cst$1527$height$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{className:"main viewport-selrect",x:$modifiers$jscomp$124_shape__$1$jscomp$113_sr_width$jscomp$4_x$jscomp$1274$$,y:$sr_height$jscomp$4_vec__80778_y$jscomp$495$$,width:$width$jscomp$216$$,height:$height$jscomp$184_map__80783__$1$$,transform:$props_80764_selrect_transform$jscomp$1_text_modifier_ref$jscomp$3_transform$jscomp$108_vec__80775$$,style:{stroke:"var(--color-accent-tertiary)",strokeWidth:1/$zoom$jscomp$86$$,fill:"none"}})};
$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$=function($JSCompiler_temp$jscomp$1523_background_color$jscomp$1_r$jscomp$inline_9256$$){if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$1523_background_color$jscomp$1_r$jscomp$inline_9256$$)){var $b$jscomp$inline_9258_vec__45387$jscomp$inline_9255$$=$APP.$app$common$types$color$hex__GT_rgb$$($JSCompiler_temp$jscomp$1523_background_color$jscomp$1_r$jscomp$inline_9256$$);$JSCompiler_temp$jscomp$1523_background_color$jscomp$1_r$jscomp$inline_9256$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_9258_vec__45387$jscomp$inline_9255$$,0,null);var $g$jscomp$inline_9257$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_9258_vec__45387$jscomp$inline_9255$$,1,null);$b$jscomp$inline_9258_vec__45387$jscomp$inline_9255$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($b$jscomp$inline_9258_vec__45387$jscomp$inline_9255$$,2,null);$JSCompiler_temp$jscomp$1523_background_color$jscomp$1_r$jscomp$inline_9256$$=
Math.sqrt(.241*$JSCompiler_temp$jscomp$1523_background_color$jscomp$1_r$jscomp$inline_9256$$+.691*$g$jscomp$inline_9257$$+.068*$b$jscomp$inline_9258_vec__45387$jscomp$inline_9255$$)>.5?"#000000":"#ffffff"}else $JSCompiler_temp$jscomp$1523_background_color$jscomp$1_r$jscomp$inline_9256$$=null;return $JSCompiler_temp$jscomp$1523_background_color$jscomp$1_r$jscomp$inline_9256$$};
$app$main$ui$workspace$shapes$text$v2_editor$coalesce_per_tick$$=function($f$jscomp$870$$){var $scheduled_QMARK__STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);return function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($scheduled_QMARK__STAR_$$)))return null;$APP.$cljs$core$reset_BANG_$$($scheduled_QMARK__STAR_$$,!0);return $APP.$app$util$timers$asap$$(function(){$APP.$cljs$core$reset_BANG_$$($scheduled_QMARK__STAR_$$,!1);return $f$jscomp$870$$.$cljs$core$IFn$_invoke$arity$0$?
$f$jscomp$870$$.$cljs$core$IFn$_invoke$arity$0$():$f$jscomp$870$$()})}};
$app$main$ui$workspace$shapes$text$v2_editor$load_fonts_BANG_$$=function($fonts$jscomp$36$$){return $APP.$cljs$core$run_BANG_$$(function($p__80824_variant_id$jscomp$55$$){var $font_id$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80824_variant_id$jscomp$55$$,0,null);$p__80824_variant_id$jscomp$55$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80824_variant_id$jscomp$55$$,1,null);return $font_id$jscomp$37$$!=null?$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($font_id$jscomp$37$$,
$p__80824_variant_id$jscomp$55$$):null},$fonts$jscomp$36$$)};
$app$main$ui$workspace$shapes$text$v2_editor$initialize_event_handlers$$=function($shape_id$jscomp$171$$,$content$jscomp$260$$,$editor_node_editor_ref$jscomp$1$$,$canvas_node$jscomp$1_canvas_ref$jscomp$3$$,$container_ref$jscomp$3$$,$text_color$jscomp$2$$){function $on_clipboard_change$$($event$jscomp$657$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_clipboard_style$$($event$jscomp$657$$.detail))}function $on_change$jscomp$102$$(){var $is_empty_QMARK_$jscomp$1_save_undo_QMARK_$jscomp$13$$=
(0,$APP.$app$main$data$workspace$texts$is_empty_QMARK_$$)($instance$jscomp$13$$);$is_empty_QMARK_$jscomp$1_save_undo_QMARK_$jscomp$13$$=$APP.$cljs$core$not$$($is_empty_QMARK_$jscomp$1_save_undo_QMARK_$jscomp$13$$);var $temp__5825__auto__$jscomp$431$$=$APP.$app$util$text$content$dom__GT_cljs$$((0,$APP.$app$main$data$workspace$texts$get_editor_root$$)($instance$jscomp$13$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$431$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape_id$jscomp$171$$,
$temp__5825__auto__$jscomp$431$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4084$update_name_QMARK_$$,!0,$APP.$cljs$cst$3164$save_undo_QMARK_$$,$is_empty_QMARK_$jscomp$1_save_undo_QMARK_$jscomp$13$$]))):null}function $on_style_change$jscomp$2$$($event$jscomp$656_styles$jscomp$29$$){$event$jscomp$656_styles$jscomp$29$$=$APP.$app$util$text$content$styles$get_styles_from_style_declaration$$($event$jscomp$656_styles$jscomp$29$$.detail);var $fill_color$jscomp$3_fills$jscomp$32$$=
$APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$656_styles$jscomp$29$$);$fill_color$jscomp$3_fills$jscomp$32$$=$APP.$cljs$core$sequential_QMARK_$$($fill_color$jscomp$3_fills$jscomp$32$$)?$APP.$cljs$core$some$$($APP.$cljs$cst$1752$fill_color$$,$fill_color$jscomp$3_fills$jscomp$32$$):null;var $temp__5825__auto___80898$$=$APP.$rumext$v2$ref_val$$($container_ref$jscomp$3$$);$APP.$cljs$core$truth_$$($temp__5825__auto___80898$$)&&$APP.$app$util$dom$set_style_BANG_$$($temp__5825__auto___80898$$,
"--text-editor-caret-color",$APP.$cljs$core$truth_$$($fill_color$jscomp$3_fills$jscomp$32$$)?$fill_color$jscomp$3_fills$jscomp$32$$:$text_color$jscomp$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_editor_styles$$($shape_id$jscomp$171$$,$event$jscomp$656_styles$jscomp$29$$))}function $on_focus$jscomp$20$$(){return $APP.$app$util$dom$set_style_BANG_$$($APP.$rumext$v2$ref_val$$($container_ref$jscomp$3$$),"opacity",1)}
function $on_key_up$jscomp$2$$($event$jscomp$655$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$655$$);return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$655$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()])):null}$editor_node_editor_ref$jscomp$1$$=$APP.$rumext$v2$ref_val$$($editor_node_editor_ref$jscomp$1$$);
$canvas_node$jscomp$1_canvas_ref$jscomp$3$$=$APP.$rumext$v2$ref_val$$($canvas_node$jscomp$1_canvas_ref$jscomp$3$$);var $default_font$jscomp$1_options$jscomp$642$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$default_font$$);$default_font$jscomp$1_options$jscomp$642$$={styleDefaults:$app$util$text$content$styles$get_style_defaults$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1639$fills$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1752$fill_color$$,$text_color$jscomp$2$$,$APP.$cljs$cst$1753$fill_opacity$$,1],null)],null)],null),$APP.$app$common$types$text$default_root_attrs$$,$default_font$jscomp$1_options$jscomp$642$$]))),allowHTMLPaste:$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"text-editor/v2-html-paste")};var $instance$jscomp$13$$=(0,$APP.$app$main$data$workspace$texts$create_editor$$)($editor_node_editor_ref$jscomp$1$$,$canvas_node$jscomp$1_canvas_ref$jscomp$3$$,$default_font$jscomp$1_options$jscomp$642$$),$on_needs_layout$$=$app$main$ui$workspace$shapes$text$v2_editor$coalesce_per_tick$$(function(){var $temp__5825__auto__$jscomp$430$$=$APP.$app$util$text$content$dom__GT_cljs$$((0,$APP.$app$main$data$workspace$texts$get_editor_root$$)($instance$jscomp$13$$));return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$430$$)?
$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$v2_sync_wasm_text_layout$$($shape_id$jscomp$171$$,$temp__5825__auto__$jscomp$430$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape_id$jscomp$171$$,
$temp__5825__auto__$jscomp$430$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4084$update_name_QMARK_$$,!0,$APP.$cljs$cst$3164$save_undo_QMARK_$$,!1]))):null});$APP.$app$util$globals$document$$.addEventListener("keyup",$on_key_up$jscomp$2$$);$instance$jscomp$13$$.addEventListener("focus",$on_focus$jscomp$20$$);$instance$jscomp$13$$.addEventListener("needslayout",$on_needs_layout$$);$instance$jscomp$13$$.addEventListener("stylechange",$on_style_change$jscomp$2$$);$instance$jscomp$13$$.addEventListener("change",
$on_change$jscomp$102$$);$instance$jscomp$13$$.addEventListener("clipboardchange",$on_clipboard_change$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_editor$$($instance$jscomp$13$$));$content$jscomp$260$$!=null&&(0,$APP.$app$main$data$workspace$texts$set_editor_root_BANG_$$)($instance$jscomp$13$$,$app$util$text$content$to_dom$create_root$$($content$jscomp$260$$));$instance$jscomp$13$$!=null&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$focus_editor$$());
return function(){var $temp__5825__auto___80890$jscomp$inline_9260$$=$APP.$app$util$text$content$dom__GT_cljs$$((0,$APP.$app$main$data$workspace$texts$get_editor_root$$)($instance$jscomp$13$$));if($APP.$cljs$core$truth_$$($temp__5825__auto___80890$jscomp$inline_9260$$)){var $current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$=$APP.$cljs$core$_deref$$($APP.$app$main$store$state$$);
$current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$1$($current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$);$current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$,$shape_id$jscomp$171$$);$current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$);
if($instance$jscomp$13$$!=null){var $generated_name_80896$jscomp$inline_9265_result$jscomp$inline_13988$$=$instance$jscomp$13$$.root.textContent;$generated_name_80896$jscomp$inline_9265_result$jscomp$inline_13988$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($generated_name_80896$jscomp$inline_9265_result$jscomp$inline_13988$$,"")?$generated_name_80896$jscomp$inline_9265_result$jscomp$inline_13988$$:null}else $generated_name_80896$jscomp$inline_9265_result$jscomp$inline_13988$$=null;
$current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$=$content$jscomp$260$$==null||$current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$!=null&&$content$jscomp$260$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$,
$APP.$app$common$types$text$generate_shape_name$$($APP.$app$common$types$text$content__GT_text$$($content$jscomp$260$$)));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($shape_id$jscomp$171$$,$temp__5825__auto___80890$jscomp$inline_9260$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4084$update_name_QMARK_$$,$current_name_80895$jscomp$inline_9264_objects_80893$jscomp$inline_9262_shape_80894$jscomp$inline_9263_state_80892$jscomp$inline_9261_update_name_QMARK__80897$jscomp$inline_9266$$,
$APP.$cljs$cst$725$name$$,$generated_name_80896$jscomp$inline_9265_result$jscomp$inline_13988$$,$APP.$cljs$cst$4111$finalize_QMARK_$$,!0,$APP.$cljs$cst$3164$save_undo_QMARK_$$,!0,$APP.$cljs$cst$4109$original_content$$,$content$jscomp$260$$])))}$APP.$app$util$dom$set_style_BANG_$$($APP.$rumext$v2$ref_val$$($container_ref$jscomp$3$$),"opacity",0);$APP.$app$util$globals$document$$.removeEventListener("keyup",$on_key_up$jscomp$2$$);$instance$jscomp$13$$.removeEventListener("focus",$on_focus$jscomp$20$$);
$instance$jscomp$13$$.removeEventListener("needslayout",$on_needs_layout$$);$instance$jscomp$13$$.removeEventListener("stylechange",$on_style_change$jscomp$2$$);$instance$jscomp$13$$.removeEventListener("change",$on_change$jscomp$102$$);$instance$jscomp$13$$.removeEventListener("clipboardchange",$on_clipboard_change$$);(0,$APP.$app$main$data$workspace$texts$dispose_BANG_$$)($instance$jscomp$13$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_editor$$(null))}};
$app$main$ui$workspace$shapes$text$v2_editor$vertical_align_editor_classes$$=function($content$jscomp$261$$,$render_wasm_QMARK_$jscomp$7$$){return $APP.$cljs$core$truth_$$($render_wasm_QMARK_$jscomp$7$$)?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[!0,!1,!1],null):new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$261$$,
"top"),"top"),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$261$$),"center"),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$261$$),"bottom")],null)};
$app$main$ui$workspace$shapes$text$v2_editor$get_color_from_content$$=function($content$jscomp$262_nodes$jscomp$45$$){function $get_color$$($node$jscomp$465$$){var $or__5025__auto__$jscomp$1367$$=$APP.$cljs$core$some$$($APP.$cljs$cst$1752$fill_color$$,$APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$465$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1367$$)?$or__5025__auto__$jscomp$1367$$:$APP.$cljs$cst$1752$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$465$$)}
$content$jscomp$262_nodes$jscomp$45$$=$APP.$cljs$core$tree_seq$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$cst$342$children$$,$content$jscomp$262_nodes$jscomp$45$$);var $or__5025__auto__$jscomp$1366$$=$APP.$cljs$core$some$$($get_color$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80838_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($p1__80838_SHARP_$$,$APP.$cljs$cst$1593$text$$)},$content$jscomp$262_nodes$jscomp$45$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1366$$)?
$or__5025__auto__$jscomp$1366$$:$APP.$cljs$core$some$$($get_color$$,$content$jscomp$262_nodes$jscomp$45$$)};
$app$main$ui$workspace$shapes$text$v2_editor$get_default_text_color$$=function($fill_color$jscomp$4_frame$jscomp$82_p__80841$$){var $background_color$jscomp$2_map__80842__$1$$=$APP.$cljs$core$__destructure_map$$($fill_color$jscomp$4_frame$jscomp$82_p__80841$$);$fill_color$jscomp$4_frame$jscomp$82_p__80841$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color$jscomp$2_map__80842__$1$$,$APP.$cljs$cst$1611$frame$$);$background_color$jscomp$2_map__80842__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($background_color$jscomp$2_map__80842__$1$$,
$APP.$cljs$cst$3839$background_color$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($fill_color$jscomp$4_frame$jscomp$82_p__80841$$)?!$APP.$app$common$files$helpers$root_QMARK_$$($fill_color$jscomp$4_frame$jscomp$82_p__80841$$)&&$APP.$cljs$core$seq$$($APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($fill_color$jscomp$4_frame$jscomp$82_p__80841$$)):$fill_color$jscomp$4_frame$jscomp$82_p__80841$$)?($fill_color$jscomp$4_frame$jscomp$82_p__80841$$=$APP.$cljs$core$some$$(function($p1__80839_SHARP_$$){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$1752$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($p1__80839_SHARP_$$))?
$APP.$cljs$cst$1752$fill_color$$.$cljs$core$IFn$_invoke$arity$1$($p1__80839_SHARP_$$):null},$APP.$cljs$cst$1639$fills$$.$cljs$core$IFn$_invoke$arity$1$($fill_color$jscomp$4_frame$jscomp$82_p__80841$$)),$APP.$cljs$core$truth_$$($fill_color$jscomp$4_frame$jscomp$82_p__80841$$)?$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$($fill_color$jscomp$4_frame$jscomp$82_p__80841$$):$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$($background_color$jscomp$2_map__80842__$1$$)):
$app$main$ui$workspace$shapes$text$v2_editor$get_contrast_color$$($background_color$jscomp$2_map__80842__$1$$)};
$app$main$ui$workspace$shapes$text$v2_editor$shape__GT_justify$$=function($content$jscomp$264_map__80856__$1_p__80855$$){$content$jscomp$264_map__80856__$1_p__80855$$=$APP.$cljs$core$__destructure_map$$($content$jscomp$264_map__80856__$1_p__80855$$);$content$jscomp$264_map__80856__$1_p__80855$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$264_map__80856__$1_p__80855$$,$APP.$cljs$cst$1642$content$$);switch($APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$264_map__80856__$1_p__80855$$),
"top")){case "center":return"center";case "top":return"flex-start";case "bottom":return"flex-end";default:return null}};
$$jscomp$scope$m743970774$0$getRangeRects$$=function($node$jscomp$466$$,$start$jscomp$251$$,$end$jscomp$109$$){const $range$jscomp$17$$=$APP.$goog$global$$.document.createRange();$range$jscomp$17$$.setStart($node$jscomp$466$$,$start$jscomp$251$$);$range$jscomp$17$$.setEnd($node$jscomp$466$$,$end$jscomp$109$$);return[...$range$jscomp$17$$.getClientRects()].filter($r$jscomp$142$$=>$r$jscomp$142$$.width>0)};
$app$util$text_position_data$parse_text_nodes$$=function($parent$jscomp$302$$,$rects$jscomp$1_textNode$jscomp$1$$,$textAlign$$){const $content$jscomp$265$$=$rects$jscomp$1_textNode$jscomp$1$$.textContent,$textSize$$=$content$jscomp$265$$.length;let $from$jscomp$32$$=0,$to$jscomp$28$$=0,$current$jscomp$59$$="",$result$jscomp$386$$=[],$prevRect$$=null,$safeguard$$=!1;for(;$to$jscomp$28$$<$textSize$$;){const $rects$jscomp$2$$=$$jscomp$scope$m743970774$0$getRangeRects$$($rects$jscomp$1_textNode$jscomp$1$$,
$from$jscomp$32$$,$to$jscomp$28$$+1),$splitByWords$$=$textAlign$$=="justify"&&$content$jscomp$265$$[$to$jscomp$28$$].trim()=="";$rects$jscomp$2$$.length>1&&$safeguard$$?($from$jscomp$32$$++,$to$jscomp$28$$++,$safeguard$$=!1):$rects$jscomp$2$$.length>1||$splitByWords$$?($result$jscomp$386$$.push({node:$parent$jscomp$302$$,position:$prevRect$$,text:$current$jscomp$59$$}),$splitByWords$$&&$to$jscomp$28$$++,$from$jscomp$32$$=$to$jscomp$28$$,$current$jscomp$59$$="",$safeguard$$=!0):($prevRect$$=$rects$jscomp$2$$[0],
$current$jscomp$59$$+=$content$jscomp$265$$[$to$jscomp$28$$],$to$jscomp$28$$+=1,$safeguard$$=!1)}$rects$jscomp$1_textNode$jscomp$1$$=$$jscomp$scope$m743970774$0$getRangeRects$$($rects$jscomp$1_textNode$jscomp$1$$,$from$jscomp$32$$,$to$jscomp$28$$);$result$jscomp$386$$.push({node:$parent$jscomp$302$$,position:$rects$jscomp$1_textNode$jscomp$1$$[0],text:$current$jscomp$59$$});return $result$jscomp$386$$};
$app$util$text_svg_position$parse_text_nodes$$=function($parent_node$jscomp$2$$,$direction$jscomp$30$$,$text_node$jscomp$1$$,$text_align$jscomp$4$$){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($entry$jscomp$85$$){return $entry$jscomp$85$$.position!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3817$node$$,$entry$jscomp$85$$.node,$APP.$cljs$cst$1681$position$$,
$app$util$dom$bounding_rect__GT_rect$$($entry$jscomp$85$$.position),$APP.$cljs$cst$1593$text$$,$entry$jscomp$85$$.text,$APP.$cljs$cst$1979$direction$$,$direction$jscomp$30$$],null):null}),$app$util$text_position_data$parse_text_nodes$$($parent_node$jscomp$2$$,$text_node$jscomp$1$$,$text_align$jscomp$4$$))};
$app$util$text_svg_position$resolve_font$$=function($node$jscomp$467_styles$jscomp$30$$){$node$jscomp$467_styles$jscomp$30$$=getComputedStyle($node$jscomp$467_styles$jscomp$30$$);var $font$jscomp$53$$=$node$jscomp$467_styles$jscomp$30$$.getPropertyValue("font"),$font__$1$jscomp$3$$=$APP.$cljs$core$not$$($font$jscomp$53$$)||$APP.$cljs$core$empty_QMARK_$$($font$jscomp$53$$)?""+($node$jscomp$467_styles$jscomp$30$$.getPropertyValue("font-size")??"")+" "+($node$jscomp$467_styles$jscomp$30$$.getPropertyValue("font-family")??
""):$font$jscomp$53$$,$font_id$jscomp$39$$=$node$jscomp$467_styles$jscomp$30$$.getPropertyValue("--font-id");return $APP.$promesa$core$merr$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){console.error("Cannot load font "+($font_id$jscomp$39$$??""));return $APP.$promesa$impl$promise$resolved$$(null)},$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){if($APP.$app$util$globals$document$$.fonts.check($font__$1$jscomp$3$$))var $JSCompiler_temp$jscomp$1901_load_promise$jscomp$inline_9276$$=
null;else $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($app$util$text_svg_position$load_promises$$),$font__$1$jscomp$3$$)?$JSCompiler_temp$jscomp$1901_load_promise$jscomp$inline_9276$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$util$text_svg_position$load_promises$$),$font__$1$jscomp$3$$):($JSCompiler_temp$jscomp$1901_load_promise$jscomp$inline_9276$$=$APP.$app$util$globals$document$$.fonts.load($font__$1$jscomp$3$$),$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$util$text_svg_position$load_promises$$,
$APP.$cljs$core$assoc$$,$font__$1$jscomp$3$$,$JSCompiler_temp$jscomp$1901_load_promise$jscomp$inline_9276$$));return $JSCompiler_temp$jscomp$1901_load_promise$jscomp$inline_9276$$},$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($font_id$jscomp$39$$)))};
$app$util$text_svg_position$process_text_node$$=function($parent_node$jscomp$3$$){var $root$jscomp$68$$=$app$util$dom$get_parent_with_selector$$($parent_node$jscomp$3$$,".text-node-html"),$paragraph$jscomp$15$$=$app$util$dom$get_parent_with_selector$$($parent_node$jscomp$3$$,".paragraph"),$shape_x$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_attribute$$($root$jscomp$68$$,"data-x")),$shape_y$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_attribute$$($root$jscomp$68$$,
"data-y")),$direction$jscomp$31$$=getComputedStyle($parent_node$jscomp$3$$).direction,$text_align$jscomp$5$$=getComputedStyle($paragraph$jscomp$15$$).textAlign;return $APP.$cljs$core$sequence$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__80822_SHARP_$$){return $app$util$text_svg_position$parse_text_nodes$$($parent_node$jscomp$3$$,$direction$jscomp$31$$,$p1__80822_SHARP_$$,$text_align$jscomp$5$$)}),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__80823_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($p1__80823_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1515$x$$],null),$APP.$cljs$core$_PLUS_$$,$shape_x$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1516$y$$],null),$APP.$cljs$core$_PLUS_$$,$shape_y$$)})),$APP.$cljs$core$seq$$($parent_node$jscomp$3$$.childNodes))};
$app$util$text_svg_position$calc_text_node_positions$$=function($shape_id$jscomp$174$$){var $text_nodes$$=$APP.$app$util$dom$query_all$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$("#html-text-node-"+($shape_id$jscomp$174$$??"")),".text-node");return $APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function(){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$util$text_svg_position$process_text_node$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$text_nodes$$]))},
$promesa$core$all$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($app$util$text_svg_position$resolve_font$$,$text_nodes$$)))};
$app$util$text_svg_position$calc_position_data$$=function($shape_id$jscomp$175$$){function $transform_data$$($p__80836_text$jscomp$150$$){var $direction$jscomp$32_map__80837__$1$$=$APP.$cljs$core$__destructure_map$$($p__80836_text$jscomp$150$$),$node$jscomp$468_styles$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($direction$jscomp$32_map__80837__$1$$,$APP.$cljs$cst$3817$node$$),$position$jscomp$214_position__$1$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($direction$jscomp$32_map__80837__$1$$,
$APP.$cljs$cst$1681$position$$);$p__80836_text$jscomp$150$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($direction$jscomp$32_map__80837__$1$$,$APP.$cljs$cst$1593$text$$);$direction$jscomp$32_map__80837__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($direction$jscomp$32_map__80837__$1$$,$APP.$cljs$cst$1979$direction$$);$node$jscomp$468_styles$jscomp$32$$=getComputedStyle($node$jscomp$468_styles$jscomp$32$$);$position$jscomp$214_position__$1$jscomp$10$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($position$jscomp$214_position__$1$jscomp$10$$,
$APP.$cljs$cst$1516$y$$,($position$jscomp$214_position__$1$jscomp$10$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$214_position__$1$jscomp$10$$,$APP.$cljs$cst$1516$y$$))+($position$jscomp$214_position__$1$jscomp$10$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$214_position__$1$jscomp$10$$,$APP.$cljs$cst$1527$height$$)));var $JSCompiler_temp_const$jscomp$1909$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$,$JSCompiler_temp_const$jscomp$1908$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$),$JSCompiler_temp_const$jscomp$1907$$=""+($get_prop$$($node$jscomp$468_styles$jscomp$32$$,"font-style")??""),$JSCompiler_temp_const$jscomp$1906$$=""+($get_prop$$($node$jscomp$468_styles$jscomp$32$$,"text-transform")??""),$JSCompiler_temp_const$jscomp$1905$$=""+($get_prop$$($node$jscomp$468_styles$jscomp$32$$,"font-size")??""),$JSCompiler_temp_const$jscomp$1904$$=""+($get_prop$$($node$jscomp$468_styles$jscomp$32$$,"font-weight")??
""),$JSCompiler_temp_const$jscomp$1903$$=""+($get_prop$$($node$jscomp$468_styles$jscomp$32$$,"text-decoration")??""),$JSCompiler_temp_const$jscomp$1902$$=""+($get_prop$$($node$jscomp$468_styles$jscomp$32$$,"letter-spacing")??""),$or__5025__auto__$jscomp$inline_9278$$=$APP.$app$common$transit$decode_str$$.$cljs$core$IFn$_invoke$arity$1$($get_prop$$($node$jscomp$468_styles$jscomp$32$$,"--fills"));return $JSCompiler_temp_const$jscomp$1909$$.call($APP.$cljs$core$into$$,$position$jscomp$214_position__$1$jscomp$10$$,
$JSCompiler_temp_const$jscomp$1908$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1768$font_style$$,$APP.$cljs$cst$1775$text_transform$$,$APP.$cljs$cst$1766$font_size$$,$APP.$cljs$cst$1767$font_weight$$,$APP.$cljs$cst$1774$text_decoration$$,$APP.$cljs$cst$1772$letter_spacing$$,$APP.$cljs$cst$1639$fills$$,$APP.$cljs$cst$1979$direction$$,$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$1593$text$$],[$JSCompiler_temp_const$jscomp$1907$$,$JSCompiler_temp_const$jscomp$1906$$,$JSCompiler_temp_const$jscomp$1905$$,
$JSCompiler_temp_const$jscomp$1904$$,$JSCompiler_temp_const$jscomp$1903$$,$JSCompiler_temp_const$jscomp$1902$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9278$$)?$or__5025__auto__$jscomp$inline_9278$$:$APP.$app$common$types$text$default_text_fills$$,$direction$jscomp$32_map__80837__$1$$,""+($get_prop$$($node$jscomp$468_styles$jscomp$32$$,"font-family")??""),$p__80836_text$jscomp$150$$]))}function $get_prop$$($styles$jscomp$31_value$jscomp$1005$$,$prop$jscomp$41$$){$styles$jscomp$31_value$jscomp$1005$$=
$styles$jscomp$31_value$jscomp$1005$$.getPropertyValue($prop$jscomp$41$$);return $styles$jscomp$31_value$jscomp$1005$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($styles$jscomp$31_value$jscomp$1005$$,"")?$styles$jscomp$31_value$jscomp$1005$$:null}return $shape_id$jscomp$175$$!=null?$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($text_data$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($transform_data$$,$text_data$$)},$app$util$text_svg_position$calc_text_node_positions$$($shape_id$jscomp$175$$)):
null};
$app$main$ui$workspace$shapes$text$viewport_texts_html$fix_position$$=function($shape$jscomp$1059$$){var $temp__5823__auto__$jscomp$251$$=$APP.$cljs$cst$1816$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1059$$);if($APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$251$$)){var $new_sr_shape_SINGLEQUOTE_$jscomp$13$$=$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1059$$,$temp__5823__auto__$jscomp$251$$),$deltav$jscomp$3_old_sr$$=$APP.$app$common$types$modifiers$safe_size_rect$$($shape$jscomp$1059$$);$new_sr_shape_SINGLEQUOTE_$jscomp$13$$=
$APP.$app$common$types$modifiers$safe_size_rect$$($new_sr_shape_SINGLEQUOTE_$jscomp$13$$);$deltav$jscomp$3_old_sr$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($new_sr_shape_SINGLEQUOTE_$jscomp$13$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($deltav$jscomp$3_old_sr$$));return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1059$$,
$APP.$app$common$types$modifiers$move$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5823__auto__$jscomp$251$$,$deltav$jscomp$3_old_sr$$)),$APP.$cljs$cst$1816$modifiers$$)}return $shape$jscomp$1059$$};
$app$main$ui$workspace$shapes$text$viewport_texts_html$update_shape_with_content$$=function($shape$jscomp$1060$$,$content$jscomp$266$$,$editor_content$$){return $shape$jscomp$1060$$!=null&&$editor_content$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1060$$,$APP.$cljs$cst$1642$content$$,$APP.$app$common$data$txt_merge$$($content$jscomp$266$$,$editor_content$$)):$shape$jscomp$1060$$};
$app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_shape$$=function($p__80844$$,$node$jscomp$469$$){var $map__80845__$1$$=$APP.$cljs$core$__destructure_map$$($p__80844$$),$grow_type$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80845__$1$$,$APP.$cljs$cst$1776$grow_type$$),$id$jscomp$1035$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80845__$1$$,$APP.$cljs$cst$266$id$$),$migrate$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80845__$1$$,
$cljs$cst$5949$migrate$$);return $APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$){$app$common$geom$shapes$text$overlaps_position_data_QMARK_$$($map__80845__$1$$,$map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_position_data$$($id$jscomp$1035$$,$map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$));
if($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2045$auto_height$$,null,$APP.$cljs$cst$2046$auto_width$$,null],null),null),$grow_type$jscomp$11$$)){$map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$=$APP.$app$util$dom$get_bounding_rect$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$469$$,".paragraph-set"));var $height_80903_height_80905__$1_map__80846_80901__$1$$=
$APP.$cljs$core$__destructure_map$$($map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$);$map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height_80903_height_80905__$1_map__80846_80901__$1$$,$APP.$cljs$cst$290$width$$);$height_80903_height_80905__$1_map__80846_80901__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height_80903_height_80905__$1_map__80846_80901__$1$$,$APP.$cljs$cst$1527$height$$);
$map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$=$APP.$app$common$math$ceil$$($map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$);$height_80903_height_80905__$1_map__80846_80901__$1$$=$APP.$app$common$math$ceil$$($height_80903_height_80905__$1_map__80846_80901__$1$$);$APP.$app$common$math$almost_zero_QMARK_$$($map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$)||$APP.$app$common$math$almost_zero_QMARK_$$($height_80903_height_80905__$1_map__80846_80901__$1$$)||
!$APP.$cljs$core$not$$($migrate$$)||$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$resize_text$$($id$jscomp$1035$$,$map__80846_80900_position_data$jscomp$16_width_80902_width_80904__$1$$,$height_80903_height_80905__$1_map__80846_80901__$1$$))}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$clean_text_modifier$$($id$jscomp$1035$$))},$app$util$text_svg_position$calc_position_data$$($id$jscomp$1035$$))};
$app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_modifier$$=function($map__80852__$1_p__80851$$,$node$jscomp$470$$){$map__80852__$1_p__80851$$=$APP.$cljs$core$__destructure_map$$($map__80852__$1_p__80851$$);var $grow_type$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80852__$1_p__80851$$,$APP.$cljs$cst$1776$grow_type$$),$id$jscomp$1036$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80852__$1_p__80851$$,$APP.$cljs$cst$266$id$$);return $APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__80850_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_text_modifier$$($id$jscomp$1036$$,
$p1__80850_SHARP_$$))},$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($G__80854__$1_position_data$jscomp$17_props$jscomp$378$$){$G__80854__$1_position_data$jscomp$17_props$jscomp$378$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1899$position_data$$,$G__80854__$1_position_data$jscomp$17_props$jscomp$378$$],null);if($APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2045$auto_height$$,
null,$APP.$cljs$cst$2046$auto_width$$,null],null),null),$grow_type$jscomp$12$$)){var $map__80853_width$jscomp$221_width__$1$jscomp$11$$=$APP.$app$util$dom$get_client_size$$($APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$02$$($node$jscomp$470$$,".paragraph-set")),$height$jscomp$189_height__$1$jscomp$7_map__80853__$1$$=$APP.$cljs$core$__destructure_map$$($map__80853_width$jscomp$221_width__$1$jscomp$11$$);$map__80853_width$jscomp$221_width__$1$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$189_height__$1$jscomp$7_map__80853__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$189_height__$1$jscomp$7_map__80853__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$189_height__$1$jscomp$7_map__80853__$1$$,$APP.$cljs$cst$1527$height$$);$map__80853_width$jscomp$221_width__$1$jscomp$11$$=$APP.$app$common$math$ceil$$($map__80853_width$jscomp$221_width__$1$jscomp$11$$);$height$jscomp$189_height__$1$jscomp$7_map__80853__$1$$=$APP.$app$common$math$ceil$$($height$jscomp$189_height__$1$jscomp$7_map__80853__$1$$);if($APP.$app$common$math$almost_zero_QMARK_$$($map__80853_width$jscomp$221_width__$1$jscomp$11$$)||
$APP.$app$common$math$almost_zero_QMARK_$$($height$jscomp$189_height__$1$jscomp$7_map__80853__$1$$))return $G__80854__$1_position_data$jscomp$17_props$jscomp$378$$;$G__80854__$1_position_data$jscomp$17_props$jscomp$378$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$12$$,$APP.$cljs$cst$2046$auto_width$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80854__$1_position_data$jscomp$17_props$jscomp$378$$,$APP.$cljs$cst$290$width$$,$map__80853_width$jscomp$221_width__$1$jscomp$11$$):
$G__80854__$1_position_data$jscomp$17_props$jscomp$378$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$12$$,$APP.$cljs$cst$2045$auto_height$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$12$$,$APP.$cljs$cst$2046$auto_width$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__80854__$1_position_data$jscomp$17_props$jscomp$378$$,$APP.$cljs$cst$1527$height$$,$height$jscomp$189_height__$1$jscomp$7_map__80853__$1$$):$G__80854__$1_position_data$jscomp$17_props$jscomp$378$$}return $G__80854__$1_position_data$jscomp$17_props$jscomp$378$$},
$app$util$text_svg_position$calc_position_data$$($id$jscomp$1036$$)))};
$app$main$ui$workspace$shapes$text$viewport_texts_html$text_properties_equal_QMARK_$$=function($shape$jscomp$1066$$,$other$jscomp$203$$){var $and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$=$shape$jscomp$1066$$===$other$jscomp$203$$;return $and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$?$and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$:
($and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1066$$),$APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$203$$)))?($and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1066$$),$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($other$jscomp$203$$)))?($and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1066$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1066$$,$APP.$cljs$cst$1515$x$$),$other$jscomp$203$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$203$$,$APP.$cljs$cst$1515$x$$)),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$)?($and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$=
$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1066$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1066$$,$APP.$cljs$cst$1516$y$$),$other$jscomp$203$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$203$$,$APP.$cljs$cst$1516$y$$)),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$)?
($and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$=$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1066$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1066$$,$APP.$cljs$cst$290$width$$),$other$jscomp$203$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$203$$,$APP.$cljs$cst$290$width$$)),
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$)?$APP.$app$common$math$close_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1066$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1066$$,$APP.$cljs$cst$1527$height$$),$other$jscomp$203$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($other$jscomp$203$$,
$APP.$cljs$cst$1527$height$$)):$and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$):$and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$):$and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$):
$and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$:$and__5023__auto__$jscomp$958_and__5023__auto____$1$jscomp$164_and__5023__auto____$2$jscomp$53_and__5023__auto____$3$jscomp$10_and__5023__auto____$4$jscomp$5_or__5025__auto__$jscomp$1371$$};
$app$main$ui$workspace$shapes$text$viewport_texts_html$text_changes_renderer$$=function($changed_texts_props_80860$$){var $text_shapes$jscomp$2$$=$changed_texts_props_80860$$["text-shapes"],$prev_text_shapes$$=$APP.$app$main$ui$hooks$use_previous$$($text_shapes$jscomp$2$$),$pending_update_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$pending_update$$=$APP.$cljs$core$_deref$$($pending_update_STAR_$$);$changed_texts_props_80860$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes$jscomp$2$$),$APP.$rumext$v2$adapt$$($pending_update$$)],function(){var $pending_shapes$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$vals$$($pending_update$$));return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($text_shapes$jscomp$2$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($id$jscomp$1038_old_shape$jscomp$inline_9282$$){var $JSCompiler_temp$jscomp$1914_new_shape$jscomp$inline_9281$$;
($JSCompiler_temp$jscomp$1914_new_shape$jscomp$inline_9281$$=$APP.$cljs$core$contains_QMARK_$$($pending_shapes$$,$id$jscomp$1038_old_shape$jscomp$inline_9282$$))||($JSCompiler_temp$jscomp$1914_new_shape$jscomp$inline_9281$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes$jscomp$2$$,$id$jscomp$1038_old_shape$jscomp$inline_9282$$),$id$jscomp$1038_old_shape$jscomp$inline_9282$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($prev_text_shapes$$,$id$jscomp$1038_old_shape$jscomp$inline_9282$$),
$JSCompiler_temp$jscomp$1914_new_shape$jscomp$inline_9281$$=$APP.$cljs$cst$2343$session_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$1914_new_shape$jscomp$inline_9281$$))==null&&$APP.$cljs$core$not$$($app$main$ui$workspace$shapes$text$viewport_texts_html$text_properties_equal_QMARK_$$($id$jscomp$1038_old_shape$jscomp$inline_9282$$,$JSCompiler_temp$jscomp$1914_new_shape$jscomp$inline_9281$$))||$APP.$cljs$cst$1899$position_data$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1914_new_shape$jscomp$inline_9281$$)==
null);return $JSCompiler_temp$jscomp$1914_new_shape$jscomp$inline_9281$$},$APP.$cljs$core$keys$$($text_shapes$jscomp$2$$)))});var $handle_update_shape$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($shape$jscomp$1067$$,$node$jscomp$472$$){var $uid$jscomp$2$$=$APP.$app$common$uuid$next$$();$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($pending_update_STAR_$$,$APP.$cljs$core$assoc$$,$uid$jscomp$2$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1067$$));
return $APP.$promesa$core$then$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_shape$$($shape$jscomp$1067$$,$node$jscomp$472$$),function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$3$($pending_update_STAR_$$,$APP.$cljs$core$dissoc$$,$uid$jscomp$2$$)})});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"text-changes-renderer",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$213$$,
$map__80872__$1_p__80871$$){$map__80872__$1_p__80871$$=$APP.$cljs$core$__destructure_map$$($map__80872__$1_p__80871$$);var $id$jscomp$1039$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80872__$1_p__80871$$,$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$213$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_container$$,{shape:$map__80872__$1_p__80871$$,"on-update":$handle_update_shape$$},"text-container-"+($id$jscomp$1039$$??"")));
return $out_arr__44092__auto__$jscomp$213$$},[],$changed_texts_props_80860$$)})};
$app$main$ui$workspace$shapes$text$viewport_texts_html$text_modifiers_renderer$$=function($changed_texts$jscomp$1_props_80874$$){function $text_change_QMARK_$jscomp$2$$($id$jscomp$1040_old_shape$jscomp$3$$){var $new_shape$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes$jscomp$3$$,$id$jscomp$1040_old_shape$jscomp$3$$);$id$jscomp$1040_old_shape$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($prev_text_shapes$jscomp$1$$,$id$jscomp$1040_old_shape$jscomp$3$$);
return $new_shape$jscomp$24$$!=null&&$id$jscomp$1040_old_shape$jscomp$3$$!=null&&$APP.$cljs$core$not$$($app$main$ui$workspace$shapes$text$viewport_texts_html$text_properties_equal_QMARK_$$($id$jscomp$1040_old_shape$jscomp$3$$,$new_shape$jscomp$24$$))}var $text_shapes$jscomp$3$$=$APP.$cljs$core$update_vals$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($changed_texts$jscomp$1_props_80874$$,"text-shapes"),$app$main$ui$workspace$shapes$text$viewport_texts_html$fix_position$$),$prev_text_shapes$jscomp$1$$=
$APP.$app$main$ui$hooks$use_previous$$($text_shapes$jscomp$3$$);$changed_texts$jscomp$1_props_80874$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes$jscomp$3$$)],function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($text_shapes$jscomp$3$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($text_change_QMARK_$jscomp$2$$,$APP.$cljs$core$keys$$($text_shapes$jscomp$3$$)))});var $handle_update_shape$jscomp$1$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_modifier$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"text-changes-renderer",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$214$$,$map__80878__$1_p__80877$$){$map__80878__$1_p__80877$$=$APP.$cljs$core$__destructure_map$$($map__80878__$1_p__80877$$);var $id$jscomp$1041$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80878__$1_p__80877$$,
$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$214$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_container$$,{shape:$map__80878__$1_p__80877$$,"on-update":$handle_update_shape$jscomp$1$$},"text-container-"+($id$jscomp$1041$$??"")));return $out_arr__44092__auto__$jscomp$214$$},[],$changed_texts$jscomp$1_props_80874$$)})};
$app$main$ui$workspace$top_toolbar$mcp_indicator_STAR_$$=function(){var $enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$mcp$$),$conn_status$jscomp$2_mcp_connected_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$,$APP.$cljs$cst$4398$connection_status$$),$has_valid_token_QMARK_$jscomp$2_show_indicator_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$,
$APP.$cljs$cst$4409$token_valid$$);$enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$,$APP.$cljs$cst$3133$enabled$$);$conn_status$jscomp$2_mcp_connected_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("connected",$conn_status$jscomp$2_mcp_connected_QMARK_$$);$has_valid_token_QMARK_$jscomp$2_show_indicator_QMARK_$$=$APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$)?
$has_valid_token_QMARK_$jscomp$2_show_indicator_QMARK_$$:$enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$;var $menu_open_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$=$APP.$cljs$core$_deref$$($menu_open_STAR_$jscomp$1$$);var $toggle_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$658$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$658$$);
return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($menu_open_STAR_$jscomp$1$$,$APP.$cljs$core$not$$)}),$close_menu$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($menu_open_STAR_$jscomp$1$$,!1)}),$connect_mcp$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$mcp$connect_mcp$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"connect-mcp-plugin",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:toolbar"],null))]))});return $APP.$cljs$core$truth_$$($has_valid_token_QMARK_$jscomp$2_show_indicator_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)("li",{children:[(0,$APP.$rumext$v2$jsxs$$)("button",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.mcp"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.mcp"),onClick:$toggle_menu$jscomp$1$$,"data-tool":"mcp","data-testid":"mcp-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button main_ui_workspace_top_toolbar__mcp-button "+($APP.$cljs$core$truth_$$($enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$)?"main_ui_workspace_top_toolbar__selected":
""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_top_toolbar__mcp-status-dot "+($conn_status$jscomp$2_mcp_connected_QMARK_$$?"main_ui_workspace_top_toolbar__connected":"")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_top_toolbar__mcp-button-label "+($conn_status$jscomp$2_mcp_connected_QMARK_$$?"main_ui_workspace_top_toolbar__connected":""),children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.mcp")})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:$enabled_QMARK_$jscomp$9_mcp$jscomp$2_menu_open_QMARK_$jscomp$2$$,onClose:$close_menu$jscomp$3$$,className:"main_ui_workspace_top_toolbar__mcp-menu",children:$conn_status$jscomp$2_mcp_connected_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("li",{role:"presentation",className:"main_ui_workspace_top_toolbar__mcp-menu-info",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.mcp-connected")}):$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_top_toolbar__mcp-menu-item",onClick:$connect_mcp$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.mcp-connect-here")})})]}):null};
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$=function($var_args$jscomp$1474$$){for(var $args__5755__auto__$jscomp$261$$=[],$len__5749__auto___80924$$=arguments.length,$i__5750__auto___80925$$=0;;)if($i__5750__auto___80925$$<$len__5749__auto___80924$$)$args__5755__auto__$jscomp$261$$.push(arguments[$i__5750__auto___80925$$]),$i__5750__auto___80925$$+=1;else break;$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(0<
$args__5755__auto__$jscomp$261$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$261$$.slice(0),0,null):null)};
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$=function($cause53632$jscomp$inline_15096_finalize_QMARK_$jscomp$2_map__80910__$1_p__80909$$){$cause53632$jscomp$inline_15096_finalize_QMARK_$jscomp$2_map__80910__$1_p__80909$$=$APP.$cljs$core$__destructure_map$$($cause53632$jscomp$inline_15096_finalize_QMARK_$jscomp$2_map__80910__$1_p__80909$$);$cause53632$jscomp$inline_15096_finalize_QMARK_$jscomp$2_map__80910__$1_p__80909$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cause53632$jscomp$inline_15096_finalize_QMARK_$jscomp$2_map__80910__$1_p__80909$$,$APP.$cljs$cst$4111$finalize_QMARK_$$);a:{var $JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=
$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$)?$app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$():$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$;if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$)){$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=
$APP.$app$render_wasm$text_editor$text_editor_get_active_shape_id$$();b:{if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $content$jscomp$inline_14966_fn_53631$jscomp$inline_15095$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_export_content;try{var $content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=$content$jscomp$inline_14966_fn_53631$jscomp$inline_15095$$()}catch($e53633$jscomp$inline_15102$$){throw $cause53632$jscomp$inline_15096_finalize_QMARK_$jscomp$2_map__80910__$1_p__80909$$=
$e53633$jscomp$inline_15102$$,$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$)?$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$.$cljs$core$IFn$_invoke$arity$0$?
$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$.$cljs$core$IFn$_invoke$arity$0$():$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$():
null,$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$,
$APP.$cljs$cst$2982$wasm_critical$$),$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=["WASM Error (",$APP.$app$common$data$name$$($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$),
")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_export_content",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$,
$APP.$cljs$cst$273$code$$,$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$],null),$cause53632$jscomp$inline_15096_finalize_QMARK_$jscomp$2_map__80910__$1_p__80909$$);}if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$)?
$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$!==0:$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$)){$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=
$app$render_wasm$mem$read_string$cljs$0core$0IFn$0_invoke$0arity$01$$($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$);$APP.$app$render_wasm$mem$free$$();$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=
JSON.parse($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$);break b}}$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=null}if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$)?
$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$:$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$)&&
($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=$APP.$cljs$core$js__GT_clj$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$127$keywordize_keys$$,!1])),$content$jscomp$inline_14966_fn_53631$jscomp$inline_15095$$=$APP.$app$render_wasm$text_editor$get_cached_content$$($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$),
$APP.$cljs$core$truth_$$($content$jscomp$inline_14966_fn_53631$jscomp$inline_15095$$))){$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=$app$render_wasm$text_editor$merge_exported_texts_into_content$$($content$jscomp$inline_14966_fn_53631$jscomp$inline_15095$$,$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$);
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$render_wasm$text_editor$shape_text_contents$$,$APP.$cljs$core$assoc$$,$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$,$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$);
$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2554$shape_id$$,$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$,
$APP.$cljs$cst$1642$content$$,$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$],null);break a}}$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=
null}$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$)&&($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$),$JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$,$APP.$cljs$cst$2554$shape_id$$),$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$,$APP.$cljs$cst$1642$content$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$v2_update_text_shape_content$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($JSCompiler_inline_result$jscomp$inline_14961_and__5023__auto__$jscomp$inline_14962_code__53067__auto__$jscomp$inline_15099_code_num__53066__auto__$jscomp$inline_15098_read_code_fn__53065__auto__$jscomp$inline_15097_shape_id$jscomp$177_shape_id$jscomp$inline_14963_temp__5825__auto__$jscomp$433$$,
$content$jscomp$269_hint__53068__auto__$jscomp$inline_15100_json_str$jscomp$inline_15101_map__80911__$1_merged$jscomp$inline_14967_new_texts$jscomp$inline_14964_ptr$jscomp$inline_15094_texts_clj$jscomp$inline_14965$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4084$update_name_QMARK_$$,!0,$APP.$cljs$cst$4111$finalize_QMARK_$$,$cause53632$jscomp$inline_15096_finalize_QMARK_$jscomp$2_map__80910__$1_p__80909$$]))))};
$app$main$ui$workspace$shapes$text$v3_editor$text_editor_STAR_$$=function($clip_id$jscomp$4_props_80912$$){var $shape$jscomp$1072$$=$clip_id$jscomp$4_props_80912$$.shape,$shape_id$jscomp$178$$=$shape$jscomp$1072$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1072$$,$APP.$cljs$cst$266$id$$);$clip_id$jscomp$4_props_80912$$="text-edition-clip"+($shape_id$jscomp$178$$??"");var $contenteditable_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$composing_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$=$APP.$app$render_wasm$api$fonts_from_text_content$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1072$$),!1);$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$){$JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$=
$APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$);$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$,"gfont-noto-sans"))?($JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$=$APP.$cuerdas$core$replace$$($JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$,
/gfont\-noto\-sans\-/,""),$JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$)>=3?$APP.$cuerdas$core$capital$$($JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$):$APP.$cuerdas$core$upper$$($JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$)):
$JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$="Noto Color Emoji";return $JSCompiler_inline_result$jscomp$1915_font$jscomp$54_font_id$jscomp$inline_9294_lang$jscomp$inline_9295$$},$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$);var $transform$jscomp$111_vec__80913$$=function(){var $map__80917_max_width$jscomp$9_width$jscomp$224$$=$APP.$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$01$$($shape_id$jscomp$178$$),
$map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$=$APP.$cljs$core$__destructure_map$$($map__80917_max_width$jscomp$9_width$jscomp$224$$);$map__80917_max_width$jscomp$9_width$jscomp$224$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$,$APP.$cljs$cst$290$width$$);var $height$jscomp$192$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$,$APP.$cljs$cst$1527$height$$);
$map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);var $transform$jscomp$112_vec__80918$$=$app$main$data$helpers$get_selrect$$($map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$,$shape$jscomp$1072$$);$map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$112_vec__80918$$,0,null);$transform$jscomp$112_vec__80918$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$112_vec__80918$$,
1,null);var $selrect_height$jscomp$2$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$),$max_height$jscomp$5_selrect_width$jscomp$2$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$);$map__80917_max_width$jscomp$9_width$jscomp$224$$=$map__80917_max_width$jscomp$9_width$jscomp$224$$>$max_height$jscomp$5_selrect_width$jscomp$2$$?$map__80917_max_width$jscomp$9_width$jscomp$224$$:
$max_height$jscomp$5_selrect_width$jscomp$2$$;$max_height$jscomp$5_selrect_width$jscomp$2$$=$height$jscomp$192$$>$selrect_height$jscomp$2$$?$height$jscomp$192$$:$selrect_height$jscomp$2$$;var $valign$jscomp$2$$=$APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1072$$)),$y$jscomp$501$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$);
return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__80917__$1_selrect$jscomp$87_selrect_transform$jscomp$3$$,$APP.$cljs$cst$1516$y$$,function(){switch($valign$jscomp$2$$){case "bottom":return $y$jscomp$501$$+($selrect_height$jscomp$2$$-$height$jscomp$192$$);case "center":return $y$jscomp$501$$+($selrect_height$jscomp$2$$-$height$jscomp$192$$)/2;default:return $y$jscomp$501$$}}(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$290$width$$,$map__80917_max_width$jscomp$9_width$jscomp$224$$,$APP.$cljs$cst$1527$height$$,$max_height$jscomp$5_selrect_width$jscomp$2$$])),$transform$jscomp$112_vec__80918$$],null)}(),$map__80916_x$jscomp$1278$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$111_vec__80913$$,0,null),$height$jscomp$191_map__80916__$1$$=$APP.$cljs$core$__destructure_map$$($map__80916_x$jscomp$1278$$);$map__80916_x$jscomp$1278$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$191_map__80916__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$500$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$191_map__80916__$1$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$223$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$191_map__80916__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$191_map__80916__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$191_map__80916__$1$$,
$APP.$cljs$cst$1527$height$$);$transform$jscomp$111_vec__80913$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$111_vec__80913$$,1,null);var $on_composition_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($composing_QMARK_$$,!0);if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){var $code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$=
$APP.$app$render_wasm$wasm$internal_module$$._text_editor_composition_start;try{var $JSCompiler_inline_result$jscomp$1554_cause53489$jscomp$inline_9298$$=$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$()}catch($e53490$jscomp$inline_9303$$){$JSCompiler_inline_result$jscomp$1554_cause53489$jscomp$inline_9298$$=$e53490$jscomp$inline_9303$$;$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$=$APP.$cljs$core$truth_$$($code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$)?$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$.$cljs$core$IFn$_invoke$arity$0$?
$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$():null;$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto__$jscomp$inline_9302$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto__$jscomp$inline_9302$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_composition_start",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto__$jscomp$inline_9302$$,$APP.$cljs$cst$273$code$$,$code__53067__auto__$jscomp$inline_9301_code_num__53066__auto__$jscomp$inline_9300_fn_53488$jscomp$inline_9297_read_code_fn__53065__auto__$jscomp$inline_9299$$],
null),$JSCompiler_inline_result$jscomp$1554_cause53489$jscomp$inline_9298$$);}}else $JSCompiler_inline_result$jscomp$1554_cause53489$jscomp$inline_9298$$=null;return $JSCompiler_inline_result$jscomp$1554_cause53489$jscomp$inline_9298$$}),$on_composition_update$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$){$APP.$cljs$core$truth_$$($composing_QMARK_$$)||$APP.$cljs$core$reset_BANG_$$($composing_QMARK_$$,
!0);$cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$=$cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$.data;if($APP.$cljs$core$truth_$$($cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$)){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$app$render_wasm$text_editor$text_editor_encode_text_pre$$($cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$);
var $code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$=$APP.$app$render_wasm$wasm$internal_module$$._text_editor_composition_update;try{$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$()}catch($e53494$jscomp$inline_9312$$){$cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$=
$e53494$jscomp$inline_9312$$;$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$=$APP.$cljs$core$truth_$$($code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$)?
$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$():
null;$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$,$APP.$cljs$cst$2982$wasm_critical$$);
var $hint__53068__auto___53748$jscomp$inline_9311$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___53748$jscomp$inline_9311$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_composition_update",
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___53748$jscomp$inline_9311$$,$APP.$cljs$cst$273$code$$,$code__53067__auto___53747$jscomp$inline_9310_code_num__53066__auto___53746$jscomp$inline_9309_fn_53491_53743$jscomp$inline_9306_read_code_fn__53065__auto___53745$jscomp$inline_9308$$],null),$cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$);}!$APP.$cljs$core$empty_QMARK_$$($cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$)&&
$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$app$render_wasm$mem$free$$()}$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$();$APP.$app$render_wasm$api$request_render$$("text-composition")}$cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);return $APP.$cljs$core$truth_$$($cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$)?
$cause53492_53744$jscomp$inline_9307_data$jscomp$500_event$jscomp$661_temp__5825__auto__$jscomp$434$$.textContent="":null}),$on_composition_end$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$){$APP.$cljs$core$reset_BANG_$$($composing_QMARK_$$,!1);$cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$=$cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$.data;
if($APP.$cljs$core$truth_$$($cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$)){if($APP.$app$render_wasm$wasm$context_initialized_QMARK_$$){$app$render_wasm$text_editor$text_editor_encode_text_pre$$($cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$);var $code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$=
$APP.$app$render_wasm$wasm$internal_module$$._text_editor_composition_end;try{$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$()}catch($e53504$jscomp$inline_9321$$){$cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$=$e53504$jscomp$inline_9321$$;$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$=$APP.$cljs$core$truth_$$($code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$)?$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$.$cljs$core$IFn$_invoke$arity$0$?
$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$():null;$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto___53756$jscomp$inline_9320$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$),
")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___53756$jscomp$inline_9320$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_text_editor_composition_end",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___53756$jscomp$inline_9320$$,$APP.$cljs$cst$273$code$$,$code__53067__auto___53755$jscomp$inline_9319_code_num__53066__auto___53754$jscomp$inline_9318_fn_53502_53751$jscomp$inline_9315_read_code_fn__53065__auto___53753$jscomp$inline_9317$$],
null),$cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$);}!$APP.$cljs$core$empty_QMARK_$$($cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$)&&$APP.$app$render_wasm$wasm$context_initialized_QMARK_$$&&$APP.$app$render_wasm$mem$free$$()}$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$();$APP.$app$render_wasm$api$request_render$$("text-composition")}$cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$=
$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);return $APP.$cljs$core$truth_$$($cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$)?$cause53503_53752$jscomp$inline_9316_data$jscomp$501_event$jscomp$662_temp__5825__auto__$jscomp$435$$.textContent="":null}),$on_paste$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$);
$event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$=$event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$.clipboardData.getData("text/plain");$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$)?$APP.$cljs$core$seq$$($event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$):$event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$)&&($app$render_wasm$text_editor$text_editor_insert_text$$($event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$),
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-paste"));$event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);return $APP.$cljs$core$truth_$$($event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$)?$event$jscomp$663_temp__5825__auto__$jscomp$436_text$jscomp$151$$.textContent="":null}),$on_copy$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$664$$){if($APP.$cljs$core$truth_$$($app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$())&&
($APP.$app$util$dom$prevent_default$$($event$jscomp$664$$),$APP.$cljs$core$truth_$$($APP.$app$render_wasm$text_editor$text_editor_get_selection$$()))){var $text$jscomp$152$$=$app$render_wasm$text_editor$text_editor_export_selection$$();return $event$jscomp$664$$.clipboardData.setData("text/plain",$text$jscomp$152$$)}return null}),$on_cut$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$665_temp__5825__auto__$jscomp$437$$){if($APP.$cljs$core$truth_$$($app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$())){$APP.$app$util$dom$prevent_default$$($event$jscomp$665_temp__5825__auto__$jscomp$437$$);
if($APP.$cljs$core$truth_$$($APP.$app$render_wasm$text_editor$text_editor_get_selection$$())){var $text_80929$$=$app$render_wasm$text_editor$text_editor_export_selection$$();$event$jscomp$665_temp__5825__auto__$jscomp$437$$.clipboardData.setData("text/plain",$APP.$cljs$core$truth_$$($text_80929$$)?$text_80929$$:"");$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($text_80929$$)?$APP.$cljs$core$seq$$($text_80929$$):$text_80929$$)&&($app$render_wasm$text_editor$text_editor_delete_backward$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-cut"))}$event$jscomp$665_temp__5825__auto__$jscomp$437$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);return $APP.$cljs$core$truth_$$($event$jscomp$665_temp__5825__auto__$jscomp$437$$)?$event$jscomp$665_temp__5825__auto__$jscomp$437$$.textContent="":null}return null}),$on_key_down$jscomp$27$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$666$$){if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$962$$=
$app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$();return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$962$$)?$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($composing_QMARK_$$)):$and__5023__auto__$jscomp$962$$}())){var $key$jscomp$424_temp__5825__auto__$jscomp$438$$=$event$jscomp$666$$.key,$ctrl_QMARK_$$=function(){var $or__5025__auto__$jscomp$1373$$=$event$jscomp$666$$.ctrlKey;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1373$$)?$or__5025__auto__$jscomp$1373$$:
$event$jscomp$666$$.metaKey}(),$shift_QMARK_$jscomp$33$$=$event$jscomp$666$$.shiftKey;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"Escape"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$key$jscomp$424_temp__5825__auto__$jscomp$438$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$),$APP.$cljs$core$truth_$$($key$jscomp$424_temp__5825__auto__$jscomp$438$$)?$key$jscomp$424_temp__5825__auto__$jscomp$438$$.blur():null;if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($ctrl_QMARK_$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cuerdas$core$lower$$($key$jscomp$424_temp__5825__auto__$jscomp$438$$),"a"):$ctrl_QMARK_$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$app$render_wasm$text_editor$text_editor_select_all$$(),$APP.$app$render_wasm$api$request_render$$("text-select-all");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"Enter"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),
$app$render_wasm$text_editor$text_editor_insert_paragraph$$(),$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-paragraph");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"Backspace"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$app$render_wasm$text_editor$text_editor_delete_backward$cljs$0core$0IFn$0_invoke$0arity$01$$($ctrl_QMARK_$$),
$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-delete-backward");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"Delete"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$app$render_wasm$text_editor$text_editor_delete_forward$cljs$0core$0IFn$0_invoke$0arity$01$$($ctrl_QMARK_$$),$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),
$APP.$app$render_wasm$api$request_render$$("text-delete-forward");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"Insert"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$app$render_wasm$text_editor$text_editor_toggle_overtype_mode$$(),$APP.$app$render_wasm$api$request_render$$("text-overtype-mode");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"ArrowLeft"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),
$app$render_wasm$text_editor$text_editor_move_cursor$$(0,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$33$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"ArrowRight"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$app$render_wasm$text_editor$text_editor_move_cursor$$(1,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$33$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"ArrowUp"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$app$render_wasm$text_editor$text_editor_move_cursor$$(2,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$33$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"ArrowDown"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),
$app$render_wasm$text_editor$text_editor_move_cursor$$(3,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$33$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"Home"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$app$render_wasm$text_editor$text_editor_move_cursor$$(4,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$33$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move");
if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($key$jscomp$424_temp__5825__auto__$jscomp$438$$,"End"))return $APP.$app$util$dom$prevent_default$$($event$jscomp$666$$),$app$render_wasm$text_editor$text_editor_move_cursor$$(5,$ctrl_QMARK_$$,$shift_QMARK_$jscomp$33$$),$APP.$app$render_wasm$api$request_render$$("text-cursor-move")}return null}),$on_input$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$667_input_type$jscomp$3_temp__5825__auto__$jscomp$439$$){var $data$jscomp$502_native_event$jscomp$2$$=
$event$jscomp$667_input_type$jscomp$3_temp__5825__auto__$jscomp$439$$.nativeEvent;$event$jscomp$667_input_type$jscomp$3_temp__5825__auto__$jscomp$439$$=$data$jscomp$502_native_event$jscomp$2$$.inputType;$data$jscomp$502_native_event$jscomp$2$$=$data$jscomp$502_native_event$jscomp$2$$.data;return $APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($composing_QMARK_$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$667_input_type$jscomp$3_temp__5825__auto__$jscomp$439$$,"insertCompositionText")?
($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($data$jscomp$502_native_event$jscomp$2$$)?$APP.$cljs$core$seq$$($data$jscomp$502_native_event$jscomp$2$$):$data$jscomp$502_native_event$jscomp$2$$)&&($app$render_wasm$text_editor$text_editor_insert_text$$($data$jscomp$502_native_event$jscomp$2$$),$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$$(),$APP.$app$render_wasm$api$request_render$$("text-input")),$event$jscomp$667_input_type$jscomp$3_temp__5825__auto__$jscomp$439$$=
$APP.$rumext$v2$ref_val$$($contenteditable_ref$$),$APP.$cljs$core$truth_$$($event$jscomp$667_input_type$jscomp$3_temp__5825__auto__$jscomp$439$$)?$event$jscomp$667_input_type$jscomp$3_temp__5825__auto__$jscomp$439$$.textContent="":null):null}),$on_pointer_down$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$668_off_pt$$){$event$jscomp$668_off_pt$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$668_off_pt$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_pointer_down$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_pointer_down$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$668_off_pt$$):$app$render_wasm$text_editor$text_editor_pointer_down$$($event$jscomp$668_off_pt$$)}),$on_pointer_move$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$669_off_pt$jscomp$1$$){$event$jscomp$669_off_pt$jscomp$1$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$669_off_pt$jscomp$1$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_pointer_move$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_pointer_move$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$669_off_pt$jscomp$1$$):$app$render_wasm$text_editor$text_editor_pointer_move$$($event$jscomp$669_off_pt$jscomp$1$$)}),$on_pointer_up$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$670_off_pt$jscomp$2$$){$event$jscomp$670_off_pt$jscomp$2$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$670_off_pt$jscomp$2$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_pointer_up$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_pointer_up$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$670_off_pt$jscomp$2$$):$app$render_wasm$text_editor$text_editor_pointer_up$$($event$jscomp$670_off_pt$jscomp$2$$)}),$on_click$jscomp$57$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$671_off_pt$jscomp$3$$){$event$jscomp$671_off_pt$jscomp$3$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$671_off_pt$jscomp$3$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$671_off_pt$jscomp$3$$):$app$render_wasm$text_editor$text_editor_set_cursor_from_offset$$($event$jscomp$671_off_pt$jscomp$3$$)}),$on_double_click$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$672_off_pt$jscomp$4$$){$event$jscomp$672_off_pt$jscomp$4$$=$APP.$app$util$dom$get_offset_position$$($event$jscomp$672_off_pt$jscomp$4$$.nativeEvent);return $app$render_wasm$text_editor$text_editor_select_word_boundary$$.$cljs$core$IFn$_invoke$arity$1$?
$app$render_wasm$text_editor$text_editor_select_word_boundary$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$672_off_pt$jscomp$4$$):$app$render_wasm$text_editor$text_editor_select_word_boundary$$($event$jscomp$672_off_pt$jscomp$4$$)}),$on_focus$jscomp$21$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$render_wasm$text_editor$text_editor_focus$$.$cljs$core$IFn$_invoke$arity$1$?$app$render_wasm$text_editor$text_editor_focus$$.$cljs$core$IFn$_invoke$arity$1$($shape_id$jscomp$178$$):
$app$render_wasm$text_editor$text_editor_focus$$($shape_id$jscomp$178$$)}),$on_blur$jscomp$35$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$app$main$ui$workspace$shapes$text$v3_editor$sync_wasm_text_editor_content_BANG_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$4111$finalize_QMARK_$$,!0],null)]));return $app$render_wasm$text_editor$text_editor_blur$$.$cljs$core$IFn$_invoke$arity$0$?
$app$render_wasm$text_editor$text_editor_blur$$.$cljs$core$IFn$_invoke$arity$0$():$app$render_wasm$text_editor$text_editor_blur$$()});$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$={pointerEvents:"all","--editor-container-width":""+($width$jscomp$223$$??"")+"px","--editor-container-height":""+($height$jscomp$191_map__80916__$1$$??"")+"px","--fallback-families":$APP.$cljs$core$seq$$($fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$)?""+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",
$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$)??""):"sourcesanspro"};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($contenteditable_ref$$)],function(){var $temp__5825__auto___80930$$=$APP.$rumext$v2$ref_val$$($contenteditable_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto___80930$$)&&$temp__5825__auto___80930$$.focus();return $on_blur$jscomp$35$$});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $timeout_id$jscomp$1$$=
$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);(function $app$main$ui$workspace$shapes$text$v3_editor$text_editor_STAR__$_schedule_blink$$(){$APP.$cljs$core$truth_$$($app$render_wasm$text_editor$text_editor_has_focus_QMARK_$cljs$0core$0IFn$0_invoke$0arity$00$$())&&$APP.$app$render_wasm$api$request_render$$("cursor-blink");return $APP.$cljs$core$reset_BANG_$$($timeout_id$jscomp$1$$,setTimeout($app$main$ui$workspace$shapes$text$v3_editor$text_editor_STAR__$_schedule_blink$$,250))})();
return function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($timeout_id$jscomp$1$$))?clearTimeout($APP.$cljs$core$_deref$$($timeout_id$jscomp$1$$)):null}});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"text-editor",clipPath:"url(#"+($clip_id$jscomp$4_props_80912$$??"")+")",transform:""+($transform$jscomp$111_vec__80913$$??""),"data-testid":"text-editor",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$4_props_80912$$,children:(0,$APP.$rumext$v2$jsx$$)("rect",
{x:$map__80916_x$jscomp$1278$$,y:$y$jscomp$500$$,width:$width$jscomp$223$$,height:$height$jscomp$191_map__80916__$1$$})})}),(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$map__80916_x$jscomp$1278$$,y:$y$jscomp$500$$,width:$width$jscomp$223$$,height:$height$jscomp$191_map__80916__$1$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$on_click$jscomp$57$$,onDoubleClick:$on_double_click$jscomp$4$$,onPointerDown:$on_pointer_down$jscomp$13$$,onPointerMove:$on_pointer_move$jscomp$9$$,onPointerUp:$on_pointer_up$jscomp$2$$,
style:$fallback_families$jscomp$1_fallback_fonts$jscomp$4_style$jscomp$81$$,className:"main_ui_workspace_shapes_text_v3_editor__text-editor",children:(0,$APP.$rumext$v2$jsx$$)("div",{onCompositionStart:$on_composition_start$$,onCut:$on_cut$$,onPaste:$on_paste$jscomp$2$$,onInput:$on_input$jscomp$1$$,className:""+($app$main$ui$css_cursors$get_dynamic$$("text",$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1072$$))??"")+" main_ui_workspace_shapes_text_v3_editor__text-editor-container",
suppressContentEditableWarning:!0,onCompositionUpdate:$on_composition_update$$,id:"text-editor-wasm-input","data-testid":"text-editor-container",onFocus:$on_focus$jscomp$21$$,onBlur:$on_blur$jscomp$35$$,ref:$contenteditable_ref$$,onCopy:$on_copy$jscomp$1$$,onKeyDown:$on_key_down$jscomp$27$$,onCompositionEnd:$on_composition_end$$,contentEditable:!0})})})]})};
$app$main$ui$workspace$viewport$actions$on_pointer_down$$=function($map__80923__$1_p__80922_type$jscomp$714$$,$selected$jscomp$191$$,$edition$jscomp$12$$,$drawing_tool$jscomp$2$$,$text_editing_QMARK_$jscomp$1$$,$node_editing_QMARK_$$,$grid_editing_QMARK_$$,$drawing_path_QMARK_$$,$create_comment_QMARK_$$,$space_QMARK_$jscomp$1$$,$panning$$,$z_QMARK_$$,$read_only_QMARK_$jscomp$24$$){$map__80923__$1_p__80922_type$jscomp$714$$=$APP.$cljs$core$__destructure_map$$($map__80923__$1_p__80922_type$jscomp$714$$);
var $id$jscomp$1043$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80923__$1_p__80922_type$jscomp$714$$,$APP.$cljs$cst$266$id$$),$blocked$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80923__$1_p__80922_type$jscomp$714$$,$APP.$cljs$cst$1628$blocked$$),$hidden$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80923__$1_p__80922_type$jscomp$714$$,$APP.$cljs$cst$1625$hidden$$);$map__80923__$1_p__80922_type$jscomp$714$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80923__$1_p__80922_type$jscomp$714$$,
$APP.$cljs$cst$139$type$$);return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1043$$),$APP.$rumext$v2$adapt$$($blocked$jscomp$4$$),$APP.$rumext$v2$adapt$$($hidden$jscomp$12$$),$APP.$rumext$v2$adapt$$($map__80923__$1_p__80922_type$jscomp$714$$),$APP.$rumext$v2$adapt$$($selected$jscomp$191$$),$APP.$rumext$v2$adapt$$($edition$jscomp$12$$),$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$2$$),$APP.$rumext$v2$adapt$$($text_editing_QMARK_$jscomp$1$$),
$APP.$rumext$v2$adapt$$($node_editing_QMARK_$$),$APP.$rumext$v2$adapt$$($grid_editing_QMARK_$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$$),$APP.$rumext$v2$adapt$$($create_comment_QMARK_$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($z_QMARK_$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$1$$)),$APP.$rumext$v2$adapt$$($panning$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$24$$)],function($event$jscomp$673$$){var $native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$=
$APP.$app$util$dom$get_target$$($event$jscomp$673$$),$ctrl_QMARK_$jscomp$1_editor_80953$$=$app$util$text$ui$closest_text_editor_content$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$);$APP.$cljs$core$truth_$$($ctrl_QMARK_$jscomp$1_editor_80953$$)?$ctrl_QMARK_$jscomp$1_editor_80953$$.setPointerCapture($event$jscomp$673$$.pointerId):$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$.setPointerCapture($event$jscomp$673$$.pointerId);if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1374_or__5025__auto____$1$jscomp$149$$=
$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$673$$),"viewport-controls");return $or__5025__auto__$jscomp$1374_or__5025__auto____$1$jscomp$149$$?$or__5025__auto__$jscomp$1374_or__5025__auto____$1$jscomp$149$$:($or__5025__auto__$jscomp$1374_or__5025__auto____$1$jscomp$149$$=$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$673$$),"viewport-selrect"))?$or__5025__auto__$jscomp$1374_or__5025__auto____$1$jscomp$149$$:$APP.$app$util$dom$child_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$673$$),
$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".grid-layout-editor"))}())){$APP.$app$util$dom$stop_propagation$$($event$jscomp$673$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($z_QMARK_$$)))return null;$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$=$event$jscomp$673$$.nativeEvent;$ctrl_QMARK_$jscomp$1_editor_80953$$=$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$.ctrlKey;var $meta_QMARK_$$=$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$.metaKey,
$shift_QMARK_$jscomp$34$$=$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$.shiftKey,$alt_QMARK_$jscomp$13$$=$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$.altKey,$mod_QMARK_$jscomp$8$$=$APP.$app$util$keyboard$mod_QMARK_$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$),$left_click_QMARK_$$=$APP.$cljs$core$not$$($panning$$)&&$app$util$dom$left_mouse_QMARK_$$($event$jscomp$673$$),$middle_click_QMARK_$$=$APP.$cljs$core$not$$($panning$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$event$jscomp$673$$.nativeEvent.which);if($APP.$cljs$core$truth_$$($middle_click_QMARK_$$?$middle_click_QMARK_$$:$left_click_QMARK_$$?$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$1$$):$left_click_QMARK_$$))return $APP.$app$util$dom$prevent_default$$($event$jscomp$673$$),$mod_QMARK_$jscomp$8$$?($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$=$APP.$app$util$dom$get_client_position$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$),$native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$=
$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$zoom$start_zooming$$($native_event$jscomp$8_pt$jscomp$29_raw_pt_target_80952$$))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$viewport$start_panning$$());if($left_click_QMARK_$$)return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$1969$down$$,
$ctrl_QMARK_$jscomp$1_editor_80953$$,$shift_QMARK_$jscomp$34$$,$alt_QMARK_$jscomp$13$$,$meta_QMARK_$$,null,null,null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3647$app_DOT_main_DOT_data_DOT_workspace_DOT_specialized_panel_SLASH_interrupt$$])),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$966$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$12$$,$id$jscomp$1043$$);return $and__5023__auto__$jscomp$966$$?$APP.$cljs$core$truth_$$($text_editing_QMARK_$jscomp$1$$)?
$text_editing_QMARK_$jscomp$1$$:$grid_editing_QMARK_$$:$and__5023__auto__$jscomp$966$$}())&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$clear_edition_mode$$()),$APP.$cljs$core$not$$($text_editing_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($blocked$jscomp$4$$)&&$APP.$cljs$core$not$$($hidden$jscomp$12$$)&&$APP.$cljs$core$not$$($create_comment_QMARK_$$)&&$APP.$cljs$core$not$$($drawing_path_QMARK_$$)?$APP.$cljs$core$truth_$$($node_editing_QMARK_$$)?
$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$24$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$path$selection$handle_area_selection$$($shift_QMARK_$jscomp$34$$,$shift_QMARK_$jscomp$34$$&&$mod_QMARK_$jscomp$8$$)):$APP.$cljs$core$truth_$$($drawing_tool$jscomp$2$$)?$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$24$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$drawing$start_drawing$$($drawing_tool$jscomp$2$$)):
$APP.$cljs$core$not$$($id$jscomp$1043$$)||$mod_QMARK_$jscomp$8$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$selection$handle_area_selection$$($shift_QMARK_$jscomp$34$$,$shift_QMARK_$jscomp$34$$&&$mod_QMARK_$jscomp$8$$,$mod_QMARK_$jscomp$8$$)):$APP.$cljs$core$not$$($drawing_tool$jscomp$2$$)?$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$24$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_move_selected$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1043$$,
$shift_QMARK_$jscomp$34$$)):null:null}return null})};
$app$main$ui$workspace$viewport$actions$on_move_selected$$=function($hover$jscomp$5$$,$hover_ids$jscomp$1$$,$selected$jscomp$192$$,$space_QMARK_$jscomp$2$$,$z_QMARK_$jscomp$1$$,$read_only_QMARK_$jscomp$25$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$5$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$1$$)),$APP.$rumext$v2$adapt$$($selected$jscomp$192$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$2$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($z_QMARK_$jscomp$1$$)),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$25$$)],function($bevent$jscomp$2$$){var $event$jscomp$674_mod_QMARK_$jscomp$9$$=$bevent$jscomp$2$$.nativeEvent,$shift_QMARK_$jscomp$35$$=$event$jscomp$674_mod_QMARK_$jscomp$9$$.shiftKey;$event$jscomp$674_mod_QMARK_$jscomp$9$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$674_mod_QMARK_$jscomp$9$$);return $app$util$dom$left_mouse_QMARK_$$($bevent$jscomp$2$$)&&!$event$jscomp$674_mod_QMARK_$jscomp$9$$&&
!$shift_QMARK_$jscomp$35$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$2$$))?($APP.$app$util$dom$prevent_default$$($bevent$jscomp$2$$),$APP.$app$util$dom$stop_propagation$$($bevent$jscomp$2$$),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$25$$)?$read_only_QMARK_$jscomp$25$$:$APP.$cljs$core$_deref$$($z_QMARK_$jscomp$1$$))?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_move_selected$$.$cljs$core$IFn$_invoke$arity$0$())):
null})};
$app$main$ui$workspace$viewport$actions$on_frame_select$$=function($selected$jscomp$193$$,$read_only_QMARK_$jscomp$26$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$193$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$26$$)],function($event$jscomp$675_shift_QMARK_$jscomp$36$$,$id$jscomp$1044$$){$event$jscomp$675_shift_QMARK_$jscomp$36$$=$event$jscomp$675_shift_QMARK_$jscomp$36$$.shiftKey;var $selected_QMARK_$jscomp$21$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$193$$,
$id$jscomp$1044$$),$selected_drawtool$jscomp$1$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$selected_drawing_tool$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($event$jscomp$675_shift_QMARK_$jscomp$36$$||!$selected_QMARK_$jscomp$21$$?$APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1044$$,$event$jscomp$675_shift_QMARK_$jscomp$36$$):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$selected_drawtool$jscomp$1$$==
null&&!$event$jscomp$675_shift_QMARK_$jscomp$36$$&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$26$$)?$APP.$app$main$data$workspace$start_move_selected$$.$cljs$core$IFn$_invoke$arity$0$():null]))})};$app$main$ui$workspace$viewport$actions$on_frame_enter$$=function($frame_hover$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1045$$){return $APP.$cljs$core$reset_BANG_$$($frame_hover$$,$id$jscomp$1045$$)})};
$app$main$ui$workspace$viewport$actions$on_frame_leave$$=function($frame_hover$jscomp$1$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($frame_hover$jscomp$1$$,null)})};
$app$main$ui$workspace$viewport$actions$on_click$$=function($hover$jscomp$6$$,$selected$jscomp$194$$,$edition$jscomp$13$$,$drawing_path_QMARK_$jscomp$1$$,$drawing_tool$jscomp$3$$,$space_QMARK_$jscomp$3$$,$selrect$jscomp$88$$,$z_QMARK_$jscomp$2$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$6$$)),$APP.$rumext$v2$adapt$$($selected$jscomp$194$$),$APP.$rumext$v2$adapt$$($edition$jscomp$13$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$1$$),
$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$3$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$3$$)),$APP.$rumext$v2$adapt$$($selrect$jscomp$88$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($z_QMARK_$jscomp$2$$))],function($event$jscomp$676$$){if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$967_or__5025__auto__$jscomp$1378_or__5025__auto____$1$jscomp$150$$=$selrect$jscomp$88$$==null;if($and__5023__auto__$jscomp$967_or__5025__auto__$jscomp$1378_or__5025__auto____$1$jscomp$150$$){if($and__5023__auto__$jscomp$967_or__5025__auto__$jscomp$1378_or__5025__auto____$1$jscomp$150$$=
$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$676$$),"viewport-controls"))return $and__5023__auto__$jscomp$967_or__5025__auto__$jscomp$1378_or__5025__auto____$1$jscomp$150$$;$and__5023__auto__$jscomp$967_or__5025__auto__$jscomp$1378_or__5025__auto____$1$jscomp$150$$=$APP.$app$util$dom$child_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$676$$),$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".grid-layout-editor"));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$967_or__5025__auto__$jscomp$1378_or__5025__auto____$1$jscomp$150$$)?
$and__5023__auto__$jscomp$967_or__5025__auto__$jscomp$1378_or__5025__auto____$1$jscomp$150$$:$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$676$$),"viewport-selrect")}return $and__5023__auto__$jscomp$967_or__5025__auto__$jscomp$1378_or__5025__auto____$1$jscomp$150$$}())){var $ctrl_QMARK_$jscomp$2$$=$event$jscomp$676$$.ctrlKey,$shift_QMARK_$jscomp$37$$=$event$jscomp$676$$.shiftKey,$alt_QMARK_$jscomp$14$$=$event$jscomp$676$$.altKey,$meta_QMARK_$jscomp$1$$=$event$jscomp$676$$.metaKey,
$hovering_QMARK_$jscomp$3$$=$APP.$cljs$core$_deref$$($hover$jscomp$6$$)!=null,$pt$jscomp$30_raw_pt$jscomp$1$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$676$$);$pt$jscomp$30_raw_pt$jscomp$1$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($pt$jscomp$30_raw_pt$jscomp$1$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$1955$click$$,$ctrl_QMARK_$jscomp$2$$,$shift_QMARK_$jscomp$37$$,$alt_QMARK_$jscomp$14$$,
$meta_QMARK_$jscomp$1$$,null,null,null));$hovering_QMARK_$jscomp$3$$&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$3$$))&&$APP.$cljs$core$not$$($edition$jscomp$13$$)&&$APP.$cljs$core$not$$($drawing_path_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($drawing_tool$jscomp$3$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($hover$jscomp$6$$)),
$shift_QMARK_$jscomp$37$$));return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$968$$=$APP.$cljs$core$_deref$$($z_QMARK_$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$968$$)?$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$3$$))&&$APP.$cljs$core$not$$($edition$jscomp$13$$)&&$APP.$cljs$core$not$$($drawing_path_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($drawing_tool$jscomp$3$$):$and__5023__auto__$jscomp$968$$}())?$alt_QMARK_$jscomp$14$$?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$30_raw_pt$jscomp$1$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$30_raw_pt$jscomp$1$$)):null}return null})};
$app$main$ui$workspace$viewport$actions$on_double_click$$=function($hover$jscomp$7$$,$hover_ids$jscomp$2$$,$selected$jscomp$195$$,$hover_top_frame_id$$,$drawing_path_QMARK_$jscomp$2$$,$objects$jscomp$819$$,$edition$jscomp$14$$,$drawing_tool$jscomp$4$$,$z_QMARK_$jscomp$3$$,$read_only_QMARK_$jscomp$27$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$7$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$)),
$APP.$rumext$v2$adapt$$($selected$jscomp$195$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_top_frame_id$$)),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($edition$jscomp$14$$),$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$4$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($z_QMARK_$jscomp$3$$)),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$27$$)],function($event$jscomp$677_meta_QMARK_$jscomp$2$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$677_meta_QMARK_$jscomp$2$$);
if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($z_QMARK_$jscomp$3$$)))return null;var $ctrl_QMARK_$jscomp$3$$=$event$jscomp$677_meta_QMARK_$jscomp$2$$.ctrlKey,$shift_QMARK_$jscomp$38$$=$event$jscomp$677_meta_QMARK_$jscomp$2$$.shiftKey,$alt_QMARK_$jscomp$15$$=$event$jscomp$677_meta_QMARK_$jscomp$2$$.altKey;$event$jscomp$677_meta_QMARK_$jscomp$2$$=$event$jscomp$677_meta_QMARK_$jscomp$2$$.metaKey;var $selected_id_under_cursor$$=$APP.$cljs$core$last$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$195$$,
$APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$))),$hover_shape$jscomp$2_map__80928_type$jscomp$715$$=function(){var $or__5025__auto__$jscomp$1379_or__5025__auto____$1$jscomp$151$$=$APP.$cljs$core$truth_$$($selected_id_under_cursor$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$819$$,$selected_id_under_cursor$$):null;if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1379_or__5025__auto____$1$jscomp$151$$))return $or__5025__auto__$jscomp$1379_or__5025__auto____$1$jscomp$151$$;
$or__5025__auto__$jscomp$1379_or__5025__auto____$1$jscomp$151$$=$APP.$cljs$core$_deref$$($hover$jscomp$7$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1379_or__5025__auto____$1$jscomp$151$$)?$or__5025__auto__$jscomp$1379_or__5025__auto____$1$jscomp$151$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$819$$,$APP.$cljs$core$first$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$)))}(),$map__80928__$1$$=$APP.$cljs$core$__destructure_map$$($hover_shape$jscomp$2_map__80928_type$jscomp$715$$),
$id$jscomp$1046$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80928__$1$$,$APP.$cljs$cst$266$id$$);$hover_shape$jscomp$2_map__80928_type$jscomp$715$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80928__$1$$,$APP.$cljs$cst$139$type$$);var $editable_QMARK_$jscomp$9$$=$APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$1422$circle$$,null,$APP.$cljs$cst$1617$image$$,
null,$APP.$cljs$cst$1616$rect$$,null,$APP.$cljs$cst$1593$text$$,null],null),null),$hover_shape$jscomp$2_map__80928_type$jscomp$715$$);$hover_shape$jscomp$2_map__80928_type$jscomp$715$$=$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$app$common$files$helpers$is_child_QMARK_$$,$objects$jscomp$819$$,$id$jscomp$1046$$),$APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$)));var $selected_shape$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$819$$,
$hover_shape$jscomp$2_map__80928_type$jscomp$715$$),$grid_layout_id$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$,$objects$jscomp$819$$),$APP.$cljs$core$reverse$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$2$$)));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$2173$double_click$$,$ctrl_QMARK_$jscomp$3$$,
$shift_QMARK_$jscomp$38$$,$alt_QMARK_$jscomp$15$$,$event$jscomp$677_meta_QMARK_$jscomp$2$$,null,null,null));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $and__5023__auto__$jscomp$inline_9324$$=$APP.$cljs$core$not$$($drawing_path_QMARK_$jscomp$2$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9324$$?$map__80928__$1$$:$and__5023__auto__$jscomp$inline_9324$$)?$editable_QMARK_$jscomp$9$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1046$$,
$edition$jscomp$14$$)&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$27$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1046$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$start_editing_selected$$()])):$selected_shape$$!=null?($APP.$cljs$core$reset_BANG_$$($hover$jscomp$7$$,$selected_shape$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($selected_shape$$)))):
$APP.$cljs$core$not$$($selected_shape$$)&&$grid_layout_id$$!=null&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$27$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$start_edition_mode$$($grid_layout_id$$)):null:null})})};
$app$main$ui$workspace$viewport$actions$on_context_menu$$=function($hover$jscomp$8$$,$hover_ids$jscomp$3$$,$read_only_QMARK_$jscomp$28$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$8$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$3$$)),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$28$$)],function($event$jscomp$678$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$678$$);if($APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1380_or__5025__auto____$1$jscomp$152$$=
$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$678$$),"viewport-controls");if($or__5025__auto__$jscomp$1380_or__5025__auto____$1$jscomp$152$$)return $or__5025__auto__$jscomp$1380_or__5025__auto____$1$jscomp$152$$;$or__5025__auto__$jscomp$1380_or__5025__auto____$1$jscomp$152$$=$APP.$app$util$dom$child_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$678$$),$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$(".grid-layout-editor"));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1380_or__5025__auto____$1$jscomp$152$$)?
$or__5025__auto__$jscomp$1380_or__5025__auto____$1$jscomp$152$$:$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$678$$),"viewport-selrect")}())){var $position$jscomp$215$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$678$$);return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$not$$($read_only_QMARK_$jscomp$28$$)&&$APP.$cljs$core$_deref$$($hover$jscomp$8$$)!=
null?$APP.$app$main$data$workspace$show_shape_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1681$position$$,$position$jscomp$215$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$core$_deref$$($hover$jscomp$8$$),$APP.$cljs$cst$2216$hover_ids$$,$APP.$cljs$core$_deref$$($hover_ids$jscomp$3$$)],null)):$APP.$app$main$data$workspace$show_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1681$position$$,$position$jscomp$215$$],null)))})}return null})};
$app$main$ui$workspace$viewport$actions$on_menu_selected$$=function($hover$jscomp$9$$,$hover_ids$jscomp$4$$,$selected$jscomp$196$$,$read_only_QMARK_$jscomp$29$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$9$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$4$$)),$APP.$rumext$v2$adapt$$($selected$jscomp$196$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$29$$)],function($event$jscomp$679_position$jscomp$216$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$679_position$jscomp$216$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$679_position$jscomp$216$$);if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$29$$))return null;$event$jscomp$679_position$jscomp$216$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$679_position$jscomp$216$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$show_shape_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$position$$,$event$jscomp$679_position$jscomp$216$$,
$APP.$cljs$cst$2216$hover_ids$$,$APP.$cljs$core$_deref$$($hover_ids$jscomp$4$$)],null)))})};
$app$main$ui$workspace$viewport$actions$on_pointer_up$$=function($disable_paste_ref$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$680_native_event$jscomp$9$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$680_native_event$jscomp$9$$);$APP.$app$util$dom$get_target$$($event$jscomp$680_native_event$jscomp$9$$).releasePointerCapture($event$jscomp$680_native_event$jscomp$9$$.pointerId);$event$jscomp$680_native_event$jscomp$9$$=$event$jscomp$680_native_event$jscomp$9$$.nativeEvent;
var $ctrl_QMARK_$jscomp$4$$=$event$jscomp$680_native_event$jscomp$9$$.ctrlKey,$shift_QMARK_$jscomp$39$$=$event$jscomp$680_native_event$jscomp$9$$.shiftKey,$alt_QMARK_$jscomp$16$$=$event$jscomp$680_native_event$jscomp$9$$.altKey,$meta_QMARK_$jscomp$3$$=$event$jscomp$680_native_event$jscomp$9$$.metaKey,$left_click_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$event$jscomp$680_native_event$jscomp$9$$.which),$middle_click_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(2,
$event$jscomp$680_native_event$jscomp$9$$.which);$left_click_QMARK_$jscomp$1$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$1970$up$$,$ctrl_QMARK_$jscomp$4$$,$shift_QMARK_$jscomp$39$$,$alt_QMARK_$jscomp$16$$,$meta_QMARK_$jscomp$3$$,null,null,null));$middle_click_QMARK_$jscomp$1$$&&($APP.$app$util$dom$prevent_default$$($event$jscomp$680_native_event$jscomp$9$$),$APP.$rumext$v2$set_ref_val_BANG_$$($disable_paste_ref$$,!0),$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($disable_paste_ref$$,
!1)}));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$viewport$finish_panning$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$zoom$finish_zooming$$()]))})};$app$main$ui$workspace$viewport$actions$on_pointer_enter$$=function($in_viewport_ref$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($in_viewport_ref$$,!0)})};
$app$main$ui$workspace$viewport$actions$on_pointer_leave$$=function($in_viewport_ref$jscomp$1$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($in_viewport_ref$jscomp$1$$,!1)})};
$app$main$ui$workspace$viewport$actions$on_key_down$$=function(){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$681$$){var $bevent$jscomp$3$$=$event$jscomp$681$$.getBrowserEvent(),$key$jscomp$425$$=$event$jscomp$681$$.key,$ctrl_QMARK_$jscomp$5$$=$event$jscomp$681$$.ctrlKey,$shift_QMARK_$jscomp$40$$=$event$jscomp$681$$.shiftKey,$alt_QMARK_$jscomp$17$$=$event$jscomp$681$$.altKey,$meta_QMARK_$jscomp$4$$=$event$jscomp$681$$.metaKey,$mod_QMARK_$jscomp$10$$=
$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$681$$),$editing_QMARK_$jscomp$11_target$jscomp$164$$=$APP.$app$util$dom$get_target$$($event$jscomp$681$$);$editing_QMARK_$jscomp$11_target$jscomp$164$$=$app$util$text$ui$closest_text_editor_content$$($editing_QMARK_$jscomp$11_target$jscomp$164$$)!=null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("rich-text",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$11_target$jscomp$164$$,"className"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("INPUT",
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$11_target$jscomp$164$$,"tagName"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("TEXTAREA",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$11_target$jscomp$164$$,"tagName"));return $APP.$cljs$core$truth_$$($bevent$jscomp$3$$.repeat)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$keyboard$KeyboardEvent$$($APP.$cljs$cst$1969$down$$,
$key$jscomp$425$$,$shift_QMARK_$jscomp$40$$,$ctrl_QMARK_$jscomp$5$$,$alt_QMARK_$jscomp$17$$,$meta_QMARK_$jscomp$4$$,$mod_QMARK_$jscomp$10$$,$editing_QMARK_$jscomp$11_target$jscomp$164$$,$event$jscomp$681$$,null,null,null))})};
$app$main$ui$workspace$viewport$actions$on_key_up$$=function(){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$682$$){var $key$jscomp$426$$=$event$jscomp$682$$.key,$ctrl_QMARK_$jscomp$6$$=$event$jscomp$682$$.ctrlKey,$shift_QMARK_$jscomp$41$$=$event$jscomp$682$$.shiftKey,$alt_QMARK_$jscomp$18$$=$event$jscomp$682$$.altKey,$meta_QMARK_$jscomp$5$$=$event$jscomp$682$$.metaKey,$mod_QMARK_$jscomp$11$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$682$$),
$editing_QMARK_$jscomp$12_target$jscomp$165$$=$APP.$app$util$dom$get_target$$($event$jscomp$682$$);$editing_QMARK_$jscomp$12_target$jscomp$165$$=$app$util$text$ui$closest_text_editor_content$$($editing_QMARK_$jscomp$12_target$jscomp$165$$)!=null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("rich-text",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$12_target$jscomp$165$$,"className"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("INPUT",
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$12_target$jscomp$165$$,"tagName"))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("TEXTAREA",$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_QMARK_$jscomp$12_target$jscomp$165$$,"tagName"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$keyboard$KeyboardEvent$$($APP.$cljs$cst$1970$up$$,$key$jscomp$426$$,$shift_QMARK_$jscomp$41$$,$ctrl_QMARK_$jscomp$6$$,
$alt_QMARK_$jscomp$18$$,$meta_QMARK_$jscomp$5$$,$mod_QMARK_$jscomp$11$$,$editing_QMARK_$jscomp$12_target$jscomp$165$$,$event$jscomp$682$$,null,null,null))})};
$app$main$ui$workspace$viewport$actions$on_pointer_move$$=function($move_stream$jscomp$1$$){var $last_position$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$683$$){var $raw_pt$jscomp$2$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$683$$),$pt$jscomp$31$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($raw_pt$jscomp$2$$),$delta$jscomp$68$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($last_position$$))?
$APP.$app$common$geom$point$subtract$$($raw_pt$jscomp$2$$,$APP.$cljs$core$_deref$$($last_position$$)):$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,0);$move_stream$jscomp$1$$.next($pt$jscomp$31$$);$APP.$cljs$core$reset_BANG_$$($last_position$$,$raw_pt$jscomp$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$PointerEvent$$($APP.$cljs$cst$2178$viewport$$,$pt$jscomp$31$$,$event$jscomp$683$$.ctrlKey,$event$jscomp$683$$.shiftKey,
$event$jscomp$683$$.altKey,$event$jscomp$683$$.metaKey,$delta$jscomp$68$$,null,null,null))})};
$app$main$ui$workspace$viewport$actions$schedule_zoom_BANG_$$=function($state$jscomp$1232$$,$scale$jscomp$45$$,$pt$jscomp$32$$){var $pending_QMARK_$$=$state$jscomp$1232$$.zoomRafId>0;$state$jscomp$1232$$.scale*=$scale$jscomp$45$$;$state$jscomp$1232$$.zoomPt=$pt$jscomp$32$$;return $pending_QMARK_$$?null:$state$jscomp$1232$$.zoomRafId=(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $s$jscomp$593$$=$state$jscomp$1232$$.scale,$zp$$=$state$jscomp$1232$$.zoomPt;$state$jscomp$1232$$.scale=
1;$state$jscomp$1232$$.zoomPt=null;$state$jscomp$1232$$.zoomRafId=0;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$set_zoom$$.$cljs$core$IFn$_invoke$arity$2$($zp$$,$s$jscomp$593$$))})};
$app$main$ui$workspace$viewport$actions$schedule_scroll_BANG_$$=function($state$jscomp$1233$$,$zoom$jscomp$87$$,$event$jscomp$684$$,$delta_x$jscomp$5$$,$delta_y$jscomp$3$$){var $pending_QMARK_$jscomp$1$$=$state$jscomp$1233$$.rafId>0;!$APP.$app$config$check_platform_QMARK_$$()&&$event$jscomp$684$$.shiftKey?$state$jscomp$1233$$.dx+=$delta_y$jscomp$3$$/$zoom$jscomp$87$$:($state$jscomp$1233$$.dx+=$delta_x$jscomp$5$$/$zoom$jscomp$87$$,$state$jscomp$1233$$.dy+=$delta_y$jscomp$3$$/$zoom$jscomp$87$$);$pending_QMARK_$jscomp$1$$||
($state$jscomp$1233$$.rafId=(0,$APP.$app$util$timers$request_animation_frame$$)(function(){var $dx$jscomp$26$$=$state$jscomp$1233$$.dx,$dy$jscomp$26$$=$state$jscomp$1233$$.dy;$state$jscomp$1233$$.dx=0;$state$jscomp$1233$$.dy=0;$state$jscomp$1233$$.rafId=0;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$viewport$update_viewport_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,function($p1__80937_SHARP_$$){return $p1__80937_SHARP_$$+
$dx$jscomp$26$$},$APP.$cljs$cst$1516$y$$,function($p1__80938_SHARP_$$){return $p1__80938_SHARP_$$+$dy$jscomp$26$$}],null)))}))};
$app$main$ui$workspace$viewport$actions$on_mouse_wheel$$=function($zoom_ref$$){var $scroll_state$$=(0,$APP.$rumext$v2$use_ref$$)({dx:0,dy:0,rafId:0,scale:1,zoomPt:null,zoomRafId:0});return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$685_event__$1$jscomp$6$$){$event$jscomp$685_event__$1$jscomp$6$$=$event$jscomp$685_event__$1$jscomp$6$$.getBrowserEvent();var $or__5025__auto__$jscomp$inline_13990_target$jscomp$166$$=$APP.$app$util$dom$get_target$$($event$jscomp$685_event__$1$jscomp$6$$),
$mod_QMARK_$jscomp$12$$=$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$685_event__$1$jscomp$6$$),$ctrl_QMARK_$jscomp$7$$=$event$jscomp$685_event__$1$jscomp$6$$.ctrlKey,$picking_color_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("pixel-overlay",$or__5025__auto__$jscomp$inline_13990_target$jscomp$166$$.id),$comments_layer_QMARK_$$=$APP.$app$util$dom$is_child_QMARK_$$($APP.$goog$dom$getElement$$("comments"),$or__5025__auto__$jscomp$inline_13990_target$jscomp$166$$),$pt$jscomp$33_raw_pt$jscomp$3$$=
$APP.$app$util$dom$get_client_position$$($event$jscomp$685_event__$1$jscomp$6$$);$pt$jscomp$33_raw_pt$jscomp$3$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($pt$jscomp$33_raw_pt$jscomp$3$$);var $delta_x$jscomp$6_norm_event$$=$APP.$$jscomp$scope$1820006746$3$normalizeWheel$$($event$jscomp$685_event__$1$jscomp$6$$),$delta_y$jscomp$4$$=$delta_x$jscomp$6_norm_event$$.pixelY;$delta_x$jscomp$6_norm_event$$=$delta_x$jscomp$6_norm_event$$.pixelX;var $delta_zoom_scale__$1$jscomp$1$$=
$delta_y$jscomp$4$$+$delta_x$jscomp$6_norm_event$$,$scale$jscomp$46$$=1+$APP.$app$common$math$abs$$(-.0057*$delta_zoom_scale__$1$jscomp$1$$);$delta_zoom_scale__$1$jscomp$1$$=$delta_zoom_scale__$1$jscomp$1$$>0?1/$scale$jscomp$46$$:$scale$jscomp$46$$;$or__5025__auto__$jscomp$inline_13990_target$jscomp$166$$=$APP.$app$util$dom$is_child_QMARK_$$($APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$),$or__5025__auto__$jscomp$inline_13990_target$jscomp$166$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13990_target$jscomp$166$$)?
$or__5025__auto__$jscomp$inline_13990_target$jscomp$166$$:$picking_color_QMARK_$jscomp$1$$)&&($APP.$app$util$dom$prevent_default$$($event$jscomp$685_event__$1$jscomp$6$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$685_event__$1$jscomp$6$$),$ctrl_QMARK_$jscomp$7$$||$mod_QMARK_$jscomp$12$$?$app$main$ui$workspace$viewport$actions$schedule_zoom_BANG_$$($APP.$rumext$v2$ref_val$$($scroll_state$$),$delta_zoom_scale__$1$jscomp$1$$,$pt$jscomp$33_raw_pt$jscomp$3$$):$app$main$ui$workspace$viewport$actions$schedule_scroll_BANG_$$($APP.$rumext$v2$ref_val$$($scroll_state$$),
$APP.$rumext$v2$ref_val$$($zoom_ref$$),$event$jscomp$685_event__$1$jscomp$6$$,$delta_x$jscomp$6_norm_event$$,$delta_y$jscomp$4$$));return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($comments_layer_QMARK_$$)?$ctrl_QMARK_$jscomp$7$$||$mod_QMARK_$jscomp$12$$:$comments_layer_QMARK_$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$685_event__$1$jscomp$6$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$685_event__$1$jscomp$6$$),$app$main$ui$workspace$viewport$actions$schedule_zoom_BANG_$$($APP.$rumext$v2$ref_val$$($scroll_state$$),
$delta_zoom_scale__$1$jscomp$1$$,$pt$jscomp$33_raw_pt$jscomp$3$$)):null})};
$app$main$ui$workspace$viewport$actions$on_drag_enter$$=function($comp_inst_ref$$){return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$383$$){var $component_inst_QMARK__80995$$=$APP.$rumext$v2$ref_val$$($comp_inst_ref$$);if($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$971$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$383$$,"penpot/component");return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$971$$)?$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($e$jscomp$383$$),
"viewport-controls")&&$APP.$cljs$core$not$$($component_inst_QMARK__80995$$):$and__5023__auto__$jscomp$971$$}())){var $point_80996_viewport_coord_80997$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$383$$.clientX,$e$jscomp$383$$.clientY);$point_80996_viewport_coord_80997$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($point_80996_viewport_coord_80997$$);var $component_81000_map__80939_80998$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$),
$final_x_81003_map__80939_80999__$1$$=$APP.$cljs$core$__destructure_map$$($component_81000_map__80939_80998$$);$component_81000_map__80939_80998$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($final_x_81003_map__80939_80999__$1$$,$APP.$cljs$cst$1630$component$$);var $file_id_81001$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($final_x_81003_map__80939_80999__$1$$,$APP.$cljs$cst$1649$file_id$$),$final_y_81004_shape_81002$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($final_x_81003_map__80939_80999__$1$$,
$APP.$cljs$cst$1817$shape$$);$final_x_81003_map__80939_80999__$1$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point_80996_viewport_coord_80997$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($final_y_81004_shape_81002$$)/2;$final_y_81004_shape_81002$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point_80996_viewport_coord_80997$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($final_y_81004_shape_81002$$)/2;$APP.$rumext$v2$set_ref_val_BANG_$$($comp_inst_ref$$,
!0);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$instantiate_component$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id_81001$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component_81000_map__80939_80998$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($final_x_81003_map__80939_80999__$1$$,$final_y_81004_shape_81002$$),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3997$start_move_QMARK_$$,
!0,$APP.$cljs$cst$3998$initial_point$$,$point_80996_viewport_coord_80997$$,$APP.$cljs$cst$1792$origin$$,"sidebar"],null)))}return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$383$$,"penpot/shape");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$))return $or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$;
$or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$383$$,"penpot/component");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$))return $or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$;$or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$=
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$383$$,"Files");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$))return $or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$;$or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$383$$,
"text/uri-list");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$)?$or__5025__auto__$jscomp$1382_or__5025__auto____$1$jscomp$153_or__5025__auto____$2$jscomp$36_or__5025__auto____$3$jscomp$10$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$383$$,"text/asset-id")}())?$APP.$app$util$dom$prevent_default$$($e$jscomp$383$$):null})};
$app$main$ui$workspace$viewport$actions$on_drag_over$$=function($move_stream$jscomp$2$$){var $on_pointer_move$jscomp$10$$=$app$main$ui$workspace$viewport$actions$on_pointer_move$$($move_stream$jscomp$2$$),$on_pointer_move__$1$$=$APP.$app$util$rxops$throttle_fn$$(function($e$jscomp$384$$){return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return $on_pointer_move$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$?$on_pointer_move$jscomp$10$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$384$$):
$on_pointer_move$jscomp$10$$($e$jscomp$384$$)})});return $APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($e$jscomp$385$$){return $APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$385$$,"penpot/shape");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$))return $or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$;
$or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$385$$,"penpot/component");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$))return $or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$;$or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$=
$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$385$$,"Files");if($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$))return $or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$;$or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$=$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$385$$,
"text/uri-list");return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$)?$or__5025__auto__$jscomp$1383_or__5025__auto____$1$jscomp$154_or__5025__auto____$2$jscomp$37_or__5025__auto____$3$jscomp$11$$:$APP.$app$util$dom$dnd$has_type_QMARK_$$($e$jscomp$385$$,"text/asset-id")}())?($on_pointer_move__$1$$($e$jscomp$385$$),$APP.$app$util$dom$prevent_default$$($e$jscomp$385$$)):null})};
$app$main$ui$workspace$viewport$actions$on_drop$$=function($file$jscomp$182$$,$comp_inst_ref$jscomp$2$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$){$APP.$app$util$dom$prevent_default$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$);var $event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$.clientX,
$data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$.clientY);$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$);if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$,
"penpot/shape"))){$data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$=$APP.$app$util$dom$dnd$get_data$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$,"penpot/shape");var $data__$1$jscomp$17_final_x_lines$jscomp$7$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$)-$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$)/
2;$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$)-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$)/2;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$add_shape$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$,
$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$()),$APP.$cljs$cst$1515$x$$,$data__$1$jscomp$17_final_x_lines$jscomp$7$$),$APP.$cljs$cst$1516$y$$,$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$)))}if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$,"penpot/component")))return $event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=
$data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$.nativeEvent,$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$MouseEvent$$($APP.$cljs$cst$1970$up$$,$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$.ctrlKey,$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$.shiftKey,$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$.altKey,
$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$.metaKey,null,null,null)),$APP.$rumext$v2$set_ref_val_BANG_$$($comp_inst_ref$jscomp$2$$,!1);if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$,"Files")))return $data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$=$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$.dataTransfer.files),
$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$182$$),$APP.$cljs$cst$1681$position$$,$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$,$APP.$cljs$cst$3748$blobs$$,$APP.$cljs$core$seq$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$)],
null),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$media$upload_media_workspace$$($event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$));if($APP.$cljs$core$truth_$$($APP.$app$util$dom$dnd$has_type_QMARK_$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$,"text/uri-list")))return $data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$=$APP.$app$util$dom$dnd$get_data$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$,
"text/uri-list"),$data__$1$jscomp$17_final_x_lines$jscomp$7$$=$APP.$cuerdas$core$split$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$,/\n|\r\n/),$data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$=$APP.$cljs$core$filterv$$(function($p1__80943_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($p1__80943_SHARP_$$,"http")},$data__$1$jscomp$17_final_x_lines$jscomp$7$$),$data__$1$jscomp$17_final_x_lines$jscomp$7$$=
$APP.$cljs$core$filterv$$(function($p1__80944_SHARP_$$){return $APP.$cuerdas$core$starts_with_QMARK_$$($p1__80944_SHARP_$$,"data:image/")},$data__$1$jscomp$17_final_x_lines$jscomp$7$$),$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$182$$),$APP.$cljs$cst$1681$position$$,$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$],
null),$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=$APP.$cljs$core$seq$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$,$APP.$cljs$cst$3744$uris$$,$data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$):$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$,
$APP.$cljs$cst$3748$blobs$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$util$webapi$data_uri__GT_blob$$,$data__$1$jscomp$17_final_x_lines$jscomp$7$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$media$upload_media_workspace$$($event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$));$data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$=$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$.dataTransfer.files);
$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$182$$),$APP.$cljs$cst$1681$position$$,$event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$,$APP.$cljs$cst$3748$blobs$$,$APP.$cljs$core$seq$$($data$jscomp$503_event$jscomp$686_files$jscomp$32_shape$jscomp$1074_uris$jscomp$12$$)],
null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$media$upload_media_workspace$$($event__$1$jscomp$7_final_y_params$jscomp$434_params__$1$jscomp$59_point$jscomp$82_viewport_coord$$))})};
$app$main$ui$workspace$viewport$actions$on_paste$$=function($disable_paste_ref$jscomp$1$$,$in_viewport_ref$jscomp$2$$,$read_only_QMARK_$jscomp$30$$){return $APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$30$$)],function($event$jscomp$687$$){var $disable_paste_QMARK_$$=$APP.$rumext$v2$ref_val$$($disable_paste_ref$jscomp$1$$),$in_viewport_QMARK_$jscomp$5$$=$APP.$rumext$v2$ref_val$$($in_viewport_ref$jscomp$2$$);return!$APP.$cljs$core$contains_QMARK_$$($app$main$ui$workspace$viewport$actions$invalid_paste_targets$$,
$APP.$app$util$dom$get_tag_name$$($APP.$app$util$dom$get_target$$($event$jscomp$687$$)))&&$APP.$cljs$core$not$$($disable_paste_QMARK_$$)&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$30$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clipboard$paste_from_event$$($event$jscomp$687$$,$in_viewport_QMARK_$jscomp$5$$)):null})};
$app$main$ui$workspace$viewport$comments$use_frame_position_modifier$$=function($frame_id$jscomp$156$$){var $modifiers$jscomp$128$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$),$wasm_mods$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_modifiers$$),$objects$jscomp$820$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$);return $APP.$app$main$data$workspace$comments$frame_pin_transform$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$820$$,
$frame_id$jscomp$156$$),$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$128$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$156$$,$APP.$cljs$cst$1816$modifiers$$],null)),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($wasm_mods$$,$frame_id$jscomp$156$$))};
$app$main$ui$workspace$viewport$comments$comment_floating_bubble_wrapper_STAR_$$=function($props_80932_thread$jscomp$49$$){var $is_open$jscomp$14$$=$props_80932_thread$jscomp$49$$.isOpen,$zoom$jscomp$88$$=$props_80932_thread$jscomp$49$$.zoom;$props_80932_thread$jscomp$49$$=$props_80932_thread$jscomp$49$$.thread;var $position_modifier$jscomp$4$$=$app$main$ui$workspace$viewport$comments$use_frame_position_modifier$$($APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($props_80932_thread$jscomp$49$$));
return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_bubble_STAR_$$,{thread:$props_80932_thread$jscomp$49$$,zoom:$zoom$jscomp$88$$,positionModifier:$position_modifier$jscomp$4$$,isOpen:$is_open$jscomp$14$$})};
$app$main$ui$workspace$viewport$comments$comment_floating_group_wrapper_STAR_$$=function($props_80933_zoom$jscomp$89$$){var $thread_group$jscomp$2$$=$props_80933_zoom$jscomp$89$$.threadGroup;$props_80933_zoom$jscomp$89$$=$props_80933_zoom$jscomp$89$$.zoom;var $position_modifier$jscomp$5_thread$jscomp$50$$=$APP.$cljs$core$first$$($thread_group$jscomp$2$$);$position_modifier$jscomp$5_thread$jscomp$50$$=$app$main$ui$workspace$viewport$comments$use_frame_position_modifier$$($APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($position_modifier$jscomp$5_thread$jscomp$50$$));
return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_group_STAR_$$,{threadGroup:$thread_group$jscomp$2$$,zoom:$props_80933_zoom$jscomp$89$$,positionModifier:$position_modifier$jscomp$5_thread$jscomp$50$$})};
$app$main$ui$workspace$viewport$comments$comment_floating_thread_wrapper_STAR_$$=function($props_80934_thread$jscomp$51$$){var $viewport$jscomp$6$$=$props_80934_thread$jscomp$51$$.viewport,$zoom$jscomp$90$$=$props_80934_thread$jscomp$51$$.zoom;$props_80934_thread$jscomp$51$$=$props_80934_thread$jscomp$51$$.thread;var $position_modifier$jscomp$6$$=$app$main$ui$workspace$viewport$comments$use_frame_position_modifier$$($APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($props_80934_thread$jscomp$51$$));
return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$comments$comment_floating_thread_STAR_$$,{thread:$props_80934_thread$jscomp$51$$,viewport:$viewport$jscomp$6$$,positionModifier:$position_modifier$jscomp$6$$,zoom:$zoom$jscomp$90$$})};
$app$main$ui$workspace$viewport$debug$debug_content_bounds_STAR_$$=function($children$jscomp$309_props_80942_selected_frame$jscomp$1$$){var $children_PLUS_bounds_layout_bounds$jscomp$12_selected_shapes$jscomp$30$$=$children$jscomp$309_props_80942_selected_frame$jscomp$1$$.selectedShapes,$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$=$children$jscomp$309_props_80942_selected_frame$jscomp$1$$.hoverTopFrameId,$zoom$jscomp$92$$=$children$jscomp$309_props_80942_selected_frame$jscomp$1$$.zoom,
$objects$jscomp$821$$=$children$jscomp$309_props_80942_selected_frame$jscomp$1$$.objects;$children$jscomp$309_props_80942_selected_frame$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($children_PLUS_bounds_layout_bounds$jscomp$12_selected_shapes$jscomp$30$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1611$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($children_PLUS_bounds_layout_bounds$jscomp$12_selected_shapes$jscomp$30$$)))?
$APP.$cljs$core$first$$($children_PLUS_bounds_layout_bounds$jscomp$12_selected_shapes$jscomp$30$$):null;$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$=$APP.$cljs$core$truth_$$($children$jscomp$309_props_80942_selected_frame$jscomp$1$$)?$children$jscomp$309_props_80942_selected_frame$jscomp$1$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$821$$,$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)?
$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$):$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)){$children$jscomp$309_props_80942_selected_frame$jscomp$1$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1625$hidden$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$821$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)));
var $bounds$jscomp$87$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$821$$),function($p1__80940_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$821$$,$p1__80940_SHARP_$$),$APP.$cljs$cst$1609$points$$)});$children_PLUS_bounds_layout_bounds$jscomp$12_selected_shapes$jscomp$30$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($shape__$1$jscomp$116$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$deref$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$87$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$116$$))),$shape__$1$jscomp$116$$],null)},$children$jscomp$309_props_80942_selected_frame$jscomp$1$$);var $grid_layout_data$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)?
$APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$,$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$),$children_PLUS_bounds_layout_bounds$jscomp$12_selected_shapes$jscomp$30$$,$bounds$jscomp$87$$,$objects$jscomp$821$$):null;$children_PLUS_bounds_layout_bounds$jscomp$12_selected_shapes$jscomp$30$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)?
$APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_bounds$$($bounds$jscomp$87$$,$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$,$children$jscomp$309_props_80942_selected_frame$jscomp$1$$,$objects$jscomp$821$$):$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)?$APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_bounds$$($bounds$jscomp$87$$,$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$,
$grid_layout_data$$):null;$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)?$APP.$cljs$core$flatten$$($APP.$app$common$geom$shapes$flex_layout$bounds$layout_content_points$$($bounds$jscomp$87$$,$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$,$children$jscomp$309_props_80942_selected_frame$jscomp$1$$,
$objects$jscomp$821$$)):$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)?$APP.$cljs$core$flatten$$($APP.$app$common$geom$shapes$grid_layout$bounds$layout_content_points$$($bounds$jscomp$87$$,$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$,$grid_layout_data$$)):null;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"debug-layout",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)("polygon",
{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80941_SHARP_$$){return""+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80941_SHARP_$$)??"")+", "+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80941_SHARP_$$)??"")},$children_PLUS_bounds_layout_bounds$jscomp$12_selected_shapes$jscomp$30$$)),style:{stroke:"red",fill:"none"}}),(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$216$$,
$p$jscomp$254$$){$out_arr__44092__auto__$jscomp$216$$.push((0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$254$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$254$$),r:4/$zoom$jscomp$92$$,style:{fill:"red"}}));return $out_arr__44092__auto__$jscomp$216$$},[],$hover_top_frame_id$jscomp$1_layout_points$jscomp$2_shape$jscomp$1075$$)})]})}return null};
$app$main$ui$workspace$viewport$debug$debug_layout_lines_STAR_$$=function($bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$){var $selected_shapes$jscomp$31$$=$bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$.selectedShapes,$children$jscomp$310_hover_top_frame_id$jscomp$2_layout_data$jscomp$18$$=$bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$.hoverTopFrameId,$zoom$jscomp$93$$=$bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$.zoom,$objects$jscomp$822$$=$bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$.objects;
$bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$31$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1611$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$31$$)))?$APP.$cljs$core$first$$($selected_shapes$jscomp$31$$):null;var $shape$jscomp$1076$$=$APP.$cljs$core$truth_$$($bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$)?
$bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$822$$,$children$jscomp$310_hover_top_frame_id$jscomp$2_layout_data$jscomp$18$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($shape$jscomp$1076$$)?$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1076$$):$shape$jscomp$1076$$)){var $row_QMARK_$jscomp$14$$=$APP.$app$common$types$shape$layout$row_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1076$$),
$col_QMARK_$jscomp$14$$=$APP.$app$common$types$shape$layout$col_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1076$$);$children$jscomp$310_hover_top_frame_id$jscomp$2_layout_data$jscomp$18$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80945_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__80945_SHARP_$$),
$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1076$$)),$p1__80945_SHARP_$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1625$hidden$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$822$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1076$$))));$bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$822$$),
function($p1__80946_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$822$$,$p1__80946_SHARP_$$),$APP.$cljs$cst$1609$points$$)});$children$jscomp$310_hover_top_frame_id$jscomp$2_layout_data$jscomp$18$$=$APP.$app$common$geom$shapes$flex_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($shape$jscomp$1076$$,$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1076$$),$children$jscomp$310_hover_top_frame_id$jscomp$2_layout_data$jscomp$18$$,
$bounds$jscomp$88_props_80950_selected_frame$jscomp$2$$,$objects$jscomp$822$$);var $layout_bounds$jscomp$13$$=$APP.$cljs$cst$3719$layout_bounds$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$310_hover_top_frame_id$jscomp$2_layout_data$jscomp$18$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"debug-layout",pointerEvents:"none",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$217$$,$map__80958_map__80958__$1_p__80954$$){var $idx$jscomp$130$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80958_map__80958__$1_p__80954$$,0,null);$map__80958_map__80958__$1_p__80954$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80958_map__80958__$1_p__80954$$,1,null);$map__80958_map__80958__$1_p__80954$$=$APP.$cljs$core$__destructure_map$$($map__80958_map__80958__$1_p__80954$$);var $start_p$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80958_map__80958__$1_p__80954$$,$APP.$cljs$cst$3716$start_p$$),
$line_width$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80958_map__80958__$1_p__80954$$,$APP.$cljs$cst$3865$line_width$$),$line_height$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80958_map__80958__$1_p__80954$$,$APP.$cljs$cst$1771$line_height$$),$layout_gap_row$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80958_map__80958__$1_p__80954$$,$APP.$cljs$cst$3867$layout_gap_row$$),$layout_gap_col$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80958_map__80958__$1_p__80954$$,
$APP.$cljs$cst$3868$layout_gap_col$$),$num_children$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80958_map__80958__$1_p__80954$$,$APP.$cljs$cst$3866$num_children$$);$out_arr__44092__auto__$jscomp$217$$.push(function(){var $line_width__$1$jscomp$5_points$jscomp$105$$=$row_QMARK_$jscomp$14$$?$line_width$jscomp$11$$+($num_children$jscomp$8$$-1)*$layout_gap_row$jscomp$13$$:$line_width$jscomp$11$$,$line_height__$1$jscomp$9$$=$col_QMARK_$jscomp$14$$?$line_height$jscomp$24$$+($num_children$jscomp$8$$-
1)*$layout_gap_col$jscomp$13$$:$line_height$jscomp$24$$;$line_width__$1$jscomp$5_points$jscomp$105$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$start_p$jscomp$12$$,$APP.$app$common$geom$point$add$$($start_p$jscomp$12$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$13$$,$line_width__$1$jscomp$5_points$jscomp$105$$)),$APP.$app$common$geom$point$add$$($APP.$app$common$geom$point$add$$($start_p$jscomp$12$$,$APP.$app$common$geom$shapes$points$start_hv$$($layout_bounds$jscomp$13$$,
$line_width__$1$jscomp$5_points$jscomp$105$$)),$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$13$$,$line_height__$1$jscomp$9$$)),$APP.$app$common$geom$point$add$$($start_p$jscomp$12$$,$APP.$app$common$geom$shapes$points$start_vv$$($layout_bounds$jscomp$13$$,$line_height__$1$jscomp$9$$))],null);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"layout-line",children:(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80949_SHARP_$$){return""+
($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80949_SHARP_$$)??"")+", "+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80949_SHARP_$$)??"")},$line_width__$1$jscomp$5_points$jscomp$105$$)),style:{stroke:"red",strokeWidth:2/$zoom$jscomp$93$$,strokeDasharray:""+10/$zoom$jscomp$93$$+" "+5/$zoom$jscomp$93$$}})},"line-"+($idx$jscomp$130$$??""))}());return $out_arr__44092__auto__$jscomp$217$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3075$layout_lines$$.$cljs$core$IFn$_invoke$arity$1$($children$jscomp$310_hover_top_frame_id$jscomp$2_layout_data$jscomp$18$$)))})}return null};
$app$main$ui$workspace$viewport$debug$debug_parent_bounds_STAR_$$=function($props_80982_selected_frame$jscomp$4$$){var $selected_shapes$jscomp$33$$=$props_80982_selected_frame$jscomp$4$$.selectedShapes,$children$jscomp$311_hover_top_frame_id$jscomp$4$$=$props_80982_selected_frame$jscomp$4$$.hoverTopFrameId,$zoom$jscomp$96$$=$props_80982_selected_frame$jscomp$4$$.zoom,$objects$jscomp$824$$=$props_80982_selected_frame$jscomp$4$$.objects;$props_80982_selected_frame$jscomp$4$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$33$$),
1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1611$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$33$$)))?$APP.$cljs$core$first$$($selected_shapes$jscomp$33$$):null;var $parent$jscomp$304$$=$APP.$cljs$core$truth_$$($props_80982_selected_frame$jscomp$4$$)?$props_80982_selected_frame$jscomp$4$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$824$$,$children$jscomp$311_hover_top_frame_id$jscomp$4$$),
$parent_bounds$jscomp$18$$=$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$304$$),$bounds$jscomp$90$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$824$$),function($p1__80981_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$824$$,$p1__80981_SHARP_$$),$APP.$cljs$cst$1609$points$$)});return $parent$jscomp$304$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$304$$))?($children$jscomp$311_hover_top_frame_id$jscomp$4$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1625$hidden$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$824$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$304$$))),(0,$APP.$rumext$v2$jsx$$)("g",{className:"debug-parent-bounds",pointerEvents:"none",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$219$$,
$p__80984$$){var $idx$jscomp$132$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80984$$,0,null),$child$jscomp$125$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__80984$$,1,null);$out_arr__44092__auto__$jscomp$219$$.push((0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$shape_parent_bound_STAR_$$,{zoom:$zoom$jscomp$96$$,shape:$child$jscomp$125$$,parent:$parent$jscomp$304$$},"bound-"+($idx$jscomp$132$$??
"")),function(){var $child_bounds$jscomp$32_points$jscomp$106$$=$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$125$$);$child_bounds$jscomp$32_points$jscomp$106$$=$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$125$$)||$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($child$jscomp$125$$)?$APP.$app$common$geom$shapes$flex_layout$child_layout_bound_points$$.$cljs$core$IFn$_invoke$arity$6$($parent$jscomp$304$$,
$child$jscomp$125$$,$parent_bounds$jscomp$18$$,$child_bounds$jscomp$32_points$jscomp$106$$,$bounds$jscomp$90$$,$objects$jscomp$824$$):$child_bounds$jscomp$32_points$jscomp$106$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$22$$,$point$jscomp$83$$){$out_arr__44092__auto____$1$jscomp$22$$.push((0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$83$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$83$$),
r:2/$zoom$jscomp$96$$,style:{fill:"red"}}));return $out_arr__44092__auto____$1$jscomp$22$$},[],$child_bounds$jscomp$32_points$jscomp$106$$)}()]}));return $out_arr__44092__auto__$jscomp$219$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($children$jscomp$311_hover_top_frame_id$jscomp$4$$))})):null};
$app$main$ui$workspace$viewport$debug$debug_grid_layout_STAR_$$=function($children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$){var $selected_shapes$jscomp$34$$=$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$.selectedShapes,$bounds$jscomp$91_hover_top_frame_id$jscomp$5_map__80994_row_tracks$jscomp$5$$=$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$.hoverTopFrameId,
$zoom$jscomp$97$$=$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$.zoom,$objects$jscomp$825$$=$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$.objects;$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$34$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1611$frame$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$34$$)))?$APP.$cljs$core$first$$($selected_shapes$jscomp$34$$):null;var $parent$jscomp$305$$=$APP.$cljs$core$truth_$$($children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$)?$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$825$$,$bounds$jscomp$91_hover_top_frame_id$jscomp$5_map__80994_row_tracks$jscomp$5$$),
$parent_bounds$jscomp$19$$=$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$305$$);$bounds$jscomp$91_hover_top_frame_id$jscomp$5_map__80994_row_tracks$jscomp$5$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$825$$),function($p1__80989_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$825$$,$p1__80989_SHARP_$$),$APP.$cljs$cst$1609$points$$)});if($parent$jscomp$305$$!=
null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$uuid$zero$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$305$$))){$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80990_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__80990_SHARP_$$),
$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$305$$)),$p1__80990_SHARP_$$],null)},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1625$hidden$$,$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$825$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$305$$))));var $width$jscomp$225$$=$APP.$app$common$geom$shapes$points$width_points$$($parent_bounds$jscomp$19$$),$height$jscomp$193$$=
$APP.$app$common$geom$shapes$points$height_points$$($parent_bounds$jscomp$19$$),$origin$jscomp$72$$=$APP.$app$common$geom$shapes$points$origin$$($parent_bounds$jscomp$19$$);$bounds$jscomp$91_hover_top_frame_id$jscomp$5_map__80994_row_tracks$jscomp$5$$=$APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($parent$jscomp$305$$,$parent_bounds$jscomp$19$$,$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$,$bounds$jscomp$91_hover_top_frame_id$jscomp$5_map__80994_row_tracks$jscomp$5$$,
$objects$jscomp$825$$);$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($bounds$jscomp$91_hover_top_frame_id$jscomp$5_map__80994_row_tracks$jscomp$5$$);$bounds$jscomp$91_hover_top_frame_id$jscomp$5_map__80994_row_tracks$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$,$APP.$cljs$cst$3714$row_tracks$$);$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$,$APP.$cljs$cst$3715$column_tracks$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$220$$,$JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$){var $JSCompiler_temp_const$jscomp$1920$$=
$out_arr__44092__auto__$jscomp$220$$.push;$JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$=$APP.$cljs$cst$2695$distance$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$);$JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$=
$APP.$app$common$geom$shapes$points$start_vv$$($parent_bounds$jscomp$19$$,$JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$);$JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$=$APP.$app$common$geom$point$add$$($origin$jscomp$72$$,$JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$);
var $end_p$jscomp$inline_9340$$=$APP.$app$common$geom$point$add$$($JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$,$APP.$app$common$geom$shapes$points$start_hv$$($parent_bounds$jscomp$19$$,$width$jscomp$225$$));$JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$=(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$),
y1:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$),x2:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$inline_9340$$),y2:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$inline_9340$$),style:{stroke:"red",strokeWidth:1/$zoom$jscomp$97$$}});$JSCompiler_temp_const$jscomp$1920$$.call($out_arr__44092__auto__$jscomp$220$$,
$JSCompiler_inline_result$jscomp$11318_JSCompiler_inline_result$jscomp$1922_p1__80992_SHARP_$jscomp$inline_13992_row_data_start_p$jscomp$inline_9339$$);return $out_arr__44092__auto__$jscomp$220$$},[],$bounds$jscomp$91_hover_top_frame_id$jscomp$5_map__80994_row_tracks$jscomp$5$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$221$$,$JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$){var $JSCompiler_temp_const$jscomp$1923$$=
$out_arr__44092__auto__$jscomp$221$$.push;$JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$=$APP.$cljs$cst$2695$distance$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$);$JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$=
$APP.$app$common$geom$shapes$points$start_hv$$($parent_bounds$jscomp$19$$,$JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$);$JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$=$APP.$app$common$geom$point$add$$($origin$jscomp$72$$,$JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$);
var $end_p$jscomp$inline_9343$$=$APP.$app$common$geom$point$add$$($JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$,$APP.$app$common$geom$shapes$points$start_vv$$($parent_bounds$jscomp$19$$,$height$jscomp$193$$));$JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$=(0,$APP.$rumext$v2$jsx$$)("line",
{x1:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$),y1:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$),x2:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$inline_9343$$),
y2:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end_p$jscomp$inline_9343$$),style:{stroke:"red",strokeWidth:1/$zoom$jscomp$97$$}});$JSCompiler_temp_const$jscomp$1923$$.call($out_arr__44092__auto__$jscomp$221$$,$JSCompiler_inline_result$jscomp$11317_JSCompiler_inline_result$jscomp$1925_column_data_p1__80991_SHARP_$jscomp$inline_13994_start_p$jscomp$inline_9342$$);return $out_arr__44092__auto__$jscomp$221$$},[],$children$jscomp$312_column_tracks$jscomp$5_map__80994__$1_props_80993_selected_frame$jscomp$5$$)]})}return null};
$app$main$ui$workspace$viewport$debug$debug_text_wasm_position_data_STAR_$$=function($position_data$jscomp$18_props_81005_selected_text$jscomp$1$$){var $selected_shapes$jscomp$35$$=$position_data$jscomp$18_props_81005_selected_text$jscomp$1$$.selectedShapes,$zoom$jscomp$98$$=$position_data$jscomp$18_props_81005_selected_text$jscomp$1$$.zoom;$position_data$jscomp$18_props_81005_selected_text$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$35$$),
1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$35$$)))?$APP.$cljs$core$first$$($selected_shapes$jscomp$35$$):null;$position_data$jscomp$18_props_81005_selected_text$jscomp$1$$=$APP.$cljs$core$truth_$$($position_data$jscomp$18_props_81005_selected_text$jscomp$1$$)?$APP.$app$render_wasm$api$calculate_position_data$$($position_data$jscomp$18_props_81005_selected_text$jscomp$1$$):
null;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$222$$,$p__81006_x$jscomp$1279$$){var $height$jscomp$194_map__81007__$1$$=$APP.$cljs$core$__destructure_map$$($p__81006_x$jscomp$1279$$);$p__81006_x$jscomp$1279$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$194_map__81007__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$502$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$194_map__81007__$1$$,$APP.$cljs$cst$1516$y$$),
$width$jscomp$226$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$194_map__81007__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$194_map__81007__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$194_map__81007__$1$$,$APP.$cljs$cst$1527$height$$);$out_arr__44092__auto__$jscomp$222$$.push((0,$APP.$rumext$v2$jsx$$)("rect",{x:$p__81006_x$jscomp$1279$$,y:$y$jscomp$502$$-$height$jscomp$194_map__81007__$1$$,width:$width$jscomp$226$$,height:$height$jscomp$194_map__81007__$1$$,
fill:"none",strokeWidth:1/$zoom$jscomp$98$$,stroke:"red"}));return $out_arr__44092__auto__$jscomp$222$$},[],$position_data$jscomp$18_props_81005_selected_text$jscomp$1$$)};
$app$main$ui$workspace$viewport$drawarea$make_edit_path_ref$$=function($id$jscomp$1048$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__80951_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__80951_SHARP_$$,$APP.$cljs$cst$1940$edit_path$$),$id$jscomp$1048$$)},$APP.$app$main$refs$workspace_local$$)};
$app$main$ui$workspace$viewport$drawarea$generic_draw_area_STAR_$$=function($map__80969_props_80959_x$jscomp$1280$$){var $zoom$jscomp$99$$=$map__80969_props_80959_x$jscomp$1280$$.zoom;$map__80969_props_80959_x$jscomp$1280$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80969_props_80959_x$jscomp$1280$$.shape,$APP.$cljs$cst$1610$selrect$$);var $height$jscomp$195_map__80969__$1$$=$APP.$cljs$core$__destructure_map$$($map__80969_props_80959_x$jscomp$1280$$);$map__80969_props_80959_x$jscomp$1280$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$195_map__80969__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$503$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$195_map__80969__$1$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$227$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$195_map__80969__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$195_map__80969__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$195_map__80969__$1$$,
$APP.$cljs$cst$1527$height$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($map__80969_props_80959_x$jscomp$1280$$)?$APP.$cljs$core$truth_$$($y$jscomp$503$$)?$APP.$cljs$core$not$$(isNaN($map__80969_props_80959_x$jscomp$1280$$))&&$APP.$cljs$core$not$$(isNaN($y$jscomp$503$$)):$y$jscomp$503$$:$map__80969_props_80959_x$jscomp$1280$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{className:"main",x:$map__80969_props_80959_x$jscomp$1280$$,y:$y$jscomp$503$$,width:$width$jscomp$227$$,height:$height$jscomp$195_map__80969__$1$$,
style:{stroke:"var(--color-accent-tertiary)",fill:"none",strokeWidth:1/$zoom$jscomp$99$$}}):null};
$app$main$ui$workspace$viewport$drawarea$path_draw_area_STAR_$$=function($props_80975$$){var $edit_path_ref_edit_path_state_shape$jscomp$1080$$=$props_80975$$.shape,$shape_id$jscomp$179$$=$edit_path_ref_edit_path_state_shape$jscomp$1080$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_ref_edit_path_state_shape$jscomp$1080$$,$APP.$cljs$cst$266$id$$);$edit_path_ref_edit_path_state_shape$jscomp$1080$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$179$$)],
function(){return $app$main$ui$workspace$viewport$drawarea$make_edit_path_ref$$($shape_id$jscomp$179$$)});$edit_path_ref_edit_path_state_shape$jscomp$1080$$=$APP.$rumext$v2$deref$$($edit_path_ref_edit_path_state_shape$jscomp$1080$$);return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$,{...$props_80975$$,state:$edit_path_ref_edit_path_state_shape$jscomp$1080$$})};
$app$main$ui$workspace$viewport$drawarea$draw_area_STAR_$$=function($props_80980$$){var $zoom$jscomp$100$$=$props_80980$$.zoom,$tool$jscomp$4$$=$props_80980$$.tool,$shape$jscomp$1081$$=$props_80980$$.shape;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"draw-area",children:[(0,$APP.$rumext$v2$jsx$$)("g",{style:{pointerEvents:"none"},children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$shapes$shape_wrapper$$,{shape:$shape$jscomp$1081$$})}),function(){switch($tool$jscomp$4$$ instanceof $APP.$cljs$core$Keyword$$?
$tool$jscomp$4$$.$fqn$:null){case "path":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$drawarea$path_draw_area_STAR_$$,$props_80980$$);case "curve":return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$shapes$path$path_shape$$,{shape:$shape$jscomp$1081$$,zoom:$zoom$jscomp$100$$});default:return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$drawarea$generic_draw_area_STAR_$$,$props_80980$$)}}()]})};
$app$main$ui$workspace$viewport$rulers$rulers_clip_path_STAR_$$=function($props_81008$$){var $vbox$jscomp$45$$=$props_81008$$.vbox,$ruler_size$$=22/$props_81008$$.zoom;return(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$props_81008$$.id,children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+$ruler_size$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)+$ruler_size$$,
width:function(){var $y__5111__auto__$jscomp$164$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)-$ruler_size$$;return 0>$y__5111__auto__$jscomp$164$$?0:$y__5111__auto__$jscomp$164$$}(),height:function(){var $y__5111__auto__$jscomp$165$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$45$$)-$ruler_size$$;return 0>$y__5111__auto__$jscomp$165$$?0:$y__5111__auto__$jscomp$165$$}()})})})};
$app$main$ui$workspace$viewport$rulers$get_ruler_params$$=function($end$jscomp$110_vbox$jscomp$48$$,$axis$jscomp$45_start$jscomp$252$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$45_start$jscomp$252$$,$APP.$cljs$cst$1515$x$$)?($axis$jscomp$45_start$jscomp$252$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$110_vbox$jscomp$48$$),$end$jscomp$110_vbox$jscomp$48$$=$axis$jscomp$45_start$jscomp$252$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$110_vbox$jscomp$48$$)):
($axis$jscomp$45_start$jscomp$252$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$110_vbox$jscomp$48$$),$end$jscomp$110_vbox$jscomp$48$$=$axis$jscomp$45_start$jscomp$252$$+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($end$jscomp$110_vbox$jscomp$48$$));return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1297$start$$,$axis$jscomp$45_start$jscomp$252$$,$APP.$cljs$cst$1298$end$$,$end$jscomp$110_vbox$jscomp$48$$],null)};
$app$main$ui$workspace$viewport$rulers$rulers_inside_path$$=function($x1$jscomp$44$$,$y1$jscomp$46$$,$x2$jscomp$41$$,$y2$jscomp$43$$,$br$$,$bw$jscomp$2$$){return"M"+($x1$jscomp$44$$+$bw$jscomp$2$$??"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$+$br$$??"")+"Q"+($x1$jscomp$44$$+$bw$jscomp$2$$??"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$??"")+","+($x1$jscomp$44$$+$bw$jscomp$2$$+$br$$??"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$??"")+"L"+($x2$jscomp$41$$-$br$$)+","+($y1$jscomp$46$$+$bw$jscomp$2$$??"")+"Q"+($x2$jscomp$41$$??
"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$??"")+","+($x2$jscomp$41$$??"")+","+($y1$jscomp$46$$+$bw$jscomp$2$$+$br$$??"")+"L"+($x2$jscomp$41$$??"")+","+($y2$jscomp$43$$-$br$$)+"Q"+($x2$jscomp$41$$??"")+","+($y2$jscomp$43$$??"")+","+($x2$jscomp$41$$-$br$$)+","+($y2$jscomp$43$$??"")+"L"+($x1$jscomp$44$$+$bw$jscomp$2$$+$br$$??"")+","+($y2$jscomp$43$$??"")+"Q"+($x1$jscomp$44$$+$bw$jscomp$2$$??"")+","+($y2$jscomp$43$$??"")+","+($x1$jscomp$44$$+$bw$jscomp$2$$??"")+","+($y2$jscomp$43$$-$br$$)+"Z"};
$app$main$ui$workspace$viewport$rulers$rulers_text_STAR_$$=function($clip_id$jscomp$5_props_81009$$){var $axis$jscomp$47$$=$clip_id$jscomp$5_props_81009$$.axis,$step$jscomp$34$$=$clip_id$jscomp$5_props_81009$$.step,$zoom_inverse$jscomp$5$$=$clip_id$jscomp$5_props_81009$$.zoomInverse,$offset$jscomp$215$$=$clip_id$jscomp$5_props_81009$$.offset,$vbox$jscomp$50$$=$clip_id$jscomp$5_props_81009$$.vbox;$clip_id$jscomp$5_props_81009$$=["clip-ruler-",$APP.$app$common$data$name$$($axis$jscomp$47$$)].join("");
var $map__81010_minv__$2_start$jscomp$253$$=$app$main$ui$workspace$viewport$rulers$get_ruler_params$$($vbox$jscomp$50$$,$axis$jscomp$47$$),$end$jscomp$111_map__81010__$1_maxv__$2$$=$APP.$cljs$core$__destructure_map$$($map__81010_minv__$2_start$jscomp$253$$);$map__81010_minv__$2_start$jscomp$253$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$111_map__81010__$1_maxv__$2$$,$APP.$cljs$cst$1297$start$$);$end$jscomp$111_map__81010__$1_maxv__$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($end$jscomp$111_map__81010__$1_maxv__$2$$,
$APP.$cljs$cst$1298$end$$);$map__81010_minv__$2_start$jscomp$253$$=$APP.$app$common$math$ceil$$(($map__81010_minv__$2_start$jscomp$253$$>-1E5?$map__81010_minv__$2_start$jscomp$253$$:-1E5)/$step$jscomp$34$$)*$step$jscomp$34$$+$APP.$cljs$core$mod$$($offset$jscomp$215$$,$step$jscomp$34$$);$end$jscomp$111_map__81010__$1_maxv__$2$$=$APP.$app$common$math$floor$$(($end$jscomp$111_map__81010__$1_maxv__$2$$<1E5?$end$jscomp$111_map__81010__$1_maxv__$2$$:1E5)/$step$jscomp$34$$)*$step$jscomp$34$$+$APP.$cljs$core$mod$$($offset$jscomp$215$$,
$step$jscomp$34$$);var $rulers_width$jscomp$1$$=1*$zoom_inverse$jscomp$5$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"rulers",clipPath:["url(#",$clip_id$jscomp$5_props_81009$$,")"].join(""),children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$5_props_81009$$,children:function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$47$$,$APP.$cljs$cst$1515$x$$))var $x$jscomp$1283_x$jscomp$inline_9348$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)+
25*$zoom_inverse$jscomp$5$$,$y$jscomp$506_y$jscomp$inline_9349$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$),$width$jscomp$230_width$jscomp$inline_9350$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)-21*$zoom_inverse$jscomp$5$$,$height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$=25*$zoom_inverse$jscomp$5$$;else $x$jscomp$1283_x$jscomp$inline_9348$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$),$y$jscomp$506_y$jscomp$inline_9349$$=
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)+25*$zoom_inverse$jscomp$5$$,$width$jscomp$230_width$jscomp$inline_9350$$=25*$zoom_inverse$jscomp$5$$,$height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)-21*$zoom_inverse$jscomp$5$$;$height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$=$APP.$cljs$core$__destructure_map$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1515$x$$,
$x$jscomp$1283_x$jscomp$inline_9348$$,$APP.$cljs$cst$1516$y$$,$y$jscomp$506_y$jscomp$inline_9349$$,$APP.$cljs$cst$290$width$$,$width$jscomp$230_width$jscomp$inline_9350$$,$APP.$cljs$cst$1527$height$$,$height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$],null));$x$jscomp$1283_x$jscomp$inline_9348$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$,$APP.$cljs$cst$1515$x$$);$y$jscomp$506_y$jscomp$inline_9349$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$,
$APP.$cljs$cst$1516$y$$);$width$jscomp$230_width$jscomp$inline_9350$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$,$APP.$cljs$cst$1527$height$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1283_x$jscomp$inline_9348$$,
y:$y$jscomp$506_y$jscomp$inline_9349$$,width:$width$jscomp$230_width$jscomp$inline_9350$$,height:$height$jscomp$198_height$jscomp$inline_9351_map__81011__$1$$})}()})}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$223$$,$JSCompiler_inline_result$jscomp$1928_step_val$$){var $JSCompiler_temp_const$jscomp$1926$$=$out_arr__44092__auto__$jscomp$223$$.push;var $map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$=
15*$zoom_inverse$jscomp$5$$;var $rulers_size$jscomp$inline_14001_text_y$jscomp$inline_9356$$=4*$zoom_inverse$jscomp$5$$;$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$47$$,$APP.$cljs$cst$1515$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5950$text_x$$,$JSCompiler_inline_result$jscomp$1928_step_val$$,$cljs$cst$5951$text_y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)+
$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$+-1*$zoom_inverse$jscomp$5$$,$cljs$cst$5952$line_x1$$,$JSCompiler_inline_result$jscomp$1928_step_val$$,$cljs$cst$5953$line_y1$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)+$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$+2*$zoom_inverse$jscomp$5$$,$cljs$cst$5954$line_x2$$,$JSCompiler_inline_result$jscomp$1928_step_val$$,$cljs$cst$5955$line_y2$$,
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)+$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$+2*$zoom_inverse$jscomp$5$$+$rulers_size$jscomp$inline_14001_text_y$jscomp$inline_9356$$],null):new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5950$text_x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)+$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$+-1*
$zoom_inverse$jscomp$5$$,$cljs$cst$5951$text_y$$,$JSCompiler_inline_result$jscomp$1928_step_val$$,$cljs$cst$5952$line_x1$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)+$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$+2*$zoom_inverse$jscomp$5$$,$cljs$cst$5953$line_y1$$,$JSCompiler_inline_result$jscomp$1928_step_val$$,$cljs$cst$5954$line_x2$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$50$$)+$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$+
2*$zoom_inverse$jscomp$5$$+$rulers_size$jscomp$inline_14001_text_y$jscomp$inline_9356$$,$cljs$cst$5955$line_y2$$,$JSCompiler_inline_result$jscomp$1928_step_val$$],null);var $line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$=$APP.$cljs$core$__destructure_map$$($map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$);$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$,
$cljs$cst$5950$text_x$$);$rulers_size$jscomp$inline_14001_text_y$jscomp$inline_9356$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$,$cljs$cst$5951$text_y$$);var $line_x1$jscomp$inline_9357$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$,$cljs$cst$5952$line_x1$$),$line_y1$jscomp$inline_9358$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$,
$cljs$cst$5953$line_y1$$),$line_x2$jscomp$inline_9359$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$,$cljs$cst$5954$line_x2$$);$line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$,$cljs$cst$5955$line_y2$$);$JSCompiler_inline_result$jscomp$1928_step_val$$=(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)("text",{x:$map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$,y:$rulers_size$jscomp$inline_14001_text_y$jscomp$inline_9356$$,textAnchor:"middle",transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$47$$,$APP.$cljs$cst$1516$y$$)?["rotate(-90 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81012$jscomp$inline_9353_rulers_pos$jscomp$inline_14000_text_x$jscomp$inline_9355$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($rulers_size$jscomp$inline_14001_text_y$jscomp$inline_9356$$),
")"].join(""):null,style:{fontSize:12*$zoom_inverse$jscomp$5$$,fontFamily:"worksans",fill:"var(--layer-row-foreground-color)"},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_inline_result$jscomp$1928_step_val$$-$offset$jscomp$215$$)}),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$line_x1$jscomp$inline_9357$$,y1:$line_y1$jscomp$inline_9358$$,x2:$line_x2$jscomp$inline_9359$$,y2:$line_y2$jscomp$inline_9360_map__81012__$1$jscomp$inline_9354$$,style:{stroke:"var(--layer-row-foreground-color)",
strokeWidth:$rulers_width$jscomp$1$$}},["line-",$APP.$app$common$data$name$$($axis$jscomp$47$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1928_step_val$$)].join(""))]},"text-"+($APP.$app$common$data$name$$($axis$jscomp$47$$)??"")+"-"+($JSCompiler_inline_result$jscomp$1928_step_val$$??""));$JSCompiler_temp_const$jscomp$1926$$.call($out_arr__44092__auto__$jscomp$223$$,$JSCompiler_inline_result$jscomp$1928_step_val$$);return $out_arr__44092__auto__$jscomp$223$$},
[],$APP.$cljs$core$range$cljs$0core$0IFn$0_invoke$0arity$03$$($map__81010_minv__$2_start$jscomp$253$$,$end$jscomp$111_map__81010__$1_maxv__$2$$+1,$step$jscomp$34$$))]})};
$app$main$ui$workspace$viewport$rulers$viewport_frame_STAR_$$=function($offset_x$jscomp$15_props_81013$$){var $JSCompiler_temp$jscomp$1930_zoom_inverse$jscomp$6$$=$offset_x$jscomp$15_props_81013$$.zoomInverse,$step$jscomp$inline_9362_zoom$jscomp$103$$=$offset_x$jscomp$15_props_81013$$.zoom,$show_rulers$$=$offset_x$jscomp$15_props_81013$$.showRulers,$offset_y$jscomp$15$$=$offset_x$jscomp$15_props_81013$$.offsetY,$vbox$jscomp$51$$=$offset_x$jscomp$15_props_81013$$.vbox;$offset_x$jscomp$15_props_81013$$=
$offset_x$jscomp$15_props_81013$$.offsetX;var $height$jscomp$199_map__81014__$1_y2$jscomp$44$$=$APP.$cljs$core$__destructure_map$$($vbox$jscomp$51$$),$JSCompiler_temp_const$jscomp$1929_x1$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$199_map__81014__$1_y2$jscomp$44$$,$APP.$cljs$cst$1515$x$$),$y1$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$199_map__81014__$1_y2$jscomp$44$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$231_x2$jscomp$42$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$199_map__81014__$1_y2$jscomp$44$$,$APP.$cljs$cst$290$width$$);$height$jscomp$199_map__81014__$1_y2$jscomp$44$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$199_map__81014__$1_y2$jscomp$44$$,$APP.$cljs$cst$1527$height$$);$width$jscomp$231_x2$jscomp$42$$=$JSCompiler_temp_const$jscomp$1929_x1$jscomp$45$$+$width$jscomp$231_x2$jscomp$42$$;$height$jscomp$199_map__81014__$1_y2$jscomp$44$$=$y1$jscomp$47$$+$height$jscomp$199_map__81014__$1_y2$jscomp$44$$;
var $bw$jscomp$3$$=$APP.$cljs$core$truth_$$($show_rulers$$)?22*$JSCompiler_temp$jscomp$1930_zoom_inverse$jscomp$6$$:0,$br$jscomp$1$$=12/$step$jscomp$inline_9362_zoom$jscomp$103$$,$bs$jscomp$1$$=4*$JSCompiler_temp$jscomp$1930_zoom_inverse$jscomp$6$$;$JSCompiler_temp_const$jscomp$1929_x1$jscomp$45$$=(0,$APP.$rumext$v2$jsxs$$)("g",{className:"viewport-frame-background",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:0,y:0,width:1,height:1,fill:"none",strokeWidth:.1,stroke:"rgba(0,0,0,0)"}),(0,$APP.$rumext$v2$jsx$$)("path",
{d:$app$main$ui$workspace$viewport$rulers$rulers_inside_path$$($JSCompiler_temp_const$jscomp$1929_x1$jscomp$45$$,$y1$jscomp$47$$,$width$jscomp$231_x2$jscomp$42$$,$height$jscomp$199_map__81014__$1_y2$jscomp$44$$,$br$jscomp$1$$,$bw$jscomp$3$$),fill:"none",strokeWidth:$bs$jscomp$1$$,stroke:"var(--panel-border-color)"}),(0,$APP.$rumext$v2$jsx$$)("path",{d:"M"+($JSCompiler_temp_const$jscomp$1929_x1$jscomp$45$$??"")+","+($y1$jscomp$47$$??"")+"L"+($width$jscomp$231_x2$jscomp$42$$??"")+","+($y1$jscomp$47$$??
"")+"L"+($width$jscomp$231_x2$jscomp$42$$??"")+","+($height$jscomp$199_map__81014__$1_y2$jscomp$44$$??"")+"L"+($JSCompiler_temp_const$jscomp$1929_x1$jscomp$45$$??"")+","+($height$jscomp$199_map__81014__$1_y2$jscomp$44$$??"")+"Z"+($app$main$ui$workspace$viewport$rulers$rulers_inside_path$$($JSCompiler_temp_const$jscomp$1929_x1$jscomp$45$$,$y1$jscomp$47$$,$width$jscomp$231_x2$jscomp$42$$,$height$jscomp$199_map__81014__$1_y2$jscomp$44$$,$br$jscomp$1$$,$bw$jscomp$3$$)??""),fillRule:"evenodd",fill:"var(--panel-background-color)"})]});
$APP.$cljs$core$truth_$$($show_rulers$$)?($step$jscomp$inline_9362_zoom$jscomp$103$$=0<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<.008?1E4:.008<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<.015?5E3:.015<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<.04?2500:.04<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<.07?1E3:.07<$step$jscomp$inline_9362_zoom$jscomp$103$$&&
$step$jscomp$inline_9362_zoom$jscomp$103$$<.2?500:.2<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<.5?250:.5<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<1?100:1<=$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<=2?50:2<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<4?25:4<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<
6?10:6<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<15?5:15<$step$jscomp$inline_9362_zoom$jscomp$103$$&&$step$jscomp$inline_9362_zoom$jscomp$103$$<25?2:1,$JSCompiler_temp$jscomp$1930_zoom_inverse$jscomp$6$$=(0,$APP.$rumext$v2$jsxs$$)("g",{className:"viewport-frame-rulers",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers_text_STAR_$$,{vbox:$vbox$jscomp$51$$,offset:$offset_x$jscomp$15_props_81013$$,step:$step$jscomp$inline_9362_zoom$jscomp$103$$,
zoomInverse:$JSCompiler_temp$jscomp$1930_zoom_inverse$jscomp$6$$,axis:$APP.$cljs$cst$1515$x$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers_text_STAR_$$,{vbox:$vbox$jscomp$51$$,offset:$offset_y$jscomp$15$$,step:$step$jscomp$inline_9362_zoom$jscomp$103$$,zoomInverse:$JSCompiler_temp$jscomp$1930_zoom_inverse$jscomp$6$$,axis:$APP.$cljs$cst$1516$y$$})]})):$JSCompiler_temp$jscomp$1930_zoom_inverse$jscomp$6$$=null;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$JSCompiler_temp_const$jscomp$1929_x1$jscomp$45$$,
$JSCompiler_temp$jscomp$1930_zoom_inverse$jscomp$6$$]})};
$app$main$ui$workspace$viewport$rulers$selection_area_STAR_$$=function($JSCompiler_temp_const$jscomp$1932_props_81015$$){var $JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$=$JSCompiler_temp_const$jscomp$1932_props_81015$$.zoomInverse,$offset_y$jscomp$16$$=$JSCompiler_temp_const$jscomp$1932_props_81015$$.offsetY,$center_x$jscomp$inline_9364_vbox$jscomp$52$$=$JSCompiler_temp_const$jscomp$1932_props_81015$$.vbox,$selection_rect$$=$JSCompiler_temp_const$jscomp$1932_props_81015$$.selectionRect,
$JSCompiler_temp_const$jscomp$1931_offset_x$jscomp$16$$=$JSCompiler_temp_const$jscomp$1932_props_81015$$.offsetX;$JSCompiler_temp_const$jscomp$1932_props_81015$$=(0,$APP.$rumext$v2$jsxs$$)("defs",{children:[(0,$APP.$rumext$v2$jsxs$$)("linearGradient",{id:"selection-gradient-start",children:[(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"0%",stopColor:"var(--panel-background-color)",stopOpacity:0}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"40%",stopColor:"var(--panel-background-color)",stopOpacity:1}),
(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"100%",stopColor:"var(--panel-background-color)",stopOpacity:1})]}),(0,$APP.$rumext$v2$jsxs$$)("linearGradient",{id:"selection-gradient-end",children:[(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"0%",stopColor:"var(--panel-background-color)",stopOpacity:1}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"60%",stopColor:"var(--panel-background-color)",stopOpacity:1}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"100%",stopColor:"var(--panel-background-color)",stopOpacity:0})]})]});
$JSCompiler_temp_const$jscomp$1931_offset_x$jscomp$16$$=(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-75*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9364_vbox$jscomp$52$$),width:100*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,height:22*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,
fill:"url('#selection-gradient-start')"}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-25,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9364_vbox$jscomp$52$$),width:100*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,height:22*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,fill:"url('#selection-gradient-end')"}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$),
y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9364_vbox$jscomp$52$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$),height:22*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,style:{fill:"var(--color-accent-tertiary)",fillOpacity:.3}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-4*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9364_vbox$jscomp$52$$)+
13.6*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,textAnchor:"end",style:{fontSize:12*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,fontFamily:"worksans",fill:"var(--color-accent-tertiary)"},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1528$x1$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-$JSCompiler_temp_const$jscomp$1931_offset_x$jscomp$16$$)}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)+
4*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9364_vbox$jscomp$52$$)+13.6*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,textAnchor:"start",style:{fontSize:12*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,fontFamily:"worksans",fill:"var(--color-accent-tertiary)"},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-
$JSCompiler_temp_const$jscomp$1931_offset_x$jscomp$16$$)})]});$center_x$jscomp$inline_9364_vbox$jscomp$52$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9364_vbox$jscomp$52$$)+11*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$;var $center_y$jscomp$inline_9365$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2-11*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$;
$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$=(0,$APP.$rumext$v2$jsxs$$)("g",{transform:["rotate(-90 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($center_x$jscomp$inline_9364_vbox$jscomp$52$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($center_y$jscomp$inline_9365$$),")"].join(""),children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$center_x$jscomp$inline_9364_vbox$jscomp$52$$-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2-11*
$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,y:$center_y$jscomp$inline_9365$$-11*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,width:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$),height:22*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,style:{fill:"var(--color-accent-tertiary)",fillOpacity:.3}}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$center_x$jscomp$inline_9364_vbox$jscomp$52$$-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/
2-11*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$-100*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,y:$center_y$jscomp$inline_9365$$-11*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,width:100*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,height:22*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,style:{fill:"var(--panel-background-color)",fillOpacity:.8}}),(0,$APP.$rumext$v2$jsx$$)("rect",{x:$center_x$jscomp$inline_9364_vbox$jscomp$52$$-
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2-11*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$),y:$center_y$jscomp$inline_9365$$-11*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,width:100*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,height:22*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,style:{fill:"var(--panel-background-color)",
fillOpacity:.8}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$center_x$jscomp$inline_9364_vbox$jscomp$52$$-$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2-15*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,y:$center_y$jscomp$inline_9365$$+4*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,textAnchor:"end",style:{fontSize:12*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,fontFamily:"worksans",fill:"var(--color-accent-tertiary)"},
children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1531$y2$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-$offset_y$jscomp$16$$)}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$center_x$jscomp$inline_9364_vbox$jscomp$52$$+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)/2,y:$center_y$jscomp$inline_9365$$+4*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,textAnchor:"start",style:{fontSize:12*$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$,
fontFamily:"worksans",fill:"var(--color-accent-tertiary)"},children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($selection_rect$$)-$offset_y$jscomp$16$$)})]});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-area",children:[$JSCompiler_temp_const$jscomp$1932_props_81015$$,$JSCompiler_temp_const$jscomp$1931_offset_x$jscomp$16$$,$JSCompiler_inline_result$jscomp$1933_zoom_inverse$jscomp$7$$]})};
$app$main$ui$workspace$viewport$rulers$rulers_STAR_$$=function($props_81017_selection_rect$jscomp$1$$){var $zoom_inverse$jscomp$8$$=$props_81017_selection_rect$jscomp$1$$.zoomInverse,$zoom$jscomp$104$$=$props_81017_selection_rect$jscomp$1$$.zoom,$show_rulers$jscomp$1$$=$props_81017_selection_rect$jscomp$1$$.showRulers,$offset_y$jscomp$17$$=$props_81017_selection_rect$jscomp$1$$.offsetY,$vbox$jscomp$53$$=$props_81017_selection_rect$jscomp$1$$.vbox,$offset_x$jscomp$17$$=$props_81017_selection_rect$jscomp$1$$.offsetX,
$selected_shapes__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($props_81017_selection_rect$jscomp$1$$.selectedShapes);$props_81017_selection_rect$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_shapes__$1$$)],function(){return $APP.$app$common$data$not_empty_QMARK_$$($selected_shapes__$1$$)?$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($selected_shapes__$1$$):null});return $vbox$jscomp$53$$!=null?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"viewport-frame",
pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$viewport_frame_STAR_$$,{showRulers:$show_rulers$jscomp$1$$,zoom:$zoom$jscomp$104$$,zoomInverse:$zoom_inverse$jscomp$8$$,vbox:$vbox$jscomp$53$$,offsetX:$offset_x$jscomp$17$$,offsetY:$offset_y$jscomp$17$$}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_rulers$jscomp$1$$)?$props_81017_selection_rect$jscomp$1$$!=null:$show_rulers$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$selection_area_STAR_$$,
{zoom:$zoom$jscomp$104$$,zoomInverse:$zoom_inverse$jscomp$8$$,vbox:$vbox$jscomp$53$$,selectionRect:$props_81017_selection_rect$jscomp$1$$,offsetX:$offset_x$jscomp$17$$,offsetY:$offset_y$jscomp$17$$}):null]}):null};
$app$main$ui$workspace$viewport$frame_grid$square_grid_STAR_$$=function($grid_id$jscomp$29_props_81026$$){var $zoom$jscomp$105$$=$grid_id$jscomp$29_props_81026$$.zoom,$frame$jscomp$84$$=$grid_id$jscomp$29_props_81026$$.frame,$color_value__$1$jscomp$1_grid$jscomp$17$$=$grid_id$jscomp$29_props_81026$$.grid;$grid_id$jscomp$29_props_81026$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$common$uuid$next$$()});var $map__81027_map__81027__$1_size$jscomp$166$$=
$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($color_value__$1$jscomp$1_grid$jscomp$17$$);$map__81027_map__81027__$1_size$jscomp$166$$=$APP.$cljs$core$__destructure_map$$($map__81027_map__81027__$1_size$jscomp$166$$);$map__81027_map__81027__$1_size$jscomp$166$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81027_map__81027__$1_size$jscomp$166$$,$APP.$cljs$cst$874$size$$);var $color_value$jscomp$7_map__81028$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($color_value__$1$jscomp$1_grid$jscomp$17$$)),
$color_opacity$jscomp$1_map__81028__$1$$=$APP.$cljs$core$__destructure_map$$($color_value$jscomp$7_map__81028$$);$color_value$jscomp$7_map__81028$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_opacity$jscomp$1_map__81028__$1$$,$APP.$cljs$cst$1303$color$$);$color_opacity$jscomp$1_map__81028__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color_opacity$jscomp$1_map__81028__$1$$,$APP.$cljs$cst$1740$opacity$$);$color_value__$1$jscomp$1_grid$jscomp$17$$=$APP.$cljs$core$truth_$$($color_value$jscomp$7_map__81028$$)?
$color_value$jscomp$7_map__81028$$:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($color_value__$1$jscomp$1_grid$jscomp$17$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$260$value$$],null)));return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"grid",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("pattern",
{id:$grid_id$jscomp$29_props_81026$$,x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$84$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$84$$),width:$map__81027_map__81027__$1_size$jscomp$166$$,height:$map__81027_map__81027__$1_size$jscomp$166$$,patternUnits:"userSpaceOnUse",children:(0,$APP.$rumext$v2$jsx$$)("path",{d:["M ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81027_map__81027__$1_size$jscomp$166$$)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(0),
" L ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(0)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(0)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(0)," ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81027_map__81027__$1_size$jscomp$166$$)," "].join(""),style:{fill:"none",stroke:$color_value__$1$jscomp$1_grid$jscomp$17$$,strokeOpacity:$color_opacity$jscomp$1_map__81028__$1$$,strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$105$$)}})})}),
(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$84$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$84$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$84$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$84$$),fill:["url(#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($grid_id$jscomp$29_props_81026$$),")"].join("")})]})};
$app$main$ui$workspace$viewport$frame_grid$layout_grid_STAR_$$=function($gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$){var $zoom$jscomp$106$$=$gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$.zoom,$frame$jscomp$85$$=$gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$.frame,$key$jscomp$427$$=$gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$.key,$grid$jscomp$18$$=$gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$.grid;$gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$=
$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$18$$));$gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$=$APP.$cljs$core$__destructure_map$$($gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$);var $color_value$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$,$APP.$cljs$cst$1303$color$$),$color_opacity$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$,
$APP.$cljs$cst$1740$opacity$$),$color_value__$1$jscomp$2$$=$APP.$cljs$core$truth_$$($color_value$jscomp$8$$)?$color_value$jscomp$8$$:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$18$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$260$value$$],null)));$gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$=
$app$common$geom$grid$grid_gutter$$($frame$jscomp$85$$,$grid$jscomp$18$$);var $gutter_QMARK_$$=$gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$!=null&&!$APP.$app$common$math$almost_zero_QMARK_$$($gutter$jscomp$5_map__81030_map__81030__$1_props_81029$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"grid",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$224$$,$map__81035_p__81031_x$jscomp$1284$$){var $idx$jscomp$133$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__81035_p__81031_x$jscomp$1284$$,
0,null);$map__81035_p__81031_x$jscomp$1284$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__81035_p__81031_x$jscomp$1284$$,1,null);var $height$jscomp$200_map__81035__$1$$=$APP.$cljs$core$__destructure_map$$($map__81035_p__81031_x$jscomp$1284$$);$map__81035_p__81031_x$jscomp$1284$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$200_map__81035__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$507$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$200_map__81035__$1$$,
$APP.$cljs$cst$1516$y$$),$width$jscomp$232$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$200_map__81035__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$200_map__81035__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$200_map__81035__$1$$,$APP.$cljs$cst$1527$height$$);$out_arr__44092__auto__$jscomp$224$$.push($gutter_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__81035_p__81031_x$jscomp$1284$$,y:$y$jscomp$507$$,width:$map__81035_p__81031_x$jscomp$1284$$+
$width$jscomp$232$$-$map__81035_p__81031_x$jscomp$1284$$,height:$y$jscomp$507$$+$height$jscomp$200_map__81035__$1$$-$y$jscomp$507$$,style:{fill:$color_value__$1$jscomp$2$$,strokeWidth:0,opacity:$color_opacity$jscomp$2$$}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$427$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81035_p__81031_x$jscomp$1284$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$507$$)].join("")):!$gutter_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$18$$))?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$133$$,0)?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__81035_p__81031_x$jscomp$1284$$,y1:$y$jscomp$507$$,x2:$map__81035_p__81031_x$jscomp$1284$$,y2:$y$jscomp$507$$+$height$jscomp$200_map__81035__$1$$,style:{stroke:$color_value__$1$jscomp$2$$,strokeWidth:1/$zoom$jscomp$106$$,strokeOpacity:$color_opacity$jscomp$2$$,
fill:"none"}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$427$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81035_p__81031_x$jscomp$1284$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$507$$),"-start"].join("")):null,(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__81035_p__81031_x$jscomp$1284$$+$width$jscomp$232$$,y1:$y$jscomp$507$$,x2:$map__81035_p__81031_x$jscomp$1284$$+$width$jscomp$232$$,y2:$y$jscomp$507$$+$height$jscomp$200_map__81035__$1$$,
style:{stroke:$color_value__$1$jscomp$2$$,strokeWidth:1/$zoom$jscomp$106$$,strokeOpacity:$color_opacity$jscomp$2$$,fill:"none"}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$427$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81035_p__81031_x$jscomp$1284$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$507$$),"-end"].join(""))]}):!$gutter_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$18$$))?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$133$$,0)?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__81035_p__81031_x$jscomp$1284$$,y1:$y$jscomp$507$$,x2:$map__81035_p__81031_x$jscomp$1284$$+$width$jscomp$232$$,y2:$y$jscomp$507$$,style:{stroke:$color_value__$1$jscomp$2$$,strokeWidth:1/$zoom$jscomp$106$$,strokeOpacity:$color_opacity$jscomp$2$$,fill:"none"}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$427$$),
"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81035_p__81031_x$jscomp$1284$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$507$$),"-start"].join("")):null,(0,$APP.$rumext$v2$jsx$$)("line",{x1:$map__81035_p__81031_x$jscomp$1284$$,y1:$y$jscomp$507$$+$height$jscomp$200_map__81035__$1$$,x2:$map__81035_p__81031_x$jscomp$1284$$+$width$jscomp$232$$,y2:$y$jscomp$507$$+$height$jscomp$200_map__81035__$1$$,style:{stroke:$color_value__$1$jscomp$2$$,strokeWidth:1/$zoom$jscomp$106$$,
strokeOpacity:$color_opacity$jscomp$2$$,fill:"none"}},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($key$jscomp$427$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81035_p__81031_x$jscomp$1284$$),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($y$jscomp$507$$),"-end"].join(""))]}):null);return $out_arr__44092__auto__$jscomp$224$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($app$common$geom$grid$grid_areas$$($frame$jscomp$85$$,$grid$jscomp$18$$)))})};
$app$main$ui$workspace$viewport$frame_grid$frame_clip_area$$=function($map__81038__$1_p__81037_selrect$jscomp$89$$,$parents$jscomp$21$$){$map__81038__$1_p__81037_selrect$jscomp$89$$=$APP.$cljs$core$__destructure_map$$($map__81038__$1_p__81037_selrect$jscomp$89$$);$map__81038__$1_p__81037_selrect$jscomp$89$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81038__$1_p__81037_selrect$jscomp$89$$,$APP.$cljs$cst$1610$selrect$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($sr$jscomp$4$$,
$parent$jscomp$306$$){return!$APP.$app$common$files$helpers$root_QMARK_$$($parent$jscomp$306$$)&&$APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$306$$)&&$APP.$cljs$core$not$$($APP.$cljs$cst$1884$show_content$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$306$$))?$APP.$app$common$geom$rect$clip_rect$$($sr$jscomp$4$$,$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($parent$jscomp$306$$)):$sr$jscomp$4$$},$map__81038__$1_p__81037_selrect$jscomp$89$$,
$parents$jscomp$21$$)};
$app$main$ui$workspace$viewport$frame_grid$has_grid_QMARK_$$=function($grids$jscomp$3_map__81053__$1_p__81052$$){$grids$jscomp$3_map__81053__$1_p__81052$$=$APP.$cljs$core$__destructure_map$$($grids$jscomp$3_map__81053__$1_p__81052$$);$grids$jscomp$3_map__81053__$1_p__81052$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grids$jscomp$3_map__81053__$1_p__81052$$,$APP.$cljs$cst$2058$grids$$);return $grids$jscomp$3_map__81053__$1_p__81052$$!=null&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1949$display$$,$grids$jscomp$3_map__81053__$1_p__81052$$))};
$app$main$ui$workspace$viewport$gradients$shadow_STAR_$$=function($id$jscomp$1050_props_81016$$){var $offset$jscomp$216$$=$id$jscomp$1050_props_81016$$.offset;$id$jscomp$1050_props_81016$$=$id$jscomp$1050_props_81016$$.id;return(0,$APP.$rumext$v2$jsxs$$)("filter",{id:$id$jscomp$1050_props_81016$$,x:"-10%",y:"-10%",width:"120%",height:"120%",filterUnits:"objectBoundingBox",colorInterpolationFilters:"sRGB",children:[(0,$APP.$rumext$v2$jsx$$)("feFlood",{floodOpacity:"0",result:"BackgroundImageFix"}),
(0,$APP.$rumext$v2$jsx$$)("feColorMatrix",{"in":"SourceAlpha",type:"matrix",values:"0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0"}),(0,$APP.$rumext$v2$jsx$$)("feOffset",{dy:$offset$jscomp$216$$}),(0,$APP.$rumext$v2$jsx$$)("feGaussianBlur",{stdDeviation:"1"}),(0,$APP.$rumext$v2$jsx$$)("feColorMatrix",{type:"matrix",values:"0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.15 0"}),(0,$APP.$rumext$v2$jsx$$)("feBlend",{mode:"normal",in2:"BackgroundImageFix",result:$id$jscomp$1050_props_81016$$}),(0,$APP.$rumext$v2$jsx$$)("feBlend",
{mode:"normal","in":"SourceGraphic",in2:$id$jscomp$1050_props_81016$$,result:"shape"})]})};
$app$main$ui$workspace$viewport$gradients$gradient_color_handler_STAR_$$=function($props_81018$$){var $on_pointer_down$jscomp$14$$=$props_81018$$.onPointerDown,$on_pointer_move$jscomp$11$$=$props_81018$$.onPointerMove,$on_lost_pointer_capture$jscomp$8$$=$props_81018$$.onLostPointerCapture,$zoom$jscomp$109$$=$props_81018$$.zoom,$selected$jscomp$198$$=$props_81018$$.selected,$index$jscomp$567$$=$props_81018$$.index,$color$jscomp$191$$=$props_81018$$.color,$on_click$jscomp$58$$=$props_81018$$.onClick,
$on_pointer_up$jscomp$3$$=$props_81018$$.onPointerUp,$point$jscomp$84$$=$props_81018$$.point;return(0,$APP.$rumext$v2$jsxs$$)("g",{filter:"url(#gradient-drop-shadow)",style:{cursor:"pointer"},transform:$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$($props_81018$$.angle,$point$jscomp$84$$),children:[(0,$APP.$rumext$v2$jsx$$)("image",{href:"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA8AAAAPCAIAAAC0tAIdAAACvUlEQVQoFQGyAk39AeLi4gAAAAAAAB0dHQAAAAAAAOPj4wAAAAAAAB0dHQAAAAAAAOPj4wAAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAB////AAAAAAAA4+PjAAAAAAAAHR0dAAAAAAAA4+PjAAAAAAAAHR0dAAAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAATj4+MAAAAAAAAdHR0AAAAAAADj4+MAAAAAAAAdHR0AAAAAAADj4+MAAAAAAAACAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAACAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAjScaa0cU7nIAAAAASUVORK5CYII\x3d",
x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$109$$+12/$zoom$jscomp$109$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$109$$,width:20.5/$zoom$jscomp$109$$,height:20.5/$zoom$jscomp$109$$}),(0,$APP.$rumext$v2$jsx$$)("rect",{width:20.5/$zoom$jscomp$109$$/2,height:20.5/$zoom$jscomp$109$$,x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$109$$+12/$zoom$jscomp$109$$,
onPointerUp:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_pointer_up$jscomp$3$$,$APP.$cljs$cst$1860$to_p$$),fill:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$191$$),rx:4/$zoom$jscomp$109$$,onClick:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_click$jscomp$58$$,$APP.$cljs$cst$1860$to_p$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$109$$,onPointerDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_pointer_down$jscomp$14$$,
$APP.$cljs$cst$1860$to_p$$)}),$APP.$cljs$core$truth_$$($selected$jscomp$198$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{width:20.5/$zoom$jscomp$109$$+4/$zoom$jscomp$109$$,height:20.5/$zoom$jscomp$109$$+4/$zoom$jscomp$109$$,x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$109$$+12/$zoom$jscomp$109$$-2/$zoom$jscomp$109$$,stroke:"var(--color-accent-tertiary)",fill:"transparent",strokeWidth:2/$zoom$jscomp$109$$,rx:(4+2/$zoom$jscomp$109$$)/$zoom$jscomp$109$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-
10.25/$zoom$jscomp$109$$-2/$zoom$jscomp$109$$,pointerEvents:"none"}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{width:20.5/$zoom$jscomp$109$$,height:20.5/$zoom$jscomp$109$$,x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$109$$+12/$zoom$jscomp$109$$,"data-index":$index$jscomp$567$$,onPointerUp:$on_pointer_up$jscomp$3$$,"data-allow-click-modal":"colorpicker",stroke:"var(--app-white)",fill:$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$191$$),
strokeWidth:2/$zoom$jscomp$109$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$8$$,rx:4/$zoom$jscomp$109$$,onClick:$on_click$jscomp$58$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$)-10.25/$zoom$jscomp$109$$,onPointerMove:$on_pointer_move$jscomp$11$$,fillOpacity:$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$191$$),onPointerDown:$on_pointer_down$jscomp$14$$,pointerEvents:"all"}),(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$),
cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$84$$),r:2/$zoom$jscomp$109$$,fill:"var(--app-white)"})]})};
$app$main$ui$workspace$viewport$gradients$gradient_handler_transformed_STAR_$$=function($endpoint_on_pointer_enter_props_81023$$){function $endpoint_on_pointer_up$$($_position$$,$event$jscomp$689$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$689$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$689$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$689$$);$APP.$cljs$core$reset_BANG_$$($moving_point$$,null);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2212$hover$$,null)}function $endpoint_on_pointer_down$$($position$jscomp$217$$,$event$jscomp$688$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$688$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$688$$);$APP.$app$util$dom$capture_pointer$$($event$jscomp$688$$);$APP.$cljs$core$reset_BANG_$$($moving_point$$,$position$jscomp$217$$);return $APP.$cljs$core$truth_$$(function(){var $fexpr__81024$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1859$from_p$$,null,$APP.$cljs$cst$1860$to_p$$,null],null),null);return $fexpr__81024$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__81024$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$217$$):$fexpr__81024$$($position$jscomp$217$$)}())?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$select_colorpicker_gradient_stop$$(function(){var $G__81025__$1$$=$position$jscomp$217$$ instanceof $APP.$cljs$core$Keyword$$?$position$jscomp$217$$.$fqn$:
null;switch($G__81025__$1$$){case "from-p":return 0;case "to-p":return 1;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__81025__$1$$)].join(""));}}())):null}var $to_p$jscomp$14$$=$endpoint_on_pointer_enter_props_81023$$.toP,$zoom$jscomp$110$$=$endpoint_on_pointer_enter_props_81023$$.zoom,$stops$jscomp$21$$=$endpoint_on_pointer_enter_props_81023$$.stops,$on_change_width$$=$endpoint_on_pointer_enter_props_81023$$.onChangeWidth,$on_change_start$jscomp$1$$=
$endpoint_on_pointer_enter_props_81023$$.onChangeStart,$on_change_finish$$=$endpoint_on_pointer_enter_props_81023$$.onChangeFinish,$width_p$$=$endpoint_on_pointer_enter_props_81023$$.widthP,$editing$jscomp$4$$=$endpoint_on_pointer_enter_props_81023$$.editing,$from_p$jscomp$16$$=$endpoint_on_pointer_enter_props_81023$$.fromP,$moving_point$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$angle$jscomp$41$$=90+$APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$02$$($from_p$jscomp$16$$,
$to_p$jscomp$14$$),$dragging_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_offset$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$handler_state$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5956$display_QMARK_$$,!1,$APP.$cljs$cst$195$offset$$,0,$APP.$cljs$cst$2212$hover$$,null],null)),$can_add_stop_QMARK_$jscomp$2$$=$APP.$app$main$features$use_feature$$("render-wasm/v1")?$APP.$cljs$core$count$$($stops$jscomp$21$$)<
16:!0;$endpoint_on_pointer_enter_props_81023$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($position$jscomp$218$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2212$hover$$,$position$jscomp$218$$)});var $endpoint_on_pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$2212$hover$$,null)}),$points_on_pointer_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $can_add_stop_QMARK_$jscomp$2$$?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,$APP.$cljs$core$assoc$$,$cljs$cst$5956$display_QMARK_$$,!0):null}),$points_on_pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5956$display_QMARK_$$,!1)}),$points_on_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stops$jscomp$21$$)],function($e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$){$APP.$app$util$dom$prevent_default$$($e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);$APP.$app$util$dom$stop_propagation$$($e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);
if($can_add_stop_QMARK_$jscomp$2$$){$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$APP.$app$util$dom$get_client_position$$($e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);
var $lv_nv$$=$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$));$lv_nv$$=$APP.$app$common$geom$point$normal_left$$($lv_nv$$);$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$APP.$app$common$math$precision$$($APP.$app$common$geom$shapes$points$project_t$$($e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_p$jscomp$16$$,$to_p$jscomp$14$$],null),$lv_nv$$),2);$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$app$common$types$color$interpolate_gradient$$($stops$jscomp$21$$,$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$21$$,$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$);$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,
$e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($e$jscomp$386_new_stop$jscomp$3_offset$jscomp$217_position$jscomp$219_raw_pt$jscomp$4_stops__$1$jscomp$8_stops__$2$jscomp$2$$))}return null}),$points_on_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($from_p$jscomp$16$$),
$APP.$rumext$v2$adapt$$($to_p$jscomp$14$$)],function($e$jscomp$387_offset$jscomp$218_position$jscomp$220_raw_pt$jscomp$5$$){$e$jscomp$387_offset$jscomp$218_position$jscomp$220_raw_pt$jscomp$5$$=$APP.$app$util$dom$get_client_position$$($e$jscomp$387_offset$jscomp$218_position$jscomp$220_raw_pt$jscomp$5$$);$e$jscomp$387_offset$jscomp$218_position$jscomp$220_raw_pt$jscomp$5$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($e$jscomp$387_offset$jscomp$218_position$jscomp$220_raw_pt$jscomp$5$$);
var $lv$jscomp$1_nv$jscomp$1$$=$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$));$lv$jscomp$1_nv$jscomp$1$$=$APP.$app$common$geom$point$normal_left$$($lv$jscomp$1_nv$jscomp$1$$);$e$jscomp$387_offset$jscomp$218_position$jscomp$220_raw_pt$jscomp$5$$=$APP.$app$common$geom$shapes$points$project_t$$($e$jscomp$387_offset$jscomp$218_position$jscomp$220_raw_pt$jscomp$5$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$from_p$jscomp$16$$,$to_p$jscomp$14$$],null),$lv$jscomp$1_nv$jscomp$1$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($handler_state$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,$e$jscomp$387_offset$jscomp$218_position$jscomp$220_raw_pt$jscomp$5$$)}),$handle_marker_pointer_down$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stops$jscomp$21$$)],function($event$jscomp$690$$){var $index$jscomp$568$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$690$$),
"index")),$stop$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($stops$jscomp$21$$,$index$jscomp$568$$);$APP.$app$util$dom$capture_pointer$$($event$jscomp$690$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$select_colorpicker_gradient_stop$$($index$jscomp$568$$));$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$4$$,!0);return $APP.$rumext$v2$set_ref_val_BANG_$$($start_offset$jscomp$2$$,$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$12$$))}),
$handle_marker_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stops$jscomp$21$$)],function($event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$4$$))){var $index$jscomp$569$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_target$$($event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$),
"index"));$event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$);$event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$);var $lv$jscomp$2_nv$jscomp$2$$=
$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$));$lv$jscomp$2_nv$jscomp$2$$=$APP.$app$common$geom$point$normal_left$$($lv$jscomp$2_nv$jscomp$2$$);$event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$=$APP.$app$common$geom$shapes$points$project_t$$($event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$from_p$jscomp$16$$,$to_p$jscomp$14$$],null),$lv$jscomp$2_nv$jscomp$2$$);$event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$=$APP.$app$common$math$precision$$($APP.$app$common$math$clamp$$($event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$,0,1),2);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($APP.$cljs$core$assoc_in$$($stops$jscomp$21$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$index$jscomp$569$$,$APP.$cljs$cst$195$offset$$],null),$event$jscomp$691_offset$jscomp$219_offset__$1$jscomp$27_position$jscomp$221_raw_pt$jscomp$6$$)))}return null}),$handle_marker_lost_pointer_capture$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($stops$jscomp$21$$)],function($event$jscomp$692_stops__$1$jscomp$9$$){$APP.$app$util$dom$release_pointer$$($event$jscomp$692_stops__$1$jscomp$9$$);
$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$4$$,!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_offset$jscomp$2$$,null);$event$jscomp$692_stops__$1$jscomp$9$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$195$offset$$,$stops$jscomp$21$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_stops$$($event$jscomp$692_stops__$1$jscomp$9$$))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($moving_point$$)),$APP.$rumext$v2$adapt$$($from_p$jscomp$16$$),$APP.$rumext$v2$adapt$$($to_p$jscomp$14$$),$APP.$rumext$v2$adapt$$($width_p$$)],function(){var $subs$jscomp$32$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($pt$jscomp$34_y0$jscomp$inline_9371$$){var $G__81036_new_width_p_width_v$$=$APP.$cljs$core$_deref$$($moving_point$$);switch($G__81036_new_width_p_width_v$$ instanceof
$APP.$cljs$core$Keyword$$?$G__81036_new_width_p_width_v$$.$fqn$:null){case "from-p":return $APP.$cljs$core$truth_$$($on_change_start$jscomp$1$$)?$on_change_start$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_start$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$34_y0$jscomp$inline_9371$$):$on_change_start$jscomp$1$$($pt$jscomp$34_y0$jscomp$inline_9371$$):null;case "to-p":return $APP.$cljs$core$truth_$$($on_change_finish$$)?$on_change_finish$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_finish$$.$cljs$core$IFn$_invoke$arity$1$($pt$jscomp$34_y0$jscomp$inline_9371$$):
$on_change_finish$$($pt$jscomp$34_y0$jscomp$inline_9371$$):null;case "width-p":if($APP.$cljs$core$truth_$$($on_change_width$$)){$G__81036_new_width_p_width_v$$=$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($width_p$$,$from_p$jscomp$16$$));var $distance$jscomp$9_x0$jscomp$inline_9370$$=$pt$jscomp$34_y0$jscomp$inline_9371$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$34_y0$jscomp$inline_9371$$,$APP.$cljs$cst$1515$x$$);$pt$jscomp$34_y0$jscomp$inline_9371$$=
$pt$jscomp$34_y0$jscomp$inline_9371$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($pt$jscomp$34_y0$jscomp$inline_9371$$,$APP.$cljs$cst$1516$y$$);var $x1$jscomp$inline_9372$$=$from_p$jscomp$16$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($from_p$jscomp$16$$,$APP.$cljs$cst$1515$x$$),$y1$jscomp$inline_9373$$=$from_p$jscomp$16$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($from_p$jscomp$16$$,$APP.$cljs$cst$1516$y$$),$x2$jscomp$inline_9374$$=$to_p$jscomp$14$$?.x??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($to_p$jscomp$14$$,$APP.$cljs$cst$1515$x$$),$y2$jscomp$inline_9375$$=$to_p$jscomp$14$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($to_p$jscomp$14$$,$APP.$cljs$cst$1516$y$$);$distance$jscomp$9_x0$jscomp$inline_9370$$=$APP.$app$common$math$abs$$($distance$jscomp$9_x0$jscomp$inline_9370$$*($y2$jscomp$inline_9375$$-$y1$jscomp$inline_9373$$)+-($pt$jscomp$34_y0$jscomp$inline_9371$$*($x2$jscomp$inline_9374$$-$x1$jscomp$inline_9372$$))+$x2$jscomp$inline_9374$$*
$y1$jscomp$inline_9373$$+-($y2$jscomp$inline_9375$$*$x1$jscomp$inline_9372$$))/$APP.$app$common$geom$point$distance$$($to_p$jscomp$14$$,$from_p$jscomp$16$$);$G__81036_new_width_p_width_v$$=$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$multiply$$($G__81036_new_width_p_width_v$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($distance$jscomp$9_x0$jscomp$inline_9370$$)));return $on_change_width$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_width$$.$cljs$core$IFn$_invoke$arity$1$($G__81036_new_width_p_width_v$$):
$on_change_width$$($G__81036_new_width_p_width_v$$)}return null;default:return null}},$APP.$beicon$v2$core$map$$($APP.$app$util$mouse$get_pointer_position$$,$APP.$beicon$v2$core$filter$$(function($p1__81019_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2178$viewport$$,$p1__81019_SHARP_$$.source)},$APP.$beicon$v2$core$filter$$($APP.$app$util$mouse$pointer_event_QMARK_$$,$APP.$app$main$store$stream$$))));return function(){return $APP.$beicon$v2$core$_dispose$$($subs$jscomp$32$$)}});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"gradient-handlers",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$shadow_STAR_$$,{id:"gradient-drop-shadow",offset:2/$zoom$jscomp$110$$})}),function(){var $lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$=$APP.$app$common$geom$point$unit$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$));$lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$=
$APP.$app$common$geom$point$normal_left$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$);var $width$jscomp$233$$=40/$zoom$jscomp$110$$;$lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$,$width$jscomp$233$$/-2)),$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,
$APP.$app$common$geom$point$scale$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$,$width$jscomp$233$$/2)),$APP.$app$common$geom$point$add$$($to_p$jscomp$14$$,$APP.$app$common$geom$point$scale$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$,$width$jscomp$233$$/2)),$APP.$app$common$geom$point$add$$($to_p$jscomp$14$$,$APP.$app$common$geom$point$scale$$($lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$,$width$jscomp$233$$/-2))],null);$lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$=
$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81020_SHARP_$$){return""+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__81020_SHARP_$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__81020_SHARP_$$)??"")},$lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$));return(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$lv$jscomp$3_nv$jscomp$3_points$jscomp$107_points_str$jscomp$2$$,
"data-allow-click-modal":"colorpicker",fill:"transparent",pointerEvents:"all",onPointerEnter:$points_on_pointer_enter$$,onPointerLeave:$points_on_pointer_leave$$,onPointerDown:$points_on_pointer_down$$,onPointerMove:$points_on_pointer_move$$})}(),(0,$APP.$rumext$v2$jsx$$)("g",{filter:"url(#gradient-drop-shadow)",children:function(){var $points$jscomp$108_pu$$=$APP.$app$common$geom$point$unit$$($app$common$geom$point$normal_right$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$))),
$sc$jscomp$13$$=2/$zoom$jscomp$110$$/2;$points$jscomp$108_pu$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($points$jscomp$108_pu$$,-$sc$jscomp$13$$)),$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($points$jscomp$108_pu$$,$sc$jscomp$13$$)),$APP.$app$common$geom$point$add$$($to_p$jscomp$14$$,$APP.$app$common$geom$point$scale$$($points$jscomp$108_pu$$,
$sc$jscomp$13$$)),$APP.$app$common$geom$point$add$$($to_p$jscomp$14$$,$APP.$app$common$geom$point$scale$$($points$jscomp$108_pu$$,-$sc$jscomp$13$$))],null);return(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81021_SHARP_$$){return""+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__81021_SHARP_$$)??"")+", "+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__81021_SHARP_$$)??
"")},$points$jscomp$108_pu$$)),fill:"var(--app-white)"})}()}),$APP.$cljs$core$truth_$$($width_p$$)?(0,$APP.$rumext$v2$jsx$$)("g",{filter:"url(#gradient-drop-shadow)",children:function(){var $points$jscomp$109_pu$jscomp$1$$=$APP.$app$common$geom$point$unit$$($app$common$geom$point$normal_right$$($APP.$app$common$geom$point$subtract$$($width_p$$,$from_p$jscomp$16$$))),$sc$jscomp$14$$=2/$zoom$jscomp$110$$/2;$points$jscomp$109_pu$jscomp$1$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($points$jscomp$109_pu$jscomp$1$$,-$sc$jscomp$14$$)),$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($points$jscomp$109_pu$jscomp$1$$,$sc$jscomp$14$$)),$APP.$app$common$geom$point$add$$($width_p$$,$APP.$app$common$geom$point$scale$$($points$jscomp$109_pu$jscomp$1$$,$sc$jscomp$14$$)),$APP.$app$common$geom$point$add$$($width_p$$,$APP.$app$common$geom$point$scale$$($points$jscomp$109_pu$jscomp$1$$,
-$sc$jscomp$14$$))],null);return(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81022_SHARP_$$){return""+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__81022_SHARP_$$)??"")+", "+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__81022_SHARP_$$)??"")},$points$jscomp$109_pu$jscomp$1$$)),fill:"var(--app-white)"})}()}):null,$APP.$cljs$core$truth_$$($width_p$$)?
(0,$APP.$rumext$v2$jsxs$$)("g",{filter:"url(#gradient-drop-shadow)",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5957$width_p$$,$APP.$cljs$cst$2212$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$)))?(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),fill:"var(--color-accent-tertiary)",
r:6/$zoom$jscomp$110$$}):null,(0,$APP.$rumext$v2$jsx$$)("circle",{"data-allow-click-modal":"colorpicker",cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),r:4/$zoom$jscomp$110$$,fill:"var(--app-white)"}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),onPointerUp:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,
$cljs$cst$5957$width_p$$),"data-allow-click-modal":"colorpicker",fill:"transparent",r:15/$zoom$jscomp$110$$,onPointerDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_down$$,$cljs$cst$5957$width_p$$),onPointerLeave:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_leave$$,$cljs$cst$5957$width_p$$),cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($width_p$$),onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_enter_props_81023$$,
$cljs$cst$5957$width_p$$),pointerEvents:"all"})]}):null,(0,$APP.$rumext$v2$jsxs$$)("g",{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1859$from_p$$,$APP.$cljs$cst$2212$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$)))?(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),
fill:"var(--color-accent-tertiary)",r:6/$zoom$jscomp$110$$}):null,(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),fill:"var(--app-white)",r:4/$zoom$jscomp$110$$}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),onPointerUp:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,
$APP.$cljs$cst$1859$from_p$$),"data-allow-click-modal":"colorpicker",fill:"transparent",onLostPointerCapture:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,$APP.$cljs$cst$1859$from_p$$),r:20/$zoom$jscomp$110$$,onPointerDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_down$$,$APP.$cljs$cst$1859$from_p$$),onPointerLeave:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_leave$$,$APP.$cljs$cst$1859$from_p$$),
cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($from_p$jscomp$16$$),onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_enter_props_81023$$,$APP.$cljs$cst$1859$from_p$$),pointerEvents:"all"})]}),(0,$APP.$rumext$v2$jsxs$$)("g",{children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1860$to_p$$,$APP.$cljs$cst$2212$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$)))?(0,$APP.$rumext$v2$jsx$$)("circle",
{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),fill:"var(--color-accent-tertiary)",r:6/$zoom$jscomp$110$$}):null,(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),fill:"var(--app-white)",
r:4/$zoom$jscomp$110$$}),(0,$APP.$rumext$v2$jsx$$)("circle",{cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),onPointerUp:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,$APP.$cljs$cst$1860$to_p$$),"data-allow-click-modal":"colorpicker",fill:"transparent",onLostPointerCapture:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_up$$,$APP.$cljs$cst$1859$from_p$$),r:20/$zoom$jscomp$110$$,onPointerDown:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_down$$,
$APP.$cljs$cst$1860$to_p$$),onPointerLeave:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_leave$$,$APP.$cljs$cst$1860$to_p$$),cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($to_p$jscomp$14$$),onPointerEnter:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($endpoint_on_pointer_enter_props_81023$$,$APP.$cljs$cst$1860$to_p$$),pointerEvents:"all"})]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$227$$,
$JSCompiler_temp_const$jscomp$1934_p__81042$$){var $JSCompiler_inline_result$jscomp$1936_index$jscomp$570$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1934_p__81042$$,0,null),$stop$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1934_p__81042$$,1,null);$JSCompiler_temp_const$jscomp$1934_p__81042$$=$out_arr__44092__auto__$jscomp$227$$.push;var $stop_p$jscomp$inline_9377$$=$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,
$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$13$$)));$JSCompiler_inline_result$jscomp$1936_index$jscomp$570$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_color_handler_STAR_$$,{selected:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($editing$jscomp$4$$,$JSCompiler_inline_result$jscomp$1936_index$jscomp$570$$),index:$JSCompiler_inline_result$jscomp$1936_index$jscomp$570$$,
zoom:$zoom$jscomp$110$$,angle:$angle$jscomp$41$$,onLostPointerCapture:$handle_marker_lost_pointer_capture$$,onPointerMove:$handle_marker_pointer_move$$,onPointerDown:$handle_marker_pointer_down$$,color:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$13$$),$APP.$cljs$cst$1740$opacity$$,$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($stop$jscomp$13$$)],null),point:$stop_p$jscomp$inline_9377$$},
$JSCompiler_inline_result$jscomp$1936_index$jscomp$570$$);$JSCompiler_temp_const$jscomp$1934_p__81042$$.call($out_arr__44092__auto__$jscomp$227$$,$JSCompiler_inline_result$jscomp$1936_index$jscomp$570$$);return $out_arr__44092__auto__$jscomp$227$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($stops$jscomp$21$$)),$APP.$cljs$core$truth_$$($cljs$cst$5956$display_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$)))?function(){var $p$jscomp$255$$=
$APP.$app$common$geom$point$add$$($from_p$jscomp$16$$,$APP.$app$common$geom$point$scale$$($APP.$app$common$geom$point$subtract$$($to_p$jscomp$14$$,$from_p$jscomp$16$$),$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($handler_state$$))));return(0,$APP.$rumext$v2$jsx$$)("circle",{filter:"url(#gradient-drop-shadow)",cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$255$$),cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p$jscomp$255$$),
r:4/$zoom$jscomp$110$$,fill:"var(--app-white)"})}():null]})};
$app$main$ui$workspace$viewport$gradients$gradient_handlers_impl_STAR_$$=function($props_81051_to_p$jscomp$15_transform$jscomp$114$$){var $zoom$jscomp$111$$=$props_81051_to_p$jscomp$15_transform$jscomp$114$$.zoom,$stops$jscomp$22$$=$props_81051_to_p$jscomp$15_transform$jscomp$114$$.stops,$editing$jscomp$5$$=$props_81051_to_p$jscomp$15_transform$jscomp$114$$.editing,$gradient$jscomp$29$$=$props_81051_to_p$jscomp$15_transform$jscomp$114$$.gradient,$gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$=
$props_81051_to_p$jscomp$15_transform$jscomp$114$$.shape;$props_81051_to_p$jscomp$15_transform$jscomp$114$$=$APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$);var $transform_inverse$jscomp$25$$=$APP.$app$common$geom$shapes$inverse_transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$);
$gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$);$gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$);
var $x$jscomp$1285$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$508$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$234$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$,
$APP.$cljs$cst$290$width$$),$height$jscomp$201$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$,$APP.$cljs$cst$1527$height$$),$from_p$jscomp$17$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1285$$+$width$jscomp$234$$*$APP.$cljs$cst$1735$start_x$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$29$$),$y$jscomp$508$$+
$height$jscomp$201$$*$APP.$cljs$cst$1736$start_y$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$29$$)),$props_81051_to_p$jscomp$15_transform$jscomp$114$$);$props_81051_to_p$jscomp$15_transform$jscomp$114$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1285$$+$width$jscomp$234$$*$APP.$cljs$cst$1737$end_x$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$29$$),$y$jscomp$508$$+$height$jscomp$201$$*$APP.$cljs$cst$1738$end_y$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$29$$)),
$props_81051_to_p$jscomp$15_transform$jscomp$114$$);$gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($props_81051_to_p$jscomp$15_transform$jscomp$114$$,$from_p$jscomp$17$$);var $gradient_length$$=$APP.$app$common$geom$point$length$$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$);$gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$=
$APP.$app$common$geom$point$multiply$$($APP.$app$common$geom$point$multiply$$($app$common$geom$point$normal_right$$($gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$29$$)*($gradient_length$$/($height$jscomp$201$$/2)))),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$234$$/
2));$gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$=$APP.$app$common$geom$point$add$$($from_p$jscomp$17$$,$gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$);var $change_BANG_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($changes$jscomp$337$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$update_colorpicker_gradient$$($changes$jscomp$337$$))}),
$on_change_start$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($transform_inverse$jscomp$25$$),$APP.$rumext$v2$adapt$$($width$jscomp$234$$),$APP.$rumext$v2$adapt$$($height$jscomp$201$$)],function($G__81056_point$jscomp$85_start_x$jscomp$6$$){var $point__$1$jscomp$2_start_y$jscomp$5$$=$APP.$app$common$geom$point$transform$$($G__81056_point$jscomp$85_start_x$jscomp$6$$,$transform_inverse$jscomp$25$$);$G__81056_point$jscomp$85_start_x$jscomp$6$$=($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point__$1$jscomp$2_start_y$jscomp$5$$)-
$x$jscomp$1285$$)/$width$jscomp$234$$;$point__$1$jscomp$2_start_y$jscomp$5$$=($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point__$1$jscomp$2_start_y$jscomp$5$$)-$y$jscomp$508$$)/$height$jscomp$201$$;$G__81056_point$jscomp$85_start_x$jscomp$6$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1735$start_x$$,$G__81056_point$jscomp$85_start_x$jscomp$6$$,$APP.$cljs$cst$1736$start_y$$,$point__$1$jscomp$2_start_y$jscomp$5$$],null);return $change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__81056_point$jscomp$85_start_x$jscomp$6$$):$change_BANG_$jscomp$1$$($G__81056_point$jscomp$85_start_x$jscomp$6$$)}),$on_change_finish$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($transform_inverse$jscomp$25$$),$APP.$rumext$v2$adapt$$($width$jscomp$234$$),$APP.$rumext$v2$adapt$$($height$jscomp$201$$)],function($G__81057_end_x$jscomp$5_point$jscomp$86$$){var $end_y$jscomp$5_point__$1$jscomp$3$$=
$APP.$app$common$geom$point$transform$$($G__81057_end_x$jscomp$5_point$jscomp$86$$,$transform_inverse$jscomp$25$$);$G__81057_end_x$jscomp$5_point$jscomp$86$$=($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($end_y$jscomp$5_point__$1$jscomp$3$$)-$x$jscomp$1285$$)/$width$jscomp$234$$;$end_y$jscomp$5_point__$1$jscomp$3$$=($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($end_y$jscomp$5_point__$1$jscomp$3$$)-$y$jscomp$508$$)/$height$jscomp$201$$;$G__81057_end_x$jscomp$5_point$jscomp$86$$=
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1737$end_x$$,$G__81057_end_x$jscomp$5_point$jscomp$86$$,$APP.$cljs$cst$1738$end_y$$,$end_y$jscomp$5_point__$1$jscomp$3$$],null);return $change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__81057_end_x$jscomp$5_point$jscomp$86$$):$change_BANG_$jscomp$1$$($G__81057_end_x$jscomp$5_point$jscomp$86$$)}),$on_change_width$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($gradient_length$$),
$APP.$rumext$v2$adapt$$($width$jscomp$234$$),$APP.$rumext$v2$adapt$$($height$jscomp$201$$)],function($G__81058_norm_dist_point$jscomp$87$$){var $scale_factor_y$$=$gradient_length$$/($height$jscomp$201$$/2);$G__81058_norm_dist_point$jscomp$87$$=$APP.$app$common$geom$point$distance$$($G__81058_norm_dist_point$jscomp$87$$,$from_p$jscomp$17$$)/($width$jscomp$234$$/2*$scale_factor_y$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__81058_norm_dist_point$jscomp$87$$)?$APP.$app$common$math$finite_QMARK_$$($G__81058_norm_dist_point$jscomp$87$$):
$G__81058_norm_dist_point$jscomp$87$$)?($G__81058_norm_dist_point$jscomp$87$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$290$width$$,$G__81058_norm_dist_point$jscomp$87$$],null),$change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__81058_norm_dist_point$jscomp$87$$):$change_BANG_$jscomp$1$$($G__81058_norm_dist_point$jscomp$87$$)):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_handler_transformed_STAR_$$,
{stops:$stops$jscomp$22$$,widthP:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1734$radial$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$29$$))?$gradient_vec$jscomp$1_map__81054_map__81054__$1_shape$jscomp$1082_width_p$jscomp$1_width_v$jscomp$1$$:null,zoom:$zoom$jscomp$111$$,onChangeFinish:$on_change_finish$jscomp$1$$,fromP:$from_p$jscomp$17$$,toP:$props_81051_to_p$jscomp$15_transform$jscomp$114$$,onChangeStart:$on_change_start$jscomp$2$$,editing:$editing$jscomp$5$$,
onChangeWidth:$on_change_width$jscomp$1$$})};
$app$main$ui$workspace$viewport$grid_layout_editor$apply_to_point$$=function($result$jscomp$387$$,$JSCompiler_inline_result$jscomp$1939_next_fn$jscomp$5$$){var $JSCompiler_temp_const$jscomp$1937$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$,$G__81061$jscomp$inline_9379$$=$APP.$cljs$core$last$$($result$jscomp$387$$);$JSCompiler_inline_result$jscomp$1939_next_fn$jscomp$5$$=$JSCompiler_inline_result$jscomp$1939_next_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1939_next_fn$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($G__81061$jscomp$inline_9379$$):
$JSCompiler_inline_result$jscomp$1939_next_fn$jscomp$5$$($G__81061$jscomp$inline_9379$$);return $JSCompiler_temp_const$jscomp$1937$$.call($APP.$cljs$core$conj$$,$result$jscomp$387$$,$JSCompiler_inline_result$jscomp$1939_next_fn$jscomp$5$$)};
$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$=function($G__81064__$1_p__81062_type$jscomp$716$$){var $map__81063__$1_value$jscomp$1006$$=$APP.$cljs$core$__destructure_map$$($G__81064__$1_p__81062_type$jscomp$716$$);$G__81064__$1_p__81062_type$jscomp$716$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81063__$1_value$jscomp$1006$$,$APP.$cljs$cst$139$type$$);$map__81063__$1_value$jscomp$1006$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81063__$1_value$jscomp$1006$$,
$APP.$cljs$cst$260$value$$);$G__81064__$1_p__81062_type$jscomp$716$$=$G__81064__$1_p__81062_type$jscomp$716$$ instanceof $APP.$cljs$core$Keyword$$?$G__81064__$1_p__81062_type$jscomp$716$$.$fqn$:null;switch($G__81064__$1_p__81062_type$jscomp$716$$){case "fixed":return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($map__81063__$1_value$jscomp$1006$$)??"")+"PX";case "percent":return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($map__81063__$1_value$jscomp$1006$$)??
"")+"%";case "flex":return""+($APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($map__81063__$1_value$jscomp$1006$$)??"")+"FR";case "auto":return"AUTO";default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__81064__$1_p__81062_type$jscomp$716$$)].join(""));}};
$app$main$ui$workspace$viewport$grid_layout_editor$grid_edition_actions$$=function($props_81065$$){var $shape$jscomp$1084$$=$props_81065$$.shape;return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_grid_layout_editor__grid-actions",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_grid_layout_editor__grid-actions-container",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_grid_layout_editor__grid-actions-title",
children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.title")," ",(0,$APP.$rumext$v2$jsx$$)("span",{css:$cljs$cst$5958$board_name$$,children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$)})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$locate_board$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1084$$)))},
className:"main_ui_workspace_viewport_grid_layout_editor__locate-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.top-bar.locate")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$clear_edition_mode$$())},className:"main_ui_workspace_viewport_grid_layout_editor__done-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.top-bar.done")})]})})};
$app$main$ui$workspace$viewport$grid_layout_editor$grid_editor_frame$$=function($frame_points_origin$jscomp$73_props_81075$$){var $bounds$jscomp$92$$=$frame_points_origin$jscomp$73_props_81075$$.bounds,$width$jscomp$235$$=$frame_points_origin$jscomp$73_props_81075$$.width,$height$jscomp$202$$=$frame_points_origin$jscomp$73_props_81075$$.height,$zoom$jscomp$113$$=$frame_points_origin$jscomp$73_props_81075$$.zoom;$frame_points_origin$jscomp$73_props_81075$$=$APP.$app$common$geom$shapes$points$origin$$($bounds$jscomp$92$$);
$frame_points_origin$jscomp$73_props_81075$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$grid_layout_editor$apply_to_point$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_points_origin$jscomp$73_props_81075$$],null),new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($p1__81069_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__81069_SHARP_$$,
$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,$width$jscomp$235$$+70/$zoom$jscomp$113$$))},function($p1__81070_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__81070_SHARP_$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,40/$zoom$jscomp$113$$))},function($p1__81071_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__81071_SHARP_$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,$width$jscomp$235$$+110/$zoom$jscomp$113$$))},
function($p1__81072_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__81072_SHARP_$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$92$$,$height$jscomp$202$$+110/$zoom$jscomp$113$$))},function($p1__81073_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__81073_SHARP_$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$92$$,40/$zoom$jscomp$113$$))}],null));return(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81074_SHARP_$$){return""+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__81074_SHARP_$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__81074_SHARP_$$)??"")},$frame_points_origin$jscomp$73_props_81075$$)),className:"main_ui_workspace_viewport_grid_layout_editor__grid-frame"})};
$app$main$ui$workspace$viewport$grid_layout_editor$plus_btn$$=function($props_81076_rect_x$jscomp$1$$){var $rect_y$jscomp$1_start_p$jscomp$15$$=$props_81076_rect_x$jscomp$1$$["start-p"],$zoom$jscomp$114$$=$props_81076_rect_x$jscomp$1$$.zoom,$on_click$jscomp$59$$=$props_81076_rect_x$jscomp$1$$["on-click"],$icon_y_vec__81077$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_81076_rect_x$jscomp$1$$.type,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)-40/$zoom$jscomp$114$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)+9/$zoom$jscomp$114$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)-31/$zoom$jscomp$114$$],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)-40/$zoom$jscomp$114$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$),$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)-31/$zoom$jscomp$114$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($rect_y$jscomp$1_start_p$jscomp$15$$)+9/$zoom$jscomp$114$$],null);$props_81076_rect_x$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon_y_vec__81077$$,
0,null);$rect_y$jscomp$1_start_p$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon_y_vec__81077$$,1,null);var $icon_x$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon_y_vec__81077$$,2,null);$icon_y_vec__81077$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($icon_y_vec__81077$$,3,null);var $handle_click$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$59$$)],function(){return $APP.$cljs$core$truth_$$($on_click$jscomp$59$$)?
$on_click$jscomp$59$$.$cljs$core$IFn$_invoke$arity$0$?$on_click$jscomp$59$$.$cljs$core$IFn$_invoke$arity$0$():$on_click$jscomp$59$$():null});return(0,$APP.$rumext$v2$jsxs$$)("g",{onClick:$handle_click$jscomp$6$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-plus-button",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$props_81076_rect_x$jscomp$1$$+6/$zoom$jscomp$114$$,y:$rect_y$jscomp$1_start_p$jscomp$15$$+6/$zoom$jscomp$114$$,width:28/$zoom$jscomp$114$$,height:28/$zoom$jscomp$114$$,
rx:4/$zoom$jscomp$114$$,ry:4/$zoom$jscomp$114$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-plus-shape"}),(0,$APP.$rumext$v2$jsx$$)("use",{x:$icon_x$$,y:$icon_y_vec__81077$$,width:22/$zoom$jscomp$114$$,height:22/$zoom$jscomp$114$$,href:"#icon-add",className:"main_ui_workspace_viewport_grid_layout_editor__grid-plus-icon"})]})};
$app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$=function($handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$){$handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$=$APP.$cljs$core$__destructure_map$$($handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$);var $on_drag_start$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$,$cljs$cst$5959$on_drag_start$$),$on_drag_end$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$,
$cljs$cst$5960$on_drag_end$$),$on_drag_delta$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$,$cljs$cst$5961$on_drag_delta$$),$on_drag_position$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$,$cljs$cst$5962$on_drag_position$$),$dragging_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_pos_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$current_pos_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);
$handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_drag_start$jscomp$5$$)],function($event$jscomp$693$$){var $raw_pt$jscomp$7$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$693$$),$position$jscomp$222$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($raw_pt$jscomp$7$$);$APP.$app$util$dom$capture_pointer$$($event$jscomp$693$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$5$$,
!0);$APP.$rumext$v2$set_ref_val_BANG_$$($start_pos_ref$$,$raw_pt$jscomp$7$$);$APP.$rumext$v2$set_ref_val_BANG_$$($current_pos_ref$$,$raw_pt$jscomp$7$$);return $APP.$cljs$core$truth_$$($on_drag_start$jscomp$5$$)?$on_drag_start$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_drag_start$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$693$$,$position$jscomp$222$$):$on_drag_start$jscomp$5$$($event$jscomp$693$$,$position$jscomp$222$$):null});var $handle_lost_pointer_capture$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_drag_end$jscomp$1$$)],
function($event$jscomp$694$$){var $delta$jscomp$69_raw_pt$jscomp$8$$=$APP.$rumext$v2$ref_val$$($current_pos_ref$$),$position$jscomp$223$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($delta$jscomp$69_raw_pt$jscomp$8$$);$delta$jscomp$69_raw_pt$jscomp$8$$=$APP.$app$common$geom$point$subtract$$($delta$jscomp$69_raw_pt$jscomp$8$$,$APP.$rumext$v2$ref_val$$($start_pos_ref$$));$APP.$app$util$dom$release_pointer$$($event$jscomp$694$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$5$$,
!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_pos_ref$$,null);return $APP.$cljs$core$truth_$$($on_drag_end$jscomp$1$$)?$on_drag_end$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$?$on_drag_end$jscomp$1$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$694$$,$position$jscomp$223$$,$delta$jscomp$69_raw_pt$jscomp$8$$):$on_drag_end$jscomp$1$$($event$jscomp$694$$,$position$jscomp$223$$,$delta$jscomp$69_raw_pt$jscomp$8$$):null}),$handle_pointer_move$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_drag_delta$$),
$APP.$rumext$v2$adapt$$($on_drag_position$$)],function($event$jscomp$695$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$5$$))){var $G__81084_81296_start$jscomp$255$$=$APP.$rumext$v2$ref_val$$($start_pos_ref$$),$pos$jscomp$157$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$695$$),$pt$jscomp$35$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($pos$jscomp$157$$);$APP.$rumext$v2$set_ref_val_BANG_$$($current_pos_ref$$,$pos$jscomp$157$$);$APP.$cljs$core$truth_$$($on_drag_delta$$)&&
($G__81084_81296_start$jscomp$255$$=$APP.$app$common$geom$point$subtract$$($pos$jscomp$157$$,$G__81084_81296_start$jscomp$255$$),$on_drag_delta$$.$cljs$core$IFn$_invoke$arity$2$?$on_drag_delta$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$695$$,$G__81084_81296_start$jscomp$255$$):$on_drag_delta$$($event$jscomp$695$$,$G__81084_81296_start$jscomp$255$$));return $APP.$cljs$core$truth_$$($on_drag_position$$)?$on_drag_position$$.$cljs$core$IFn$_invoke$arity$2$?$on_drag_position$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$695$$,
$pt$jscomp$35$$):$on_drag_position$$($event$jscomp$695$$,$pt$jscomp$35$$):null}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5963$handle_pointer_down$$,$handle_pointer_down$jscomp$1_map__81081__$1_p__81080$$,$cljs$cst$5964$handle_lost_pointer_capture$$,$handle_lost_pointer_capture$$,$cljs$cst$5965$handle_pointer_move$$,$handle_pointer_move$$],null)};
$app$main$ui$workspace$viewport$grid_layout_editor$resize_cell_handler$$=function($handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$){var $shape$jscomp$1085$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$.shape,$x$jscomp$1286$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$.x,$y$jscomp$509$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$.y,$width$jscomp$236$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$.width,
$height$jscomp$203$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$.height,$handler$jscomp$49$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$.handler,$on_set_modifiers$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$["on-set-modifiers"],$on_clear_modifiers$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$["on-clear-modifiers"],$objects$jscomp$826$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page_objects$$),
$cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$=$APP.$cljs$core$__destructure_map$$($handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$.cell);$cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$,$APP.$cljs$cst$266$id$$);$cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$=
$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1085$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1701$layout_grid_cells$$,$cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$],null));$cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$=$APP.$cljs$core$__destructure_map$$($cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$);
var $row$jscomp$35$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$,$APP.$cljs$cst$1661$row$$),$column$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$,$APP.$cljs$cst$216$column$$),$row_span$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$,
$APP.$cljs$cst$1662$row_span$$),$column_span$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$,$APP.$cljs$cst$1663$column_span$$);$cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$.direction;var $layout_data$jscomp$19$$=$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$["layout-data"],
$calculate_drag_modifiers$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1085$$),$APP.$rumext$v2$adapt$$($row$jscomp$35$$),$APP.$rumext$v2$adapt$$($column$jscomp$45$$),$APP.$rumext$v2$adapt$$($row_span$jscomp$13$$),$APP.$rumext$v2$adapt$$($column_span$jscomp$13$$)],function($new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$){$new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$=$APP.$app$common$geom$shapes$grid_layout$positions$get_position_grid_coord$$($layout_data$jscomp$19$$,
$new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$);var $drag_row$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$,0,null),$drag_column$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$,1,null),$new_column_span$jscomp$1_vec__81092$$=function(){var $G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$=$handler$jscomp$49$$ instanceof
$APP.$cljs$core$Keyword$$?$handler$jscomp$49$$.$fqn$:null;switch($G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$){case "top":$G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$=function(){var $x__5113__auto__$jscomp$89$$=$row$jscomp$35$$+($row_span$jscomp$13$$-1);return $x__5113__auto__$jscomp$89$$<$drag_row$$?$x__5113__auto__$jscomp$89$$:$drag_row$$}();var $new_column_span$jscomp$2_new_row_span$jscomp$3$$=$row$jscomp$35$$-$G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$+$row_span$jscomp$13$$;
return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$,$column$jscomp$45$$,$new_column_span$jscomp$2_new_row_span$jscomp$3$$,$column_span$jscomp$13$$],null);case "left":return $G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$=function(){var $x__5113__auto__$jscomp$90$$=$column$jscomp$45$$+($column_span$jscomp$13$$-1);return $x__5113__auto__$jscomp$90$$<$drag_column$$?$x__5113__auto__$jscomp$90$$:
$drag_column$$}(),$new_column_span$jscomp$2_new_row_span$jscomp$3$$=$column$jscomp$45$$-$G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$+$column_span$jscomp$13$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$35$$,$G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$,$row_span$jscomp$13$$,$new_column_span$jscomp$2_new_row_span$jscomp$3$$],null);case "bottom":return $new_column_span$jscomp$2_new_row_span$jscomp$3$$=function(){var $y__5111__auto__$jscomp$167$$=
$drag_row$$-$row$jscomp$35$$+1;return 1>$y__5111__auto__$jscomp$167$$?1:$y__5111__auto__$jscomp$167$$}(),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$35$$,$column$jscomp$45$$,$new_column_span$jscomp$2_new_row_span$jscomp$3$$,$column_span$jscomp$13$$],null);case "right":return $new_column_span$jscomp$2_new_row_span$jscomp$3$$=function(){var $y__5111__auto__$jscomp$168$$=$drag_column$$-$column$jscomp$45$$+1;return 1>$y__5111__auto__$jscomp$168$$?
1:$y__5111__auto__$jscomp$168$$}(),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$row$jscomp$35$$,$column$jscomp$45$$,$row_span$jscomp$13$$,$new_column_span$jscomp$2_new_row_span$jscomp$3$$],null);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__81095__$1_new_column$jscomp$2_new_row$jscomp$2$$)].join(""));}}();$new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_column_span$jscomp$1_vec__81092$$,
0,null);var $new_column$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_column_span$jscomp$1_vec__81092$$,1,null),$new_row_span$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_column_span$jscomp$1_vec__81092$$,2,null);$new_column_span$jscomp$1_vec__81092$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($new_column_span$jscomp$1_vec__81092$$,3,null);$new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$=$APP.$app$common$types$shape$layout$assign_cells$$($APP.$app$common$types$shape$layout$resize_cell_area$$($shape$jscomp$1085$$,
$row$jscomp$35$$,$column$jscomp$45$$,$new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$,$new_column$jscomp$1$$,$new_row_span$jscomp$2$$,$new_column_span$jscomp$1_vec__81092$$),$objects$jscomp$826$$);return $APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$APP.$cljs$cst$1699$layout_grid_rows$$,$APP.$cljs$cst$1699$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$)),
$APP.$cljs$cst$1700$layout_grid_columns$$,$APP.$cljs$cst$1700$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$)),$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$cst$1701$layout_grid_cells$$.$cljs$core$IFn$_invoke$arity$1$($new_row$jscomp$1_position$jscomp$224_shape__$1$jscomp$117_vec__81089$$))});$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_drag_modifiers$$),
$APP.$rumext$v2$adapt$$($on_set_modifiers$$)],function($_$jscomp$3125_modifiers$jscomp$129$$,$modif_tree$jscomp$63_position$jscomp$225$$){$_$jscomp$3125_modifiers$jscomp$129$$=$calculate_drag_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$calculate_drag_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($modif_tree$jscomp$63_position$jscomp$225$$):$calculate_drag_modifiers$$($modif_tree$jscomp$63_position$jscomp$225$$);$modif_tree$jscomp$63_position$jscomp$225$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1085$$)],null),$_$jscomp$3125_modifiers$jscomp$129$$);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?($APP.$cljs$core$truth_$$($on_set_modifiers$$)&&($on_set_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$on_set_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3125_modifiers$jscomp$129$$):$on_set_modifiers$$($_$jscomp$3125_modifiers$jscomp$129$$)),
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modif_tree$jscomp$63_position$jscomp$225$$))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modif_tree$jscomp$63_position$jscomp$225$$,!1,!1,null))});var $handle_drag_end_handle_lost_pointer_capture$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_drag_modifiers$$),
$APP.$rumext$v2$adapt$$($on_clear_modifiers$$)],function($_$jscomp$3126_modifiers$jscomp$130$$,$modif_tree$jscomp$64_position$jscomp$226$$){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?($_$jscomp$3126_modifiers$jscomp$130$$=$calculate_drag_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$calculate_drag_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($modif_tree$jscomp$64_position$jscomp$226$$):$calculate_drag_modifiers$$($modif_tree$jscomp$64_position$jscomp$226$$),
$modif_tree$jscomp$64_position$jscomp$226$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1085$$)],null),$_$jscomp$3126_modifiers$jscomp$130$$),$APP.$cljs$core$truth_$$($on_clear_modifiers$$)&&($on_clear_modifiers$$.$cljs$core$IFn$_invoke$arity$1$?$on_clear_modifiers$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3126_modifiers$jscomp$130$$):
$on_clear_modifiers$$($_$jscomp$3126_modifiers$jscomp$130$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($modif_tree$jscomp$64_position$jscomp$226$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null))});
$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$=$app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5962$on_drag_position$$,$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$,$cljs$cst$5960$on_drag_end$$,$handle_drag_end_handle_lost_pointer_capture$jscomp$1$$],null));var $handle_pointer_move$jscomp$1_map__81088__$1$$=$APP.$cljs$core$__destructure_map$$($handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$);
$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$1_map__81088__$1$$,$cljs$cst$5963$handle_pointer_down$$);$handle_drag_end_handle_lost_pointer_capture$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$1_map__81088__$1$$,$cljs$cst$5964$handle_lost_pointer_capture$$);$handle_pointer_move$jscomp$1_map__81088__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$1_map__81088__$1$$,
$cljs$cst$5965$handle_pointer_move$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$width$jscomp$236$$,height:$height$jscomp$203$$,className:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cell_id$jscomp$14_direction$jscomp$33_map__81086__$1_map__81087_map__81087__$1$$,$APP.$cljs$cst$1661$row$$)?$app$main$ui$css_cursors$get_dynamic$$("scale-ns",$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1085$$)):$app$main$ui$css_cursors$get_dynamic$$("scale-ew",$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1085$$)),
x:$x$jscomp$1286$$,style:{fill:"transparent",strokeWidth:0},onLostPointerCapture:$handle_drag_end_handle_lost_pointer_capture$jscomp$1$$,y:$y$jscomp$509$$,onPointerMove:$handle_pointer_move$jscomp$1_map__81088__$1$$,onPointerDown:$handle_drag_position_handle_pointer_down$jscomp$2_map__81088_props_81085$$})};
$app$main$ui$workspace$viewport$grid_layout_editor$grid_cell_area_label$$=function($props_81098_text$jscomp$153$$){var $area_y$jscomp$1_cell_origin$jscomp$2$$=$props_81098_text$jscomp$153$$.origin,$area_x$jscomp$1_cell_width$jscomp$2$$=$props_81098_text$jscomp$153$$.width,$zoom$jscomp$115$$=$props_81098_text$jscomp$153$$.zoom;$props_81098_text$jscomp$153$$=$props_81098_text$jscomp$153$$.text;var $area_width$jscomp$1$$=10*$APP.$cljs$core$count$$($props_81098_text$jscomp$153$$)/$zoom$jscomp$115$$,$area_height$jscomp$1$$=
25/$zoom$jscomp$115$$;$area_x$jscomp$1_cell_width$jscomp$2$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($area_y$jscomp$1_cell_origin$jscomp$2$$)+$area_x$jscomp$1_cell_width$jscomp$2$$-$area_width$jscomp$1$$;$area_y$jscomp$1_cell_origin$jscomp$2$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($area_y$jscomp$1_cell_origin$jscomp$2$$);var $area_text_x$jscomp$1$$=$area_x$jscomp$1_cell_width$jscomp$2$$+$area_width$jscomp$1$$/2,$area_text_y$jscomp$1$$=$area_y$jscomp$1_cell_origin$jscomp$2$$+
$area_height$jscomp$1$$/2;return(0,$APP.$rumext$v2$jsxs$$)("g",{pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$area_x$jscomp$1_cell_width$jscomp$2$$,y:$area_y$jscomp$1_cell_origin$jscomp$2$$,width:$area_width$jscomp$1$$,height:$area_height$jscomp$1$$,style:{fill:"var(--grid-editor-area-background)",fillOpacity:.3}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$area_text_x$jscomp$1$$,y:$area_text_y$jscomp$1$$,style:{fill:"var(--grid-editor-area-text)",fontFamily:"worksans",fontWeight:600,
fontSize:14/$zoom$jscomp$115$$,alignmentBaseline:"central",textAnchor:"middle"},children:$props_81098_text$jscomp$153$$})]})};
$app$main$ui$workspace$viewport$grid_layout_editor$use_resize_track$$=function($type$jscomp$718$$,$shape$jscomp$1087$$,$index$jscomp$571$$,$track_before$$,$track_after$$,$zoom$jscomp$117$$,$snap_pixel_QMARK_$jscomp$9$$,$on_set_modifiers$jscomp$2$$,$on_clear_modifiers$jscomp$2$$){var $start_size_before$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$start_size_after$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$handle_drag_start$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1087$$),
$APP.$rumext$v2$adapt$$($track_before$$),$APP.$rumext$v2$adapt$$($track_after$$)],function(){$APP.$cljs$core$reset_BANG_$$($start_size_before$$,$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_before$$));$APP.$cljs$core$reset_BANG_$$($start_size_after$$,$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_after$$));var $modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$type$jscomp$718$$)?
$APP.$cljs$cst$1700$layout_grid_columns$$:$APP.$cljs$cst$1699$layout_grid_rows$$;var $G__81124$jscomp$inline_14006_shape__$1$jscomp$118$$=$track_before$$!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1087$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$,$index$jscomp$571$$-1],null),$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1676$fixed$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_before$$)],null)):$shape$jscomp$1087$$;$G__81124$jscomp$inline_14006_shape__$1$jscomp$118$$=$track_after$$!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__81124$jscomp$inline_14006_shape__$1$jscomp$118$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$,
$index$jscomp$571$$],null),$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1676$fixed$$,$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_after$$)],null)):$G__81124$jscomp$inline_14006_shape__$1$jscomp$118$$;$modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$=$APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__81124$jscomp$inline_14006_shape__$1$jscomp$118$$,$modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$));$modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__81124$jscomp$inline_14006_shape__$1$jscomp$118$$)],
null),$modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modif_tree$jscomp$65_modifiers$jscomp$131_tracks_prop$jscomp$2$$,
!1,!1,null))}),$calculate_modifiers$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1087$$),$APP.$rumext$v2$adapt$$($track_before$$),$APP.$rumext$v2$adapt$$($track_after$$)],function($position$jscomp$228_shape__$1$jscomp$119$$){var $axis$jscomp$48_vec__81127$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$type$jscomp$718$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1700$layout_grid_columns$$,$APP.$cljs$cst$1515$x$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1699$layout_grid_rows$$,$APP.$cljs$cst$1516$y$$],null),$tracks_prop$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($axis$jscomp$48_vec__81127$$,0,null);$axis$jscomp$48_vec__81127$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($axis$jscomp$48_vec__81127$$,1,null);var $precision$jscomp$25$$=
$APP.$cljs$core$truth_$$($snap_pixel_QMARK_$jscomp$9$$)?$APP.$app$common$math$round$$:$APP.$cljs$core$identity$$,$delta$jscomp$70$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$228_shape__$1$jscomp$119$$,$axis$jscomp$48_vec__81127$$)/$zoom$jscomp$117$$,$new_size_before$$=function(){var $G__81130$jscomp$inline_9381_y__5111__auto__$jscomp$169$$=$APP.$cljs$core$_deref$$($start_size_before$$)+$delta$jscomp$70$$;$G__81130$jscomp$inline_9381_y__5111__auto__$jscomp$169$$=$precision$jscomp$25$$.$cljs$core$IFn$_invoke$arity$1$?
$precision$jscomp$25$$.$cljs$core$IFn$_invoke$arity$1$($G__81130$jscomp$inline_9381_y__5111__auto__$jscomp$169$$):$precision$jscomp$25$$($G__81130$jscomp$inline_9381_y__5111__auto__$jscomp$169$$);return 0>$G__81130$jscomp$inline_9381_y__5111__auto__$jscomp$169$$?0:$G__81130$jscomp$inline_9381_y__5111__auto__$jscomp$169$$}(),$new_size_after$$=function(){var $G__81131$jscomp$inline_9383_y__5111__auto__$jscomp$170$$=$APP.$cljs$core$_deref$$($start_size_after$$)-$delta$jscomp$70$$;$G__81131$jscomp$inline_9383_y__5111__auto__$jscomp$170$$=
$precision$jscomp$25$$.$cljs$core$IFn$_invoke$arity$1$?$precision$jscomp$25$$.$cljs$core$IFn$_invoke$arity$1$($G__81131$jscomp$inline_9383_y__5111__auto__$jscomp$170$$):$precision$jscomp$25$$($G__81131$jscomp$inline_9383_y__5111__auto__$jscomp$170$$);return 0>$G__81131$jscomp$inline_9383_y__5111__auto__$jscomp$170$$?0:$G__81131$jscomp$inline_9383_y__5111__auto__$jscomp$170$$}();$position$jscomp$228_shape__$1$jscomp$119$$=function(){var $G__81133$$=$track_before$$!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1087$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tracks_prop$jscomp$3$$,$index$jscomp$571$$-1],null),$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1676$fixed$$,$APP.$cljs$cst$260$value$$,$new_size_before$$],null)):$shape$jscomp$1087$$;return $track_after$$!=null?$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($G__81133$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$tracks_prop$jscomp$3$$,$index$jscomp$571$$],null),$APP.$cljs$core$merge$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1676$fixed$$,$APP.$cljs$cst$260$value$$,$new_size_after$$],null)):$G__81133$$}();return $APP.$app$common$types$modifiers$change_property$$($APP.$app$common$types$modifiers$empty$$(),$tracks_prop$jscomp$3$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$228_shape__$1$jscomp$119$$,$tracks_prop$jscomp$3$$))}),$handle_drag_position$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_modifiers$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_set_modifiers$jscomp$2$$)],function($_$jscomp$3127_modifiers$jscomp$132$$,$modif_tree$jscomp$66_position$jscomp$229$$){$_$jscomp$3127_modifiers$jscomp$132$$=$calculate_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$calculate_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($modif_tree$jscomp$66_position$jscomp$229$$):$calculate_modifiers$jscomp$1$$($modif_tree$jscomp$66_position$jscomp$229$$);
$modif_tree$jscomp$66_position$jscomp$229$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1087$$)],null),$_$jscomp$3127_modifiers$jscomp$132$$);return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?($APP.$cljs$core$truth_$$($on_set_modifiers$jscomp$2$$)&&
($on_set_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_set_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$3127_modifiers$jscomp$132$$):$on_set_modifiers$jscomp$2$$($_$jscomp$3127_modifiers$jscomp$132$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$modifiers$set_wasm_modifiers$$($modif_tree$jscomp$66_position$jscomp$229$$))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($modif_tree$jscomp$66_position$jscomp$229$$,
!1,!1,null))}),$handle_drag_end$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($calculate_modifiers$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_clear_modifiers$jscomp$2$$)],function($_$jscomp$3128_modif_tree_81335_modifiers_81334$$,$___$1$jscomp$2109$$,$position$jscomp$230$$){$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1")?($_$jscomp$3128_modif_tree_81335_modifiers_81334$$=$calculate_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$calculate_modifiers$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($position$jscomp$230$$):$calculate_modifiers$jscomp$1$$($position$jscomp$230$$),$_$jscomp$3128_modif_tree_81335_modifiers_81334$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1087$$)],null),$_$jscomp$3128_modif_tree_81335_modifiers_81334$$),$APP.$cljs$core$truth_$$($on_clear_modifiers$jscomp$2$$)&&
($on_clear_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$?$on_clear_modifiers$jscomp$2$$.$cljs$core$IFn$_invoke$arity$0$():$on_clear_modifiers$jscomp$2$$()),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$$($_$jscomp$3128_modif_tree_81335_modifiers_81334$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$finish_transform$$()]))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null));
$APP.$cljs$core$reset_BANG_$$($start_size_before$$,null);return $APP.$cljs$core$reset_BANG_$$($start_size_after$$,null)});return $app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5959$on_drag_start$$,$handle_drag_start$$,$cljs$cst$5961$on_drag_delta$$,$handle_drag_position$jscomp$1$$,$cljs$cst$5960$on_drag_end$$,$handle_drag_end$jscomp$1$$],null))};
$app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$=function($props_81139_vec__81142$$){var $shape$jscomp$1088$$=$props_81139_vec__81142$$.shape,$index$jscomp$572$$=$props_81139_vec__81142$$.index,$last_QMARK_$jscomp$4$$=$props_81139_vec__81142$$["last?"],$drop_QMARK_$jscomp$1$$=$props_81139_vec__81142$$["drop?"],$handle_pointer_down$jscomp$4_map__81145_track_before$jscomp$1$$=$props_81139_vec__81142$$["track-before"],$handle_lost_pointer_capture$jscomp$2_track_after$jscomp$1$$=
$props_81139_vec__81142$$["track-after"],$handle_pointer_move$jscomp$2_map__81145__$1_snap_pixel_QMARK_$jscomp$10$$=$props_81139_vec__81142$$["snap-pixel?"],$on_set_modifiers$jscomp$3$$=$props_81139_vec__81142$$["on-set-modifiers"],$on_clear_modifiers$jscomp$3$$=$props_81139_vec__81142$$["on-clear-modifiers"],$map__81141__$1_row_total_gap$jscomp$1$$=$APP.$cljs$core$__destructure_map$$($props_81139_vec__81142$$["layout-data"]),$column_total_size$jscomp$1_start_p_resize_vec__81146$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81141__$1_row_total_gap$jscomp$1$$,
$APP.$cljs$cst$3717$column_total_size$$),$column_total_gap$jscomp$1_start_p_drop$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81141__$1_row_total_gap$jscomp$1$$,$APP.$cljs$cst$3718$column_total_gap$$),$row_total_size$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81141__$1_row_total_gap$jscomp$1$$,$APP.$cljs$cst$3722$row_total_size$$);$map__81141__$1_row_total_gap$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81141__$1_row_total_gap$jscomp$1$$,
$APP.$cljs$cst$3720$row_total_gap$$);var $start_p$jscomp$16$$=$props_81139_vec__81142$$["start-p"],$type$jscomp$719$$=$props_81139_vec__81142$$.type,$zoom$jscomp$118$$=$props_81139_vec__81142$$.zoom,$bounds$jscomp$93$$=$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1088$$);$props_81139_vec__81142$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$1088$$);var $layout_gap_row$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($props_81139_vec__81142$$,
0,null),$layout_gap_col$jscomp$14$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($props_81139_vec__81142$$,1,null);$handle_pointer_down$jscomp$4_map__81145_track_before$jscomp$1$$=$app$main$ui$workspace$viewport$grid_layout_editor$use_resize_track$$($type$jscomp$719$$,$shape$jscomp$1088$$,$index$jscomp$572$$,$handle_pointer_down$jscomp$4_map__81145_track_before$jscomp$1$$,$handle_lost_pointer_capture$jscomp$2_track_after$jscomp$1$$,$zoom$jscomp$118$$,$handle_pointer_move$jscomp$2_map__81145__$1_snap_pixel_QMARK_$jscomp$10$$,
$on_set_modifiers$jscomp$3$$,$on_clear_modifiers$jscomp$3$$);$handle_pointer_move$jscomp$2_map__81145__$1_snap_pixel_QMARK_$jscomp$10$$=$APP.$cljs$core$__destructure_map$$($handle_pointer_down$jscomp$4_map__81145_track_before$jscomp$1$$);$handle_pointer_down$jscomp$4_map__81145_track_before$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$2_map__81145__$1_snap_pixel_QMARK_$jscomp$10$$,$cljs$cst$5963$handle_pointer_down$$);$handle_lost_pointer_capture$jscomp$2_track_after$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$2_map__81145__$1_snap_pixel_QMARK_$jscomp$10$$,$cljs$cst$5964$handle_lost_pointer_capture$$);$handle_pointer_move$jscomp$2_map__81145__$1_snap_pixel_QMARK_$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$2_map__81145__$1_snap_pixel_QMARK_$jscomp$10$$,$cljs$cst$5965$handle_pointer_move$$);$column_total_size$jscomp$1_start_p_resize_vec__81146$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,
$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function(){var $x__5110__auto__$jscomp$171_y__5111__auto__$jscomp$inline_9385$$=$layout_gap_col$jscomp$14$$-10/$zoom$jscomp$118$$;$x__5110__auto__$jscomp$171_y__5111__auto__$jscomp$inline_9385$$=0>$x__5110__auto__$jscomp$171_y__5111__auto__$jscomp$inline_9385$$?0:$x__5110__auto__$jscomp$171_y__5111__auto__$jscomp$inline_9385$$;var $y__5111__auto__$jscomp$171$$=8/$zoom$jscomp$118$$;
return $x__5110__auto__$jscomp$171_y__5111__auto__$jscomp$inline_9385$$>$y__5111__auto__$jscomp$171$$?$x__5110__auto__$jscomp$171_y__5111__auto__$jscomp$inline_9385$$:$y__5111__auto__$jscomp$171$$}(),$row_total_size$jscomp$1$$+$map__81141__$1_row_total_gap$jscomp$1$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$column_total_size$jscomp$1_start_p_resize_vec__81146$$+$column_total_gap$jscomp$1_start_p_drop$$,function(){var $x__5110__auto__$jscomp$173_y__5111__auto__$jscomp$inline_9387$$=
$layout_gap_row$jscomp$14$$-10/$zoom$jscomp$118$$;$x__5110__auto__$jscomp$173_y__5111__auto__$jscomp$inline_9387$$=0>$x__5110__auto__$jscomp$173_y__5111__auto__$jscomp$inline_9387$$?0:$x__5110__auto__$jscomp$173_y__5111__auto__$jscomp$inline_9387$$;var $y__5111__auto__$jscomp$173$$=8/$zoom$jscomp$118$$;return $x__5110__auto__$jscomp$173_y__5111__auto__$jscomp$inline_9387$$>$y__5111__auto__$jscomp$173$$?$x__5110__auto__$jscomp$173_y__5111__auto__$jscomp$inline_9387$$:$y__5111__auto__$jscomp$173$$}()],
null);var $width$jscomp$238$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_total_size$jscomp$1_start_p_resize_vec__81146$$,0,null),$height$jscomp$205$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($column_total_size$jscomp$1_start_p_resize_vec__81146$$,1,null);$column_total_size$jscomp$1_start_p_resize_vec__81146$$=function(){var $G__81150__$1_G__81150__$2_G__81150__$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$216$column$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$572$$,0)?$APP.$app$common$geom$point$subtract$$($start_p$jscomp$16$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,$width$jscomp$238$$/2)):$start_p$jscomp$16$$;$G__81150__$1_G__81150__$2_G__81150__$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$1661$row$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$572$$,0)?$APP.$app$common$geom$point$subtract$$($G__81150__$1_G__81150__$2_G__81150__$3$$,
$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,$height$jscomp$205$$/2)):$G__81150__$1_G__81150__$2_G__81150__$3$$;$G__81150__$1_G__81150__$2_G__81150__$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$216$column$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$572$$,0)&&$APP.$cljs$core$not$$($last_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($G__81150__$1_G__81150__$2_G__81150__$3$$,
$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,$layout_gap_col$jscomp$14$$/2)),$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,$width$jscomp$238$$/2)):$G__81150__$1_G__81150__$2_G__81150__$3$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$1661$row$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$572$$,0)&&$APP.$cljs$core$not$$($last_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($G__81150__$1_G__81150__$2_G__81150__$3$$,
$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,$layout_gap_row$jscomp$14$$/2)),$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,$height$jscomp$205$$/2)):$G__81150__$1_G__81150__$2_G__81150__$3$$}();$column_total_gap$jscomp$1_start_p_drop$$=function(){var $G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$216$column$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$572$$,
0)?$APP.$app$common$geom$point$subtract$$($start_p$jscomp$16$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,$width$jscomp$238$$/2)):$start_p$jscomp$16$$;$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$1661$row$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$572$$,0)?$APP.$app$common$geom$point$subtract$$($G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$,
$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,$height$jscomp$205$$/2)):$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$;$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$979$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$216$column$$);return $and__5023__auto__$jscomp$979$$?$last_QMARK_$jscomp$4$$:$and__5023__auto__$jscomp$979$$}())?
$APP.$app$common$geom$point$add$$($G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,$width$jscomp$238$$/2)):$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$;$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$980$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$1661$row$$);
return $and__5023__auto__$jscomp$980$$?$last_QMARK_$jscomp$4$$:$and__5023__auto__$jscomp$980$$}())?$APP.$app$common$geom$point$add$$($G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,$height$jscomp$205$$/2)):$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$;$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,
$APP.$cljs$cst$216$column$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$572$$,0)&&$APP.$cljs$core$not$$($last_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,$layout_gap_col$jscomp$14$$/2)),$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$93$$,5/$zoom$jscomp$118$$)):$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$;
return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$1661$row$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$572$$,0)&&$APP.$cljs$core$not$$($last_QMARK_$jscomp$4$$)?$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$point$subtract$$($G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,$layout_gap_row$jscomp$14$$/2)),$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$93$$,
5/$zoom$jscomp$118$$)):$G__81153__$1_G__81153__$2_G__81153__$3_G__81153__$4_G__81153__$5$$}();return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($drop_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{className:"drop",x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($column_total_gap$jscomp$1_start_p_drop$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($column_total_gap$jscomp$1_start_p_drop$$),width:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,
$APP.$cljs$cst$216$column$$)?10/$zoom$jscomp$118$$:$width$jscomp$238$$,height:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$1661$row$$)?10/$zoom$jscomp$118$$:$height$jscomp$205$$,fill:"var(--grid-editor-area-background)"}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{width:$width$jscomp$238$$,height:$height$jscomp$205$$,className:"resize-track-handler "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$719$$,$APP.$cljs$cst$216$column$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",
$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1088$$)):$app$main$ui$css_cursors$get_dynamic$$("resize-ns",$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1088$$)))??""),x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($column_total_size$jscomp$1_start_p_resize_vec__81146$$),transform:""+($APP.$app$common$geom$matrix$transform_in$$($start_p$jscomp$16$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1088$$))??
""),style:{fill:"transparent",strokeWidth:0},onLostPointerCapture:$handle_lost_pointer_capture$jscomp$2_track_after$jscomp$1$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($column_total_size$jscomp$1_start_p_resize_vec__81146$$),onPointerMove:$handle_pointer_move$jscomp$2_map__81145__$1_snap_pixel_QMARK_$jscomp$10$$,onPointerDown:$handle_pointer_down$jscomp$4_map__81145_track_before$jscomp$1$$})]})};
$app$main$ui$workspace$viewport$grid_layout_editor$marker_shape_d$$=function($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$){var $marker_width$$=24/$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$,$marker_h1$$=20/$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$,$marker_h2$$=10/$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$;$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$=2/$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$;var $marker_half_width$$=$marker_width$$/
2;$a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$=$APP.$app$common$geom$point$subtract$$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($marker_half_width$$,($marker_h1$$+$marker_h2$$)/2));var $e$jscomp$388_vec__81165$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$grid_layout_editor$apply_to_point$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$],null),new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($p1__81160_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__81160_SHARP_$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($marker_width$$,0))},function($p1__81161_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__81161_SHARP_$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(0,$marker_h1$$))},
function($p1__81162_SHARP_$$){return $APP.$app$common$geom$point$add$$($p1__81162_SHARP_$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(-$marker_half_width$$,$marker_h2$$))},function($p1__81163_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__81163_SHARP_$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($marker_half_width$$,$marker_h2$$))}],null));$a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$388_vec__81165$$,
0,null);var $b$jscomp$364$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$388_vec__81165$$,1,null),$c$jscomp$318$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$388_vec__81165$$,2,null),$d$jscomp$245$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$388_vec__81165$$,3,null);$e$jscomp$388_vec__81165$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($e$jscomp$388_vec__81165$$,4,null);var $vea$$=$APP.$app$common$geom$point$subtract$$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,
$e$jscomp$388_vec__81165$$),$b1$jscomp$4_vab$$=$APP.$app$common$geom$point$subtract$$($b$jscomp$364$$,$a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$),$c1$jscomp$38_vbc$jscomp$1$$=$APP.$app$common$geom$point$subtract$$($c$jscomp$318$$,$b$jscomp$364$$),$d1$jscomp$1_vcd$$=$APP.$app$common$geom$point$subtract$$($d$jscomp$245$$,$c$jscomp$318$$),$e1$jscomp$10_vde$$=$APP.$app$common$geom$point$subtract$$($e$jscomp$388_vec__81165$$,$d$jscomp$245$$),$a1$jscomp$8_lea$$=$APP.$app$common$geom$point$length$$($vea$$),
$b2$jscomp$2_lab$$=$APP.$app$common$geom$point$length$$($b1$jscomp$4_vab$$),$c2$jscomp$27_lbc$$=$APP.$app$common$geom$point$length$$($c1$jscomp$38_vbc$jscomp$1$$),$d2$jscomp$1_lcd$$=$APP.$app$common$geom$point$length$$($d1$jscomp$1_vcd$$),$lde$$=$APP.$app$common$geom$point$length$$($e1$jscomp$10_vde$$);$a1$jscomp$8_lea$$=$APP.$app$common$geom$point$add$$($e$jscomp$388_vec__81165$$,$app$common$geom$point$resize$$($vea$$,$a1$jscomp$8_lea$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));var $a2$jscomp$4$$=
$APP.$app$common$geom$point$add$$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,$app$common$geom$point$resize$$($b1$jscomp$4_vab$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));$b1$jscomp$4_vab$$=$APP.$app$common$geom$point$add$$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$,$app$common$geom$point$resize$$($b1$jscomp$4_vab$$,$b2$jscomp$2_lab$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));$b2$jscomp$2_lab$$=$APP.$app$common$geom$point$add$$($b$jscomp$364$$,$app$common$geom$point$resize$$($c1$jscomp$38_vbc$jscomp$1$$,
$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));$c1$jscomp$38_vbc$jscomp$1$$=$APP.$app$common$geom$point$add$$($b$jscomp$364$$,$app$common$geom$point$resize$$($c1$jscomp$38_vbc$jscomp$1$$,$c2$jscomp$27_lbc$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));$c2$jscomp$27_lbc$$=$APP.$app$common$geom$point$add$$($c$jscomp$318$$,$app$common$geom$point$resize$$($d1$jscomp$1_vcd$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));$d1$jscomp$1_vcd$$=$APP.$app$common$geom$point$add$$($c$jscomp$318$$,$app$common$geom$point$resize$$($d1$jscomp$1_vcd$$,
$d2$jscomp$1_lcd$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));$d2$jscomp$1_lcd$$=$APP.$app$common$geom$point$add$$($d$jscomp$245$$,$app$common$geom$point$resize$$($e1$jscomp$10_vde$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));$e1$jscomp$10_vde$$=$APP.$app$common$geom$point$add$$($d$jscomp$245$$,$app$common$geom$point$resize$$($e1$jscomp$10_vde$$,$lde$$-$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$=$APP.$app$common$geom$point$add$$($e$jscomp$388_vec__81165$$,
$app$common$geom$point$resize$$($vea$$,$e2$jscomp$5_marker_bradius_zoom$jscomp$119$$));return"M"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$8_lea$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$8_lea$$)??"")+("Q"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($a$jscomp$429_center$jscomp$55_start_p$jscomp$17$$)??"")+
","+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$4$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($a2$jscomp$4$$)??""))+("L"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($b1$jscomp$4_vab$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($b1$jscomp$4_vab$$)??""))+("Q"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$364$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($b$jscomp$364$$)??
"")+","+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($b2$jscomp$2_lab$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($b2$jscomp$2_lab$$)??""))+("L"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$38_vbc$jscomp$1$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($c1$jscomp$38_vbc$jscomp$1$$)??""))+("Q"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$318$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($c$jscomp$318$$)??
"")+","+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$27_lbc$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($c2$jscomp$27_lbc$$)??""))+("L"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($d1$jscomp$1_vcd$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($d1$jscomp$1_vcd$$)??""))+("Q"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$245$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($d$jscomp$245$$)??
"")+","+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($d2$jscomp$1_lcd$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($d2$jscomp$1_lcd$$)??""))+("L"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($e1$jscomp$10_vde$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($e1$jscomp$10_vde$$)??""))+("Q"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$388_vec__81165$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$388_vec__81165$$)??
"")+","+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($e2$jscomp$5_marker_bradius_zoom$jscomp$119$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($e2$jscomp$5_marker_bradius_zoom$jscomp$119$$)??""))+("L"+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$8_lea$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($a1$jscomp$8_lea$$)??""))+"Z"};
$app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$=function($props_81170_text_x$jscomp$2$$){var $center$jscomp$56$$=$props_81170_text_x$jscomp$2$$.center,$value$jscomp$1007$$=$props_81170_text_x$jscomp$2$$.value,$zoom$jscomp$120$$=$props_81170_text_x$jscomp$2$$.zoom,$shape$jscomp$1089$$=$props_81170_text_x$jscomp$2$$.shape,$handle_pointer_down$jscomp$5_index$jscomp$573_map__81172$$=$props_81170_text_x$jscomp$2$$.index,$type$jscomp$720$$=$props_81170_text_x$jscomp$2$$.type,$handle_lost_pointer_capture$jscomp$3_track_before$jscomp$2$$=
$props_81170_text_x$jscomp$2$$["track-before"],$handle_pointer_move$jscomp$3_map__81172__$1_track_after$jscomp$2$$=$props_81170_text_x$jscomp$2$$["track-after"],$snap_pixel_QMARK_$jscomp$11$$=$props_81170_text_x$jscomp$2$$["snap-pixel?"],$on_set_modifiers$jscomp$4$$=$props_81170_text_x$jscomp$2$$["on-set-modifiers"],$on_clear_modifiers$jscomp$4$$=$props_81170_text_x$jscomp$2$$["on-clear-modifiers"];$props_81170_text_x$jscomp$2$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$56$$);
var $text_y$jscomp$2$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($center$jscomp$56$$);$handle_pointer_down$jscomp$5_index$jscomp$573_map__81172$$=$app$main$ui$workspace$viewport$grid_layout_editor$use_resize_track$$($type$jscomp$720$$,$shape$jscomp$1089$$,$handle_pointer_down$jscomp$5_index$jscomp$573_map__81172$$,$handle_lost_pointer_capture$jscomp$3_track_before$jscomp$2$$,$handle_pointer_move$jscomp$3_map__81172__$1_track_after$jscomp$2$$,$zoom$jscomp$120$$,$snap_pixel_QMARK_$jscomp$11$$,
$on_set_modifiers$jscomp$4$$,$on_clear_modifiers$jscomp$4$$);$handle_pointer_move$jscomp$3_map__81172__$1_track_after$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($handle_pointer_down$jscomp$5_index$jscomp$573_map__81172$$);$handle_pointer_down$jscomp$5_index$jscomp$573_map__81172$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$3_map__81172__$1_track_after$jscomp$2$$,$cljs$cst$5963$handle_pointer_down$$);$handle_lost_pointer_capture$jscomp$3_track_before$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$3_map__81172__$1_track_after$jscomp$2$$,$cljs$cst$5964$handle_lost_pointer_capture$$);$handle_pointer_move$jscomp$3_map__81172__$1_track_after$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_pointer_move$jscomp$3_map__81172__$1_track_after$jscomp$2$$,$cljs$cst$5965$handle_pointer_move$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerDown:$handle_pointer_down$jscomp$5_index$jscomp$573_map__81172$$,
onLostPointerCapture:$handle_lost_pointer_capture$jscomp$3_track_before$jscomp$2$$,onPointerMove:$handle_pointer_move$jscomp$3_map__81172__$1_track_after$jscomp$2$$,transform:""+($APP.$app$common$geom$matrix$transform_in$$($center$jscomp$56$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1089$$))??""),className:$APP.$app$util$dom$classnames$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["main_ui_workspace_viewport_grid_layout_editor__grid-track-marker",
!0,$app$main$ui$css_cursors$get_dynamic$$("resize-ew",$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1089$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$720$$,$APP.$cljs$cst$216$column$$),$app$main$ui$css_cursors$get_dynamic$$("resize-ns",$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1089$$)),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$720$$,$APP.$cljs$cst$1661$row$$)])),children:[(0,$APP.$rumext$v2$jsx$$)("path",
{d:$app$main$ui$workspace$viewport$grid_layout_editor$marker_shape_d$$($center$jscomp$56$$,$zoom$jscomp$120$$),className:"main_ui_workspace_viewport_grid_layout_editor__marker-shape"}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$props_81170_text_x$jscomp$2$$,y:$text_y$jscomp$2$$,width:26.26/$zoom$jscomp$120$$,height:36/$zoom$jscomp$120$$,textAnchor:"middle",dominantBaseline:"middle",className:"main_ui_workspace_viewport_grid_layout_editor__marker-text",children:""+($value$jscomp$1007$$??"")})]})};
$app$main$ui$workspace$viewport$guides$compute_guide_drag_position$$=function($new_position_p__81096_position$jscomp$235$$){var $map__81097__$1_snap_pixel_QMARK_$jscomp$14$$=$APP.$cljs$core$__destructure_map$$($new_position_p__81096_position$jscomp$235$$),$axis$jscomp$49_delta$jscomp$71$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81097__$1_snap_pixel_QMARK_$jscomp$14$$,$APP.$cljs$cst$2062$axis$$);$new_position_p__81096_position$jscomp$235$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81097__$1_snap_pixel_QMARK_$jscomp$14$$,
$APP.$cljs$cst$1681$position$$);var $start_pos$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81097__$1_snap_pixel_QMARK_$jscomp$14$$,$APP.$cljs$cst$1387$start_pos$$),$start_pt$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81097__$1_snap_pixel_QMARK_$jscomp$14$$,$cljs$cst$5966$start_pt$$),$current_pt$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81097__$1_snap_pixel_QMARK_$jscomp$14$$,$cljs$cst$5967$current_pt$$),$zoom$jscomp$123$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81097__$1_snap_pixel_QMARK_$jscomp$14$$,$APP.$cljs$cst$2204$zoom$$);$map__81097__$1_snap_pixel_QMARK_$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81097__$1_snap_pixel_QMARK_$jscomp$14$$,$APP.$cljs$cst$3886$snap_pixel_QMARK_$$);$axis$jscomp$49_delta$jscomp$71$$=($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($current_pt$jscomp$2$$,$axis$jscomp$49_delta$jscomp$71$$)-$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($start_pt$jscomp$2$$,
$axis$jscomp$49_delta$jscomp$71$$))/$zoom$jscomp$123$$;$new_position_p__81096_position$jscomp$235$$=$new_position_p__81096_position$jscomp$235$$!=null?$new_position_p__81096_position$jscomp$235$$+$axis$jscomp$49_delta$jscomp$71$$:$start_pos$jscomp$19$$+$axis$jscomp$49_delta$jscomp$71$$;return $APP.$cljs$core$truth_$$($map__81097__$1_snap_pixel_QMARK_$jscomp$14$$)?$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($new_position_p__81096_position$jscomp$235$$):$new_position_p__81096_position$jscomp$235$$};
$app$main$ui$workspace$viewport$guides$guide_visible_in_focus_QMARK_$$=function($focus$jscomp$19$$,$frame_id$jscomp$158$$){return $frame_id$jscomp$158$$==null||$APP.$cljs$core$empty_QMARK_$$($focus$jscomp$19$$)||$APP.$cljs$core$contains_QMARK_$$($focus$jscomp$19$$,$frame_id$jscomp$158$$)};
$app$main$ui$workspace$viewport$guides$wasm_visible_guides$$=function($dragging_id_map__81100__$1_p__81099$$){$dragging_id_map__81100__$1_p__81099$$=$APP.$cljs$core$__destructure_map$$($dragging_id_map__81100__$1_p__81099$$);var $G__81105_guides$jscomp$13_guides__$1$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dragging_id_map__81100__$1_p__81099$$,$APP.$cljs$cst$2065$guides$$),$visible_QMARK_$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dragging_id_map__81100__$1_p__81099$$,
$cljs$cst$5968$visible_QMARK_$$),$focused$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dragging_id_map__81100__$1_p__81099$$,$APP.$cljs$cst$4824$focused$$);$dragging_id_map__81100__$1_p__81099$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($dragging_id_map__81100__$1_p__81099$$,$cljs$cst$5969$dragging_id$$);$G__81105_guides$jscomp$13_guides__$1$jscomp$3$$=$APP.$cljs$core$truth_$$($visible_QMARK_$jscomp$7$$)?$APP.$cljs$core$truth_$$($G__81105_guides$jscomp$13_guides__$1$jscomp$3$$)?
$G__81105_guides$jscomp$13_guides__$1$jscomp$3$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$;$G__81105_guides$jscomp$13_guides__$1$jscomp$3$$=$APP.$cljs$core$seq$$($focused$jscomp$4$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($guide$jscomp$13_p__81101$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($guide$jscomp$13_p__81101$$,
0,null);$guide$jscomp$13_p__81101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($guide$jscomp$13_p__81101$$,1,null);return $app$main$ui$workspace$viewport$guides$guide_visible_in_focus_QMARK_$$($focused$jscomp$4$$,$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$13_p__81101$$))},$G__81105_guides$jscomp$13_guides__$1$jscomp$3$$)):$G__81105_guides$jscomp$13_guides__$1$jscomp$3$$;return $APP.$cljs$core$truth_$$($dragging_id_map__81100__$1_p__81099$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($G__81105_guides$jscomp$13_guides__$1$jscomp$3$$,
$dragging_id_map__81100__$1_p__81099$$):$G__81105_guides$jscomp$13_guides__$1$jscomp$3$$};
$app$main$ui$workspace$viewport$guides$use_guide$$=function($on_guide_change$$,$get_hover_frame$$,$zoom$jscomp$124$$,$frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$){$frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$);var $id$jscomp$1052$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$,$APP.$cljs$cst$266$id$$),$position$jscomp$236$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$,
$APP.$cljs$cst$1681$position$$),$axis$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$,$APP.$cljs$cst$2062$axis$$),$frame_id$jscomp$159$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$,$APP.$cljs$cst$1612$frame_id$$),$dragging_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$start_pos_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$state$jscomp$1235$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2212$hover$$,!1,$cljs$cst$5970$new_position$$,null,$APP.$cljs$cst$5126$new_frame_id$$,$frame_id$jscomp$159$$],null)}),$frame_id__$1$jscomp$12$$=$APP.$cljs$cst$5126$new_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1235$$));$frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id__$1$jscomp$12$$)],
function(){return $app$main$refs$object_by_id$$($frame_id__$1$jscomp$12$$)});$frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$=$APP.$rumext$v2$deref$$($frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$);var $snap_pixel_QMARK_$jscomp$15$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$snap_pixel_QMARK_$$),$read_only_QMARK_$jscomp$31$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$on_pointer_enter$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],
function(){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$guides$set_hover_guide$$($id$jscomp$1052$$,!0));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1235$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2212$hover$$,!0)}),$on_pointer_leave$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],
function(){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$guides$set_hover_guide$$($id$jscomp$1052$$,!1));return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1235$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2212$hover$$,!1)}),$on_pointer_down$jscomp$15$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],
function($event$jscomp$703$$){return $APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$event$jscomp$703$$.button)?($APP.$app$util$dom$capture_pointer$$($event$jscomp$703$$),$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$6$$,!0),$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$3$$,$APP.$app$util$dom$get_client_position$$($event$jscomp$703$$)),$APP.$rumext$v2$set_ref_val_BANG_$$($start_pos_ref$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$),
$axis$jscomp$50$$))):null}),$on_pointer_up$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$select_keys$$($APP.$cljs$core$_deref$$($state$jscomp$1235$$),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5970$new_position$$,$APP.$cljs$cst$5126$new_frame_id$$],null))),$APP.$rumext$v2$adapt$$($on_guide_change$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],function(){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;
if($on_guide_change$$!=null&&$cljs$cst$5970$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1235$$))!=null){var $G__81111$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$position$$,$cljs$cst$5970$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1235$$)),$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$5126$new_frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1235$$))],null);
return $on_guide_change$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_change$$.$cljs$core$IFn$_invoke$arity$1$($G__81111$$):$on_guide_change$$($G__81111$$)}return null}),$on_lost_pointer_capture$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$)],function($event$jscomp$704$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;$APP.$app$util$dom$release_pointer$$($event$jscomp$704$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$6$$,
!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$3$$,null);$APP.$rumext$v2$set_ref_val_BANG_$$($start_pos_ref$jscomp$1$$,null);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1235$$,$APP.$cljs$core$assoc$$,$cljs$cst$5970$new_position$$,null)}),$on_pointer_move$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($position$jscomp$236$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$124$$),$APP.$rumext$v2$adapt$$($snap_pixel_QMARK_$jscomp$15$$),
$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$31$$),$APP.$rumext$v2$adapt$$($get_hover_frame$$),$APP.$rumext$v2$adapt$$($axis$jscomp$50$$)],function($current_pt$jscomp$3_event$jscomp$705$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$31$$))return null;if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$6$$))){var $new_position$jscomp$1_start_pt$jscomp$3$$=$APP.$rumext$v2$ref_val$$($start_ref$jscomp$3$$),$new_frame_id$jscomp$1_start_pos$jscomp$20$$=$APP.$rumext$v2$ref_val$$($start_pos_ref$jscomp$1$$);
$current_pt$jscomp$3_event$jscomp$705$$=$APP.$app$util$dom$get_client_position$$($current_pt$jscomp$3_event$jscomp$705$$);$new_position$jscomp$1_start_pt$jscomp$3$$=$app$main$ui$workspace$viewport$guides$compute_guide_drag_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$2062$axis$$,$axis$jscomp$50$$,$APP.$cljs$cst$1681$position$$,$position$jscomp$236$$,$APP.$cljs$cst$1387$start_pos$$,$new_frame_id$jscomp$1_start_pos$jscomp$20$$,$cljs$cst$5966$start_pt$$,$new_position$jscomp$1_start_pt$jscomp$3$$,
$cljs$cst$5967$current_pt$$,$current_pt$jscomp$3_event$jscomp$705$$,$APP.$cljs$cst$2204$zoom$$,$zoom$jscomp$124$$,$APP.$cljs$cst$3886$snap_pixel_QMARK_$$,$snap_pixel_QMARK_$jscomp$15$$],null));$new_frame_id$jscomp$1_start_pos$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($get_hover_frame$$.$cljs$core$IFn$_invoke$arity$0$?$get_hover_frame$$.$cljs$core$IFn$_invoke$arity$0$():$get_hover_frame$$(),$APP.$cljs$cst$266$id$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state$jscomp$1235$$,
$APP.$cljs$core$assoc$$,$cljs$cst$5970$new_position$$,$new_position$jscomp$1_start_pt$jscomp$3$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5126$new_frame_id$$,$new_frame_id$jscomp$1_start_pos$jscomp$20$$]))}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$cljs$cst$5971$on_pointer_enter$$,$on_pointer_enter$jscomp$13$$,$cljs$cst$5972$on_pointer_leave$$,$on_pointer_leave$jscomp$13$$,$APP.$cljs$cst$4610$on_pointer_down$$,$on_pointer_down$jscomp$15$$,
$cljs$cst$5973$on_pointer_up$$,$on_pointer_up$jscomp$4$$,$APP.$cljs$cst$4611$on_lost_pointer_capture$$,$on_lost_pointer_capture$jscomp$9$$,$APP.$cljs$cst$4612$on_pointer_move$$,$on_pointer_move$jscomp$12$$,$APP.$cljs$cst$769$state$$,$state$jscomp$1235$$,$APP.$cljs$cst$1611$frame$$,$frame$jscomp$88_frame_ref_map__81110__$1_p__81109$$],null)};
$app$main$ui$workspace$viewport$guides$guide_area_axis$$=function($pos$jscomp$158$$,$vbox$jscomp$55$$,$guide_active_area_zoom$jscomp$125$$,$frame$jscomp$89$$,$axis$jscomp$51$$){var $rulers_pos$jscomp$1$$=15/$guide_active_area_zoom$jscomp$125$$;$guide_active_area_zoom$jscomp$125$$=16/$guide_active_area_zoom$jscomp$125$$;return $frame$jscomp$89$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$51$$,$APP.$cljs$cst$1515$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1515$x$$,
$pos$jscomp$158$$-$guide_active_area_zoom$jscomp$125$$/2,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$89$$),$APP.$cljs$cst$290$width$$,$guide_active_area_zoom$jscomp$125$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$89$$)],null):$frame$jscomp$89$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$89$$),
$APP.$cljs$cst$1516$y$$,$pos$jscomp$158$$-$guide_active_area_zoom$jscomp$125$$/2,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$89$$),$APP.$cljs$cst$1527$height$$,$guide_active_area_zoom$jscomp$125$$],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$51$$,$APP.$cljs$cst$1515$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1515$x$$,$pos$jscomp$158$$-$guide_active_area_zoom$jscomp$125$$/2,$APP.$cljs$cst$1516$y$$,
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$rulers_pos$jscomp$1$$,$APP.$cljs$cst$290$width$$,$guide_active_area_zoom$jscomp$125$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$)+$rulers_pos$jscomp$1$$,$APP.$cljs$cst$1516$y$$,$pos$jscomp$158$$-$guide_active_area_zoom$jscomp$125$$/
2,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$55$$),$APP.$cljs$cst$1527$height$$,$guide_active_area_zoom$jscomp$125$$],null)};
$app$main$ui$workspace$viewport$guides$is_guide_inside_frame_QMARK_$$=function($guide$jscomp$14$$,$frame$jscomp$91$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$2062$axis$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$14$$))?$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$14$$)>=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$91$$)&&$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$14$$)<=
$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$91$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$91$$):$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$14$$)>=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$91$$)&&$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$14$$)<=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$91$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$91$$)};
$app$main$ui$workspace$viewport$guides$new_guide_area_STAR_$$=function($disabled_guides$jscomp$1_props_81168$$){var $axis$jscomp$60$$=$disabled_guides$jscomp$1_props_81168$$.axis,$zoom$jscomp$133$$=$disabled_guides$jscomp$1_props_81168$$.zoom,$vbox$jscomp$64$$=$disabled_guides$jscomp$1_props_81168$$.vbox,$get_hover_frame$jscomp$2$$=$disabled_guides$jscomp$1_props_81168$$.getHoverFrame;$disabled_guides$jscomp$1_props_81168$$=$disabled_guides$jscomp$1_props_81168$$.disabledGuides;var $map__81169_on_guide_change$jscomp$2_state$jscomp$1237$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vbox$jscomp$64$$)],function($guide$jscomp$16_guide__$1$jscomp$2$$){$guide$jscomp$16_guide__$1$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$16_guide__$1$jscomp$2$$,$APP.$cljs$cst$266$id$$,$APP.$app$common$uuid$next$$()),$APP.$cljs$cst$2062$axis$$,$axis$jscomp$60$$);return $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$3$($zoom$jscomp$133$$,
$vbox$jscomp$64$$,$guide$jscomp$16_guide__$1$jscomp$2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$guides$update_guides$$($guide$jscomp$16_guide__$1$jscomp$2$$)):null});$map__81169_on_guide_change$jscomp$2_state$jscomp$1237$$=$app$main$ui$workspace$viewport$guides$use_guide$$($map__81169_on_guide_change$jscomp$2_state$jscomp$1237$$,$get_hover_frame$jscomp$2$$,$zoom$jscomp$133$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2062$axis$$,
$axis$jscomp$60$$],null));var $frame$jscomp$94_map__81169__$1$$=$APP.$cljs$core$__destructure_map$$($map__81169_on_guide_change$jscomp$2_state$jscomp$1237$$),$on_pointer_enter$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$94_map__81169__$1$$,$cljs$cst$5971$on_pointer_enter$$),$on_pointer_leave$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$94_map__81169__$1$$,$cljs$cst$5972$on_pointer_leave$$),$on_pointer_down$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$94_map__81169__$1$$,
$APP.$cljs$cst$4610$on_pointer_down$$),$on_pointer_up$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$94_map__81169__$1$$,$cljs$cst$5973$on_pointer_up$$),$on_lost_pointer_capture$jscomp$11$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$94_map__81169__$1$$,$APP.$cljs$cst$4611$on_lost_pointer_capture$$),$on_pointer_move$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$94_map__81169__$1$$,$APP.$cljs$cst$4612$on_pointer_move$$);
$map__81169_on_guide_change$jscomp$2_state$jscomp$1237$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$94_map__81169__$1$$,$APP.$cljs$cst$769$state$$);$frame$jscomp$94_map__81169__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$94_map__81169__$1$$,$APP.$cljs$cst$1611$frame$$);var $read_only_QMARK_$jscomp$33$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"new-guides",
children:[$APP.$cljs$core$truth_$$($disabled_guides$jscomp$1_props_81168$$)?null:function(){var $map__81171_x$jscomp$1290$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$60$$,$APP.$cljs$cst$1515$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$)+8/$zoom$jscomp$133$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$),$APP.$cljs$cst$290$width$$,
16/$zoom$jscomp$133$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$)+28/$zoom$jscomp$133$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$),$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$64$$),
$APP.$cljs$cst$1527$height$$,24/$zoom$jscomp$133$$],null);var $height$jscomp$209_map__81171__$1$$=$APP.$cljs$core$__destructure_map$$($map__81171_x$jscomp$1290$$);$map__81171_x$jscomp$1290$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$209_map__81171__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$513$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$209_map__81171__$1$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$243$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$209_map__81171__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$209_map__81171__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$209_map__81171__$1$$,$APP.$cljs$cst$1527$height$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$width$jscomp$243$$,height:$height$jscomp$209_map__81171__$1$$,className:$APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$33$$)?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$60$$,$APP.$cljs$cst$1515$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",
0):$app$main$ui$css_cursors$get_dynamic$$("resize-ns",0),x:$map__81171_x$jscomp$1290$$,onPointerUp:$on_pointer_up$jscomp$6$$,style:{fill:"none",pointerEvents:"fill"},onLostPointerCapture:$on_lost_pointer_capture$jscomp$11$$,y:$y$jscomp$513$$,onPointerMove:$on_pointer_move$jscomp$14$$,onPointerDown:$on_pointer_down$jscomp$17$$,onPointerLeave:$on_pointer_leave$jscomp$15$$,onPointerEnter:$on_pointer_enter$jscomp$15$$})}(),$APP.$cljs$core$truth_$$($cljs$cst$5970$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($map__81169_on_guide_change$jscomp$2_state$jscomp$1237$$)))?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_STAR_$$,{guide:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2062$axis$$,$axis$jscomp$60$$,$APP.$cljs$cst$1681$position$$,$cljs$cst$5970$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($map__81169_on_guide_change$jscomp$2_state$jscomp$1237$$))],null),getHoverFrame:$get_hover_frame$jscomp$2$$,vbox:$vbox$jscomp$64$$,zoom:$zoom$jscomp$133$$,isHover:!0,hoverFrame:$frame$jscomp$94_map__81169__$1$$}):
null]})};$app$main$ui$workspace$viewport$guides$guide_by_serialized_index$$=function($guides$jscomp$14$$,$index$jscomp$577$$){return $index$jscomp$577$$>=0?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$vec$$($APP.$cljs$core$vals$$($guides$jscomp$14$$)),$index$jscomp$577$$,null):null};
$app$main$ui$workspace$viewport$guides$guide_overlay_STAR_$$=function($position$jscomp$238_props_81173$$){var $on_input_commit$$=$position$jscomp$238_props_81173$$.onInputCommit,$zoom$jscomp$134$$=$position$jscomp$238_props_81173$$.zoom,$on_input_cancel$$=$position$jscomp$238_props_81173$$.onInputCancel,$frame$jscomp$95$$=$position$jscomp$238_props_81173$$.frame,$vbox$jscomp$65$$=$position$jscomp$238_props_81173$$.vbox,$mode$jscomp$52$$=$position$jscomp$238_props_81173$$.mode,$guide$jscomp$17$$=$position$jscomp$238_props_81173$$.guide,
$frame_offset$jscomp$13$$=$position$jscomp$238_props_81173$$.frameOffset;$position$jscomp$238_props_81173$$=$position$jscomp$238_props_81173$$.position;var $axis$jscomp$61$$=$APP.$cljs$cst$2062$axis$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$17$$),$guide_color$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1398$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$17$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1398$$)?$or__5025__auto__$jscomp$1398$$:
"#ff3277"}(),$input_ref$jscomp$15$$=(0,$APP.$rumext$v2$use_ref$$)(null),$show_line_QMARK_$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$52$$,$APP.$cljs$cst$2212$hover$$),$show_pill_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$52$$,$APP.$cljs$cst$4996$edit$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$52$$,$APP.$cljs$cst$2212$hover$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$52$$,$cljs$cst$5990$drag$$),
$editing_QMARK_$jscomp$13$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$52$$,$APP.$cljs$cst$4996$edit$$),$on_key_down$jscomp$28$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_input_commit$$),$APP.$rumext$v2$adapt$$($on_input_cancel$$)],function($G__81177_event$jscomp$709$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($G__81177_event$jscomp$709$$))?($APP.$app$util$dom$prevent_default$$($G__81177_event$jscomp$709$$),
$APP.$app$util$dom$stop_propagation$$($G__81177_event$jscomp$709$$),$G__81177_event$jscomp$709$$=$APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$15$$)),$on_input_commit$$.$cljs$core$IFn$_invoke$arity$1$?$on_input_commit$$.$cljs$core$IFn$_invoke$arity$1$($G__81177_event$jscomp$709$$):$on_input_commit$$($G__81177_event$jscomp$709$$)):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($G__81177_event$jscomp$709$$))?($APP.$app$util$dom$prevent_default$$($G__81177_event$jscomp$709$$),
$APP.$app$util$dom$stop_propagation$$($G__81177_event$jscomp$709$$),$on_input_cancel$$.$cljs$core$IFn$_invoke$arity$0$?$on_input_cancel$$.$cljs$core$IFn$_invoke$arity$0$():$on_input_cancel$$()):null}),$on_blur$jscomp$36$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_input_commit$$)],function(){var $G__81178$$=$APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($input_ref$jscomp$15$$));return $on_input_commit$$.$cljs$core$IFn$_invoke$arity$1$?$on_input_commit$$.$cljs$core$IFn$_invoke$arity$1$($G__81178$$):
$on_input_commit$$($G__81178$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mode$jscomp$52$$)],function(){if($editing_QMARK_$jscomp$13$$){var $G__81179$$=$APP.$rumext$v2$ref_val$$($input_ref$jscomp$15$$);return $G__81179$$==null?null:$APP.$app$util$dom$select_text_BANG_$$($G__81179$$)}return null});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"guide-overlay",children:[$show_line_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_line_STAR_$$,
{pos:$position$jscomp$238_props_81173$$,vbox:$vbox$jscomp$65$$,zoom:$zoom$jscomp$134$$,axis:$axis$jscomp$61$$,color:$guide_color$jscomp$1$$,"hover?":!0}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($mode$jscomp$52$$,$APP.$cljs$cst$2212$hover$$)&&$frame$jscomp$95$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_line_STAR_$$,{pos:$position$jscomp$238_props_81173$$,vbox:$vbox$jscomp$65$$,zoom:$zoom$jscomp$134$$,axis:$axis$jscomp$61$$,color:$guide_color$jscomp$1$$,
frame:$frame$jscomp$95$$,"hover?":!0,showMain:!1}):null,$show_pill_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_pill_STAR_$$,{inputRef:$input_ref$jscomp$15$$,pos:$position$jscomp$238_props_81173$$,onInputKeyDown:$on_key_down$jscomp$28$$,zoom:$zoom$jscomp$134$$,frameOffset:$frame_offset$jscomp$13$$,onInputBlur:$on_blur$jscomp$36$$,axis:$axis$jscomp$61$$,vbox:$vbox$jscomp$65$$,editing:$editing_QMARK_$jscomp$13$$,color:$guide_color$jscomp$1$$}):null]})};
$app$main$ui$workspace$viewport$guides$use_wasm_guide_interaction$$=function($map__81195__$1_p__81194$$){function $double_click$$($G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$){if($APP.$cljs$core$not$$($read_only_QMARK_$jscomp$34$$)&&$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($editing_ref$jscomp$2$$))){var $guide$jscomp$23$$=$visible_guide_at_event$$($G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$),$frame_id$jscomp$161_map__81237__$1$$=$APP.$cljs$core$__destructure_map$$($guide$jscomp$23$$),
$id$jscomp$1055$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$161_map__81237__$1$$,$APP.$cljs$cst$266$id$$),$axis$jscomp$65_offset$jscomp$220$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$161_map__81237__$1$$,$APP.$cljs$cst$2062$axis$$),$position$jscomp$240$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$161_map__81237__$1$$,$APP.$cljs$cst$1681$position$$);$frame_id$jscomp$161_map__81237__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$161_map__81237__$1$$,
$APP.$cljs$cst$1612$frame_id$$);if($APP.$cljs$core$truth_$$($guide$jscomp$23$$))return $APP.$app$util$dom$prevent_default$$($G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$),$APP.$app$util$dom$stop_propagation$$($G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$),$on_guide_drag$$!=null&&($on_guide_drag$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_drag$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1055$$):$on_guide_drag$$($id$jscomp$1055$$)),$APP.$rumext$v2$set_ref_val_BANG_$$($guide_ref$$,
$guide$jscomp$23$$),$APP.$rumext$v2$set_ref_val_BANG_$$($editing_ref$jscomp$2$$,!0),$G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$=$frame_id$jscomp$161_map__81237__$1$$==null?null:$app$main$refs$object_by_id$$($frame_id$jscomp$161_map__81237__$1$$),$G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$=$G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$==null?null:$APP.$cljs$core$_deref$$($G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$),
$axis$jscomp$65_offset$jscomp$220$$=$APP.$cljs$core$truth_$$($G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$axis$jscomp$65_offset$jscomp$220$$)?$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$):$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($G__81238__$1$jscomp$inline_9453_event$jscomp$715_frame$jscomp$98$$):0,$set_state$jscomp$1$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
5,[$APP.$cljs$cst$3916$guide$$,$guide$jscomp$23$$,$cljs$cst$5970$new_position$$,$position$jscomp$240$$,$APP.$cljs$cst$5126$new_frame_id$$,$frame_id$jscomp$161_map__81237__$1$$,$cljs$cst$6000$frame_offset$$,$axis$jscomp$65_offset$jscomp$220$$,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$4996$edit$$],null))}return null}function $pointer_down$$($event$jscomp$714_temp__5825__auto__$jscomp$448$$){if($APP.$cljs$core$not$$($read_only_QMARK_$jscomp$34$$)&&$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($editing_ref$jscomp$2$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$event$jscomp$714_temp__5825__auto__$jscomp$448$$.button)){var $client_pos_on_move$jscomp$2$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$714_temp__5825__auto__$jscomp$448$$),$guide$jscomp$22_on_up$jscomp$1$$=$visible_guide_at_event$$($event$jscomp$714_temp__5825__auto__$jscomp$448$$),$frame_id$jscomp$160_map__81236__$1$$=$APP.$cljs$core$__destructure_map$$($guide$jscomp$22_on_up$jscomp$1$$),$id$jscomp$1054$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$160_map__81236__$1$$,
$APP.$cljs$cst$266$id$$),$axis$jscomp$64$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$160_map__81236__$1$$,$APP.$cljs$cst$2062$axis$$),$position$jscomp$239$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$160_map__81236__$1$$,$APP.$cljs$cst$1681$position$$);$frame_id$jscomp$160_map__81236__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_id$jscomp$160_map__81236__$1$$,$APP.$cljs$cst$1612$frame_id$$);if($APP.$cljs$core$truth_$$($guide$jscomp$22_on_up$jscomp$1$$)){var $temp__5825__auto___81350$$=
$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto___81350$$)&&$temp__5825__auto___81350$$.setPointerCapture($event$jscomp$714_temp__5825__auto__$jscomp$448$$.pointerId);$APP.$app$util$dom$stop_propagation$$($event$jscomp$714_temp__5825__auto__$jscomp$448$$);$emit_hover_axis$$($axis$jscomp$64$$);$emit_hover_guide_id$$($id$jscomp$1054$$);$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$7$$,!0);$APP.$rumext$v2$set_ref_val_BANG_$$($moved_ref$$,
!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$4$$,$client_pos_on_move$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($guide_ref$$,$guide$jscomp$22_on_up$jscomp$1$$);$APP.$rumext$v2$set_ref_val_BANG_$$($pending_ref$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3916$guide$$,$guide$jscomp$22_on_up$jscomp$1$$,$cljs$cst$5970$new_position$$,$position$jscomp$239$$,$APP.$cljs$cst$5126$new_frame_id$$,$frame_id$jscomp$160_map__81236__$1$$,$APP.$cljs$cst$320$mode$$,$cljs$cst$5990$drag$$],
null));$event$jscomp$714_temp__5825__auto__$jscomp$448$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$);if($APP.$cljs$core$truth_$$($event$jscomp$714_temp__5825__auto__$jscomp$448$$))return $client_pos_on_move$jscomp$2$$=function($already_moved_QMARK_$jscomp$inline_14015_p1__81192_SHARP_$$){a:{if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$7$$))){var $G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$=
$APP.$rumext$v2$ref_val$$($guide_ref$$);if($APP.$cljs$core$truth_$$($G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$)){var $new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$=$APP.$rumext$v2$ref_val$$($start_ref$jscomp$4$$),$current_pt$jscomp$inline_14014_new_frame_id$jscomp$inline_14019$$=$APP.$app$util$dom$get_client_position$$($already_moved_QMARK_$jscomp$inline_14015_p1__81192_SHARP_$$);
$already_moved_QMARK_$jscomp$inline_14015_p1__81192_SHARP_$$=$APP.$rumext$v2$ref_val$$($moved_ref$$);var $axis$jscomp$inline_14017_past_threshold_QMARK_$jscomp$inline_14016$$=$APP.$cljs$core$truth_$$($already_moved_QMARK_$jscomp$inline_14015_p1__81192_SHARP_$$)?$already_moved_QMARK_$jscomp$inline_14015_p1__81192_SHARP_$$:$APP.$app$common$math$abs$$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($current_pt$jscomp$inline_14014_new_frame_id$jscomp$inline_14019$$)-$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$))+
$APP.$app$common$math$abs$$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($current_pt$jscomp$inline_14014_new_frame_id$jscomp$inline_14019$$)-$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$))>3;if($APP.$cljs$core$truth_$$($axis$jscomp$inline_14017_past_threshold_QMARK_$jscomp$inline_14016$$)){$axis$jscomp$inline_14017_past_threshold_QMARK_$jscomp$inline_14016$$=$APP.$cljs$cst$2062$axis$$.$cljs$core$IFn$_invoke$arity$1$($G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$);
$new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$=$app$main$ui$workspace$viewport$guides$compute_guide_drag_position$$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$2062$axis$$,$axis$jscomp$inline_14017_past_threshold_QMARK_$jscomp$inline_14016$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$),
$cljs$cst$5966$start_pt$$,$new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$,$cljs$cst$5967$current_pt$$,$current_pt$jscomp$inline_14014_new_frame_id$jscomp$inline_14019$$,$APP.$cljs$cst$2204$zoom$$,$zoom$jscomp$135$$,$APP.$cljs$cst$3886$snap_pixel_QMARK_$$,$snap_pixel_QMARK_$jscomp$16$$],null));$current_pt$jscomp$inline_14014_new_frame_id$jscomp$inline_14019$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($get_hover_frame$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?
$get_hover_frame$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():$get_hover_frame$jscomp$3$$(),$APP.$cljs$cst$266$id$$);$new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$3916$guide$$,$G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$,$cljs$cst$5970$new_position$$,$new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$,
$APP.$cljs$cst$5126$new_frame_id$$,$current_pt$jscomp$inline_14014_new_frame_id$jscomp$inline_14019$$,$APP.$cljs$cst$320$mode$$,$cljs$cst$5990$drag$$],null);$APP.$cljs$core$truth_$$($already_moved_QMARK_$jscomp$inline_14015_p1__81192_SHARP_$$)||($APP.$rumext$v2$set_ref_val_BANG_$$($moved_ref$$,!0),$on_guide_drag$$!=null&&($G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$),
$on_guide_drag$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_drag$$.$cljs$core$IFn$_invoke$arity$1$($G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$):$on_guide_drag$$($G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$)));$APP.$rumext$v2$set_ref_val_BANG_$$($pending_ref$$,$new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$);$G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$=
$set_state$jscomp$1$$($new_position$jscomp$inline_14018_pending$jscomp$inline_14020_start_pt$jscomp$inline_14013$$);break a}}}$G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$=null}return $G__81214_81348$jscomp$inline_14021_JSCompiler_inline_result$jscomp$11320_temp__5825__auto__$jscomp$inline_14012$$},$guide$jscomp$22_on_up$jscomp$1$$=function($JSCompiler_inline_result$jscomp$11319_p1__81193_SHARP_$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$7$$))){var $moved_QMARK_$jscomp$inline_14024$$=
$APP.$rumext$v2$ref_val$$($moved_ref$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($moved_QMARK_$jscomp$inline_14024$$)?$on_guide_change$jscomp$3$$!=null:$moved_QMARK_$jscomp$inline_14024$$)){var $G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$=$APP.$rumext$v2$ref_val$$($pending_ref$$);if($APP.$cljs$core$truth_$$($G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$)){var $map__81206_81330__$1$jscomp$inline_14026_new_frame_id_81333$jscomp$inline_14029$$=
$APP.$cljs$core$__destructure_map$$($G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$);$G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81206_81330__$1$jscomp$inline_14026_new_frame_id_81333$jscomp$inline_14029$$,$APP.$cljs$cst$3916$guide$$);
var $new_position_81332$jscomp$inline_14028$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81206_81330__$1$jscomp$inline_14026_new_frame_id_81333$jscomp$inline_14029$$,$cljs$cst$5970$new_position$$);$map__81206_81330__$1$jscomp$inline_14026_new_frame_id_81333$jscomp$inline_14029$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81206_81330__$1$jscomp$inline_14026_new_frame_id_81333$jscomp$inline_14029$$,$APP.$cljs$cst$5126$new_frame_id$$);$G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$!=
null&&$new_position_81332$jscomp$inline_14028$$!=null&&($G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$,$APP.$cljs$cst$1681$position$$,$new_position_81332$jscomp$inline_14028$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1612$frame_id$$,$map__81206_81330__$1$jscomp$inline_14026_new_frame_id_81333$jscomp$inline_14029$$])),$on_guide_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$):$on_guide_change$jscomp$3$$($G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$))}}$G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$=
$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$);$APP.$cljs$core$truth_$$($G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$)&&$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11319_p1__81193_SHARP_$$.pointerId)&&$G__81211_81336$jscomp$inline_14030_guide_81331$jscomp$inline_14027_temp__5825__auto___81328$jscomp$inline_14025_temp__5825__auto___81338$jscomp$inline_14031$$.releasePointerCapture($JSCompiler_inline_result$jscomp$11319_p1__81193_SHARP_$$.pointerId);
$JSCompiler_inline_result$jscomp$11319_p1__81193_SHARP_$$=$APP.$cljs$core$truth_$$($moved_QMARK_$jscomp$inline_14024$$)?$reset_state$$():$clear_drag_refs$$()}else $JSCompiler_inline_result$jscomp$11319_p1__81193_SHARP_$$=null;return $JSCompiler_inline_result$jscomp$11319_p1__81193_SHARP_$$},$APP.$rumext$v2$set_ref_val_BANG_$$($drag_listeners_ref$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5998$on_move$$,$client_pos_on_move$jscomp$2$$,$cljs$cst$5999$on_up$$,$guide$jscomp$22_on_up$jscomp$1$$],
null)),$event$jscomp$714_temp__5825__auto__$jscomp$448$$.addEventListener("pointermove",$client_pos_on_move$jscomp$2$$,!0),$event$jscomp$714_temp__5825__auto__$jscomp$448$$.addEventListener("pointerup",$guide$jscomp$22_on_up$jscomp$1$$,!0),$event$jscomp$714_temp__5825__auto__$jscomp$448$$.addEventListener("pointercancel",$guide$jscomp$22_on_up$jscomp$1$$,!0)}}return null}function $pointer_move_hover$$($event$jscomp$713_guide$jscomp$21$$){if($APP.$cljs$core$not$$($read_only_QMARK_$jscomp$34$$)&&$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($editing_ref$jscomp$2$$))&&
$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$7$$))){$event$jscomp$713_guide$jscomp$21$$=$visible_guide_at_event$$($event$jscomp$713_guide$jscomp$21$$);var $G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$=$APP.$rumext$v2$ref_val$$($state_ref$$);$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2212$hover$$,
$APP.$cljs$cst$320$mode$$.$cljs$core$IFn$_invoke$arity$1$($G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$))?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$3916$guide$$.$cljs$core$IFn$_invoke$arity$1$($G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$)):null;$emit_hover_axis$$($APP.$cljs$cst$2062$axis$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$713_guide$jscomp$21$$));
$emit_hover_guide_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$713_guide$jscomp$21$$));if($event$jscomp$713_guide$jscomp$21$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$713_guide$jscomp$21$$),$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$)){$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$=
$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$713_guide$jscomp$21$$);$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$=$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$==null?null:$app$main$refs$object_by_id$$($G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$);
$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$=$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$==null?null:$APP.$cljs$core$_deref$$($G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$);var $JSCompiler_temp_const$jscomp$14358$$=$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$713_guide$jscomp$21$$);
var $G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$=$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$713_guide$jscomp$21$$);$G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$=$G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$==null?null:
$app$main$refs$object_by_id$$($G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$);$G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$=$G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$==null?null:$APP.$cljs$core$_deref$$($G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$);
$G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$=$APP.$cljs$core$truth_$$($G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$2062$axis$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$713_guide$jscomp$21$$))?$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$):
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$):0;return $set_state$jscomp$1$$(new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$3916$guide$$,$event$jscomp$713_guide$jscomp$21$$,$cljs$cst$5970$new_position$$,$JSCompiler_temp_const$jscomp$14358$$,$cljs$cst$6000$frame_offset$$,$G__81217$jscomp$inline_14975_G__81217__$1$jscomp$inline_14976_JSCompiler_inline_result$jscomp$14359_frame$jscomp$inline_14974$$,
$APP.$cljs$cst$1611$frame$$,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$)?$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$)&&!!$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$2$($G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$,
0)):$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$)?$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$:null,$APP.$cljs$cst$320$mode$$,$APP.$cljs$cst$2212$hover$$],null))}return $event$jscomp$713_guide$jscomp$21$$==null&&$G__81223$jscomp$inline_14008_G__81223__$1$jscomp$inline_14009_current_hover_id_current_state$jscomp$1_frame$jscomp$97$$!=null?$set_state$jscomp$1$$(null):
null}return null}function $visible_guide_at_event$$($event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$){$event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($APP.$app$util$dom$get_client_position$$($event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$));$event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$=
$APP.$cljs$core$truth_$$($event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$)?$app$main$ui$workspace$viewport$guides$guide_by_serialized_index$$($wasm_guides$$,$app$render_wasm$api$find_guide_at$$($event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$,$zoom$jscomp$135$$)):null;return $APP.$cljs$core$truth_$$($event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$)?$app$main$ui$workspace$viewport$guides$guide_visible_in_focus_QMARK_$$($focus$jscomp$20$$,
$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$))?$event$jscomp$712_temp__5825__auto__$jscomp$447_temp__5825__auto__$jscomp$inline_9448$$:null:null}function $reset_state$$(){$clear_drag_refs$$();$APP.$rumext$v2$set_ref_val_BANG_$$($editing_ref$jscomp$2$$,!1);$on_guide_drag$$!=null&&($on_guide_drag$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_drag$$.$cljs$core$IFn$_invoke$arity$1$(null):$on_guide_drag$$(null));
$emit_hover_axis$$(null);$emit_hover_guide_id$$(null);return $set_state$jscomp$1$$(null)}function $clear_drag_refs$$(){var $on_move$jscomp$inline_9443_temp__5825__auto__$jscomp$inline_9441$$=$APP.$rumext$v2$ref_val$$($drag_listeners_ref$$);if($APP.$cljs$core$truth_$$($on_move$jscomp$inline_9443_temp__5825__auto__$jscomp$inline_9441$$)){var $map__81200__$1$jscomp$inline_9442_on_up$jscomp$inline_9444$$=$APP.$cljs$core$__destructure_map$$($on_move$jscomp$inline_9443_temp__5825__auto__$jscomp$inline_9441$$);
$on_move$jscomp$inline_9443_temp__5825__auto__$jscomp$inline_9441$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81200__$1$jscomp$inline_9442_on_up$jscomp$inline_9444$$,$cljs$cst$5998$on_move$$);$map__81200__$1$jscomp$inline_9442_on_up$jscomp$inline_9444$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81200__$1$jscomp$inline_9442_on_up$jscomp$inline_9444$$,$cljs$cst$5999$on_up$$);var $temp__5825__auto___81325__$1$jscomp$inline_9445$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$);
$APP.$cljs$core$truth_$$($temp__5825__auto___81325__$1$jscomp$inline_9445$$)&&($temp__5825__auto___81325__$1$jscomp$inline_9445$$.removeEventListener("pointermove",$on_move$jscomp$inline_9443_temp__5825__auto__$jscomp$inline_9441$$,!0),$temp__5825__auto___81325__$1$jscomp$inline_9445$$.removeEventListener("pointerup",$map__81200__$1$jscomp$inline_9442_on_up$jscomp$inline_9444$$,!0),$temp__5825__auto___81325__$1$jscomp$inline_9445$$.removeEventListener("pointercancel",$map__81200__$1$jscomp$inline_9442_on_up$jscomp$inline_9444$$,
!0));$APP.$rumext$v2$set_ref_val_BANG_$$($drag_listeners_ref$$,null)}$APP.$rumext$v2$set_ref_val_BANG_$$($dragging_ref$jscomp$7$$,!1);$APP.$rumext$v2$set_ref_val_BANG_$$($moved_ref$$,!1);$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$4$$,null);$APP.$rumext$v2$set_ref_val_BANG_$$($guide_ref$$,null);return $APP.$rumext$v2$set_ref_val_BANG_$$($pending_ref$$,null)}function $emit_hover_guide_id$$($id$jscomp$1053$$){var $prev$jscomp$22$$=$APP.$rumext$v2$ref_val$$($hover_guide_id_ref$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1053$$,
$prev$jscomp$22$$)?($APP.$rumext$v2$set_ref_val_BANG_$$($hover_guide_id_ref$$,$id$jscomp$1053$$),$APP.$cljs$core$truth_$$($prev$jscomp$22$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$guides$set_hover_guide$$($prev$jscomp$22$$,!1)),$APP.$cljs$core$truth_$$($id$jscomp$1053$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$guides$set_hover_guide$$($id$jscomp$1053$$,!0)):null):null}function $emit_hover_axis$$($axis$jscomp$62$$){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$62$$,
$APP.$rumext$v2$ref_val$$($hover_axis_ref$$))?($APP.$rumext$v2$set_ref_val_BANG_$$($hover_axis_ref$$,$axis$jscomp$62$$),$on_guide_hover$$!=null?$on_guide_hover$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_hover$$.$cljs$core$IFn$_invoke$arity$1$($axis$jscomp$62$$):$on_guide_hover$$($axis$jscomp$62$$):null):null}function $set_state$jscomp$1$$($value$jscomp$1009$$){$APP.$rumext$v2$set_ref_val_BANG_$$($state_ref$$,$value$jscomp$1009$$);return $APP.$cljs$core$reset_BANG_$$($state$jscomp$1238$$,$value$jscomp$1009$$)}
$map__81195__$1_p__81194$$=$APP.$cljs$core$__destructure_map$$($map__81195__$1_p__81194$$);var $wasm_guides$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,$cljs$cst$5991$wasm_guides$$),$on_guide_hover$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,$cljs$cst$5992$on_guide_hover$$),$zoom$jscomp$135$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,$APP.$cljs$cst$2204$zoom$$),$on_guide_drag$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,
$cljs$cst$5993$on_guide_drag$$),$get_hover_frame$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,$cljs$cst$5994$get_hover_frame$$),$disabled_guides_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,$cljs$cst$5995$disabled_guides_QMARK_$$),$on_guide_change$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,$cljs$cst$5996$on_guide_change$$),$wasm_guides_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,
$cljs$cst$5997$wasm_guides_QMARK_$$),$focus$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81195__$1_p__81194$$,$APP.$cljs$cst$4857$focus$$),$dragging_ref$jscomp$7$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$moved_ref$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$editing_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$start_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null),$guide_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$pending_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$drag_listeners_ref$$=
(0,$APP.$rumext$v2$use_ref$$)(null),$hover_axis_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$hover_guide_id_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$state$jscomp$1238$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$state_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$snap_pixel_QMARK_$jscomp$16$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$snap_pixel_QMARK_$$),$read_only_QMARK_$jscomp$34$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($wasm_guides_QMARK_$$),
$APP.$rumext$v2$adapt$$($disabled_guides_QMARK_$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$34$$),$APP.$rumext$v2$adapt$$($wasm_guides$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$135$$),$APP.$rumext$v2$adapt$$($focus$jscomp$20$$),$APP.$rumext$v2$adapt$$($snap_pixel_QMARK_$jscomp$16$$),$APP.$rumext$v2$adapt$$($on_guide_change$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_guide_drag$$),$APP.$rumext$v2$adapt$$($on_guide_hover$$),$APP.$rumext$v2$adapt$$($get_hover_frame$jscomp$3$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($wasm_guides_QMARK_$$)?
$APP.$cljs$core$not$$($disabled_guides_QMARK_$$)&&$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$34$$):$wasm_guides_QMARK_$$)){var $temp__5825__auto__$jscomp$449$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$449$$))return $temp__5825__auto__$jscomp$449$$.addEventListener("pointerdown",$pointer_down$$,!0),$temp__5825__auto__$jscomp$449$$.addEventListener("pointermove",$pointer_move_hover$$,!0),$temp__5825__auto__$jscomp$449$$.addEventListener("dblclick",
$double_click$$,!0),function(){$temp__5825__auto__$jscomp$449$$.removeEventListener("pointerdown",$pointer_down$$,!0);$temp__5825__auto__$jscomp$449$$.removeEventListener("pointermove",$pointer_move_hover$$,!0);$temp__5825__auto__$jscomp$449$$.removeEventListener("dblclick",$double_click$$,!0);var $or__5025__auto__$jscomp$inline_9455$$=$APP.$rumext$v2$ref_val$$($dragging_ref$jscomp$7$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9455$$)?$or__5025__auto__$jscomp$inline_9455$$:
$APP.$rumext$v2$ref_val$$($editing_ref$jscomp$2$$))?null:$reset_state$$()}}return null});return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$769$state$$,$state$jscomp$1238$$,$cljs$cst$6001$commit_edit$$,function($G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($editing_ref$jscomp$2$$))){var $frame_offset$jscomp$14_map__81239__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$rumext$v2$ref_val$$($state_ref$$)),
$G__81241_81357_guide$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_offset$jscomp$14_map__81239__$1$$,$APP.$cljs$cst$3916$guide$$),$new_frame_id$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_offset$jscomp$14_map__81239__$1$$,$APP.$cljs$cst$5126$new_frame_id$$);$frame_offset$jscomp$14_map__81239__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_offset$jscomp$14_map__81239__$1$$,$cljs$cst$6000$frame_offset$$);$G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$=
$G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$==null?null:$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$);$G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$=$G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$==null?null:$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$);
$G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$!=null&&$on_guide_change$jscomp$3$$!=null&&($G__81241_81357_guide$jscomp$24$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__81241_81357_guide$jscomp$24$$,$APP.$cljs$cst$1681$position$$,$G__81240__$1$jscomp$inline_9457_parsed$jscomp$11_raw_value$jscomp$5$$+$frame_offset$jscomp$14_map__81239__$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1612$frame_id$$,$new_frame_id$jscomp$3$$])),
$on_guide_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_change$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($G__81241_81357_guide$jscomp$24$$):$on_guide_change$jscomp$3$$($G__81241_81357_guide$jscomp$24$$));return $reset_state$$()}return null},$cljs$cst$6002$cancel_edit$$,function(){return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($editing_ref$jscomp$2$$))?$reset_state$$():null}],null)};
$app$main$ui$workspace$viewport$guides$wasm_guide_overlay_layer_STAR_$$=function($commit_edit$jscomp$1_map__81257_props_81256$$){var $zoom$jscomp$136$$=$commit_edit$jscomp$1_map__81257_props_81256$$.zoom,$vbox$jscomp$66$$=$commit_edit$jscomp$1_map__81257_props_81256$$.vbox;$commit_edit$jscomp$1_map__81257_props_81256$$=$app$main$ui$workspace$viewport$guides$use_wasm_guide_interaction$$($APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$2204$zoom$$,$cljs$cst$5993$on_guide_drag$$,$cljs$cst$5994$get_hover_frame$$,
$cljs$cst$5995$disabled_guides_QMARK_$$,$cljs$cst$5996$on_guide_change$$,$cljs$cst$5997$wasm_guides_QMARK_$$,$APP.$cljs$cst$4857$focus$$,$cljs$cst$5991$wasm_guides$$,$cljs$cst$5992$on_guide_hover$$],[$zoom$jscomp$136$$,$commit_edit$jscomp$1_map__81257_props_81256$$.onGuideDrag,$commit_edit$jscomp$1_map__81257_props_81256$$.getHoverFrame,$commit_edit$jscomp$1_map__81257_props_81256$$.disabledGuides,$commit_edit$jscomp$1_map__81257_props_81256$$.onGuideChange,$commit_edit$jscomp$1_map__81257_props_81256$$.wasmGuides,
$commit_edit$jscomp$1_map__81257_props_81256$$.focus,$commit_edit$jscomp$1_map__81257_props_81256$$.wasmGuides,$commit_edit$jscomp$1_map__81257_props_81256$$.onGuideHover]));var $cancel_edit$jscomp$2_map__81257__$1$$=$APP.$cljs$core$__destructure_map$$($commit_edit$jscomp$1_map__81257_props_81256$$),$guide$jscomp$25_map__81258_state$jscomp$1239$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_edit$jscomp$2_map__81257__$1$$,$APP.$cljs$cst$769$state$$);$commit_edit$jscomp$1_map__81257_props_81256$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_edit$jscomp$2_map__81257__$1$$,$cljs$cst$6001$commit_edit$$);$cancel_edit$jscomp$2_map__81257__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cancel_edit$jscomp$2_map__81257__$1$$,$cljs$cst$6002$cancel_edit$$);$guide$jscomp$25_map__81258_state$jscomp$1239$$=$APP.$cljs$core$_deref$$($guide$jscomp$25_map__81258_state$jscomp$1239$$);var $frame_offset$jscomp$15_map__81258__$1$$=$APP.$cljs$core$__destructure_map$$($guide$jscomp$25_map__81258_state$jscomp$1239$$);
$guide$jscomp$25_map__81258_state$jscomp$1239$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_offset$jscomp$15_map__81258__$1$$,$APP.$cljs$cst$3916$guide$$);var $new_position$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_offset$jscomp$15_map__81258__$1$$,$cljs$cst$5970$new_position$$),$mode$jscomp$53$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_offset$jscomp$15_map__81258__$1$$,$APP.$cljs$cst$320$mode$$),$frame$jscomp$99$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_offset$jscomp$15_map__81258__$1$$,
$APP.$cljs$cst$1611$frame$$);$frame_offset$jscomp$15_map__81258__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_offset$jscomp$15_map__81258__$1$$,$cljs$cst$6000$frame_offset$$);return $guide$jscomp$25_map__81258_state$jscomp$1239$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_overlay_STAR_$$,{zoom:$zoom$jscomp$136$$,frameOffset:$APP.$cljs$core$truth_$$($frame_offset$jscomp$15_map__81258__$1$$)?$frame_offset$jscomp$15_map__81258__$1$$:0,guide:$guide$jscomp$25_map__81258_state$jscomp$1239$$,
vbox:$vbox$jscomp$66$$,mode:$mode$jscomp$53$$,position:$new_position$jscomp$3$$,onInputCommit:$commit_edit$jscomp$1_map__81257_props_81256$$,onInputCancel:$cancel_edit$jscomp$2_map__81257__$1$$,frame:$frame$jscomp$99$$}):null};
$app$main$data$workspace$grid_layout$shortcuts$esc_pressed$$=function(){typeof $app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$==="undefined"&&($app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$=function($meta81155$$){this.$meta81155$=$meta81155$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $cljs$cst$6003$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_shortcuts_SLASH_esc_pressed$$},$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_81156$$,$meta81155__$1$$){return new $app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$($meta81155__$1$$)},$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$.prototype.$cljs$core$IMeta$_meta$arity$1$=
function(){return this.$meta81155$},$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$3136_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9459$$,$path_edit_mode_state$jscomp$1240$$){$_$jscomp$3136_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9459$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($path_edit_mode_state$jscomp$1240$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2197$workspace_drawing$$,$APP.$cljs$cst$2206$object$$,$APP.$cljs$cst$266$id$$],null));$_$jscomp$3136_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9459$$=$APP.$cljs$core$truth_$$($_$jscomp$3136_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9459$$)?$_$jscomp$3136_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9459$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($path_edit_mode_state$jscomp$1240$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$2207$edition$$],null));$path_edit_mode_state$jscomp$1240$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($path_edit_mode_state$jscomp$1240$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1940$edit_path$$,$_$jscomp$3136_edition_id$jscomp$5_or__5025__auto__$jscomp$inline_9459$$,
$APP.$cljs$cst$4290$edit_mode$$],null));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4291$draw$$,$path_edit_mode_state$jscomp$1240$$)?$APP.$beicon$v2$core$empty$$():(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$cst$2177$interrupt$$)});return new $app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$ui$workspace$viewport$hooks$setup_dom_events$$=function($zoom$jscomp$138$$,$disable_paste_ref$jscomp$2$$,$in_viewport_ref$jscomp$3$$,$workspace_read_only_QMARK_$$,$drawing_tool$jscomp$5$$,$drawing_path_QMARK_$jscomp$3$$){var $zoom_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)($zoom$jscomp$138$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($zoom$jscomp$138$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($zoom_ref$jscomp$1$$,$zoom$jscomp$138$$)});
var $on_key_down$jscomp$29$$=$app$main$ui$workspace$viewport$actions$on_key_down$$(),$on_key_up$jscomp$3$$=$app$main$ui$workspace$viewport$actions$on_key_up$$(),$on_mouse_wheel$jscomp$2$$=$app$main$ui$workspace$viewport$actions$on_mouse_wheel$$($zoom_ref$jscomp$1$$),$on_paste$jscomp$3$$=$app$main$ui$workspace$viewport$actions$on_paste$$($disable_paste_ref$jscomp$2$$,$in_viewport_ref$jscomp$3$$,$workspace_read_only_QMARK_$$),$on_pointer_down$jscomp$18$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$5$$),
$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$3$$)],function($e$jscomp$389_parent_QMARK_$jscomp$4$$){$e$jscomp$389_parent_QMARK_$jscomp$4$$=$APP.$app$util$dom$get_parent_with_data$$($APP.$app$util$dom$get_target$$($e$jscomp$389_parent_QMARK_$jscomp$4$$),"dont-clear-path");return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($drawing_path_QMARK_$jscomp$3$$)?$APP.$cljs$core$not$$($e$jscomp$389_parent_QMARK_$jscomp$4$$):$drawing_path_QMARK_$jscomp$3$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$clear_edition_mode$$()):
null}),$on_blur$jscomp$37$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$app$util$mouse$BlurEvent$$(null,null,null))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$5$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$3$$)],function(){var $key$jscomp$428$$=$APP.$goog$events$listen$$(window,"pointerdown",$on_pointer_down$jscomp$18$$);
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$5$$,$APP.$cljs$cst$3489$comments$$)?$APP.$rumext$v2$set_ref_val_BANG_$$($disable_paste_ref$jscomp$2$$,!0):$APP.$rumext$v2$set_ref_val_BANG_$$($disable_paste_ref$jscomp$2$$,!1);return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$428$$)}});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_key_down$jscomp$29$$),$APP.$rumext$v2$adapt$$($on_key_up$jscomp$3$$),
$APP.$rumext$v2$adapt$$($on_paste$jscomp$3$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$$)],function(){var $keys$jscomp$58$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$(document,"keydown",$on_key_down$jscomp$29$$),$APP.$goog$events$listen$$(document,"keyup",$on_key_up$jscomp$3$$),$APP.$goog$events$listen$$(window,"wheel",$on_mouse_wheel$jscomp$2$$,{passive:!1}),$APP.$goog$events$listen$$(window,"paste",$on_paste$jscomp$3$$),
$APP.$goog$events$listen$$(window,"blur",$on_blur$jscomp$37$$)],null);return function(){for(var $c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$=$APP.$cljs$core$seq$$($keys$jscomp$58$$),$G__81318_chunk__81203_seq__81202__$1$$=null,$G__81317_count__81204$$=0,$i__81205$$=0;;)if($i__81205$$<$G__81317_count__81204$$){var $G__81319_key$jscomp$429$$=$G__81318_chunk__81203_seq__81202__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__81205$$);$APP.$goog$events$unlistenByKey$$($G__81319_key$jscomp$429$$);
$i__81205$$+=1}else if($c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$))$G__81318_chunk__81203_seq__81202__$1$$=$c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__81318_chunk__81203_seq__81202__$1$$)?($c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$=$APP.$cljs$core$_chunked_first$$($G__81318_chunk__81203_seq__81202__$1$$),
$G__81317_count__81204$$=$APP.$cljs$core$_chunked_rest$$($G__81318_chunk__81203_seq__81202__$1$$),$G__81318_chunk__81203_seq__81202__$1$$=$c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$,$G__81319_key$jscomp$429$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$),$c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$=$G__81317_count__81204$$,$G__81317_count__81204$$=$G__81319_key$jscomp$429$$):($G__81319_key$jscomp$429$$=
$APP.$cljs$core$first$$($G__81318_chunk__81203_seq__81202__$1$$),$APP.$goog$events$unlistenByKey$$($G__81319_key$jscomp$429$$),$c__5548__auto__$jscomp$49_seq__81202_temp__5825__auto__$jscomp$451$$=$APP.$cljs$core$next$$($G__81318_chunk__81203_seq__81202__$1$$),$G__81318_chunk__81203_seq__81202__$1$$=null,$G__81317_count__81204$$=0),$i__81205$$=0;else return null}})};
$app$main$ui$workspace$viewport$hooks$setup_viewport_size$$=function($vport$jscomp$12$$,$viewport_ref$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vport$jscomp$12$$)],function(){var $JSCompiler_inline_result$jscomp$1649_param72450$jscomp$inline_9461_prnt$$=$APP.$app$util$dom$get_parent$$($APP.$rumext$v2$ref_val$$($viewport_ref$$)),$JSCompiler_temp$jscomp$1646_JSCompiler_temp_const$jscomp$1647_size$jscomp$167$$=$APP.$app$util$dom$get_client_size$$($JSCompiler_inline_result$jscomp$1649_param72450$jscomp$inline_9461_prnt$$);
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1646_JSCompiler_temp_const$jscomp$1647_size$jscomp$167$$,$vport$jscomp$12$$)?($JSCompiler_temp$jscomp$1646_JSCompiler_temp_const$jscomp$1647_size$jscomp$167$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$,$JSCompiler_inline_result$jscomp$1649_param72450$jscomp$inline_9461_prnt$$=$APP.$app$util$dom$get_client_size$$($JSCompiler_inline_result$jscomp$1649_param72450$jscomp$inline_9461_prnt$$),$JSCompiler_inline_result$jscomp$1649_param72450$jscomp$inline_9461_prnt$$=
$app$main$data$workspace$viewport$initialize_viewport$$($JSCompiler_inline_result$jscomp$1649_param72450$jscomp$inline_9461_prnt$$),$JSCompiler_temp$jscomp$1646_JSCompiler_temp_const$jscomp$1647_size$jscomp$167$$=$JSCompiler_temp$jscomp$1646_JSCompiler_temp_const$jscomp$1647_size$jscomp$167$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1649_param72450$jscomp$inline_9461_prnt$$)):$JSCompiler_temp$jscomp$1646_JSCompiler_temp_const$jscomp$1647_size$jscomp$167$$=null;return $JSCompiler_temp$jscomp$1646_JSCompiler_temp_const$jscomp$1647_size$jscomp$167$$})};
$app$main$ui$workspace$viewport$hooks$setup_cursor$$=function($cursor$jscomp$10$$,$alt_QMARK_$jscomp$20$$,$mod_QMARK_$jscomp$13$$,$space_QMARK_$jscomp$4$$,$panning$jscomp$1$$,$drawing_tool$jscomp$6$$,$drawing_path_QMARK_$jscomp$4$$,$path_editing_QMARK_$jscomp$1$$,$z_QMARK_$jscomp$4$$,$workspace_read_only_QMARK_$jscomp$1$$){$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($cursor$jscomp$10$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$20$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$13$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$4$$)),$APP.$rumext$v2$adapt$$($panning$jscomp$1$$),$APP.$rumext$v2$adapt$$($drawing_tool$jscomp$6$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($path_editing_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($z_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$jscomp$1$$)],function(){var $new_cursor_show_pen_QMARK_$$=
function(){var $or__5025__auto__$jscomp$1403$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$296$path$$);return $or__5025__auto__$jscomp$1403$$?$or__5025__auto__$jscomp$1403$$:$APP.$cljs$core$truth_$$($drawing_path_QMARK_$jscomp$4$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$2060$curve$$):$drawing_path_QMARK_$jscomp$4$$}(),$show_zoom_QMARK_$$=function(){var $and__5023__auto__$jscomp$988$$=$APP.$cljs$core$_deref$$($z_QMARK_$jscomp$4$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$988$$)?$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($space_QMARK_$jscomp$4$$))&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$13$$))&&$APP.$cljs$core$not$$($drawing_path_QMARK_$jscomp$4$$)&&$APP.$cljs$core$not$$($drawing_tool$jscomp$6$$):$and__5023__auto__$jscomp$988$$}();$new_cursor_show_pen_QMARK_$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$989$$=$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$13$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$989$$)?$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$4$$):$and__5023__auto__$jscomp$989$$}())?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($APP.$cljs$cst$2204$zoom$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($panning$jscomp$1$$)?$panning$jscomp$1$$:$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$4$$))?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6004$hand$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,
$APP.$cljs$cst$3489$comments$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($APP.$cljs$cst$3489$comments$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$1611$frame$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6005$create_artboard$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$1616$rect$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6006$create_rectangle$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$1422$circle$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6007$create_ellipse$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_zoom_QMARK_$$)?$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$20$$)):$show_zoom_QMARK_$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6008$zoom_in$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_zoom_QMARK_$$)?
$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$20$$):$show_zoom_QMARK_$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6009$zoom_out$$):$APP.$cljs$core$truth_$$($new_cursor_show_pen_QMARK_$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6010$pen$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$6$$,$APP.$cljs$cst$2060$curve$$)?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6011$pencil$$):$APP.$cljs$core$truth_$$($drawing_tool$jscomp$6$$)?
$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6012$create_shape$$):$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$992$$=$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$20$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$992$$)?$APP.$cljs$core$not$$($path_editing_QMARK_$jscomp$1$$)&&$APP.$cljs$core$not$$($workspace_read_only_QMARK_$jscomp$1$$):$and__5023__auto__$jscomp$992$$}())?$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($APP.$cljs$cst$4903$duplicate$$):
$APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6013$pointer_inner$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($cursor$jscomp$10$$),$new_cursor_show_pen_QMARK_$$)?$APP.$cljs$core$reset_BANG_$$($cursor$jscomp$10$$,$new_cursor_show_pen_QMARK_$$):null})};
$app$main$ui$workspace$viewport$hooks$setup_keyboard$$=function($alt_STAR_$$,$mod_STAR_$$,$space_STAR_$$,$z_STAR_$$,$shift_STAR_$$){var $kbd_zoom_s$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),$APP.$beicon$v2$core$filter$$(function($kevent$$){return(0,$APP.$app$util$keyboard$minus_QMARK_$$)($kevent$$)||(0,$APP.$app$util$keyboard$underscore_QMARK_$$)($kevent$$)||
(0,$APP.$app$util$keyboard$equals_QMARK_$$)($kevent$$)||(0,$APP.$app$util$keyboard$plus_QMARK_$$)($kevent$$)},$APP.$beicon$v2$core$filter$$($app$util$keyboard$mod_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$app$main$streams$keyboard$$))))}),$kbd_shift_s$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$app$util$keyboard$editing_event_QMARK_$$),$APP.$beicon$v2$core$filter$$($APP.$app$util$keyboard$shift_key_QMARK_$$,$APP.$app$main$streams$keyboard$$))))}),$kbd_z_s$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$operators$pipe$$($APP.$beicon$v2$operators$distinct_contiguous$cljs$0core$0IFn$0_invoke$0arity$00$$(),
$APP.$beicon$v2$core$map$$($APP.$app$util$keyboard$key_down_event_QMARK_$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$complement$$($APP.$app$util$keyboard$editing_event_QMARK_$$),$APP.$beicon$v2$core$filter$$($APP.$app$util$keyboard$z_QMARK_$$,$APP.$app$main$streams$keyboard$$))))});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5664$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$alt_STAR_$$));$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$sub$jscomp$inline_5676$$,
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$space_STAR_$$));$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($kbd_z_s$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$z_STAR_$$));$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($kbd_shift_s$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$reset_BANG_$$,$shift_STAR_$$));$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$streams$keyboard_mod$$,
function($value$jscomp$1010$$){$APP.$cljs$core$reset_BANG_$$($mod_STAR_$$,$value$jscomp$1010$$);return $value$jscomp$1010$$?null:$APP.$cljs$core$reset_BANG_$$($z_STAR_$$,!1)});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($kbd_zoom_s$$,function($kevent$jscomp$1$$){$APP.$app$util$dom$prevent_default$$($kevent$jscomp$1$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$util$keyboard$minus_QMARK_$$)($kevent$jscomp$1$$)||(0,$APP.$app$util$keyboard$underscore_QMARK_$$)($kevent$jscomp$1$$)?
$APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$0$():$APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$0$())})};
$app$main$ui$workspace$viewport$hooks$setup_hover_shapes$$=function($page_id$jscomp$453$$,$move_stream$jscomp$3$$,$objects$jscomp$828$$,$selected$jscomp$199$$,$mod_QMARK_$jscomp$14$$,$hover$jscomp$10$$,$measure_hover$$,$hover_ids$jscomp$5$$,$hover_top_frame_id$jscomp$6$$,$hover_disabled_QMARK_$$,$focus$jscomp$23$$,$zoom$jscomp$139$$,$show_measures_QMARK_$$,$read_only_QMARK_$jscomp$35$$,$transform$jscomp$115$$){var $zoom_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)($zoom$jscomp$139$$),$mod_ref$$=(0,$APP.$rumext$v2$use_ref$$)($APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$14$$)),
$selected_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)($selected$jscomp$199$$),$hover_disabled_ref$$=(0,$APP.$rumext$v2$use_ref$$)($hover_disabled_QMARK_$$),$focus_ref$$=(0,$APP.$rumext$v2$use_ref$$)($focus$jscomp$23$$),$transform_ref$$=(0,$APP.$rumext$v2$use_ref$$)($transform$jscomp$115$$),$read_only_ref$$=(0,$APP.$rumext$v2$use_ref$$)($read_only_QMARK_$jscomp$35$$),$last_point_ref$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$mod_str$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),
$query_point$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$453$$)],function($point$jscomp$88_rect$jscomp$48$$){var $size$jscomp$inline_14034$$=5/$APP.$rumext$v2$ref_val$$($zoom_ref$jscomp$2$$);$point$jscomp$88_rect$jscomp$48$$=$APP.$app$common$geom$rect$center__GT_rect$cljs$0core$0IFn$0_invoke$0arity$03$$($point$jscomp$88_rect$jscomp$48$$,$size$jscomp$inline_14034$$,$size$jscomp$inline_14034$$);return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($hover_disabled_ref$$))?
(0,$APP.$beicon$v2$core$of$$)($APP.$cljs$core$PersistentVector$EMPTY$$):$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$APP.$cljs$cst$3139$cmd$$,$APP.$cljs$cst$3657$index_SLASH_query_selection$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$453$$,$APP.$cljs$cst$1616$rect$$,$point$jscomp$88_rect$jscomp$48$$,$APP.$cljs$cst$3658$include_frames_QMARK_$$,!0,$cljs$cst$6014$clip_children_QMARK_$$,
$APP.$cljs$core$not$$($APP.$rumext$v2$ref_val$$($mod_ref$$)),$APP.$cljs$cst$3661$using_selrect_QMARK_$$,!1],null)))}),$over_shapes_stream$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($query_point$$),$APP.$rumext$v2$adapt$$($move_stream$jscomp$3$$),$APP.$rumext$v2$adapt$$($mod_str$$)],function(){return $APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$merge_map$$($query_point$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,
$APP.$beicon$v2$core$map$$(function(){return $APP.$cljs$core$_deref$$($last_point_ref$$)},$APP.$beicon$v2$core$observe_on$$($APP.$cljs$cst$2340$async$$,$mod_str$$)))),$APP.$beicon$v2$core$merge_map$$($query_point$$,$APP.$beicon$v2$core$tap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__81267_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($last_point_ref$$,$p1__81267_SHARP_$$)},$move_stream$jscomp$3$$))))}),$over_shapes_stream_debounced$$=$APP.$beicon$v2$core$debounce$$(50,$over_shapes_stream$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($zoom$jscomp$139$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($zoom_ref$jscomp$2$$,$zoom$jscomp$139$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$14$$))],function(){$mod_str$$.next($cljs$cst$6015$update$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($mod_ref$$,$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$14$$))});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$199$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($selected_ref$jscomp$1$$,$selected$jscomp$199$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hover_disabled_QMARK_$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($hover_disabled_ref$$,$hover_disabled_QMARK_$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focus$jscomp$23$$)],
function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($focus_ref$$,$focus$jscomp$23$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($transform$jscomp$115$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($transform_ref$$,$transform$jscomp$115$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$35$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($read_only_ref$$,$read_only_QMARK_$jscomp$35$$)});
$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$03$$($over_shapes_stream_debounced$$,[$APP.$rumext$v2$adapt$$($objects$jscomp$828$$)],function(){return $APP.$cljs$core$reset_BANG_$$($hover_top_frame_id$jscomp$6$$,$APP.$app$common$types$shape_tree$top_nested_frame$cljs$0core$0IFn$0_invoke$0arity$04$$($objects$jscomp$828$$,$APP.$cljs$core$_deref$$($last_point_ref$$),null,$APP.$rumext$v2$ref_val$$($read_only_ref$$)))});var $sorted_ids_cache$$=(0,$APP.$rumext$v2$use_ref$$)($APP.$cljs$core$PersistentArrayMap$EMPTY$$);
$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$04$$($over_shapes_stream$$,[$APP.$rumext$v2$adapt$$($page_id$jscomp$453$$),$APP.$rumext$v2$adapt$$($objects$jscomp$828$$),$APP.$rumext$v2$adapt$$($show_measures_QMARK_$$),$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$35$$)],function($ids$jscomp$323$$){function $no_fill_nested_frames_QMARK_$$($id$jscomp$1058_shape$jscomp$1092$$){$id$jscomp$1058_shape$jscomp$1092$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,
$id$jscomp$1058_shape$jscomp$1092$$);return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1058_shape$jscomp$1092$$)&&!$APP.$app$common$files$helpers$is_direct_child_of_root_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($id$jscomp$1058_shape$jscomp$1092$$)&&$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1058_shape$jscomp$1092$$,$APP.$cljs$cst$1639$fills$$))}function $grouped_QMARK_$$($id$jscomp$1057$$){var $and__5023__auto__$jscomp$994$$=
$APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$id$jscomp$1057$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$994$$)?!$APP.$app$common$files$helpers$mask_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$id$jscomp$1057$$):$and__5023__auto__$jscomp$994$$}function $make_sorted_ids$$($mod_QMARK___$2$$,$ids__$1$jscomp$32$$){var $sorted_ids$jscomp$1$$=
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$common$files$helpers$hidden_parent_QMARK_$$,$objects$jscomp$828$$)),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__81278_SHARP_$$){var $and__5023__auto__$jscomp$993$$=$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$35$$);
return $and__5023__auto__$jscomp$993$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$p1__81278_SHARP_$$),$APP.$cljs$cst$1628$blocked$$):$and__5023__auto__$jscomp$993$$}),$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$svg_raw_shape_QMARK_$$,$objects$jscomp$828$$))),$APP.$app$common$types$shape_tree$sort_z_index$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$828$$,
$ids__$1$jscomp$32$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2095$bottom_frames_QMARK_$$,$mod_QMARK___$2$$],null)));$APP.$rumext$v2$set_ref_val_BANG_$$($sorted_ids_cache$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($cached_ids$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$mod_QMARK___$2$$,$ids__$1$jscomp$32$$],null),$sorted_ids$jscomp$1$$));return $sorted_ids$jscomp$1$$}var $selected__$1$jscomp$18$$=$APP.$rumext$v2$ref_val$$($selected_ref$jscomp$1$$),
$focus__$1$jscomp$1$$=$APP.$rumext$v2$ref_val$$($focus_ref$$),$mod_QMARK___$1$$=$APP.$rumext$v2$ref_val$$($mod_ref$$),$cached_ids$$=$APP.$rumext$v2$ref_val$$($sorted_ids_cache$$),$ids__$1$jscomp$31$$=function(){var $or__5025__auto__$jscomp$1405$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cached_ids$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$mod_QMARK___$1$$,$ids$jscomp$323$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1405$$)?
$or__5025__auto__$jscomp$1405$$:$make_sorted_ids$$($mod_QMARK___$1$$,$ids$jscomp$323$$)}(),$measure_hover_shape_remove_measure_QMARK__selected_with_parents$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__81279_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$828$$,$p1__81279_SHARP_$$)}),$selected__$1$jscomp$18$$),$remove_hover_QMARK__remove_hover_xf$$=
$APP.$cljs$core$truth_$$($mod_QMARK___$1$$)?$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($grouped_QMARK_$$):$APP.$cljs$core$not$$($mod_QMARK___$1$$)?function(){var $child_parent_QMARK_$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__81281_SHARP_$$){return $APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,
$p1__81281_SHARP_$$)}),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__81282_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$828$$,$p1__81282_SHARP_$$)})),$ids__$1$jscomp$31$$);return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$){var $JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$);if($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=
$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$)&&$APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$))&&
!$APP.$app$common$types$component$instance_head_QMARK_$$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$)&&!$APP.$app$common$types$component$main_instance_QMARK_$$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$))return $JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$;
$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$);
$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=$APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$)?
!$APP.$cljs$core$contains_QMARK_$$($child_parent_QMARK_$$,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$):$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$;
if($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$))var $JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$=$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$;
else{if($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"render-wasm/v1"))if($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=
$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$)))if($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=
!$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$18$$,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$)){$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=
$APP.$cljs$core$_deref$$($last_point_ref$$);if($APP.$app$render_wasm$api$initialized_QMARK_$$()){$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$=$APP.$app$common$uuid$get_u32$$($buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$);var $fn_54204$jscomp$inline_14043$$=
$APP.$app$render_wasm$wasm$internal_module$$._intersect_position_in_shape;try{$JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$=$fn_54204$jscomp$inline_14043$$($buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$[0],$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$[1],
$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$[2],$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$[3],$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$),
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$))}catch($e54206$jscomp$inline_14049$$){throw $JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$=
$e54206$jscomp$inline_14049$$,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$=$APP.$cljs$core$truth_$$($buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$)?
$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$.$cljs$core$IFn$_invoke$arity$0$?$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$.$cljs$core$IFn$_invoke$arity$0$():$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$():
null,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$,$APP.$cljs$cst$2982$wasm_critical$$),$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=
["WASM Error (",$APP.$app$common$data$name$$($buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$),")"].join(""),$APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_intersect_position_in_shape",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$,$APP.$cljs$cst$273$code$$,$buffer$jscomp$inline_14041_code__53067__auto__$jscomp$inline_14047_code_num__53066__auto__$jscomp$inline_14046_p1__81283_SHARP__read_code_fn__53065__auto__$jscomp$inline_14045$$],
null),$JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$);}$JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$,1)}else $JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$=
!1;$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$=!$JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$}$JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$=
$JSCompiler_temp$jscomp$11234_JSCompiler_temp$jscomp$11235_JSCompiler_temp$jscomp$11236_and__5023__auto__$jscomp$inline_9463_hint__53068__auto__$jscomp$inline_14048_obj$jscomp$inline_14037_or__5025__auto__$jscomp$1406_or__5025__auto____$1$jscomp$156_position$jscomp$inline_14040$$}return $JSCompiler_inline_result$jscomp$11237_JSCompiler_temp$jscomp$11233_cause54205$jscomp$inline_14044_result$jscomp$inline_14042$$})}():null,$hover_shape$jscomp$3_remove_measure_xf$$=$APP.$cljs$core$truth_$$($mod_QMARK___$1$$)?
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($grouped_QMARK_$$):$APP.$cljs$core$not$$($mod_QMARK___$1$$)?function(){var $child_parent_QMARK_$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__81285_SHARP_$$){return $APP.$app$common$files$helpers$group_like_shape_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,
$p1__81285_SHARP_$$))}),$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__81286_SHARP_$$){return $APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$828$$,$p1__81286_SHARP_$$)})),$ids__$1$jscomp$31$$);return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__81287_SHARP_$$){var $and__5023__auto__$jscomp$996$$=$APP.$app$common$files$helpers$group_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$p1__81287_SHARP_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$996$$)?
!$APP.$cljs$core$contains_QMARK_$$($child_parent_QMARK_$jscomp$1$$,$p1__81287_SHARP_$$):$and__5023__auto__$jscomp$996$$})}():null;$remove_hover_QMARK__remove_hover_xf$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($measure_hover_shape_remove_measure_QMARK__selected_with_parents$$,$remove_hover_QMARK__remove_hover_xf$$,$ids__$1$jscomp$31$$);$measure_hover_shape_remove_measure_QMARK__selected_with_parents$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($measure_hover_shape_remove_measure_QMARK__selected_with_parents$$,
$hover_shape$jscomp$3_remove_measure_xf$$,$ids__$1$jscomp$31$$);$hover_shape$jscomp$3_remove_measure_xf$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81289_SHARP_$$){var $or__5025__auto__$jscomp$1407$$=$APP.$cljs$core$empty_QMARK_$$($focus__$1$jscomp$1$$);return $or__5025__auto__$jscomp$1407$$?$or__5025__auto__$jscomp$1407$$:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,
$focus__$1$jscomp$1$$),$APP.$cljs$core$cons$$($p1__81289_SHARP_$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$828$$,$p1__81289_SHARP_$$)))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81288_SHARP_$$){return $APP.$cljs$core$truth_$$($mod_QMARK___$1$$)?$no_fill_nested_frames_QMARK_$$($p1__81288_SHARP_$$):$mod_QMARK___$1$$},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($remove_hover_QMARK__remove_hover_xf$$,$ids__$1$jscomp$31$$)))));$measure_hover_shape_remove_measure_QMARK__selected_with_parents$$=
$APP.$cljs$core$truth_$$($show_measures_QMARK_$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$828$$,$APP.$cljs$core$first$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81291_SHARP_$$){var $or__5025__auto__$jscomp$1408$$=$APP.$cljs$core$empty_QMARK_$$($focus__$1$jscomp$1$$);return $or__5025__auto__$jscomp$1408$$?$or__5025__auto__$jscomp$1408$$:$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$contains_QMARK_$$,
$focus__$1$jscomp$1$$),$APP.$cljs$core$cons$$($p1__81291_SHARP_$$,$APP.$app$common$files$helpers$get_parent_ids$$($objects$jscomp$828$$,$p1__81291_SHARP_$$)))},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81290_SHARP_$$){return $APP.$cljs$core$truth_$$($mod_QMARK___$1$$)?$no_fill_nested_frames_QMARK_$$($p1__81290_SHARP_$$):$mod_QMARK___$1$$},$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($measure_hover_shape_remove_measure_QMARK__selected_with_parents$$,$ids__$1$jscomp$31$$))))):
null;$APP.$cljs$core$reset_BANG_$$($hover$jscomp$10$$,$hover_shape$jscomp$3_remove_measure_xf$$);$APP.$cljs$core$reset_BANG_$$($measure_hover$$,$measure_hover_shape_remove_measure_QMARK__selected_with_parents$$);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1804$move$$,$APP.$rumext$v2$ref_val$$($transform_ref$$))?$APP.$cljs$core$reset_BANG_$$($hover_ids$jscomp$5$$,$ids__$1$jscomp$31$$):null},function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($sorted_ids_cache$$,
$APP.$cljs$core$PersistentArrayMap$EMPTY$$)})};
$app$main$ui$workspace$viewport$hooks$setup_viewport_modifiers$$=function($modifiers$jscomp$135_modifiers__$1$jscomp$21$$,$objects$jscomp$829$$){var $root_frame_ids$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$829$$)],function(){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$app$common$types$shape_tree$get_root_shapes$$($objects$jscomp$829$$))});$modifiers$jscomp$135_modifiers__$1$jscomp$21$$=$APP.$cljs$core$select_keys$$($modifiers$jscomp$135_modifiers__$1$jscomp$21$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($root_frame_ids$$,$APP.$app$common$uuid$zero$$));$APP.$app$main$ui$workspace$shapes$frame$dynamic_modifiers$use_dynamic_modifiers$$($objects$jscomp$829$$,$APP.$app$util$globals$document$$,$modifiers$jscomp$135_modifiers__$1$jscomp$21$$)};
$app$main$ui$workspace$viewport$hooks$inside_vbox$$=function($vbox$jscomp$68$$,$frame$jscomp$100_objects$jscomp$830$$,$and__5023__auto__$jscomp$999_frame_id$jscomp$163$$){$frame$jscomp$100_objects$jscomp$830$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$100_objects$jscomp$830$$,$and__5023__auto__$jscomp$999_frame_id$jscomp$163$$);return($and__5023__auto__$jscomp$999_frame_id$jscomp$163$$=$frame$jscomp$100_objects$jscomp$830$$!=null)?$app$common$geom$shapes$intersect$overlaps_QMARK_$$($frame$jscomp$100_objects$jscomp$830$$,
$vbox$jscomp$68$$):$and__5023__auto__$jscomp$999_frame_id$jscomp$163$$};
$app$main$ui$workspace$viewport$hooks$setup_active_frames$$=function($objects$jscomp$831$$,$hover_ids$jscomp$6$$,$selected$jscomp$200$$,$active_frames$jscomp$2$$,$zoom$jscomp$140$$,$transform$jscomp$116$$,$vbox$jscomp$69$$){var $all_frames$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$831$$)],function(){return $app$common$types$shape_tree$get_root_frames_ids$$($objects$jscomp$831$$)}),$selected_frames$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$200$$)],
function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$200$$,$all_frames$jscomp$1$$)}),$xf_selected_frame$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$files$helpers$root_frame_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__81303_SHARP_$$){return $APP.$app$common$files$helpers$get_shape_id_root_frame$$($objects$jscomp$831$$,$p1__81303_SHARP_$$)})),
$selected_shapes_frames$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$200$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$xf_selected_frame$$,$selected$jscomp$200$$)}),$active_selection$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$116$$,$APP.$cljs$cst$1804$move$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_frames$jscomp$2$$),
1)?$APP.$cljs$core$first$$($selected_frames$jscomp$2$$):null,$last_hover_ids$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$))],function(){return $APP.$app$common$data$not_empty_QMARK_$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$))?$APP.$cljs$core$reset_BANG_$$($last_hover_ids$$,$APP.$cljs$core$set$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$))):
null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$831$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$)),$APP.$rumext$v2$adapt$$($selected$jscomp$200$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$140$$),$APP.$rumext$v2$adapt$$($transform$jscomp$116$$),$APP.$rumext$v2$adapt$$($vbox$jscomp$69$$)],function(){var $hover_ids_QMARK_$$=$APP.$cljs$core$set$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81304_SHARP_$$){return $APP.$app$common$files$helpers$get_shape_id_root_frame$$($objects$jscomp$831$$,
$p1__81304_SHARP_$$)},$APP.$cljs$core$_deref$$($hover_ids$jscomp$6$$))),$new_active_frames_new_active_frames__$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($id$jscomp$1059$$){return $zoom$jscomp$140$$>1.3||($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1804$move$$,$transform$jscomp$116$$)||$zoom$jscomp$140$$>=
.25)&&($APP.$cljs$core$contains_QMARK_$$($hover_ids_QMARK_$$,$id$jscomp$1059$$)||$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$_deref$$($last_hover_ids$$),$id$jscomp$1059$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1059$$,$active_selection$$)||$APP.$cljs$core$contains_QMARK_$$($selected_shapes_frames$$,$id$jscomp$1059$$)}),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$hooks$inside_vbox$$,
$vbox$jscomp$69$$,$objects$jscomp$831$$))),$all_frames$jscomp$1$$);$new_active_frames_new_active_frames__$1$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3074$disable_frame_thumbnails$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$all_frames$jscomp$1$$):$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3087$force_frame_thumbnails$$)?$APP.$cljs$core$PersistentHashSet$EMPTY$$:$new_active_frames_new_active_frames__$1$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($active_frames$jscomp$2$$),
$new_active_frames_new_active_frames__$1$$)?$APP.$cljs$core$reset_BANG_$$($active_frames$jscomp$2$$,$new_active_frames_new_active_frames__$1$$):null})};
$app$main$ui$workspace$viewport$hooks$setup_shortcuts$$=function($path_editing_QMARK_$jscomp$2$$,$drawing_path_QMARK_$jscomp$5$$,$text_editing_QMARK_$jscomp$2$$,$grid_editing_QMARK_$jscomp$1$$){$APP.$app$main$ui$hooks$use_shortcuts$$($cljs$cst$6016$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_workspace$$,$APP.$app$main$data$workspace$shortcuts$shortcuts$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){window.addEventListener("keydown",$app$main$data$workspace$shortcuts$on_display_guides_keydown$$);
return function(){return window.removeEventListener("keydown",$app$main$data$workspace$shortcuts$on_display_guides_keydown$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path_editing_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($drawing_path_QMARK_$jscomp$5$$),$APP.$rumext$v2$adapt$$($grid_editing_QMARK_$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($grid_editing_QMARK_$jscomp$1$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($cljs$cst$6017$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_grid$$,
$app$main$data$workspace$grid_layout$shortcuts$shortcuts$$)),function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($cljs$cst$6017$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_grid$$))}):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($drawing_path_QMARK_$jscomp$5$$)?$drawing_path_QMARK_$jscomp$5$$:$path_editing_QMARK_$jscomp$2$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($cljs$cst$6018$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_path$$,
$APP.$app$main$data$workspace$path$shortcuts$shortcuts$$)),function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($cljs$cst$6018$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_path$$))}):$APP.$cljs$core$truth_$$($text_editing_QMARK_$jscomp$2$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$push_shortcuts$$($cljs$cst$6019$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_text$$,
$APP.$app$main$data$workspace$text$shortcuts$shortcuts$$)),function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$shortcuts$pop_shortcuts$$($cljs$cst$6019$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_text$$))}):null})};
$app$main$ui$workspace$viewport$outline$outline_STAR_$$=function($props$jscomp$396_props_81260_zoom__$1$jscomp$4$$){var $modifier$jscomp$8_outline_type$$=$props$jscomp$396_props_81260_zoom__$1$jscomp$4$$.modifier,$shape$jscomp$1093_transform$jscomp$117$$=$props$jscomp$396_props_81260_zoom__$1$jscomp$4$$.shape;$props$jscomp$396_props_81260_zoom__$1$jscomp$4$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props$jscomp$396_props_81260_zoom__$1$jscomp$4$$.zoom,1);var $shape__$1$jscomp$120$$=
$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1093_transform$jscomp$117$$,$APP.$cljs$cst$1816$modifiers$$.$cljs$core$IFn$_invoke$arity$1$($modifier$jscomp$8_outline_type$$));$shape$jscomp$1093_transform$jscomp$117$$=$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$120$$);var $objects$jscomp$832$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$color$jscomp$194$$=$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1410$$=
$APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$832$$,$shape__$1$jscomp$120$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1410$$)?$or__5025__auto__$jscomp$1410$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape__$1$jscomp$120$$)}())?"var(--assets-component-hightlight)":"var(--color-accent-tertiary)",$x$jscomp$1291$$=$shape__$1$jscomp$120$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1515$x$$),
$y$jscomp$514$$=$shape__$1$jscomp$120$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$244$$=$shape__$1$jscomp$120$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$290$width$$),$height$jscomp$210$$=$shape__$1$jscomp$120$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1527$height$$),$selrect$jscomp$90$$=$shape__$1$jscomp$120$$?.selrect??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1610$selrect$$),$type$jscomp$724$$=$shape__$1$jscomp$120$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$139$type$$),$content$jscomp$270$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$120$$,$APP.$cljs$cst$1642$content$$),$path_QMARK_$jscomp$7$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$120$$),
$path_data$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($path_QMARK_$jscomp$7$$),$APP.$rumext$v2$adapt$$($content$jscomp$270$$)],function(){return $path_QMARK_$jscomp$7$$&&$content$jscomp$270$$!=null?$content$jscomp$270$$.toString():null}),$border_attrs$$=$APP.$app$main$ui$shapes$attrs$get_border_props$$($shape__$1$jscomp$120$$);$modifier$jscomp$8_outline_type$$=function(){switch($type$jscomp$724$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$724$$.$fqn$:
null){case "circle":return"ellipse";case "path":return"path";default:return $APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($border_attrs$$,"d")!=null?"path":"rect"}}();$props$jscomp$396_props_81260_zoom__$1$jscomp$4$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({fill:"none",stroke:$color$jscomp$194$$,strokeWidth:1/$props$jscomp$396_props_81260_zoom__$1$jscomp$4$$,pointerEvents:"none",transform:$shape$jscomp$1093_transform$jscomp$117$$},function(){switch($type$jscomp$724$$ instanceof
$APP.$cljs$core$Keyword$$?$type$jscomp$724$$.$fqn$:null){case "circle":return{cx:$x$jscomp$1291$$+$width$jscomp$244$$/2,cy:$y$jscomp$514$$+$height$jscomp$210$$/2,rx:$width$jscomp$244$$/2,ry:$height$jscomp$210$$/2};case "path":return{d:$path_data$$,transform:null};default:var $x__$1$jscomp$30$$=$selrect$jscomp$90$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$90$$,$APP.$cljs$cst$1515$x$$),$y__$1$jscomp$3$$=$selrect$jscomp$90$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$90$$,
$APP.$cljs$cst$1516$y$$),$w$jscomp$46$$=$selrect$jscomp$90$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$90$$,$APP.$cljs$cst$290$width$$),$h$jscomp$187$$=$selrect$jscomp$90$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($selrect$jscomp$90$$,$APP.$cljs$cst$1527$height$$);return{x:$x__$1$jscomp$30$$,y:$y__$1$jscomp$3$$,width:$w$jscomp$46$$,height:$h$jscomp$187$$,rx:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($border_attrs$$,"rx"),
ry:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($border_attrs$$,"ry"),d:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($border_attrs$$,"d")}}}());return(0,$APP.$rumext$v2$create_element$$)($modifier$jscomp$8_outline_type$$,$props$jscomp$396_props_81260_zoom__$1$jscomp$4$$)};
$app$main$ui$workspace$viewport$outline$shape_outlines_STAR_$$=function($lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$){function $edition_QMARK_$jscomp$2$$($o$jscomp$277$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$15$$,$o$jscomp$277$$)}var $edition$jscomp$15$$=$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$.edition,$zoom$jscomp$143$$=$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$.zoom,$selected$jscomp$201_selected__$1$jscomp$19$$=
$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$.selected,$highlighted$jscomp$5_highlighted__$1$$=$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$.highlighted,$hover$jscomp$11_hover__$1$$=$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$.hover,$modifiers$jscomp$137_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$=$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$.modifiers;$selected$jscomp$201_selected__$1$jscomp$19$$=
$APP.$cljs$core$truth_$$($selected$jscomp$201_selected__$1$jscomp$19$$)?$selected$jscomp$201_selected__$1$jscomp$19$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$;$hover$jscomp$11_hover__$1$$=$APP.$cljs$core$truth_$$($hover$jscomp$11_hover__$1$$)?$hover$jscomp$11_hover__$1$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$;$highlighted$jscomp$5_highlighted__$1$$=$APP.$cljs$core$truth_$$($highlighted$jscomp$5_highlighted__$1$$)?$highlighted$jscomp$5_highlighted__$1$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$;
$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$=$APP.$app$common$data$getf$$($lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$.objects);$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($edition_QMARK_$jscomp$2$$),
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$)),$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$201_selected__$1$jscomp$19$$,$hover$jscomp$11_hover__$1$$)),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$1$($edition_QMARK_$jscomp$2$$),$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$)),
$highlighted$jscomp$5_highlighted__$1$$);$modifiers$jscomp$137_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$=$APP.$cljs$core$select_keys$$($modifiers$jscomp$137_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$));$modifiers$jscomp$137_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$=$APP.$app$main$ui$hooks$use_equal_memo$$($modifiers$jscomp$137_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$);
$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$=$APP.$app$main$ui$hooks$use_equal_memo$$($lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"outlines blurrable",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines_render_STAR_$$,{shapes:$lookup$jscomp$20_props_81284_shapes$jscomp$235_shapes__$1$jscomp$37$$,zoom:$zoom$jscomp$143$$,modifiers:$modifiers$jscomp$137_modifiers__$1$jscomp$22_modifiers__$2$jscomp$9$$})})};
$app$main$ui$workspace$viewport$interactions$on_pointer_down$$=function($event$jscomp$718$$,$index$jscomp$579$$,$id$jscomp$1060_map__81302__$1_p__81300$$){$id$jscomp$1060_map__81302__$1_p__81300$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$1060_map__81302__$1_p__81300$$);$id$jscomp$1060_map__81302__$1_p__81300$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1060_map__81302__$1_p__81300$$,$APP.$cljs$cst$266$id$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$718$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$select_shape$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1060_map__81302__$1_p__81300$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$start_edit_interaction$$($index$jscomp$579$$))};
$app$main$ui$workspace$viewport$interactions$connect_to_shape$$=function($orig_rect_orig_shape$jscomp$1_orig_y$$,$dest_shape$jscomp$8_orig_pos$jscomp$4$$){$orig_rect_orig_shape$jscomp$1_orig_y$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$);var $dest_rect_dest_y$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$8_orig_pos$jscomp$4$$),$orig_x_orig_x_left$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$),
$orig_x_right$$=$orig_x_orig_x_left$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$),$dest_pos_orig_x_center$$=$orig_x_orig_x_left$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$)/2,$dest_x_dest_x_left$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$),$dest_x_right$$=$dest_x_dest_x_left$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$),
$dest_x_center$$=$dest_x_dest_x_left$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$)/2;$dest_shape$jscomp$8_orig_pos$jscomp$4$$=$orig_x_right$$<=$dest_x_dest_x_left$$?$APP.$cljs$cst$258$right$$:$orig_x_orig_x_left$$>=$dest_x_right$$?$APP.$cljs$cst$257$left$$:$dest_pos_orig_x_center$$<=$dest_x_center$$?$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$258$right$$;$dest_pos_orig_x_center$$=$orig_x_right$$<=$dest_x_dest_x_left$$?$APP.$cljs$cst$257$left$$:$orig_x_orig_x_left$$>=
$dest_x_right$$?$APP.$cljs$cst$258$right$$:$dest_pos_orig_x_center$$<=$dest_x_center$$?$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$258$right$$;$orig_x_orig_x_left$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dest_shape$jscomp$8_orig_pos$jscomp$4$$,$APP.$cljs$cst$258$right$$)?$orig_x_right$$:$orig_x_orig_x_left$$;$dest_x_dest_x_left$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($dest_pos_orig_x_center$$,$APP.$cljs$cst$258$right$$)?$dest_x_right$$:$dest_x_dest_x_left$$;$orig_rect_orig_shape$jscomp$1_orig_y$$=
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect_orig_shape$jscomp$1_orig_y$$)/2;$dest_rect_dest_y$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($dest_rect_dest_y$$)/2;return new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$dest_shape$jscomp$8_orig_pos$jscomp$4$$,
$orig_x_orig_x_left$$,$orig_rect_orig_shape$jscomp$1_orig_y$$,$dest_pos_orig_x_center$$,$dest_x_dest_x_left$$,$dest_rect_dest_y$$],null)};
$app$main$ui$workspace$viewport$interactions$connect_to_point$$=function($dest_x$jscomp$1_orig_shape$jscomp$2$$,$dest_point_dest_y$jscomp$1$$){var $orig_rect$jscomp$1_orig_y$jscomp$1$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($dest_x$jscomp$1_orig_shape$jscomp$2$$),$orig_x$jscomp$1_orig_x_left$jscomp$1$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$),$orig_x_right$jscomp$1$$=$orig_x$jscomp$1_orig_x_left$jscomp$1$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$),
$dest_pos$jscomp$1_orig_x_center$jscomp$1$$=$orig_x$jscomp$1_orig_x_left$jscomp$1$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$)/2;$dest_x$jscomp$1_orig_shape$jscomp$2$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($dest_point_dest_y$jscomp$1$$);$dest_point_dest_y$jscomp$1$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($dest_point_dest_y$jscomp$1$$);var $orig_pos$jscomp$5$$=$orig_x_right$jscomp$1$$<=$dest_x$jscomp$1_orig_shape$jscomp$2$$?
$APP.$cljs$cst$258$right$$:$orig_x$jscomp$1_orig_x_left$jscomp$1$$>=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$257$left$$:$dest_pos$jscomp$1_orig_x_center$jscomp$1$$<=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$257$left$$;$dest_pos$jscomp$1_orig_x_center$jscomp$1$$=$orig_x_right$jscomp$1$$<=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$257$left$$:$orig_x$jscomp$1_orig_x_left$jscomp$1$$>=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$258$right$$:
$dest_pos$jscomp$1_orig_x_center$jscomp$1$$<=$dest_x$jscomp$1_orig_shape$jscomp$2$$?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$257$left$$;$orig_x$jscomp$1_orig_x_left$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orig_pos$jscomp$5$$,$APP.$cljs$cst$258$right$$)?$orig_x_right$jscomp$1$$:$orig_x$jscomp$1_orig_x_left$jscomp$1$$;$orig_rect$jscomp$1_orig_y$jscomp$1$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($orig_rect$jscomp$1_orig_y$jscomp$1$$)/
2;return new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$orig_pos$jscomp$5$$,$orig_x$jscomp$1_orig_x_left$jscomp$1$$,$orig_rect$jscomp$1_orig_y$jscomp$1$$,$dest_pos$jscomp$1_orig_x_center$jscomp$1$$,$dest_x$jscomp$1_orig_shape$jscomp$2$$,$dest_point_dest_y$jscomp$1$$],null)};
$app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$=function($icon_pdata_props_81305$$){var $x$jscomp$1292$$=$icon_pdata_props_81305$$.x,$action_type$jscomp$3$$=$icon_pdata_props_81305$$.actionType,$y$jscomp$515$$=$icon_pdata_props_81305$$.y,$zoom$jscomp$144$$=$icon_pdata_props_81305$$.zoom,$stroke$jscomp$35$$=$icon_pdata_props_81305$$.stroke,$arrow_dir$$=$icon_pdata_props_81305$$.arrowDir;$icon_pdata_props_81305$$=function(){switch($action_type$jscomp$3$$ instanceof $APP.$cljs$core$Keyword$$?
$action_type$jscomp$3$$.$fqn$:null){case "navigate":switch($arrow_dir$$ instanceof $APP.$cljs$core$Keyword$$?$arrow_dir$$.$fqn$:null){case "right":return"M -6.5 0 L 5.5 0 M 6.715 0.715 L -0.5 -6.5 M 6.715 -0.715 L -0.365 6.635";case "left":return"M 6.5 0 l -12 0 m -0.715 0.715 l 6.5 -6.9 m -6 6 l 6 6.35";default:return null}case "open-overlay":return"M-5 -5 h7 v7 h-7 z M2 -2 h3.5 v7 h-7 v-2.5";case "toggle-overlay":return"M-5 -5 h7 v7 h-7 z M2 -2 h3.5 v7 h-7 v-2.5";case "close-overlay":return"M -5 -5 L 5 5 M -5 5 L 5 -5";
case "prev-screen":switch($arrow_dir$$ instanceof $APP.$cljs$core$Keyword$$?$arrow_dir$$.$fqn$:null){case "left":return"M -6.5 0 l 12 0 l -6 -6 m 6 6 l -6 6";case "right":return"M 6.5 0 l -12 0 l 6 -6 m -6 6 l 6 6";default:return null}case "open-url":return"M1 -5 L 3 -7 L 7 -3 L 1 3 L -1 1M-1 5 L -3 7 L -7 3 L -1 -3 L 1 -1";default:return null}}();var $inv_zoom$jscomp$1$$=1/$zoom$jscomp$144$$;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("circle",
{cx:0,cy:0,r:$action_type$jscomp$3$$!=null?11:4,fill:$stroke$jscomp$35$$,transform:["scale(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($inv_zoom$jscomp$1$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($inv_zoom$jscomp$1$$),") translate(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$144$$*$x$jscomp$1292$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$144$$*$y$jscomp$515$$),")"].join("")}),$APP.$cljs$core$truth_$$($icon_pdata_props_81305$$)?
(0,$APP.$rumext$v2$jsx$$)("path",{fill:$stroke$jscomp$35$$,strokeWidth:2,stroke:"var(--app-white)",d:$icon_pdata_props_81305$$,transform:["scale(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($inv_zoom$jscomp$1$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($inv_zoom$jscomp$1$$),") translate(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$144$$*$x$jscomp$1292$$),", ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($zoom$jscomp$144$$*$y$jscomp$515$$),
")"].join("")}):null]})};
$app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$=function($orig_x$jscomp$2_props_81311$$){var $dest_point$jscomp$1_orig_y$jscomp$2$$=$orig_x$jscomp$2_props_81311$$.destPoint,$action_type$jscomp$4$$=$orig_x$jscomp$2_props_81311$$.actionType,$zoom$jscomp$145$$=$orig_x$jscomp$2_props_81311$$.zoom,$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$=$orig_x$jscomp$2_props_81311$$.selected,$index$jscomp$580$$=$orig_x$jscomp$2_props_81311$$.index,$is_selected$jscomp$14$$=$orig_x$jscomp$2_props_81311$$.isSelected,
$dest_shape$jscomp$9$$=$orig_x$jscomp$2_props_81311$$.destShape,$dest_x$jscomp$2_level$jscomp$63$$=$orig_x$jscomp$2_props_81311$$.level,$orig_shape$jscomp$3$$=$orig_x$jscomp$2_props_81311$$.origShape,$dest_y$jscomp$2_vec__81339$$=$APP.$cljs$core$truth_$$($dest_shape$jscomp$9$$)?$app$main$ui$workspace$viewport$interactions$connect_to_shape$$($orig_shape$jscomp$3$$,$dest_shape$jscomp$9$$):$APP.$cljs$core$truth_$$($dest_point$jscomp$1_orig_y$jscomp$2$$)?$app$main$ui$workspace$viewport$interactions$connect_to_point$$($orig_shape$jscomp$3$$,
$dest_point$jscomp$1_orig_y$jscomp$2$$):$app$main$ui$workspace$viewport$interactions$connect_to_point$$($orig_shape$jscomp$3$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($orig_shape$jscomp$3$$))+100/$zoom$jscomp$145$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1529$y1$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($orig_shape$jscomp$3$$))-
50/$zoom$jscomp$145$$+$dest_x$jscomp$2_level$jscomp$63$$*32/$zoom$jscomp$145$$],null)),$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__81339$$,0,null);$orig_x$jscomp$2_props_81311$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__81339$$,1,null);$dest_point$jscomp$1_orig_y$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__81339$$,2,null);var $arrow_dir$jscomp$1_dest_pos$jscomp$2$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__81339$$,3,null);$dest_x$jscomp$2_level$jscomp$63$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__81339$$,4,null);$dest_y$jscomp$2_vec__81339$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dest_y$jscomp$2_vec__81339$$,5,null);$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$,$APP.$cljs$cst$258$right$$)?
100:-100)/$zoom$jscomp$145$$;var $dest_dx$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arrow_dir$jscomp$1_dest_pos$jscomp$2$$,$APP.$cljs$cst$258$right$$)?100:-100)/$zoom$jscomp$145$$;$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$=$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(" ",new $APP.$cljs$core$PersistentVector$$(null,10,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["M",$orig_x$jscomp$2_props_81311$$,$dest_point$jscomp$1_orig_y$jscomp$2$$,"C",$orig_x$jscomp$2_props_81311$$+
$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$,$dest_point$jscomp$1_orig_y$jscomp$2$$,$dest_x$jscomp$2_level$jscomp$63$$+$dest_dx$$,$dest_y$jscomp$2_vec__81339$$,$dest_x$jscomp$2_level$jscomp$63$$,$dest_y$jscomp$2_vec__81339$$],null));$arrow_dir$jscomp$1_dest_pos$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($arrow_dir$jscomp$1_dest_pos$jscomp$2$$,$APP.$cljs$cst$257$left$$)?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$257$left$$;$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$=
$dest_shape$jscomp$9$$!=null&&$APP.$cljs$core$contains_QMARK_$$($incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$9$$));$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$=$APP.$cljs$core$truth_$$($is_selected$jscomp$14$$)?"var(--color-accent-tertiary)":$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$?"var(--color-accent-quaternary)":"var(--df-secondary)";return $APP.$cljs$core$not$$($is_selected$jscomp$14$$)?
(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerDown:function($p1__81309_SHARP_$$){return $app$main$ui$workspace$viewport$interactions$on_pointer_down$$($p1__81309_SHARP_$$,$index$jscomp$580$$,$orig_shape$jscomp$3$$)},children:[(0,$APP.$rumext$v2$jsx$$)("path",{stroke:$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$,fill:"none",pointerEvents:"visible",strokeWidth:2/$zoom$jscomp$145$$,d:$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$}),$APP.$cljs$core$not$$($dest_shape$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,
{index:$index$jscomp$580$$,x:$dest_x$jscomp$2_level$jscomp$63$$,y:$dest_y$jscomp$2_vec__81339$$,stroke:$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$,actionType:$action_type$jscomp$4$$,arrowDir:$arrow_dir$jscomp$1_dest_pos$jscomp$2$$,zoom:$zoom$jscomp$145$$}):null]}):(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerDown:function($p1__81310_SHARP_$$){return $app$main$ui$workspace$viewport$interactions$on_pointer_down$$($p1__81310_SHARP_$$,$index$jscomp$580$$,$orig_shape$jscomp$3$$)},children:[(0,$APP.$rumext$v2$jsx$$)("path",
{stroke:$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$,fill:"none",pointerEvents:"visible",strokeWidth:2/$zoom$jscomp$145$$,d:$orig_dx_orig_pos$jscomp$6_pdata$jscomp$13$$}),$APP.$cljs$core$truth_$$($dest_shape$jscomp$9$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$outline_STAR_$$,{zoom:$zoom$jscomp$145$$,shape:$dest_shape$jscomp$9$$,color:$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,
{index:$index$jscomp$580$$,x:$orig_x$jscomp$2_props_81311$$,y:$dest_point$jscomp$1_orig_y$jscomp$2$$,stroke:$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$,zoom:$zoom$jscomp$145$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,{index:$index$jscomp$580$$,x:$dest_x$jscomp$2_level$jscomp$63$$,y:$dest_y$jscomp$2_vec__81339$$,stroke:$incoming_QMARK__selected$jscomp$202_stroke_color$jscomp$1$$,actionType:$action_type$jscomp$4$$,arrowDir:$arrow_dir$jscomp$1_dest_pos$jscomp$2$$,
zoom:$zoom$jscomp$145$$})]})};
$app$main$ui$workspace$viewport$interactions$interaction_handle_STAR_$$=function($handle_x_props_81347$$){var $zoom$jscomp$146$$=$handle_x_props_81347$$.zoom,$index$jscomp$581$$=$handle_x_props_81347$$.index,$shape$jscomp$1096$$=$handle_x_props_81347$$.shape,$handle_y_shape_rect$jscomp$1$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1096$$);$handle_x_props_81347$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($handle_y_shape_rect$jscomp$1$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($handle_y_shape_rect$jscomp$1$$);
$handle_y_shape_rect$jscomp$1$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($handle_y_shape_rect$jscomp$1$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($handle_y_shape_rect$jscomp$1$$)/2;return(0,$APP.$rumext$v2$jsx$$)("g",{onPointerDown:function($p1__81346_SHARP_$$){return $app$main$ui$workspace$viewport$interactions$on_pointer_down$$($p1__81346_SHARP_$$,$index$jscomp$581$$,$shape$jscomp$1096$$)},children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_marker_STAR_$$,
{x:$handle_x_props_81347$$,y:$handle_y_shape_rect$jscomp$1$$,stroke:"var(--color-accent-tertiary)",actionType:$APP.$cljs$cst$1957$navigate$$,arrowDir:$APP.$cljs$cst$258$right$$,zoom:$zoom$jscomp$146$$})})};
$app$main$ui$workspace$viewport$interactions$overlay_marker_STAR_$$=function($marker_y_position$jscomp$243_props_81352$$){function $start_move_position$$(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$interactions$start_move_overlay_pos$$($index$jscomp$582$$))}var $index$jscomp$582$$=$marker_y_position$jscomp$243_props_81352$$.index,$objects$jscomp$834$$=$marker_y_position$jscomp$243_props_81352$$.objects,$dest_shape$jscomp$10_dest_shape__$1$$=
$marker_y_position$jscomp$243_props_81352$$.destShape,$page_id$jscomp$454_thumbnail_data_thumbnail_data_ref$$=$marker_y_position$jscomp$243_props_81352$$.pageId,$marker_x_orig_shape$jscomp$4$$=$marker_y_position$jscomp$243_props_81352$$.origShape,$is_hover_disabled$$=$marker_y_position$jscomp$243_props_81352$$.isHoverDisabled;$marker_y_position$jscomp$243_props_81352$$=$marker_y_position$jscomp$243_props_81352$$.position;if($APP.$cljs$core$truth_$$($dest_shape$jscomp$10_dest_shape__$1$$)){var $orig_frame$jscomp$2_width$jscomp$245$$=
$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$834$$,$marker_x_orig_shape$jscomp$4$$);$marker_x_orig_shape$jscomp$4$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($orig_frame$jscomp$2_width$jscomp$245$$)+$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($marker_y_position$jscomp$243_props_81352$$);$marker_y_position$jscomp$243_props_81352$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($orig_frame$jscomp$2_width$jscomp$245$$)+
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($marker_y_position$jscomp$243_props_81352$$);$orig_frame$jscomp$2_width$jscomp$245$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$);var $height$jscomp$211$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$),$dest_x$jscomp$3$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$),$dest_y$jscomp$3$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$),
$shape_wrapper$jscomp$21$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$834$$)],function(){return $APP.$app$main$render$shape_wrapper_factory$$($objects$jscomp$834$$)}),$dest_shape_id$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($dest_shape$jscomp$10_dest_shape__$1$$);$page_id$jscomp$454_thumbnail_data_thumbnail_data_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$454_thumbnail_data_thumbnail_data_ref$$),
$APP.$rumext$v2$adapt$$($dest_shape_id$$)],function(){return $APP.$app$main$refs$workspace_thumbnail_by_id$$($dest_shape_id$$)});$page_id$jscomp$454_thumbnail_data_thumbnail_data_ref$$=$APP.$rumext$v2$deref$$($page_id$jscomp$454_thumbnail_data_thumbnail_data_ref$$);$dest_shape$jscomp$10_dest_shape__$1$$=$page_id$jscomp$454_thumbnail_data_thumbnail_data_ref$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($dest_shape$jscomp$10_dest_shape__$1$$,$APP.$cljs$cst$5269$thumbnail$$,$page_id$jscomp$454_thumbnail_data_thumbnail_data_ref$$):
$dest_shape$jscomp$10_dest_shape__$1$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerDown:$start_move_position$$,onPointerEnter:function(){return $APP.$cljs$core$reset_BANG_$$($is_hover_disabled$$,!0)},onPointerLeave:function(){return $APP.$cljs$core$reset_BANG_$$($is_hover_disabled$$,!1)},children:[(0,$APP.$rumext$v2$jsx$$)("g",{transform:$APP.$app$common$geom$matrix$translate_matrix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($marker_x_orig_shape$jscomp$4$$-
$dest_x$jscomp$3$$,$marker_y_position$jscomp$243_props_81352$$-$dest_y$jscomp$3$$)),children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$render_thumbnails$$),{value:!0,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$embed$context$$),{value:!1,children:(0,$APP.$rumext$v2$jsx$$)($shape_wrapper$jscomp$21$$,{shape:$dest_shape$jscomp$10_dest_shape__$1$$})})})}),(0,$APP.$rumext$v2$jsx$$)("path",{stroke:"var(--color-accent-tertiary)",
fill:"var(--app-black)",fillOpacity:.5,strokeWidth:1,d:"M"+($marker_x_orig_shape$jscomp$4$$??"")+" "+($marker_y_position$jscomp$243_props_81352$$??"")+" h "+($orig_frame$jscomp$2_width$jscomp$245$$??"")+" v "+($height$jscomp$211$$??"")+" h -"+($orig_frame$jscomp$2_width$jscomp$245$$??"")+" zM"+($marker_x_orig_shape$jscomp$4$$??"")+" "+($marker_y_position$jscomp$243_props_81352$$??"")+" l "+($orig_frame$jscomp$2_width$jscomp$245$$??"")+" "+($height$jscomp$211$$??"")+" M"+($marker_x_orig_shape$jscomp$4$$??
"")+" "+($marker_y_position$jscomp$243_props_81352$$+$height$jscomp$211$$??"")+" l "+($orig_frame$jscomp$2_width$jscomp$245$$??"")+" -"+($height$jscomp$211$$??"")+" "}),(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$marker_x_orig_shape$jscomp$4$$+$orig_frame$jscomp$2_width$jscomp$245$$/2,cy:$marker_y_position$jscomp$243_props_81352$$+$height$jscomp$211$$/2,r:8,fill:"var(--color-accent-tertiary)"})]})}return null};
$app$main$ui$workspace$viewport$interactions$interactions_STAR_$$=function($active_shapes_props_81365$$){function $calc_level$$($index$jscomp$583$$,$interactions$jscomp$25$$){return $APP.$cljs$core$count$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81364_SHARP_$$){return $APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($p1__81364_SHARP_$$)==null},$APP.$cljs$core$subvec$cljs$0core$0IFn$0_invoke$0arity$03$$($interactions$jscomp$25$$,0,$index$jscomp$583$$)))}
var $zoom$jscomp$147$$=$active_shapes_props_81365$$.zoom,$selected$jscomp$203$$=$active_shapes_props_81365$$.selected,$objects$jscomp$835$$=$active_shapes_props_81365$$.objects,$current_transform$$=$active_shapes_props_81365$$.currentTransform,$page_id$jscomp$455$$=$active_shapes_props_81365$$.pageId,$is_hover_disabled$jscomp$1$$=$active_shapes_props_81365$$.isHoverDisabled;$active_shapes_props_81365$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__81362_SHARP_$$){return $APP.$cljs$core$seq$$($APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($p1__81362_SHARP_$$))})),$APP.$cljs$core$vals$$($objects$jscomp$835$$));var $selected_shapes$jscomp$37$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$835$$)),
$selected$jscomp$203$$),$draw_interaction_to_map__81367$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$viewport$interactions$interactions_ref$$),$first_selected$jscomp$2_map__81367__$1$$=$APP.$cljs$core$__destructure_map$$($draw_interaction_to_map__81367$$),$editing_interaction_index$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__81367__$1$$,$APP.$cljs$cst$4382$editing_interaction_index$$);$draw_interaction_to_map__81367$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__81367__$1$$,
$APP.$cljs$cst$4384$draw_interaction_to$$);var $draw_interaction_to_frame$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__81367__$1$$,$APP.$cljs$cst$4385$draw_interaction_to_frame$$),$move_overlay_to$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__81367__$1$$,$APP.$cljs$cst$4388$move_overlay_to$$),$move_overlay_index$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($first_selected$jscomp$2_map__81367__$1$$,$APP.$cljs$cst$4389$move_overlay_index$$);
$first_selected$jscomp$2_map__81367__$1$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$37$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"interactions",children:[(0,$APP.$rumext$v2$jsx$$)("g",{className:"non-selected",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$234$$,$shape$jscomp$1097$$){$out_arr__44092__auto__$jscomp$234$$.push($APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$23$$,
$JSCompiler_temp_const$jscomp$1954_p__81368$$){var $JSCompiler_inline_result$jscomp$1956_index$jscomp$584$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1954_p__81368$$,0,null),$interaction$jscomp$54$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1954_p__81368$$,1,null);$JSCompiler_temp_const$jscomp$1954_p__81368$$=$out_arr__44092__auto____$1$jscomp$23$$.push;var $dest_shape$jscomp$inline_9468$$=$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$destination_QMARK_$$($interaction$jscomp$54$$))?
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$835$$,$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$54$$)):null,$selected_QMARK_$jscomp$inline_9469$$=$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$203$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1097$$)),$level$jscomp$inline_9470$$=$calc_level$$($JSCompiler_inline_result$jscomp$1956_index$jscomp$584$$,$APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1097$$));
$JSCompiler_inline_result$jscomp$1956_index$jscomp$584$$=$selected_QMARK_$jscomp$inline_9469$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$,{zoom:$zoom$jscomp$147$$,selected:$selected$jscomp$203$$,index:$JSCompiler_inline_result$jscomp$1956_index$jscomp$584$$,isSelected:!1,destShape:$dest_shape$jscomp$inline_9468$$,level:$level$jscomp$inline_9470$$,origShape:$shape$jscomp$1097$$,actionType:$APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$54$$)},
"non-selected-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1097$$)??"")+"-"+($JSCompiler_inline_result$jscomp$1956_index$jscomp$584$$??""));$JSCompiler_temp_const$jscomp$1954_p__81368$$.call($out_arr__44092__auto____$1$jscomp$23$$,$JSCompiler_inline_result$jscomp$1956_index$jscomp$584$$);return $out_arr__44092__auto____$1$jscomp$23$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1097$$))));
return $out_arr__44092__auto__$jscomp$234$$},[],$active_shapes_props_81365$$)}),(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selected",children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($draw_interaction_to_map__81367$$)?$first_selected$jscomp$2_map__81367__$1$$:$draw_interaction_to_map__81367$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$,{index:null,origShape:$first_selected$jscomp$2_map__81367__$1$$,destPoint:$draw_interaction_to_map__81367$$,
destShape:$draw_interaction_to_frame$$,isSelected:!0,actionType:$APP.$cljs$cst$1957$navigate$$,zoom:$zoom$jscomp$147$$},"interactive"):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$235$$,$shape$jscomp$1098$$){$out_arr__44092__auto__$jscomp$235$$.push($APP.$cljs$core$seq$$($APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1098$$))?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto____$1$jscomp$24$$,
$JSCompiler_temp_const$jscomp$1957_p__81375$$){var $JSCompiler_temp$jscomp$1959_index$jscomp$585$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1957_p__81375$$,0,null),$interaction$jscomp$55$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1957_p__81375$$,1,null);$JSCompiler_temp_const$jscomp$1957_p__81375$$=$out_arr__44092__auto____$1$jscomp$24$$.push;if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1959_index$jscomp$585$$,
$editing_interaction_index$$))$JSCompiler_temp$jscomp$1959_index$jscomp$585$$=null;else{var $dest_shape$jscomp$inline_9472$$=$APP.$cljs$core$truth_$$($app$common$types$shape$interactions$destination_QMARK_$$($interaction$jscomp$55$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$835$$,$APP.$cljs$cst$1983$destination$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$)):null,$level$jscomp$inline_9473$$=$calc_level$$($JSCompiler_temp$jscomp$1959_index$jscomp$585$$,$APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1098$$));
$JSCompiler_temp$jscomp$1959_index$jscomp$585$$=(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_path_STAR_$$,{index:$JSCompiler_temp$jscomp$1959_index$jscomp$585$$,level:$level$jscomp$inline_9473$$,origShape:$shape$jscomp$1098$$,destShape:$dest_shape$jscomp$inline_9472$$,selected:$selected$jscomp$203$$,isSelected:!0,actionType:$APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),zoom:$zoom$jscomp$147$$}),
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),$APP.$cljs$cst$1962$open_overlay$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1982$action_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),$APP.$cljs$cst$1960$toggle_overlay$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1987$overlay_pos_type$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),
$APP.$cljs$cst$1678$manual$$)?$move_overlay_to$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($move_overlay_index$$,$JSCompiler_temp$jscomp$1959_index$jscomp$585$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$overlay_marker_STAR_$$,{pageId:$page_id$jscomp$455$$,index:$JSCompiler_temp$jscomp$1959_index$jscomp$585$$,origShape:$shape$jscomp$1098$$,destShape:$dest_shape$jscomp$inline_9472$$,position:$move_overlay_to$$,objects:$objects$jscomp$835$$,isHoverDisabled:$is_hover_disabled$jscomp$1$$}):
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$overlay_marker_STAR_$$,{pageId:$page_id$jscomp$455$$,index:$JSCompiler_temp$jscomp$1959_index$jscomp$585$$,origShape:$shape$jscomp$1098$$,destShape:$dest_shape$jscomp$inline_9472$$,position:$APP.$cljs$cst$1986$overlay_position$$.$cljs$core$IFn$_invoke$arity$1$($interaction$jscomp$55$$),objects:$objects$jscomp$835$$,isHoverDisabled:$is_hover_disabled$jscomp$1$$}):null]},"interaction-path-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1098$$)??
"")+"-"+($JSCompiler_temp$jscomp$1959_index$jscomp$585$$??""))}$JSCompiler_temp_const$jscomp$1957_p__81375$$.call($out_arr__44092__auto____$1$jscomp$24$$,$JSCompiler_temp$jscomp$1959_index$jscomp$585$$);return $out_arr__44092__auto____$1$jscomp$24$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$2059$interactions$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1098$$))):$APP.$cljs$core$truth_$$(function(){var $JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$;
if($APP.$cljs$core$truth_$$($shape$jscomp$1098$$)){if($JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$=!$app$common$files$helpers$unframed_shape_QMARK_$$($shape$jscomp$1098$$))$JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1804$move$$,
null,$APP.$cljs$cst$2874$rotate$$,null],null),null),$JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$=$JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$.$cljs$core$IFn$_invoke$arity$1$?$JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$.$cljs$core$IFn$_invoke$arity$1$($current_transform$$):
$JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$($current_transform$$),$JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$=$APP.$cljs$core$not$$($JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$)}else $JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$=
$shape$jscomp$1098$$;return $JSCompiler_inline_result$jscomp$1962_JSCompiler_temp$jscomp$1960_JSCompiler_temp$jscomp$1961_fexpr__81379$jscomp$inline_9475$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interaction_handle_STAR_$$,{index:null,shape:$shape$jscomp$1098$$,selected:$selected$jscomp$203$$,zoom:$zoom$jscomp$147$$},$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1098$$)):null);return $out_arr__44092__auto__$jscomp$235$$},[],$selected_shapes$jscomp$37$$)]})]})};
$app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move$$=function($brx_img_width$jscomp$1_map__81312_viewport_node$$,$canvas$jscomp$24_offset$jscomp$221$$,$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$,$zoom_context_zoom_view_context$$,$last_picked_color$$,$client_x$jscomp$2_x$jscomp$1293$$,$client_y_y$jscomp$516$$){$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$=$APP.$rumext$v2$ref_val$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$);
if($APP.$cljs$core$truth_$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$)){var $bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$=$APP.$goog$dom$getElement$$("picker-detail");if($APP.$cljs$core$truth_$$($bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$)){$APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($zoom_context_zoom_view_context$$))||$APP.$rumext$v2$set_ref_val_BANG_$$($zoom_context_zoom_view_context$$,$bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$.getContext("2d"));
$brx_img_width$jscomp$1_map__81312_viewport_node$$=$APP.$app$util$dom$get_bounding_rect$$($brx_img_width$jscomp$1_map__81312_viewport_node$$);$bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$=$APP.$cljs$core$__destructure_map$$($brx_img_width$jscomp$1_map__81312_viewport_node$$);$brx_img_width$jscomp$1_map__81312_viewport_node$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$,$APP.$cljs$cst$257$left$$);
$bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$,$APP.$cljs$cst$1567$top$$);$client_x$jscomp$2_x$jscomp$1293$$=$APP.$app$common$math$floor$$($client_x$jscomp$2_x$jscomp$1293$$-$brx_img_width$jscomp$1_map__81312_viewport_node$$);$client_y_y$jscomp$516$$=$APP.$app$common$math$floor$$($client_y_y$jscomp$516$$-$bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$);
$brx_img_width$jscomp$1_map__81312_viewport_node$$=$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$.width;$bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$=$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$.height;$zoom_context_zoom_view_context$$=$APP.$rumext$v2$ref_val$$($zoom_context_zoom_view_context$$);var $sx$jscomp$12$$=$client_x$jscomp$2_x$jscomp$1293$$-32,$sy$jscomp$11$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1351$safari$$)?
$client_y_y$jscomp$516$$:$client_y_y$jscomp$516$$-17;$APP.$cljs$core$truth_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($zoom_context_zoom_view_context$$,"imageSmoothingEnabled"))&&$APP.$app$util$object$set_BANG_$$($zoom_context_zoom_view_context$$,"imageSmoothingEnabled",!1);$zoom_context_zoom_view_context$$.clearRect(0,0,260,140);$zoom_context_zoom_view_context$$.drawImage($canvas$jscomp$24_offset$jscomp$221$$,$sx$jscomp$12$$,$sy$jscomp$11$$,65,35,0,0,260,140);if($client_x$jscomp$2_x$jscomp$1293$$>=
0&&$client_x$jscomp$2_x$jscomp$1293$$<$brx_img_width$jscomp$1_map__81312_viewport_node$$&&$client_y_y$jscomp$516$$>=0&&$client_y_y$jscomp$516$$<$bry_img_height$jscomp$1_map__81312__$1_temp__5825__auto____$1$jscomp$25$$){$canvas$jscomp$24_offset$jscomp$221$$=($client_y_y$jscomp$516$$*$brx_img_width$jscomp$1_map__81312_viewport_node$$+$client_x$jscomp$2_x$jscomp$1293$$)*4;$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$=$canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$.data;
var $color$jscomp$195$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$,0+$canvas$jscomp$24_offset$jscomp$221$$),255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$,1+$canvas$jscomp$24_offset$jscomp$221$$),
255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$,2+$canvas$jscomp$24_offset$jscomp$221$$),255),$APP.$app$common$math$finite$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_image_data_rgba$jscomp$12_temp__5825__auto__$jscomp$452$$,3+$canvas$jscomp$24_offset$jscomp$221$$),255)],null);$APP.$rumext$v2$set_ref_val_BANG_$$($last_picked_color$$,$color$jscomp$195$$);
return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$pick_color$$($color$jscomp$195$$))})}}}return null};
$app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_STAR_$$=function($handle_pointer_down_picker_props_81337$$){var $vport$jscomp$13$$=$handle_pointer_down_picker_props_81337$$.vport,$viewport_node$jscomp$1$$=$APP.$rumext$v2$ref_val$$($handle_pointer_down_picker_props_81337$$.viewportRef),$canvas$jscomp$25$$=$app$main$ui$workspace$viewport$pixel_overlay$get_offscreen_canvas$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$13$$),$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$13$$)),
$canvas_context$jscomp$1$$=$canvas$jscomp$25$$.getContext("2d",{willReadFrequently:!0}),$canvas_image_data$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$zoom_view_context$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$last_picked_color$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),$initial_mouse_pos$$=(0,$APP.$rumext$v2$use_ref$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,0,$APP.$cljs$cst$1516$y$$,0],null)),$update_str$$=$APP.$beicon$v2$core$subject$$(),$handle_keydown$jscomp$3$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$719$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$719$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$719$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$719$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$stop_picker$$()),$APP.$app$main$data$modal$disallow_click_outside_BANG_$$()):null});$handle_pointer_down_picker_props_81337$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$720$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$720$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$720$$);var $color$jscomp$196$$=$APP.$rumext$v2$ref_val$$($last_picked_color$jscomp$1$$);return $color$jscomp$196$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$6020$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$pick_color$$($color$jscomp$196$$),
$app$main$data$workspace$colors$pick_color_select$$($event$jscomp$720$$.shiftKey)])):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$6020$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$pick_color_select$$($event$jscomp$720$$.shiftKey)]))});var $handle_pointer_up_picker$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$721$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$721$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$721$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($cljs$cst$6020$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$stop_picker$$()]));return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$()}),$handle_draw_picker_canvas$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $svg_node$jscomp$1$$=
$APP.$goog$dom$getElement$$("render"),$fonts$jscomp$39$$=$app$main$fonts$get_node_fonts$$($svg_node$jscomp$1$$),$result$jscomp$388$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$3817$node$$,$svg_node$jscomp$1$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vport$jscomp$13$$),$APP.$cljs$cst$828$result$$,"image-bitmap"],null);return $APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($image_bitmap_image_data$jscomp$3$$){$canvas_context$jscomp$1$$.drawImage($image_bitmap_image_data$jscomp$3$$,
0,0);$image_bitmap_image_data$jscomp$3$$=$canvas_context$jscomp$1$$.getImageData(0,0,$canvas$jscomp$25$$.width,$canvas$jscomp$25$$.height);var $map__81349__$1_my$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($APP.$rumext$v2$ref_val$$($initial_mouse_pos$$)),$mx$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81349__$1_my$jscomp$2$$,$APP.$cljs$cst$1515$x$$);$map__81349__$1_my$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81349__$1_my$jscomp$2$$,$APP.$cljs$cst$1516$y$$);
$APP.$rumext$v2$set_ref_val_BANG_$$($canvas_image_data$jscomp$1$$,$image_bitmap_image_data$jscomp$3$$);return $app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move$$($viewport_node$jscomp$1$$,$canvas$jscomp$25$$,$canvas_image_data$jscomp$1$$,$zoom_view_context$jscomp$1$$,$last_picked_color$jscomp$1$$,$mx$jscomp$2$$,$map__81349__$1_my$jscomp$2$$)},$APP.$beicon$v2$core$mapcat$$($app$main$rasterizer$render_node$$,$APP.$beicon$v2$core$map$$(function($styles$jscomp$33$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($result$jscomp$388$$,
$APP.$cljs$cst$2951$styles$$,$styles$jscomp$33$$)},$APP.$app$main$fonts$render_font_styles_cached$$($fonts$jscomp$39$$))))}),$handle_svg_change$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $update_str$$.next($cljs$cst$6015$update$$)}),$handle_mouse_enter$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$1$$)],function($event$jscomp$722$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($initial_mouse_pos$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,$event$jscomp$722$$.clientX,$APP.$cljs$cst$1516$y$$,$event$jscomp$722$$.clientY],null))}),$handle_pointer_move_picker$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$1$$)],function($event$jscomp$723$$){return $app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move$$($viewport_node$jscomp$1$$,$canvas$jscomp$25$$,$canvas_image_data$jscomp$1$$,$zoom_view_context$jscomp$1$$,
$last_picked_color$jscomp$1$$,$event$jscomp$723$$.clientX,$event$jscomp$723$$.clientY)});$APP.$cljs$core$truth_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas_context$jscomp$1$$,"imageSmoothingEnabled"))&&$APP.$app$util$object$set_BANG_$$($canvas_context$jscomp$1$$,"imageSmoothingEnabled",!1);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$453$$=$APP.$goog$dom$getElement$$("pixel-overlay");return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$453$$)?
$temp__5825__auto__$jscomp$453$$.focus():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $listener$jscomp$110$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keydown",$handle_keydown$jscomp$3$$);return function(){return $APP.$goog$events$unlistenByKey$$($listener$jscomp$110$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $sub$jscomp$28$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_draw_picker_canvas$$,
$APP.$beicon$v2$core$debounce$$(10,$update_str$$));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$28$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $svg_node$jscomp$2$$=$APP.$goog$dom$getElement$$("render"),$observer$jscomp$8$$=new MutationObserver($handle_svg_change$$);$observer$jscomp$8$$.observe($svg_node$jscomp$2$$,{attributes:!0,childList:!0,subtree:!0,characterData:!0});$handle_svg_change$$.$cljs$core$IFn$_invoke$arity$0$?$handle_svg_change$$.$cljs$core$IFn$_invoke$arity$0$():
$handle_svg_change$$();return function(){return $observer$jscomp$8$$.disconnect()}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $listener$jscomp$111$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"pointermove",function($e$jscomp$390$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($initial_mouse_pos$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,$e$jscomp$390$$.clientX,$APP.$cljs$cst$1516$y$$,$e$jscomp$390$$.clientY],null))});
return function(){return $APP.$goog$events$unlistenByKey$$($listener$jscomp$111$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{id:"pixel-overlay",tabIndex:0,onPointerDown:$handle_pointer_down_picker_props_81337$$,onPointerUp:$handle_pointer_up_picker$$,onPointerMove:$handle_pointer_move_picker$$,onMouseEnter:$handle_mouse_enter$$,className:""+($APP.$app$main$ui$css_cursors$get_static$$("picker")??"")+" main_ui_workspace_viewport_pixel_overlay__pixel-overlay"})};
$app$main$ui$workspace$viewport$pixel_overlay$viewport__GT_canvas_coords$$=function($brx$jscomp$1_map__81353_viewport_node$jscomp$2$$,$client_x$jscomp$3$$,$client_y$jscomp$1$$){$brx$jscomp$1_map__81353_viewport_node$jscomp$2$$=$APP.$app$util$dom$get_bounding_rect$$($brx$jscomp$1_map__81353_viewport_node$jscomp$2$$);var $bry$jscomp$1_map__81353__$1$$=$APP.$cljs$core$__destructure_map$$($brx$jscomp$1_map__81353_viewport_node$jscomp$2$$);$brx$jscomp$1_map__81353_viewport_node$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bry$jscomp$1_map__81353__$1$$,
$APP.$cljs$cst$257$left$$);$bry$jscomp$1_map__81353__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bry$jscomp$1_map__81353__$1$$,$APP.$cljs$cst$1567$top$$);var $dpr$jscomp$6$$=$APP.$app$render_wasm$api$get_dpr$$();return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$math$floor$$($APP.$app$common$math$floor$$($client_x$jscomp$3$$-$brx$jscomp$1_map__81353_viewport_node$jscomp$2$$)*$dpr$jscomp$6$$),$APP.$app$common$math$floor$$($APP.$app$common$math$floor$$($client_y$jscomp$1$$-
$bry$jscomp$1_map__81353__$1$$)*$dpr$jscomp$6$$)],null)};
$app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move_wasm$$=function($canvas_x_sx$jscomp$13_viewport_node$jscomp$3$$,$canvas$jscomp$26$$,$zoom_context$jscomp$1_zoom_view_context$jscomp$2$$,$canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$,$client_y$jscomp$2$$){if($APP.$cljs$core$truth_$$($canvas$jscomp$26$$)){var $temp__5825__auto__$jscomp$454$$=$APP.$goog$dom$getElement$$("picker-detail");if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$454$$))return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$))||$APP.$rumext$v2$set_ref_val_BANG_$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$,
$temp__5825__auto__$jscomp$454$$.getContext("2d")),$canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$=$app$main$ui$workspace$viewport$pixel_overlay$viewport__GT_canvas_coords$$($canvas_x_sx$jscomp$13_viewport_node$jscomp$3$$,$canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$,$client_y$jscomp$2$$),$canvas_x_sx$jscomp$13_viewport_node$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$,0,null),$canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$,1,null),$zoom_context$jscomp$1_zoom_view_context$jscomp$2$$=$APP.$rumext$v2$ref_val$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$),$canvas_x_sx$jscomp$13_viewport_node$jscomp$3$$-=32,$canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1351$safari$$)?$canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$:$canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$-
17,$APP.$cljs$core$truth_$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$,"imageSmoothingEnabled"))&&$APP.$app$util$object$set_BANG_$$($zoom_context$jscomp$1_zoom_view_context$jscomp$2$$,"imageSmoothingEnabled",!1),$zoom_context$jscomp$1_zoom_view_context$jscomp$2$$.clearRect(0,0,260,140),$zoom_context$jscomp$1_zoom_view_context$jscomp$2$$.drawImage($canvas$jscomp$26$$,$canvas_x_sx$jscomp$13_viewport_node$jscomp$3$$,$canvas_y_client_x$jscomp$4_sy$jscomp$12_vec__81354$$,
65,35,0,0,260,140)}return null};
$app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_wasm_STAR_$$=function($handle_pointer_down_picker$jscomp$1_props_81363$$){var $viewport_node$jscomp$5$$=$APP.$rumext$v2$ref_val$$($handle_pointer_down_picker$jscomp$1_props_81363$$.viewportRef),$canvas$jscomp$28$$=$APP.$rumext$v2$ref_val$$($handle_pointer_down_picker$jscomp$1_props_81363$$.canvasRef),$zoom_view_context$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(null),$initial_mouse_pos$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(new $APP.$cljs$core$PersistentArrayMap$$(null,2,
[$APP.$cljs$cst$1515$x$$,0,$APP.$cljs$cst$1516$y$$,0],null)),$update_str$jscomp$1$$=$APP.$beicon$v2$core$subject$$(),$handle_keydown$jscomp$4$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$724$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$724$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$724$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$724$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$stop_picker$$()),
$APP.$app$main$data$modal$disallow_click_outside_BANG_$$()):null});$handle_pointer_down_picker$jscomp$1_props_81363$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$5$$),$APP.$rumext$v2$adapt$$($canvas$jscomp$28$$)],function($event$jscomp$725$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$725$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$725$$);a:{if($APP.$cljs$core$truth_$$($canvas$jscomp$28$$)){var $canvas_y$jscomp$inline_9488_vec__81358$jscomp$inline_9486$$=
$app$main$ui$workspace$viewport$pixel_overlay$viewport__GT_canvas_coords$$($viewport_node$jscomp$5$$,$event$jscomp$725$$.clientX,$event$jscomp$725$$.clientY);var $canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($canvas_y$jscomp$inline_9488_vec__81358$jscomp$inline_9486$$,0,null);$canvas_y$jscomp$inline_9488_vec__81358$jscomp$inline_9486$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($canvas_y$jscomp$inline_9488_vec__81358$jscomp$inline_9486$$,
1,null);var $ctx$jscomp$inline_9491_img_width$jscomp$inline_9489$$=$canvas$jscomp$28$$.width,$img_height$jscomp$inline_9490$$=$canvas$jscomp$28$$.height;if($canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$>=0&&$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$<$ctx$jscomp$inline_9491_img_width$jscomp$inline_9489$$&&$canvas_y$jscomp$inline_9488_vec__81358$jscomp$inline_9486$$>=0&&$canvas_y$jscomp$inline_9488_vec__81358$jscomp$inline_9486$$<$img_height$jscomp$inline_9490$$){$ctx$jscomp$inline_9491_img_width$jscomp$inline_9489$$=
$app$main$ui$workspace$viewport$pixel_overlay$get_pick_canvas$$().getContext("2d",{willReadFrequently:!0});$ctx$jscomp$inline_9491_img_width$jscomp$inline_9489$$.clearRect(0,0,1,1);$ctx$jscomp$inline_9491_img_width$jscomp$inline_9489$$.drawImage($canvas$jscomp$28$$,$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$,$canvas_y$jscomp$inline_9488_vec__81358$jscomp$inline_9486$$,1,1,0,0,1,1);$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$=$ctx$jscomp$inline_9491_img_width$jscomp$inline_9489$$.getImageData(0,
0,1,1).data;$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$[0],$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$[1],$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$[2],$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$[3]],null);break a}}$canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$=
null}return $canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$6020$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$pick_color$$($canvas_x$jscomp$inline_9487_color$jscomp$197_data$jscomp$inline_9492$$),$app$main$data$workspace$colors$pick_color_select$$($event$jscomp$725$$.shiftKey)])):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($cljs$cst$6020$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$pick_color_select$$($event$jscomp$725$$.shiftKey)]))});var $handle_pointer_up_picker$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$726$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$726$$);
$APP.$app$util$dom$stop_propagation$$($event$jscomp$726$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($cljs$cst$6020$mouse_down_picker$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$stop_picker$$()]));return $APP.$app$main$data$modal$disallow_click_outside_BANG_$$()}),$handle_draw_picker_canvas$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){if($APP.$cljs$core$truth_$$($canvas$jscomp$28$$)){var $map__81366__$1_my$jscomp$3$$=
$APP.$cljs$core$__destructure_map$$($APP.$rumext$v2$ref_val$$($initial_mouse_pos$jscomp$1$$)),$mx$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81366__$1_my$jscomp$3$$,$APP.$cljs$cst$1515$x$$);$map__81366__$1_my$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81366__$1_my$jscomp$3$$,$APP.$cljs$cst$1516$y$$);return $app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move_wasm$$($viewport_node$jscomp$5$$,$canvas$jscomp$28$$,$zoom_view_context$jscomp$3$$,
$mx$jscomp$3$$,$map__81366__$1_my$jscomp$3$$)}return null}),$handle_canvas_changed$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $update_str$jscomp$1$$.next($cljs$cst$6015$update$$)}),$handle_mouse_enter$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$5$$)],function($event$jscomp$727$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($initial_mouse_pos$jscomp$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1515$x$$,$event$jscomp$727$$.clientX,$APP.$cljs$cst$1516$y$$,$event$jscomp$727$$.clientY],null))}),$handle_pointer_move_picker$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($viewport_node$jscomp$5$$)],function($event$jscomp$728$$){return $app$main$ui$workspace$viewport$pixel_overlay$process_pointer_move_wasm$$($viewport_node$jscomp$5$$,$canvas$jscomp$28$$,$zoom_view_context$jscomp$3$$,$event$jscomp$728$$.clientX,$event$jscomp$728$$.clientY)});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $temp__5825__auto__$jscomp$455$$=$APP.$goog$dom$getElement$$("pixel-overlay");return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$455$$)?$temp__5825__auto__$jscomp$455$$.focus():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $listener$jscomp$112$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"keydown",$handle_keydown$jscomp$4$$);return function(){return $APP.$goog$events$unlistenByKey$$($listener$jscomp$112$$)}});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $sub$jscomp$29$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_draw_picker_canvas$jscomp$1$$,$APP.$beicon$v2$core$debounce$$(10,$update_str$jscomp$1$$));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$29$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){$handle_canvas_changed$$.$cljs$core$IFn$_invoke$arity$0$?$handle_canvas_changed$$.$cljs$core$IFn$_invoke$arity$0$():
$handle_canvas_changed$$();$APP.$app$util$globals$document$$.addEventListener("penpot:wasm:render",$handle_canvas_changed$$);return function(){return $APP.$app$util$globals$document$$.removeEventListener("penpot:wasm:render",$handle_canvas_changed$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $listener$jscomp$113$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"pointermove",function($e$jscomp$391$$){return $APP.$rumext$v2$set_ref_val_BANG_$$($initial_mouse_pos$jscomp$1$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1515$x$$,$e$jscomp$391$$.clientX,$APP.$cljs$cst$1516$y$$,$e$jscomp$391$$.clientY],null))});return function(){return $APP.$goog$events$unlistenByKey$$($listener$jscomp$113$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{id:"pixel-overlay",tabIndex:0,onPointerDown:$handle_pointer_down_picker$jscomp$1_props_81363$$,onPointerUp:$handle_pointer_up_picker$jscomp$1$$,onPointerMove:$handle_pointer_move_picker$jscomp$1$$,onMouseEnter:$handle_mouse_enter$jscomp$1$$,
className:""+($APP.$app$main$ui$css_cursors$get_static$$("picker")??"")+" main_ui_workspace_viewport_pixel_overlay__pixel-overlay"})};
$app$main$ui$workspace$viewport$presence$active_cursors$$=function($props_81345_sessions$jscomp$1_sessions__$1$$){var $page_id$jscomp$456$$=$props_81345_sessions$jscomp$1_sessions__$1$$["page-id"],$counter$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(0),$profiles$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$);$props_81345_sessions$jscomp$1_sessions__$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_presence$$);var $zoom$jscomp$149$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$);
$props_81345_sessions$jscomp$1_sessions__$1$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81344_SHARP_$$){return 5E3>=$APP.$cljs$core$inst_ms_STAR_$$($APP.$app$common$time$now$$())-$APP.$cljs$core$inst_ms$$($APP.$cljs$cst$3463$updated_at$$.$cljs$core$IFn$_invoke$arity$1$($p1__81344_SHARP_$$))},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81343_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($page_id$jscomp$456$$,$APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__81343_SHARP_$$))},
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2171$point$$,$APP.$cljs$core$vals$$($props_81345_sessions$jscomp$1_sessions__$1$$))));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$(null,function(){var $sem$jscomp$10$$=$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(1E3,function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($counter$jscomp$6$$,$APP.$cljs$core$inc$$)});return function(){return $APP.$beicon$v2$core$_dispose$$($sem$jscomp$10$$)}});
return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$236$$,$session$jscomp$6$$){$out_arr__44092__auto__$jscomp$236$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$presence$session_cursor$$,{session:$session$jscomp$6$$,zoom:$zoom$jscomp$149$$,profile:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profiles$jscomp$6$$,$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$6$$))},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$6$$)??
"")));return $out_arr__44092__auto__$jscomp$236$$},[],$props_81345_sessions$jscomp$1_sessions__$1$$)};
$app$main$ui$workspace$viewport$selection$selection_rect$$=function($on_move_selected$jscomp$6_props_81391$$){var $rect$jscomp$49_x__$1$jscomp$31$$=$on_move_selected$jscomp$6_props_81391$$.rect,$zoom$jscomp$151$$=$on_move_selected$jscomp$6_props_81391$$.zoom,$transform$jscomp$119$$=$on_move_selected$jscomp$6_props_81391$$.transform,$color$jscomp$198$$=$on_move_selected$jscomp$6_props_81391$$.color,$on_context_menu$jscomp$23$$=$on_move_selected$jscomp$6_props_81391$$["on-context-menu"];$on_move_selected$jscomp$6_props_81391$$=
$on_move_selected$jscomp$6_props_81391$$["on-move-selected"];var $x$jscomp$1295$$=$rect$jscomp$49_x__$1$jscomp$31$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$49_x__$1$jscomp$31$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$518$$=$rect$jscomp$49_x__$1$jscomp$31$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$49_x__$1$jscomp$31$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$250$$=$rect$jscomp$49_x__$1$jscomp$31$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$49_x__$1$jscomp$31$$,
$APP.$cljs$cst$290$width$$),$height$jscomp$216$$=$rect$jscomp$49_x__$1$jscomp$31$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($rect$jscomp$49_x__$1$jscomp$31$$,$APP.$cljs$cst$1527$height$$),$vec__81392_vec__81395$$=$width$jscomp$250$$<10/$zoom$jscomp$151$$?function(){var $width_SINGLEQUOTE_$jscomp$2$$=10/$zoom$jscomp$151$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$x$jscomp$1295$$-($width_SINGLEQUOTE_$jscomp$2$$-$width$jscomp$250$$)/
2,$width_SINGLEQUOTE_$jscomp$2$$],null)}():new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$x$jscomp$1295$$,$width$jscomp$250$$],null);$rect$jscomp$49_x__$1$jscomp$31$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81392_vec__81395$$,0,null);var $width__$1$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81392_vec__81395$$,1,null);$vec__81392_vec__81395$$=$height$jscomp$216$$<10/$zoom$jscomp$151$$?function(){var $height_SINGLEQUOTE_$jscomp$2$$=
10/$zoom$jscomp$151$$;return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$y$jscomp$518$$-($height_SINGLEQUOTE_$jscomp$2$$-$height$jscomp$216$$)/2,$height_SINGLEQUOTE_$jscomp$2$$],null)}():new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$y$jscomp$518$$,$height$jscomp$216$$],null);var $y__$1$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81392_vec__81395$$,0,null),$height__$1$jscomp$8$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81392_vec__81395$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("rect",{width:function(){var $y__5111__auto__$jscomp$189$$=10/$zoom$jscomp$151$$;return $width__$1$jscomp$12$$>$y__5111__auto__$jscomp$189$$?$width__$1$jscomp$12$$:$y__5111__auto__$jscomp$189$$}(),height:function(){var $y__5111__auto__$jscomp$190$$=10/$zoom$jscomp$151$$;return $height__$1$jscomp$8$$>$y__5111__auto__$jscomp$190$$?$height__$1$jscomp$8$$:$y__5111__auto__$jscomp$190$$}(),
className:"main viewport-selrect",x:$rect$jscomp$49_x__$1$jscomp$31$$,transform:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($transform$jscomp$119$$),onContextMenu:$on_context_menu$jscomp$23$$,style:{stroke:$color$jscomp$198$$,strokeWidth:1/$zoom$jscomp$151$$,fill:"none"},y:$y__$1$jscomp$4$$,onPointerDown:$on_move_selected$jscomp$6_props_81391$$})};
$app$main$ui$workspace$viewport$selection$calculate_handlers$$=function($height$jscomp$217_selection$jscomp$16$$,$path_QMARK_$jscomp$8_shape$jscomp$1099$$,$small_width_QMARK__zoom$jscomp$152$$){var $JSCompiler_temp$jscomp$1502_x$jscomp$1296$$=$height$jscomp$217_selection$jscomp$16$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$217_selection$jscomp$16$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$519$$=$height$jscomp$217_selection$jscomp$16$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$217_selection$jscomp$16$$,
$APP.$cljs$cst$1516$y$$),$width$jscomp$251$$=$height$jscomp$217_selection$jscomp$16$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$217_selection$jscomp$16$$,$APP.$cljs$cst$290$width$$);$height$jscomp$217_selection$jscomp$16$$=$height$jscomp$217_selection$jscomp$16$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$217_selection$jscomp$16$$,$APP.$cljs$cst$1527$height$$);var $threshold_small$$=25/$small_width_QMARK__zoom$jscomp$152$$,$threshold_tiny_tiny_height_QMARK_$$=
10/$small_width_QMARK__zoom$jscomp$152$$;$small_width_QMARK__zoom$jscomp$152$$=$width$jscomp$251$$<=$threshold_small$$;var $tiny_width_QMARK_$$=$width$jscomp$251$$<=$threshold_tiny_tiny_height_QMARK_$$,$small_height_QMARK_$$=$height$jscomp$217_selection$jscomp$16$$<=$threshold_small$$;$threshold_tiny_tiny_height_QMARK_$$=$height$jscomp$217_selection$jscomp$16$$<=$threshold_tiny_tiny_height_QMARK_$$;var $vertical_line_QMARK_$jscomp$1$$=($path_QMARK_$jscomp$8_shape$jscomp$1099$$=$APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($path_QMARK_$jscomp$8_shape$jscomp$1099$$))&&
$tiny_width_QMARK_$$,$align$jscomp$6$$=$small_width_QMARK__zoom$jscomp$152$$||$small_height_QMARK_$$?$cljs$cst$6021$outside$$:$cljs$cst$6022$inside$$,$result$jscomp$389$$=[{type:$APP.$cljs$cst$1794$rotation$$,position:$APP.$cljs$cst$1891$top_left$$,props:{cx:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$,cy:$y$jscomp$519$$}},{type:$APP.$cljs$cst$1794$rotation$$,position:$APP.$cljs$cst$1892$top_right$$,props:{cx:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$+$width$jscomp$251$$,cy:$y$jscomp$519$$}},{type:$APP.$cljs$cst$1794$rotation$$,
position:$APP.$cljs$cst$1893$bottom_right$$,props:{cx:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$+$width$jscomp$251$$,cy:$y$jscomp$519$$+$height$jscomp$217_selection$jscomp$16$$}},{type:$APP.$cljs$cst$1794$rotation$$,position:$APP.$cljs$cst$1894$bottom_left$$,props:{cx:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$,cy:$y$jscomp$519$$+$height$jscomp$217_selection$jscomp$16$$}}];$path_QMARK_$jscomp$8_shape$jscomp$1099$$&&$threshold_tiny_tiny_height_QMARK_$$||$result$jscomp$389$$.push({type:$cljs$cst$6023$resize_side$$,
position:$APP.$cljs$cst$1567$top$$,props:{x:$small_width_QMARK__zoom$jscomp$152$$?$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$+($width$jscomp$251$$-$threshold_small$$)/2:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$,y:$y$jscomp$519$$,length:$small_width_QMARK__zoom$jscomp$152$$?$threshold_small$$:$width$jscomp$251$$,angle:0,align:$align$jscomp$6$$,"show-handler":$tiny_width_QMARK_$$}},{type:$cljs$cst$6023$resize_side$$,position:$APP.$cljs$cst$1568$bottom$$,props:{x:$small_width_QMARK__zoom$jscomp$152$$?
$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$+($width$jscomp$251$$+$threshold_small$$)/2:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$+$width$jscomp$251$$,y:$y$jscomp$519$$+$height$jscomp$217_selection$jscomp$16$$,length:$small_width_QMARK__zoom$jscomp$152$$?$threshold_small$$:$width$jscomp$251$$,angle:180,align:$align$jscomp$6$$,"show-handler":$tiny_width_QMARK_$$}});$vertical_line_QMARK_$jscomp$1$$||$result$jscomp$389$$.push({type:$cljs$cst$6023$resize_side$$,position:$APP.$cljs$cst$258$right$$,props:{x:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$+
$width$jscomp$251$$,y:$small_height_QMARK_$$?$y$jscomp$519$$+($height$jscomp$217_selection$jscomp$16$$-$threshold_small$$)/2:$y$jscomp$519$$,length:$small_height_QMARK_$$?$threshold_small$$:$height$jscomp$217_selection$jscomp$16$$,angle:90,align:$align$jscomp$6$$,"show-handler":$threshold_tiny_tiny_height_QMARK_$$}},{type:$cljs$cst$6023$resize_side$$,position:$APP.$cljs$cst$257$left$$,props:{x:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$,y:$small_height_QMARK_$$?$y$jscomp$519$$+($height$jscomp$217_selection$jscomp$16$$+
$threshold_small$$)/2:$y$jscomp$519$$+$height$jscomp$217_selection$jscomp$16$$,length:$small_height_QMARK_$$?$threshold_small$$:$height$jscomp$217_selection$jscomp$16$$,angle:270,align:$align$jscomp$6$$,"show-handler":$threshold_tiny_tiny_height_QMARK_$$}});$tiny_width_QMARK_$$||$threshold_tiny_tiny_height_QMARK_$$?$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$=null:($result$jscomp$389$$.push({type:$cljs$cst$6024$resize_point$$,position:$APP.$cljs$cst$1891$top_left$$,props:{cx:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$,
cy:$y$jscomp$519$$,align:$align$jscomp$6$$}},{type:$cljs$cst$6024$resize_point$$,position:$APP.$cljs$cst$1892$top_right$$,props:{cx:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$+$width$jscomp$251$$,cy:$y$jscomp$519$$,align:$align$jscomp$6$$}},{type:$cljs$cst$6024$resize_point$$,position:$APP.$cljs$cst$1893$bottom_right$$,props:{cx:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$+$width$jscomp$251$$,cy:$y$jscomp$519$$+$height$jscomp$217_selection$jscomp$16$$,align:$align$jscomp$6$$}},{type:$cljs$cst$6024$resize_point$$,
position:$APP.$cljs$cst$1894$bottom_left$$,props:{cx:$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$,cy:$y$jscomp$519$$+$height$jscomp$217_selection$jscomp$16$$,align:$align$jscomp$6$$}}),$JSCompiler_temp$jscomp$1502_x$jscomp$1296$$=$result$jscomp$389$$);return $JSCompiler_temp$jscomp$1502_x$jscomp$1296$$};
$app$main$ui$workspace$viewport$selection$rotation_handler$$=function($props_81400_size$jscomp$168$$){var $on_rotate$$=$props_81400_size$jscomp$168$$["on-rotate"],$transform$jscomp$120$$=$props_81400_size$jscomp$168$$.transform,$rotation$jscomp$24$$=$props_81400_size$jscomp$168$$.rotation,$cx$jscomp$22_x$jscomp$1297$$=$props_81400_size$jscomp$168$$.cx,$cy$jscomp$23_y$jscomp$520$$=$props_81400_size$jscomp$168$$.cy,$position$jscomp$244$$=$props_81400_size$jscomp$168$$.position;$props_81400_size$jscomp$168$$=
20/$props_81400_size$jscomp$168$$.zoom;var $delta_x$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$244$$,$APP.$cljs$cst$1891$top_left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$244$$,$APP.$cljs$cst$1894$bottom_left$$)?$props_81400_size$jscomp$168$$:0,$angle$jscomp$42_delta_y$jscomp$5$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1891$top_left$$,$position$jscomp$244$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1892$top_right$$,
$position$jscomp$244$$)?$props_81400_size$jscomp$168$$:0;$cx$jscomp$22_x$jscomp$1297$$-=$delta_x$jscomp$7$$;$cy$jscomp$23_y$jscomp$520$$-=$angle$jscomp$42_delta_y$jscomp$5$$;$angle$jscomp$42_delta_y$jscomp$5$$=function(){var $G__81401__$1$$=$position$jscomp$244$$ instanceof $APP.$cljs$core$Keyword$$?$position$jscomp$244$$.$fqn$:null;switch($G__81401__$1$$){case "top-left":return 0;case "top-right":return 90;case "bottom-right":return 180;case "bottom-left":return 270;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__81401__$1$$)].join(""));}}();return(0,$APP.$rumext$v2$jsx$$)("rect",{width:$props_81400_size$jscomp$168$$,height:$props_81400_size$jscomp$168$$,className:$app$main$ui$css_cursors$get_dynamic$$("rotate",$rotation$jscomp$24$$+$angle$jscomp$42_delta_y$jscomp$5$$),x:$cx$jscomp$22_x$jscomp$1297$$,transform:""+($transform$jscomp$120$$??""),fill:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$1304$handlers$$)?"blue":"none",strokeWidth:0,y:$cy$jscomp$23_y$jscomp$520$$,
onPointerDown:$on_rotate$$})};
$app$main$ui$workspace$viewport$selection$resize_point_handler$$=function($position$jscomp$245_props_81402$$){var $JSCompiler_temp$jscomp$1965_on_resize$jscomp$1$$=$position$jscomp$245_props_81402$$["on-resize"],$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9508$$=$position$jscomp$245_props_81402$$.align,$offset_x$jscomp$inline_9509_zoom$jscomp$154$$=$position$jscomp$245_props_81402$$.zoom,$cx_SINGLEQUOTE___$1$jscomp$inline_9512_transform$jscomp$121$$=$position$jscomp$245_props_81402$$.transform,$rotation$jscomp$25$$=
$position$jscomp$245_props_81402$$.rotation,$cursor$jscomp$11_scale_text$jscomp$1$$=$position$jscomp$245_props_81402$$["scale-text"],$JSCompiler_temp_const$jscomp$1964_color$jscomp$199$$=$position$jscomp$245_props_81402$$.color,$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$=$position$jscomp$245_props_81402$$.cx,$cy$jscomp$24$$=$position$jscomp$245_props_81402$$.cy;$position$jscomp$245_props_81402$$=$position$jscomp$245_props_81402$$.position;$cursor$jscomp$11_scale_text$jscomp$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$245_props_81402$$,$APP.$cljs$cst$1891$top_left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$245_props_81402$$,$APP.$cljs$cst$1893$bottom_right$$)?$cursor$jscomp$11_scale_text$jscomp$1$$?$app$main$ui$css_cursors$get_dynamic$$("scale-nesw",$rotation$jscomp$25$$):$app$main$ui$css_cursors$get_dynamic$$("resize-nesw",$rotation$jscomp$25$$):$cursor$jscomp$11_scale_text$jscomp$1$$?$app$main$ui$css_cursors$get_dynamic$$("scale-nwse",
$rotation$jscomp$25$$):$app$main$ui$css_cursors$get_dynamic$$("resize-nwse",$rotation$jscomp$25$$);var $cy_SINGLEQUOTE__pt$jscomp$38$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$,$cy$jscomp$24$$),$cx_SINGLEQUOTE___$1$jscomp$inline_9512_transform$jscomp$121$$),$cx_SINGLEQUOTE__offset_y$jscomp$inline_9510$$=$cy_SINGLEQUOTE__pt$jscomp$38$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cy_SINGLEQUOTE__pt$jscomp$38$$,
$APP.$cljs$cst$1515$x$$);$cy_SINGLEQUOTE__pt$jscomp$38$$=$cy_SINGLEQUOTE__pt$jscomp$38$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cy_SINGLEQUOTE__pt$jscomp$38$$,$APP.$cljs$cst$1516$y$$);$JSCompiler_temp_const$jscomp$1964_color$jscomp$199$$=(0,$APP.$rumext$v2$jsx$$)("circle",{r:4/$offset_x$jscomp$inline_9509_zoom$jscomp$154$$,style:{fillOpacity:"1",strokeWidth:"1px",vectorEffect:"non-scaling-stroke"},fill:"var(--app-white)",stroke:$JSCompiler_temp_const$jscomp$1964_color$jscomp$199$$,
cx:$cx_SINGLEQUOTE__offset_y$jscomp$inline_9510$$,cy:$cy_SINGLEQUOTE__pt$jscomp$38$$});$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align$jscomp$7_resize_point_circle_radius$jscomp$inline_9508$$,$cljs$cst$6021$outside$$)?($align$jscomp$7_resize_point_circle_radius$jscomp$inline_9508$$=10/$offset_x$jscomp$inline_9509_zoom$jscomp$154$$,$offset_x$jscomp$inline_9509_zoom$jscomp$154$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$245_props_81402$$,$APP.$cljs$cst$1892$top_right$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$245_props_81402$$,$APP.$cljs$cst$1893$bottom_right$$)?0:-$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9508$$,$cx_SINGLEQUOTE__offset_y$jscomp$inline_9510$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$245_props_81402$$,$APP.$cljs$cst$1894$bottom_left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$245_props_81402$$,$APP.$cljs$cst$1893$bottom_right$$)?0:-$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9508$$,
$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$=$APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$+$offset_x$jscomp$inline_9509_zoom$jscomp$154$$,$cy$jscomp$24$$+$cx_SINGLEQUOTE__offset_y$jscomp$inline_9510$$),$cx_SINGLEQUOTE___$1$jscomp$inline_9512_transform$jscomp$121$$),$cx_SINGLEQUOTE___$1$jscomp$inline_9512_transform$jscomp$121$$=
$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$,$APP.$cljs$cst$1515$x$$),$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$=$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$,
$APP.$cljs$cst$1516$y$$),$JSCompiler_temp$jscomp$1965_on_resize$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)("rect",{width:$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9508$$,height:$align$jscomp$7_resize_point_circle_radius$jscomp$inline_9508$$,className:$cursor$jscomp$11_scale_text$jscomp$1$$,x:$cx_SINGLEQUOTE___$1$jscomp$inline_9512_transform$jscomp$121$$,transform:$rotation$jscomp$25$$!=null?"rotate("+($rotation$jscomp$25$$??"")+", "+($cx_SINGLEQUOTE___$1$jscomp$inline_9512_transform$jscomp$121$$??
"")+", "+($cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$??"")+")":null,style:{fill:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$1304$handlers$$)?"red":"none",strokeWidth:0},"data-position":$APP.$cljs$core$name$$($position$jscomp$245_props_81402$$),y:$cx$jscomp$23_cy_SINGLEQUOTE___$1$jscomp$inline_9513_pt__$1$jscomp$inline_9511$$,onPointerDown:$JSCompiler_temp$jscomp$1965_on_resize$jscomp$1$$})):$JSCompiler_temp$jscomp$1965_on_resize$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)("circle",
{"data-x":$cx_SINGLEQUOTE__offset_y$jscomp$inline_9510$$,cy:$cy_SINGLEQUOTE__pt$jscomp$38$$,className:$cursor$jscomp$11_scale_text$jscomp$1$$,style:{fill:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$1304$handlers$$)?"red":"none",strokeWidth:0},"data-position":$APP.$cljs$core$name$$($position$jscomp$245_props_81402$$),"data-y":$cy_SINGLEQUOTE__pt$jscomp$38$$,r:10/$offset_x$jscomp$inline_9509_zoom$jscomp$154$$,onPointerDown:$JSCompiler_temp$jscomp$1965_on_resize$jscomp$1$$,cx:$cx_SINGLEQUOTE__offset_y$jscomp$inline_9510$$});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"resize-handler",children:[$JSCompiler_temp_const$jscomp$1964_color$jscomp$199$$,$JSCompiler_temp$jscomp$1965_on_resize$jscomp$1$$]})};
$app$main$ui$workspace$viewport$selection$resize_side_handler$$=function($offset_y$jscomp$19_props_81405_target_y$$){var $x$jscomp$1298$$=$offset_y$jscomp$19_props_81405_target_y$$.x,$on_resize$jscomp$2$$=$offset_y$jscomp$19_props_81405_target_y$$["on-resize"],$y$jscomp$521$$=$offset_y$jscomp$19_props_81405_target_y$$.y,$zoom$jscomp$155$$=$offset_y$jscomp$19_props_81405_target_y$$.zoom,$shape_type$jscomp$9$$=$offset_y$jscomp$19_props_81405_target_y$$["shape-type"],$show_handler$$=$offset_y$jscomp$19_props_81405_target_y$$["show-handler"],
$transform$jscomp$122_transform_str$jscomp$1$$=$offset_y$jscomp$19_props_81405_target_y$$.transform,$cursor$jscomp$12_rotation$jscomp$26$$=$offset_y$jscomp$19_props_81405_target_y$$.rotation,$on_double_click$jscomp$7_scale_text$jscomp$2$$=$offset_y$jscomp$19_props_81405_target_y$$["scale-text"],$color$jscomp$200$$=$offset_y$jscomp$19_props_81405_target_y$$.color,$angle$jscomp$43$$=$offset_y$jscomp$19_props_81405_target_y$$.angle,$shape_id$jscomp$181$$=$offset_y$jscomp$19_props_81405_target_y$$["shape-id"],
$length$jscomp$62$$=$offset_y$jscomp$19_props_81405_target_y$$.length,$position$jscomp$246$$=$offset_y$jscomp$19_props_81405_target_y$$.position,$height$jscomp$218$$=8/$zoom$jscomp$155$$;$offset_y$jscomp$19_props_81405_target_y$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset_y$jscomp$19_props_81405_target_y$$.align,$cljs$cst$6021$outside$$)?-$height$jscomp$218$$:-($height$jscomp$218$$/2);$offset_y$jscomp$19_props_81405_target_y$$=$y$jscomp$521$$+$offset_y$jscomp$19_props_81405_target_y$$;
$transform$jscomp$122_transform_str$jscomp$1$$=""+($APP.$app$common$geom$matrix$multiply$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$122_transform_str$jscomp$1$$,$APP.$app$common$geom$matrix$rotate_matrix$$.$cljs$core$IFn$_invoke$arity$2$($angle$jscomp$43$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1298$$,$y$jscomp$521$$)))??"");$cursor$jscomp$12_rotation$jscomp$26$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$246$$,$APP.$cljs$cst$257$left$$)||
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$246$$,$APP.$cljs$cst$258$right$$)?$on_double_click$jscomp$7_scale_text$jscomp$2$$?$app$main$ui$css_cursors$get_dynamic$$("scale-ew",$cursor$jscomp$12_rotation$jscomp$26$$):$app$main$ui$css_cursors$get_dynamic$$("resize-ew",$cursor$jscomp$12_rotation$jscomp$26$$):$on_double_click$jscomp$7_scale_text$jscomp$2$$?$app$main$ui$css_cursors$get_dynamic$$("scale-ns",$cursor$jscomp$12_rotation$jscomp$26$$):$app$main$ui$css_cursors$get_dynamic$$("resize-ns",
$cursor$jscomp$12_rotation$jscomp$26$$);$on_double_click$jscomp$7_scale_text$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$181$$),$APP.$rumext$v2$adapt$$($position$jscomp$246$$),$APP.$rumext$v2$adapt$$($shape_type$jscomp$9$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$9$$,$APP.$cljs$cst$1593$text$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$246$$,$APP.$cljs$cst$258$right$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$181$$],null),function($p1__81403_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__81403_SHARP_$$,$APP.$cljs$cst$1776$grow_type$$,$APP.$cljs$cst$2046$auto_width$$)})):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$246$$,
$APP.$cljs$cst$1568$bottom$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$181$$],null),function($p1__81404_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__81404_SHARP_$$,$APP.$cljs$cst$1776$grow_type$$,$APP.$cljs$cst$2045$auto_height$$)})):null:null});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"resize-handler",children:[$show_handler$$?(0,$APP.$rumext$v2$jsx$$)("circle",{r:4/$zoom$jscomp$155$$,style:{fillOpacity:1,stroke:$color$jscomp$200$$,strokeWidth:"1px",fill:"var(--app-white)",vectorEffect:"non-scaling-stroke"},"data-position":$APP.$cljs$core$name$$($position$jscomp$246$$),cx:$x$jscomp$1298$$+$length$jscomp$62$$/2,cy:$y$jscomp$521$$,transform:$transform$jscomp$122_transform_str$jscomp$1$$}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{onDoubleClick:$on_double_click$jscomp$7_scale_text$jscomp$2$$,
width:$length$jscomp$62$$,height:$height$jscomp$218$$,className:$cursor$jscomp$12_rotation$jscomp$26$$,x:$x$jscomp$1298$$,transform:$transform$jscomp$122_transform_str$jscomp$1$$,style:{fill:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$1304$handlers$$)?"yellow":"none",strokeWidth:0},"data-position":$APP.$cljs$core$name$$($position$jscomp$246$$),y:$offset_y$jscomp$19_props_81405_target_y$$,onPointerDown:$on_resize$jscomp$2$$})]})};
$app$main$ui$workspace$viewport$selection$controls_selection_STAR_$$=function($props_81406_transform_type$$){var $zoom$jscomp$156$$=$props_81406_transform_type$$.zoom,$color$jscomp$201$$=$props_81406_transform_type$$.color,$disabled$jscomp$21$$=$props_81406_transform_type$$.disabled,$on_context_menu$jscomp$24$$=$props_81406_transform_type$$.onContextMenu,$on_move_selected$jscomp$7$$=$props_81406_transform_type$$.onMoveSelected,$selrect$jscomp$91_shape$jscomp$1100$$=$props_81406_transform_type$$.shape,
$selrect_transform$jscomp$4_transform$jscomp$123_vec__81408$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);$props_81406_transform_type$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$current_transform$$);$selrect_transform$jscomp$4_transform$jscomp$123_vec__81408$$=$app$main$data$helpers$get_selrect$$($selrect_transform$jscomp$4_transform$jscomp$123_vec__81408$$,$selrect$jscomp$91_shape$jscomp$1100$$);$selrect$jscomp$91_shape$jscomp$1100$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($selrect_transform$jscomp$4_transform$jscomp$123_vec__81408$$,
0,null);$selrect_transform$jscomp$4_transform$jscomp$123_vec__81408$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($selrect_transform$jscomp$4_transform$jscomp$123_vec__81408$$,1,null);return $selrect$jscomp$91_shape$jscomp$1100$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_81406_transform_type$$,$APP.$cljs$cst$1804$move$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_81406_transform_type$$,$APP.$cljs$cst$2874$rotate$$)?null:(0,$APP.$rumext$v2$jsx$$)("g",
{className:"controls",pointerEvents:$disabled$jscomp$21$$?"none":"visible",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$selection_rect$$,{rect:$selrect$jscomp$91_shape$jscomp$1100$$,transform:$selrect_transform$jscomp$4_transform$jscomp$123_vec__81408$$,zoom:$zoom$jscomp$156$$,color:$color$jscomp$201$$,"on-move-selected":$on_move_selected$jscomp$7$$,"on-context-menu":$on_context_menu$jscomp$24$$})})};
$app$main$ui$workspace$viewport$selection$controls_handlers_STAR_$$=function($props_81411_transform_type$jscomp$1$$){var $on_resize$jscomp$3$$=$props_81411_transform_type$jscomp$1$$.onResize,$on_rotate$jscomp$1$$=$props_81411_transform_type$jscomp$1$$.onRotate,$zoom$jscomp$157$$=$props_81411_transform_type$jscomp$1$$.zoom,$color$jscomp$202$$=$props_81411_transform_type$jscomp$1$$.color,$disabled$jscomp$22$$=$props_81411_transform_type$jscomp$1$$.disabled,$shape$jscomp$1101$$=$props_81411_transform_type$jscomp$1$$.shape,
$selrect_transform$jscomp$5_vec__81412$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);$props_81411_transform_type$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$current_transform$$);var $read_only_QMARK_$jscomp$36$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$layout$jscomp$31_selrect$jscomp$92$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_layout$$),$scale_text_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$31_selrect$jscomp$92$$,
$APP.$cljs$cst$3765$scale_text$$);$selrect_transform$jscomp$5_vec__81412$$=$app$main$data$helpers$get_selrect$$($selrect_transform$jscomp$5_vec__81412$$,$shape$jscomp$1101$$);$layout$jscomp$31_selrect$jscomp$92$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($selrect_transform$jscomp$5_vec__81412$$,0,null);var $transform$jscomp$124$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($selrect_transform$jscomp$5_vec__81412$$,1,null),$rotation$jscomp$27$$=$APP.$cljs$core$mod$$($APP.$app$common$geom$point$angle$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$geom$point$transform$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$(1,
0),$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1101$$))),360),$flip_x$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1101$$,$APP.$cljs$cst$1887$flip_x$$),$flip_y$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1101$$,$APP.$cljs$cst$1888$flip_y$$),$half_flip_QMARK_$$=function(){var $or__5025__auto__$jscomp$1418$$=$APP.$cljs$core$truth_$$($flip_x$jscomp$10$$)?$APP.$cljs$core$not$$($flip_y$jscomp$10$$):
$flip_x$jscomp$10$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1418$$)?$or__5025__auto__$jscomp$1418$$:$APP.$cljs$core$truth_$$($flip_y$jscomp$10$$)?$APP.$cljs$core$not$$($flip_x$jscomp$10$$):$flip_y$jscomp$10$$}();return $read_only_QMARK_$jscomp$36$$||!$APP.$cljs$core$not$$($APP.$cljs$cst$1628$blocked$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1101$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_81411_transform_type$jscomp$1$$,$APP.$cljs$cst$1804$move$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_81411_transform_type$jscomp$1$$,
$APP.$cljs$cst$2874$rotate$$)?null:(0,$APP.$rumext$v2$jsx$$)("g",{className:"controls",pointerEvents:$disabled$jscomp$22$$?"none":"visible",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$237$$,$handler$jscomp$51$$){$out_arr__44092__auto__$jscomp$237$$.push(function(){var $G__81436__$1_type$jscomp$725$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handler$jscomp$51$$,"type"),$position$jscomp$247_props__$1$jscomp$103$$=
$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handler$jscomp$51$$,"position"),$props$jscomp$398$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handler$jscomp$51$$,"props"),$rotation__$1$jscomp$1$$=$half_flip_QMARK_$$&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$247_props__$1$jscomp$103$$,$APP.$cljs$cst$1891$top_left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$247_props__$1$jscomp$103$$,$APP.$cljs$cst$1893$bottom_right$$))?
$rotation$jscomp$27$$-90:$half_flip_QMARK_$$&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$247_props__$1$jscomp$103$$,$APP.$cljs$cst$1892$top_right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($position$jscomp$247_props__$1$jscomp$103$$,$APP.$cljs$cst$1894$bottom_left$$))?$rotation$jscomp$27$$+90:$rotation$jscomp$27$$;$position$jscomp$247_props__$1$jscomp$103$$=$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$({zoom:$zoom$jscomp$157$$,"shape-type":$shape$jscomp$1101$$?.type??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1101$$,$APP.$cljs$cst$139$type$$),transform:$transform$jscomp$124$$,rotation:$rotation__$1$jscomp$1$$,"scale-text":$scale_text_QMARK_$$,color:$color$jscomp$202$$,key:""+($APP.$cljs$core$name$$($G__81436__$1_type$jscomp$725$$)??"")+"-"+($APP.$cljs$core$name$$($position$jscomp$247_props__$1$jscomp$103$$)??""),"shape-id":$shape$jscomp$1101$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1101$$,$APP.$cljs$cst$266$id$$),
position:$position$jscomp$247_props__$1$jscomp$103$$,"on-resize":$on_resize$jscomp$3$$,"on-rotate":$on_rotate$jscomp$1$$},$props$jscomp$398$$);$G__81436__$1_type$jscomp$725$$=$G__81436__$1_type$jscomp$725$$ instanceof $APP.$cljs$core$Keyword$$?$G__81436__$1_type$jscomp$725$$.$fqn$:null;switch($G__81436__$1_type$jscomp$725$$){case "rotation":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$selection$rotation_handler$$,$position$jscomp$247_props__$1$jscomp$103$$);case "resize-point":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$selection$resize_point_handler$$,
$position$jscomp$247_props__$1$jscomp$103$$);case "resize-side":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$selection$resize_side_handler$$,$position$jscomp$247_props__$1$jscomp$103$$);default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__81436__$1_type$jscomp$725$$)].join(""));}}());return $out_arr__44092__auto__$jscomp$237$$},[],$app$main$ui$workspace$viewport$selection$calculate_handlers$$($layout$jscomp$31_selrect$jscomp$92$$,
$shape$jscomp$1101$$,$zoom$jscomp$157$$))})};
$app$main$ui$workspace$viewport$selection$text_edition_selection$$=function($props_81451_shape$jscomp$1102$$){var $zoom$jscomp$158$$=$props_81451_shape$jscomp$1102$$.zoom,$color$jscomp$203$$=$props_81451_shape$jscomp$1102$$.color;$props_81451_shape$jscomp$1102$$=$props_81451_shape$jscomp$1102$$.shape;var $x$jscomp$1299$$=$props_81451_shape$jscomp$1102$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_81451_shape$jscomp$1102$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$522$$=$props_81451_shape$jscomp$1102$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_81451_shape$jscomp$1102$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$252$$=$props_81451_shape$jscomp$1102$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_81451_shape$jscomp$1102$$,$APP.$cljs$cst$290$width$$),$height$jscomp$219$$=$props_81451_shape$jscomp$1102$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_81451_shape$jscomp$1102$$,$APP.$cljs$cst$1527$height$$);return(0,$APP.$rumext$v2$jsx$$)("g",
{className:"controls",children:(0,$APP.$rumext$v2$jsx$$)("rect",{className:"main",x:$x$jscomp$1299$$,y:$y$jscomp$522$$,transform:$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($props_81451_shape$jscomp$1102$$),width:$width$jscomp$252$$,height:$height$jscomp$219$$,pointerEvents:"visible",style:{stroke:$color$jscomp$203$$,strokeWidth:.5/$zoom$jscomp$158$$,strokeOpacity:1,fill:"none"}})})};
$app$main$ui$workspace$viewport$selection$multiple_handlers_STAR_$$=function($disabled$jscomp$23_props_81452$$){var $shapes$jscomp$236$$=$disabled$jscomp$23_props_81452$$.shapes,$zoom$jscomp$159$$=$disabled$jscomp$23_props_81452$$.zoom,$selected$jscomp$204$$=$disabled$jscomp$23_props_81452$$.selected,$color$jscomp$204$$=$disabled$jscomp$23_props_81452$$.color;$disabled$jscomp$23_props_81452$$=$disabled$jscomp$23_props_81452$$.disabled;var $shape$jscomp$1103$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$236$$)],
function(){return $APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$236$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1621$multiple$$))}),$on_resize$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected$jscomp$204$$),$APP.$rumext$v2$adapt$$($shape$jscomp$1103$$)],function($event$jscomp$731_position$jscomp$248$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$731_position$jscomp$248$$)?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$731_position$jscomp$248$$),$event$jscomp$731_position$jscomp$248$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$731_position$jscomp$248$$),"position")),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$start_resize$$($event$jscomp$731_position$jscomp$248$$,$selected$jscomp$204$$,$shape$jscomp$1103$$))):
null}),$on_rotate$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$236$$)],function($event$jscomp$732$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$732$$)?($APP.$app$util$dom$stop_propagation$$($event$jscomp$732$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$start_rotate$$($shapes$jscomp$236$$))):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$controls_handlers_STAR_$$,
{shape:$shape$jscomp$1103$$,zoom:$zoom$jscomp$159$$,color:$color$jscomp$204$$,disabled:$disabled$jscomp$23_props_81452$$,onResize:$on_resize$jscomp$4$$,onRotate:$on_rotate$jscomp$2$$})};
$app$main$ui$workspace$viewport$selection$multiple_selection_STAR_$$=function($on_move_selected$jscomp$8_props_81463$$){var $shapes$jscomp$237$$=$on_move_selected$jscomp$8_props_81463$$.shapes,$zoom$jscomp$160$$=$on_move_selected$jscomp$8_props_81463$$.zoom,$color$jscomp$205$$=$on_move_selected$jscomp$8_props_81463$$.color,$disabled$jscomp$24$$=$on_move_selected$jscomp$8_props_81463$$.disabled,$on_context_menu$jscomp$25$$=$on_move_selected$jscomp$8_props_81463$$.onContextMenu;$on_move_selected$jscomp$8_props_81463$$=
$on_move_selected$jscomp$8_props_81463$$.onMoveSelected;var $shape$jscomp$1104$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$237$$)],function(){return $APP.$app$common$types$shape$setup_shape$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$237$$),$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1621$multiple$$))});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$controls_selection_STAR_$$,
{shape:$shape$jscomp$1104$$,zoom:$zoom$jscomp$160$$,color:$color$jscomp$205$$,disabled:$disabled$jscomp$24$$,onMoveSelected:$on_move_selected$jscomp$8_props_81463$$,onContextMenu:$on_context_menu$jscomp$25$$})};
$app$main$ui$workspace$viewport$selection$single_handlers_STAR_$$=function($on_resize$jscomp$5_props_81471$$){var $zoom$jscomp$161$$=$on_resize$jscomp$5_props_81471$$.zoom,$color$jscomp$206$$=$on_resize$jscomp$5_props_81471$$.color,$disabled$jscomp$25$$=$on_resize$jscomp$5_props_81471$$.disabled,$shape$jscomp$1105$$=$on_resize$jscomp$5_props_81471$$.shape,$shape_id$jscomp$182$$=$shape$jscomp$1105$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1105$$,$APP.$cljs$cst$266$id$$),
$grow_type$jscomp$13$$=$shape$jscomp$1105$$?.$grow_type$??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1105$$,$APP.$cljs$cst$1776$grow_type$$),$shape_type$jscomp$10$$=$shape$jscomp$1105$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1105$$,$APP.$cljs$cst$139$type$$);$on_resize$jscomp$5_props_81471$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$182$$),$APP.$rumext$v2$adapt$$($shape$jscomp$1105$$),
$APP.$rumext$v2$adapt$$($grow_type$jscomp$13$$),$APP.$rumext$v2$adapt$$($shape_type$jscomp$10$$)],function($event$jscomp$733_position$jscomp$249$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$733_position$jscomp$249$$)?($APP.$app$util$dom$stop_propagation$$($event$jscomp$733_position$jscomp$249$$),$event$jscomp$733_position$jscomp$249$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$733_position$jscomp$249$$),
"position")),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$10$$,$APP.$cljs$cst$1593$text$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$13$$,$APP.$cljs$cst$2046$auto_width$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$733_position$jscomp$249$$,$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$733_position$jscomp$249$$,$APP.$cljs$cst$257$left$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$182$$],null),function($p1__81468_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__81468_SHARP_$$,$APP.$cljs$cst$1776$grow_type$$,$APP.$cljs$cst$2045$auto_height$$),$cljs$cst$6025$last_resize_direction$$,$APP.$cljs$cst$1926$horizontal$$)})):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$10$$,$APP.$cljs$cst$1593$text$$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$13$$,$APP.$cljs$cst$2045$auto_height$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$733_position$jscomp$249$$,$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$733_position$jscomp$249$$,$APP.$cljs$cst$257$left$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$182$$],null),function($p1__81469_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__81469_SHARP_$$,$cljs$cst$6025$last_resize_direction$$,$APP.$cljs$cst$1926$horizontal$$)})):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_type$jscomp$10$$,$APP.$cljs$cst$1593$text$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grow_type$jscomp$13$$,$APP.$cljs$cst$2045$auto_height$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$733_position$jscomp$249$$,
$APP.$cljs$cst$1567$top$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$733_position$jscomp$249$$,$APP.$cljs$cst$1568$bottom$$))&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape_id$jscomp$182$$],null),function($p1__81470_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__81470_SHARP_$$,
$cljs$cst$6025$last_resize_direction$$,$APP.$cljs$cst$1927$vertical$$)})),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$start_resize$$($event$jscomp$733_position$jscomp$249$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$shape_id$jscomp$182$$]),$shape$jscomp$1105$$))):null});var $on_rotate$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1105$$)],function($event$jscomp$734$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$734$$)?
($APP.$app$util$dom$stop_propagation$$($event$jscomp$734$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$start_rotate$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1105$$],null)))):null});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$controls_handlers_STAR_$$,{shape:$shape$jscomp$1105$$,zoom:$zoom$jscomp$161$$,color:$color$jscomp$206$$,disabled:$disabled$jscomp$25$$,
onRotate:$on_rotate$jscomp$3$$,onResize:$on_resize$jscomp$5_props_81471$$})};$app$main$ui$workspace$viewport$selection$single_selection_STAR_$$=function($props_81493$$){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$controls_selection_STAR_$$,{shape:$props_81493$$.shape,zoom:$props_81493$$.zoom,color:$props_81493$$.color,disabled:$props_81493$$.disabled,onMoveSelected:$props_81493$$.onMoveSelected,onContextMenu:$props_81493$$.onContextMenu})};
$app$main$ui$workspace$viewport$selection$area_STAR_$$=function($on_move_selected$jscomp$10_props_81502$$){var $edition$jscomp$16$$=$on_move_selected$jscomp$10_props_81502$$.edition,$shapes$jscomp$238$$=$on_move_selected$jscomp$10_props_81502$$.shapes,$zoom$jscomp$163$$=$on_move_selected$jscomp$10_props_81502$$.zoom,$disabled$jscomp$27$$=$on_move_selected$jscomp$10_props_81502$$.disabled,$on_context_menu$jscomp$27$$=$on_move_selected$jscomp$10_props_81502$$.onContextMenu;$on_move_selected$jscomp$10_props_81502$$=
$on_move_selected$jscomp$10_props_81502$$.onMoveSelected;var $total$jscomp$23$$=$APP.$cljs$core$count$$($shapes$jscomp$238$$),$shape$jscomp$1107$$=$APP.$cljs$core$first$$($shapes$jscomp$238$$),$shape_id$jscomp$183$$=$shape$jscomp$1107$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1107$$,$APP.$cljs$cst$266$id$$),$JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);
var $and__5023__auto__$jscomp$inline_9515$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($total$jscomp$23$$,1);$and__5023__auto__$jscomp$inline_9515$$?($JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$,$shape$jscomp$1107$$),$JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$)?$JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$1107$$)):$JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$=$and__5023__auto__$jscomp$inline_9515$$;$JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$=
$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$)?"var(--assets-component-hightlight)":"var(--color-accent-tertiary)";return $total$jscomp$23$$>1?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$multiple_selection_STAR_$$,{shapes:$shapes$jscomp$238$$,zoom:$zoom$jscomp$163$$,color:$JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$,disabled:$disabled$jscomp$27$$,
onMoveSelected:$on_move_selected$jscomp$10_props_81502$$,onContextMenu:$on_context_menu$jscomp$27$$}):$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1107$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$16$$,$shape_id$jscomp$183$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$text_edition_selection$$,{shape:$shape$jscomp$1107$$,zoom:$zoom$jscomp$163$$,color:$JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$}):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$16$$,$shape_id$jscomp$183$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$single_selection_STAR_$$,{shape:$shape$jscomp$1107$$,zoom:$zoom$jscomp$163$$,color:$JSCompiler_inline_result$jscomp$1966_color$jscomp$208_objects$jscomp$837_or__5025__auto__$jscomp$inline_9516$$,disabled:$disabled$jscomp$27$$,onMoveSelected:$on_move_selected$jscomp$10_props_81502$$,onContextMenu:$on_context_menu$jscomp$27$$})};
$app$main$ui$workspace$viewport$selection$handlers_STAR_$$=function($disabled$jscomp$28_props_81509$$){var $shapes$jscomp$239$$=$disabled$jscomp$28_props_81509$$.shapes,$zoom$jscomp$164$$=$disabled$jscomp$28_props_81509$$.zoom,$selected$jscomp$205$$=$disabled$jscomp$28_props_81509$$.selected;$disabled$jscomp$28_props_81509$$=$disabled$jscomp$28_props_81509$$.disabled;var $total$jscomp$24$$=$APP.$cljs$core$count$$($shapes$jscomp$239$$),$shape$jscomp$1108$$=$APP.$cljs$core$first$$($shapes$jscomp$239$$),
$JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);var $and__5023__auto__$jscomp$inline_9518$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($total$jscomp$24$$,1);$and__5023__auto__$jscomp$inline_9518$$?($JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$,
$shape$jscomp$1108$$),$JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$)?$JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($shape$jscomp$1108$$)):$JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$=
$and__5023__auto__$jscomp$inline_9518$$;$JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$)?"var(--assets-component-hightlight)":"var(--color-accent-tertiary)";return $total$jscomp$24$$>1?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$multiple_handlers_STAR_$$,{shapes:$shapes$jscomp$239$$,
selected:$selected$jscomp$205$$,zoom:$zoom$jscomp$164$$,color:$JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$,disabled:$disabled$jscomp$28_props_81509$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$single_handlers_STAR_$$,{shape:$shape$jscomp$1108$$,zoom:$zoom$jscomp$164$$,color:$JSCompiler_inline_result$jscomp$1967_color$jscomp$209_objects$jscomp$838_or__5025__auto__$jscomp$inline_9519$$,disabled:$disabled$jscomp$28_props_81509$$})};
$app$main$ui$workspace$viewport$snap_distances$half_point$$=function($c2$jscomp$28_coord$jscomp$19$$,$sr1$jscomp$2$$,$sr2$jscomp$2$$){var $c1$jscomp$39$$=Math.max($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$2$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$c2$jscomp$28_coord$jscomp$19$$)?$APP.$cljs$cst$1529$y1$$:$APP.$cljs$cst$1528$x1$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr2$jscomp$2$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,
$c2$jscomp$28_coord$jscomp$19$$)?$APP.$cljs$cst$1529$y1$$:$APP.$cljs$cst$1528$x1$$));$c2$jscomp$28_coord$jscomp$19$$=Math.min($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$2$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$c2$jscomp$28_coord$jscomp$19$$)?$APP.$cljs$cst$1531$y2$$:$APP.$cljs$cst$1530$x2$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr2$jscomp$2$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,
$c2$jscomp$28_coord$jscomp$19$$)?$APP.$cljs$cst$1531$y2$$:$APP.$cljs$cst$1530$x2$$));return $c1$jscomp$39$$+($c2$jscomp$28_coord$jscomp$19$$-$c1$jscomp$39$$)/2};
$app$main$ui$workspace$viewport$snap_distances$shape_distance_segment_STAR_$$=function($props_81407_sr2$jscomp$3$$){var $sr1$jscomp$3$$=$props_81407_sr2$jscomp$3$$.sr1,$coord$jscomp$20$$=$props_81407_sr2$jscomp$3$$.coord,$zoom$jscomp$165$$=$props_81407_sr2$jscomp$3$$.zoom;$props_81407_sr2$jscomp$3$$=$props_81407_sr2$jscomp$3$$.sr2;var $from_c$$=Math.min($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$3$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,
$coord$jscomp$20$$)?$APP.$cljs$cst$1530$x2$$:$APP.$cljs$cst$1531$y2$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_81407_sr2$jscomp$3$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$APP.$cljs$cst$1530$x2$$:$APP.$cljs$cst$1531$y2$$)),$to_c$$=Math.max($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$3$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$APP.$cljs$cst$1528$x1$$:
$APP.$cljs$cst$1529$y1$$),$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_81407_sr2$jscomp$3$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$APP.$cljs$cst$1528$x1$$:$APP.$cljs$cst$1529$y1$$)),$distance$jscomp$10$$=$to_c$$-$from_c$$,$distance_str$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($distance$jscomp$10$$),$half_point$$=$app$main$ui$workspace$viewport$snap_distances$half_point$$($coord$jscomp$20$$,
$sr1$jscomp$3$$,$props_81407_sr2$jscomp$3$$),$width$jscomp$253$$=$APP.$cljs$core$count$$($distance_str$$)*(6/$zoom$jscomp$165$$)+6/$zoom$jscomp$165$$+6/$zoom$jscomp$165$$*2;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"distance-segment",children:[function(){var $point$jscomp$90_x$jscomp$1300$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_c$$+$distance$jscomp$10$$/2,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,
$APP.$cljs$cst$1515$x$$)?$half_point$$-10/$zoom$jscomp$165$$:$half_point$$+5/$zoom$jscomp$165$$],null),$vec__81415_y$jscomp$523$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$point$jscomp$90_x$jscomp$1300$$:$APP.$cljs$core$reverse$$($point$jscomp$90_x$jscomp$1300$$);$point$jscomp$90_x$jscomp$1300$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81415_y$jscomp$523$$,0,null);$vec__81415_y$jscomp$523$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81415_y$jscomp$523$$,
1,null);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,$APP.$cljs$cst$1515$x$$)?$point$jscomp$90_x$jscomp$1300$$-$width$jscomp$253$$/2:$point$jscomp$90_x$jscomp$1300$$,y:$vec__81415_y$jscomp$523$$-20/$zoom$jscomp$165$$/2-($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,$APP.$cljs$cst$1515$x$$)?2/$zoom$jscomp$165$$:0),width:$width$jscomp$253$$,
height:20/$zoom$jscomp$165$$,rx:4/$zoom$jscomp$165$$,fill:"var(--color-accent-quaternary)"}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,$APP.$cljs$cst$1515$x$$)?$point$jscomp$90_x$jscomp$1300$$:$point$jscomp$90_x$jscomp$1300$$+$width$jscomp$253$$/2,y:$vec__81415_y$jscomp$523$$+20/$zoom$jscomp$165$$/2+-(6/$zoom$jscomp$165$$)-($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$20$$,$APP.$cljs$cst$1515$x$$)?2/$zoom$jscomp$165$$:
0),fontSize:12/$zoom$jscomp$165$$,fill:"var(--app-white)",textAnchor:"middle",children:$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($distance$jscomp$10$$)})]})}(),function(){var $p1$jscomp$88_x1$jscomp$48$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_c$$+2/$zoom$jscomp$165$$,$half_point$$+5/$zoom$jscomp$165$$],null),$p2$jscomp$69_x2$jscomp$45$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$from_c$$+2/$zoom$jscomp$165$$,$half_point$$-5/$zoom$jscomp$165$$],null),$vec__81418_y1$jscomp$50$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$p1$jscomp$88_x1$jscomp$48$$:$APP.$cljs$core$reverse$$($p1$jscomp$88_x1$jscomp$48$$);$p1$jscomp$88_x1$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81418_y1$jscomp$50$$,0,null);$vec__81418_y1$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81418_y1$jscomp$50$$,
1,null);var $vec__81421_y2$jscomp$47$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$p2$jscomp$69_x2$jscomp$45$$:$APP.$cljs$core$reverse$$($p2$jscomp$69_x2$jscomp$45$$);$p2$jscomp$69_x2$jscomp$45$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81421_y2$jscomp$47$$,0,null);$vec__81421_y2$jscomp$47$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81421_y2$jscomp$47$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("line",
{x1:$p1$jscomp$88_x1$jscomp$48$$,y1:$vec__81418_y1$jscomp$50$$,x2:$p2$jscomp$69_x2$jscomp$45$$,y2:$vec__81421_y2$jscomp$47$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$165$$)}})}(),function(){var $p1$jscomp$89_x1$jscomp$49$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_c$$-2/$zoom$jscomp$165$$,$half_point$$+5/$zoom$jscomp$165$$],null),$p2$jscomp$70_x2$jscomp$46$$=
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_c$$-2/$zoom$jscomp$165$$,$half_point$$-5/$zoom$jscomp$165$$],null),$vec__81424_y1$jscomp$51$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$p1$jscomp$89_x1$jscomp$49$$:$APP.$cljs$core$reverse$$($p1$jscomp$89_x1$jscomp$49$$);$p1$jscomp$89_x1$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81424_y1$jscomp$51$$,0,null);$vec__81424_y1$jscomp$51$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81424_y1$jscomp$51$$,1,null);var $vec__81427_y2$jscomp$48$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$p2$jscomp$70_x2$jscomp$46$$:$APP.$cljs$core$reverse$$($p2$jscomp$70_x2$jscomp$46$$);$p2$jscomp$70_x2$jscomp$46$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81427_y2$jscomp$48$$,0,null);$vec__81427_y2$jscomp$48$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81427_y2$jscomp$48$$,
1,null);return(0,$APP.$rumext$v2$jsx$$)("line",{x1:$p1$jscomp$89_x1$jscomp$49$$,y1:$vec__81424_y1$jscomp$51$$,x2:$p2$jscomp$70_x2$jscomp$46$$,y2:$vec__81427_y2$jscomp$48$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$165$$)}})}(),function(){var $p1$jscomp$90_x1$jscomp$50$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$from_c$$+2/$zoom$jscomp$165$$,$half_point$$],null),
$p2$jscomp$71_x2$jscomp$47$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$to_c$$-2/$zoom$jscomp$165$$,$half_point$$],null),$vec__81430_y1$jscomp$52$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$p1$jscomp$90_x1$jscomp$50$$:$APP.$cljs$core$reverse$$($p1$jscomp$90_x1$jscomp$50$$);$p1$jscomp$90_x1$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81430_y1$jscomp$52$$,0,null);
$vec__81430_y1$jscomp$52$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81430_y1$jscomp$52$$,1,null);var $vec__81433_y2$jscomp$49$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$,$coord$jscomp$20$$)?$p2$jscomp$71_x2$jscomp$47$$:$APP.$cljs$core$reverse$$($p2$jscomp$71_x2$jscomp$47$$);$p2$jscomp$71_x2$jscomp$47$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81433_y2$jscomp$49$$,0,null);$vec__81433_y2$jscomp$49$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81433_y2$jscomp$49$$,
1,null);return(0,$APP.$rumext$v2$jsx$$)("line",{x1:$p1$jscomp$90_x1$jscomp$50$$,y1:$vec__81430_y1$jscomp$52$$,x2:$p2$jscomp$71_x2$jscomp$47$$,y2:$vec__81433_y2$jscomp$49$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$165$$)}})}()]})};
$app$main$ui$workspace$viewport$snap_distances$calculate_segments$$=function($coord$jscomp$23$$,$selrect$jscomp$94$$,$lt_shapes_selection_segments$$,$gt_shapes$$){function $show_distance_QMARK_$$($p1__81445_SHARP_$$){return $check_in_set$$($p1__81445_SHARP_$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$min_distance$$]))}function $show_candidate_QMARK_$$($p1__81442_SHARP_$$){return $check_in_set$$($p1__81442_SHARP_$$,$distances$jscomp$1$$)}function $check_in_set$$($value$jscomp$1011$$,
$number_set$jscomp$1$$){return $APP.$cljs$core$some$$(function($p1__81441_SHARP_$$){return $APP.$app$common$math$abs$$($value$jscomp$1011$$-$p1__81441_SHARP_$$)<=1.5},$number_set$jscomp$1$$)}function $get_shapes_match$$($pred_QMARK_$jscomp$5$$,$shapes$jscomp$240$$){return $APP.$cljs$core$filterv$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($pred_QMARK_$jscomp$5$$,$APP.$cljs$core$first$$),$APP.$app$common$data$map_perm$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__81437_SHARP_$$,$p2__81438_SHARP_$$){var $dist$jscomp$inline_9528_sr1$jscomp$inline_9524$$=
$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p1__81437_SHARP_$$),$sr2$jscomp$inline_9525$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p2__81438_SHARP_$$),$c1$jscomp$inline_9526$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$1528$x1$$:$APP.$cljs$cst$1529$y1$$,$c2$jscomp$inline_9527$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$1530$x2$$:
$APP.$cljs$cst$1531$y2$$;$dist$jscomp$inline_9528_sr1$jscomp$inline_9524$$=$c1$jscomp$inline_9526$$.$cljs$core$IFn$_invoke$arity$1$($sr2$jscomp$inline_9525$$)-$c2$jscomp$inline_9527$$.$cljs$core$IFn$_invoke$arity$1$($dist$jscomp$inline_9528_sr1$jscomp$inline_9524$$);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$dist$jscomp$inline_9528_sr1$jscomp$inline_9524$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$p1__81437_SHARP_$$,$p2__81438_SHARP_$$],null)],null)},function($p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$,$p2__81440_SHARP__s1c1$jscomp$inline_9537$$){var $s1c2$jscomp$inline_9538_sr1$jscomp$inline_9533$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$);$p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p2__81440_SHARP__s1c1$jscomp$inline_9537$$);
var $c1$jscomp$inline_9535_s2c1$jscomp$inline_9539$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$1529$y1$$:$APP.$cljs$cst$1528$x1$$,$c2$jscomp$inline_9536$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$1531$y2$$:$APP.$cljs$cst$1530$x2$$;$p2__81440_SHARP__s1c1$jscomp$inline_9537$$=$c1$jscomp$inline_9535_s2c1$jscomp$inline_9539$$.$cljs$core$IFn$_invoke$arity$1$($s1c2$jscomp$inline_9538_sr1$jscomp$inline_9533$$);
$s1c2$jscomp$inline_9538_sr1$jscomp$inline_9533$$=$c2$jscomp$inline_9536$$.$cljs$core$IFn$_invoke$arity$1$($s1c2$jscomp$inline_9538_sr1$jscomp$inline_9533$$);$c1$jscomp$inline_9535_s2c1$jscomp$inline_9539$$=$c1$jscomp$inline_9535_s2c1$jscomp$inline_9539$$.$cljs$core$IFn$_invoke$arity$1$($p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$);$p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$=$c2$jscomp$inline_9536$$.$cljs$core$IFn$_invoke$arity$1$($p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$);
return $c1$jscomp$inline_9535_s2c1$jscomp$inline_9539$$>=$p2__81440_SHARP__s1c1$jscomp$inline_9537$$&&$c1$jscomp$inline_9535_s2c1$jscomp$inline_9539$$<=$s1c2$jscomp$inline_9538_sr1$jscomp$inline_9533$$||$p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$>=$p2__81440_SHARP__s1c1$jscomp$inline_9537$$&&$p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$<=$s1c2$jscomp$inline_9538_sr1$jscomp$inline_9533$$||$p2__81440_SHARP__s1c1$jscomp$inline_9537$$>=$c1$jscomp$inline_9535_s2c1$jscomp$inline_9539$$&&
$p2__81440_SHARP__s1c1$jscomp$inline_9537$$<=$p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$||$s1c2$jscomp$inline_9538_sr1$jscomp$inline_9533$$>=$c1$jscomp$inline_9535_s2c1$jscomp$inline_9539$$&&$s1c2$jscomp$inline_9538_sr1$jscomp$inline_9533$$<=$p1__81439_SHARP__s2c2$jscomp$inline_9540_sr2$jscomp$inline_9534$$},$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$23$$,$APP.$cljs$cst$1610$selrect$$),$shapes$jscomp$240$$)))}
function $distance_to_selrect$$($G__81450_shape$jscomp$1109_sr$jscomp$6$$){$G__81450_shape$jscomp$1109_sr$jscomp$6$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($G__81450_shape$jscomp$1109_sr$jscomp$6$$);$G__81450_shape$jscomp$1109_sr$jscomp$6$$=($coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($G__81450_shape$jscomp$1109_sr$jscomp$6$$):$coord$jscomp$23$$($G__81450_shape$jscomp$1109_sr$jscomp$6$$))<=($coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?
$coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($selrect$jscomp$94$$):$coord$jscomp$23$$($selrect$jscomp$94$$))?$app$common$geom$shapes$distance_selrect$$($G__81450_shape$jscomp$1109_sr$jscomp$6$$,$selrect$jscomp$94$$):$app$common$geom$shapes$distance_selrect$$($selrect$jscomp$94$$,$G__81450_shape$jscomp$1109_sr$jscomp$6$$);return $coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$?$coord$jscomp$23$$.$cljs$core$IFn$_invoke$arity$1$($G__81450_shape$jscomp$1109_sr$jscomp$6$$):$coord$jscomp$23$$($G__81450_shape$jscomp$1109_sr$jscomp$6$$)}
var $distance_coincidences_distances_xf_other_shapes_segments$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$some_QMARK_$$),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($distance_to_selrect$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$pos_QMARK_$$)),$lt_distances$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$distance_coincidences_distances_xf_other_shapes_segments$$,
$lt_shapes_selection_segments$$),$gt_distances$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$distance_coincidences_distances_xf_other_shapes_segments$$,$gt_shapes$$),$distances$jscomp$1$$=$APP.$clojure$set$union$$.$cljs$core$IFn$_invoke$arity$2$($lt_distances$$,$gt_distances$$);$distance_coincidences_distances_xf_other_shapes_segments$$=$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($get_shapes_match$$($show_candidate_QMARK_$$,
$lt_shapes_selection_segments$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$get_shapes_match$$($show_candidate_QMARK_$$,$gt_shapes$$)]));var $distance_candidates$$=$APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$,$distance_coincidences_distances_xf_other_shapes_segments$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81443_SHARP_$$){return $check_in_set$$($p1__81443_SHARP_$$,
$lt_distances$$)},$gt_distances$$),$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81444_SHARP_$$){return $check_in_set$$($p1__81444_SHARP_$$,$gt_distances$$)},$lt_distances$$)])),$min_distance$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,$distance_candidates$$);$distance_coincidences_distances_xf_other_shapes_segments$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81447_SHARP_$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1610$selrect$$,
$p1__81447_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81446_SHARP_$$){return $show_distance_QMARK_$$($APP.$cljs$core$first$$($p1__81446_SHARP_$$))},$distance_coincidences_distances_xf_other_shapes_segments$$)));$lt_shapes_selection_segments$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81449_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$selrect$jscomp$94$$,$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($p1__81449_SHARP_$$)],null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81448_SHARP_$$){return $show_distance_QMARK_$$($distance_to_selrect$$($p1__81448_SHARP_$$))},$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($lt_shapes_selection_segments$$,$gt_shapes$$)));return $APP.$app$common$data$concat_set$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($distance_coincidences_distances_xf_other_shapes_segments$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$lt_shapes_selection_segments$$]))};
$app$main$ui$workspace$viewport$snap_distances$query_worker$$=function($page_id$jscomp$457$$,$coord$jscomp$24_gt_side$$,$lt_side_p__81453$$){function $query_side$$($rect$jscomp$50_side$jscomp$5$$){$rect$jscomp$50_side$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($areas$jscomp$3$$,$rect$jscomp$50_side$jscomp$5$$);return $APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$50_side$jscomp$5$$)>0&&$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($rect$jscomp$50_side$jscomp$5$$)>
0?$APP.$app$main$snap$select_shapes_area$$($page_id$jscomp$457$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$102$$),$selected$jscomp$206$$,$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$rect$jscomp$50_side$jscomp$5$$):(0,$APP.$beicon$v2$core$of$$)(null)}var $selrect$jscomp$95$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lt_side_p__81453$$,0,null),$selected$jscomp$206$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lt_side_p__81453$$,
1,null),$frame$jscomp$102$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($lt_side_p__81453$$,2,null);$lt_side_p__81453$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$24_gt_side$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$257$left$$:$APP.$cljs$cst$1567$top$$;$coord$jscomp$24_gt_side$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$24_gt_side$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$258$right$$:$APP.$cljs$cst$1568$bottom$$;var $bounds$jscomp$96_vbox$jscomp$71$$=
$APP.$cljs$core$_deref$$($APP.$app$main$refs$vbox$$),$frame_sr$jscomp$1$$=$APP.$app$common$files$helpers$root_QMARK_$$($frame$jscomp$102$$)?null:$frame$jscomp$102$$?.selrect??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$102$$,$APP.$cljs$cst$1610$selrect$$);$bounds$jscomp$96_vbox$jscomp$71$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$geom$rect$clip_rect$$($frame_sr$jscomp$1$$,$bounds$jscomp$96_vbox$jscomp$71$$),$bounds$jscomp$96_vbox$jscomp$71$$);
var $areas$jscomp$3$$=$APP.$app$common$geom$shapes$get_areas$$($bounds$jscomp$96_vbox$jscomp$71$$,$selrect$jscomp$95$$);return $APP.$beicon$v2$core$combine_latest$$($query_side$$($lt_side_p__81453$$),$query_side$$($coord$jscomp$24_gt_side$$))};
$app$main$ui$workspace$viewport$snap_distances$shape_distance_STAR_$$=function($props_81457_segments_to_display$jscomp$1$$){var $selrect$jscomp$96$$=$props_81457_segments_to_display$jscomp$1$$.selrect,$coord$jscomp$25$$=$props_81457_segments_to_display$jscomp$1$$.coord,$zoom$jscomp$166$$=$props_81457_segments_to_display$jscomp$1$$.zoom,$selected$jscomp$207$$=$props_81457_segments_to_display$jscomp$1$$.selected,$frame$jscomp$103$$=$props_81457_segments_to_display$jscomp$1$$.frame,$page_id$jscomp$458$$=
$props_81457_segments_to_display$jscomp$1$$.pageId,$subject$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$lt_shapes_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$lt_shapes$jscomp$1$$=$APP.$cljs$core$_deref$$($lt_shapes_STAR_$$),$gt_shapes_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$gt_shapes$jscomp$1$$=$APP.$cljs$core$_deref$$($gt_shapes_STAR_$$);$props_81457_segments_to_display$jscomp$1$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($lt_shapes$jscomp$1$$),$APP.$rumext$v2$adapt$$($gt_shapes$jscomp$1$$),$APP.$rumext$v2$adapt$$($selrect$jscomp$96$$)],function(){return $app$main$ui$workspace$viewport$snap_distances$calculate_segments$$($coord$jscomp$25$$,$selrect$jscomp$96$$,$lt_shapes$jscomp$1$$,$gt_shapes$jscomp$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$458$$)],function(){var $sub$jscomp$30$$=
$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($gt_shapes__$1_p__81458$$){var $lt_shapes__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gt_shapes__$1_p__81458$$,0,null);$gt_shapes__$1_p__81458$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($gt_shapes__$1_p__81458$$,1,null);$APP.$cljs$core$reset_BANG_$$($lt_shapes_STAR_$$,$lt_shapes__$1$$);return $APP.$cljs$core$reset_BANG_$$($gt_shapes_STAR_$$,$gt_shapes__$1_p__81458$$)},$APP.$beicon$v2$core$switch_map$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$snap_distances$query_worker$$,
$page_id$jscomp$458$$,$coord$jscomp$25$$),$APP.$beicon$v2$core$throttle$cljs$0core$0IFn$0_invoke$0arity$02$$(100,$subject$jscomp$1$$)));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$30$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selrect$jscomp$96$$)],function(){return $subject$jscomp$1$$.next(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$selrect$jscomp$96$$,$selected$jscomp$207$$,
$frame$jscomp$103$$],null))});return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$238$$,$p__81462_sr2$jscomp$6$$){var $sr1$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81462_sr2$jscomp$6$$,0,null);$p__81462_sr2$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81462_sr2$jscomp$6$$,1,null);$out_arr__44092__auto__$jscomp$238$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$shape_distance_segment_STAR_$$,
{sr1:$sr1$jscomp$6$$,sr2:$p__81462_sr2$jscomp$6$$,coord:$coord$jscomp$25$$,zoom:$zoom$jscomp$166$$},""+($sr1$jscomp$6$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$6$$,$APP.$cljs$cst$1515$x$$)??"")+"-"+($sr1$jscomp$6$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($sr1$jscomp$6$$,$APP.$cljs$cst$1516$y$$)??"")+"-"+($p__81462_sr2$jscomp$6$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p__81462_sr2$jscomp$6$$,$APP.$cljs$cst$1515$x$$)??"")+"-"+($p__81462_sr2$jscomp$6$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p__81462_sr2$jscomp$6$$,$APP.$cljs$cst$1516$y$$)??"")));return $out_arr__44092__auto__$jscomp$238$$},[],$props_81457_segments_to_display$jscomp$1$$)};
$app$main$ui$workspace$viewport$snap_distances$snap_distances_STAR_$$=function($page_id$jscomp$459_props_81467$$){var $selected_shapes$jscomp$38_selrect$jscomp$97$$=$page_id$jscomp$459_props_81467$$.selectedShapes,$zoom$jscomp$167$$=$page_id$jscomp$459_props_81467$$.zoom,$selected$jscomp$208$$=$page_id$jscomp$459_props_81467$$.selected;$page_id$jscomp$459_props_81467$$=$page_id$jscomp$459_props_81467$$.pageId;var $frame$jscomp$104_frame_id$jscomp$164$$=$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$38_selrect$jscomp$97$$));
$frame$jscomp$104_frame_id$jscomp$164$$=$APP.$rumext$v2$deref$$($app$main$refs$object_by_id$$($frame$jscomp$104_frame_id$jscomp$164$$));$selected_shapes$jscomp$38_selrect$jscomp$97$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($selected_shapes$jscomp$38_selrect$jscomp$97$$);return $APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$104_frame_id$jscomp$164$$)?null:(0,$APP.$rumext$v2$jsxs$$)("g",{className:"distance",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$shape_distance_STAR_$$,
{selrect:$selected_shapes$jscomp$38_selrect$jscomp$97$$,pageId:$page_id$jscomp$459_props_81467$$,frame:$frame$jscomp$104_frame_id$jscomp$164$$,zoom:$zoom$jscomp$167$$,coord:$APP.$cljs$cst$1515$x$$,selected:$selected$jscomp$208$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$shape_distance_STAR_$$,{selrect:$selected_shapes$jscomp$38_selrect$jscomp$97$$,pageId:$page_id$jscomp$459_props_81467$$,frame:$frame$jscomp$104_frame_id$jscomp$164$$,zoom:$zoom$jscomp$167$$,coord:$APP.$cljs$cst$1516$y$$,
selected:$selected$jscomp$208$$})]})};
$app$main$ui$workspace$viewport$snap_points$snap_point_STAR_$$=function($props_81472_x$jscomp$1301$$){var $zoom$jscomp$168$$=$props_81472_x$jscomp$1301$$.zoom,$map__81473__$1_y$jscomp$524$$=$APP.$cljs$core$__destructure_map$$($props_81472_x$jscomp$1301$$.point);$props_81472_x$jscomp$1301$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81473__$1_y$jscomp$524$$,$APP.$cljs$cst$1515$x$$);$map__81473__$1_y$jscomp$524$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81473__$1_y$jscomp$524$$,$APP.$cljs$cst$1516$y$$);
var $cross_width$$=3/$zoom$jscomp$168$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{children:[(0,$APP.$rumext$v2$jsx$$)("line",{x1:$props_81472_x$jscomp$1301$$-$cross_width$$,y1:$map__81473__$1_y$jscomp$524$$-$cross_width$$,x2:$props_81472_x$jscomp$1301$$+$cross_width$$,y2:$map__81473__$1_y$jscomp$524$$+$cross_width$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$168$$)}}),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$props_81472_x$jscomp$1301$$-
$cross_width$$,y1:$map__81473__$1_y$jscomp$524$$+$cross_width$$,x2:$props_81472_x$jscomp$1301$$+$cross_width$$,y2:$map__81473__$1_y$jscomp$524$$-$cross_width$$,style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$168$$)}})]})};
$app$main$ui$workspace$viewport$snap_points$snap_line_STAR_$$=function($point$jscomp$92_props_81474$$){var $zoom$jscomp$169$$=$point$jscomp$92_props_81474$$.zoom,$snap$jscomp$4$$=$point$jscomp$92_props_81474$$.snap;$point$jscomp$92_props_81474$$=$point$jscomp$92_props_81474$$.point;return(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($snap$jscomp$4$$),y1:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($snap$jscomp$4$$),x2:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$92_props_81474$$),
y2:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$92_props_81474$$),style:{stroke:"var(--color-accent-quaternary)",strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$169$$)},opacity:.6})};
$app$main$ui$workspace$viewport$snap_points$get_snap$$=function($coord$jscomp$26$$,$shapes$jscomp$241$$,$page_id$jscomp$460$$,$remove_snap$$,$zoom$jscomp$170$$){var $bounds$jscomp$97$$=$APP.$app$common$geom$shapes$common$shapes__GT_rect$$($shapes$jscomp$241$$),$frame_id$jscomp$165$$=$APP.$app$main$snap$snap_frame_id$$($shapes$jscomp$241$$);return $APP.$beicon$v2$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$beicon$v2$core$merge_map$$(function($p__81479$$){var $frame_id__$1$jscomp$13$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81479$$,0,null),$point$jscomp$93$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81479$$,1,null);return $APP.$beicon$v2$core$map$$(function($p1__81478_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$point$jscomp$93$$,$p1__81478_SHARP_$$,$coord$jscomp$26$$],null)},$APP.$beicon$v2$core$map$$(function($p1__81477_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2167$pt$$,
$p1__81477_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__81476_SHARP_$$){return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$second$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__81476_SHARP_$$]))},$app$main$snap$get_snap_points$$($page_id$jscomp$460$$,$frame_id__$1$jscomp$13$$,$remove_snap$$,$zoom$jscomp$170$$,$point$jscomp$93$$,$coord$jscomp$26$$))))},$APP.$beicon$v2$core$merge_map$$(function($bounds__$1$jscomp$6$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81475_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$frame_id$jscomp$165$$,$p1__81475_SHARP_$$],null)},$APP.$app$common$geom$snap$rect__GT_snap_points$$($bounds__$1$jscomp$6$$))},(0,$APP.$beicon$v2$core$of$$)($bounds$jscomp$97$$))))};
$app$main$ui$workspace$viewport$snap_points$add_point_to_snaps$$=function($p__81484$$){var $point$jscomp$94$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81484$$,0,null),$snaps$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81484$$,1,null),$coord$jscomp$28$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81484$$,2,null);return $APP.$cljs$core$cons$$($point$jscomp$94$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81483_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__81483_SHARP_$$,
$coord$jscomp$28$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$94$$,$coord$jscomp$28$$))},$snaps$$))};
$app$main$ui$workspace$viewport$snap_points$process_snap_lines$$=function($snaps$jscomp$1$$,$coord$jscomp$29$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($minv$jscomp$1_p__81494$$){var $fixedv$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($minv$jscomp$1_p__81494$$,0,null),$maxv$jscomp$1_vec__81498$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($minv$jscomp$1_p__81494$$,1,null);$minv$jscomp$1_p__81494$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($maxv$jscomp$1_vec__81498$$,
0,null);$maxv$jscomp$1_vec__81498$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($maxv$jscomp$1_vec__81498$$,1,null);return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentHashMap$fromArrays$$([$coord$jscomp$29$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$29$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$1516$y$$:$APP.$cljs$cst$1515$x$$],[$fixedv$$,$minv$jscomp$1_p__81494$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$coord$jscomp$29$$,
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$29$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$1516$y$$:$APP.$cljs$cst$1515$x$$],[$fixedv$$,$maxv$jscomp$1_vec__81498$$])],null)},$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__81492_SHARP_$$,$p2__81491_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$min$$,$p2__81491_SHARP_$$),
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$max$$,$p2__81491_SHARP_$$)],null)},$APP.$app$common$data$mapm$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__81490_SHARP_$$,$p2__81489_SHARP_$$){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($coord$jscomp$29$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$1516$y$$:$APP.$cljs$cst$1515$x$$,$p2__81489_SHARP_$$)},$APP.$cljs$core$group_by$$($coord$jscomp$29$$,$APP.$cljs$core$flatten$$($APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($app$main$ui$workspace$viewport$snap_points$add_point_to_snaps$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81488_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__81488_SHARP_$$,2),$coord$jscomp$29$$)},$snaps$jscomp$1$$)])))))))};
$app$main$ui$workspace$viewport$snap_points$snap_feedback_STAR_$$=function($modifiers$jscomp$138_props_81501$$){var $shapes$jscomp$242$$=$modifiers$jscomp$138_props_81501$$.shapes,$zoom$jscomp$171$$=$modifiers$jscomp$138_props_81501$$.zoom,$remove_snap$jscomp$1$$=$modifiers$jscomp$138_props_81501$$.removeSnap,$page_id$jscomp$461$$=$modifiers$jscomp$138_props_81501$$.pageId;$modifiers$jscomp$138_props_81501$$=$modifiers$jscomp$138_props_81501$$.modifiers;var $state$jscomp$1241$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentVector$EMPTY$$),
$subject$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$snap_points$jscomp$2$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$viewport$snap_points$add_point_to_snaps$$),$APP.$cljs$core$_deref$$($state$jscomp$1241$$)),$snap_lines$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$viewport$snap_points$process_snap_lines$$($APP.$cljs$core$_deref$$($state$jscomp$1241$$),$APP.$cljs$cst$1515$x$$),$app$main$ui$workspace$viewport$snap_points$process_snap_lines$$($APP.$cljs$core$_deref$$($state$jscomp$1241$$),$APP.$cljs$cst$1516$y$$)));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $sub$jscomp$31$$=$APP.$beicon$v2$core$subs_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$(function($data$jscomp$505_rs$jscomp$3$$){$data$jscomp$505_rs$jscomp$3$$=
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__81503$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81503$$,0,null);var $snaps$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81503$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81503$$,2,null);return $APP.$cljs$core$count$$($snaps$jscomp$2$$)>0},$data$jscomp$505_rs$jscomp$3$$);return $APP.$cljs$core$reset_BANG_$$($state$jscomp$1241$$,$data$jscomp$505_rs$jscomp$3$$)},
$APP.$beicon$v2$core$map$$(function($result$jscomp$390$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$concat_vec$$,$APP.$cljs$core$seq$$($result$jscomp$390$$))},$APP.$beicon$v2$core$switch_map$$(function($p__81507_shapes__$1$jscomp$38$$){var $map__81508__$1_zoom__$1$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($p__81507_shapes__$1$jscomp$38$$);$p__81507_shapes__$1$jscomp$38$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81508__$1_zoom__$1$jscomp$5$$,
$APP.$cljs$cst$1619$shapes$$);var $page_id__$1$jscomp$25$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81508__$1_zoom__$1$jscomp$5$$,$APP.$cljs$cst$2051$page_id$$),$remove_snap__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81508__$1_zoom__$1$jscomp$5$$,$cljs$cst$6026$remove_snap$$);$map__81508__$1_zoom__$1$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81508__$1_zoom__$1$jscomp$5$$,$APP.$cljs$cst$2204$zoom$$);return $APP.$beicon$v2$core$combine_latest$$($app$main$ui$workspace$viewport$snap_points$get_snap$$($APP.$cljs$cst$1515$x$$,
$p__81507_shapes__$1$jscomp$38$$,$page_id__$1$jscomp$25$$,$remove_snap__$1$$,$map__81508__$1_zoom__$1$jscomp$5$$),$app$main$ui$workspace$viewport$snap_points$get_snap$$($APP.$cljs$cst$1516$y$$,$p__81507_shapes__$1$jscomp$38$$,$page_id__$1$jscomp$25$$,$remove_snap__$1$$,$map__81508__$1_zoom__$1$jscomp$5$$))},$subject$jscomp$2$$)));return function(){return $APP.$beicon$v2$core$_dispose$$($sub$jscomp$31$$)}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$242$$),
$APP.$rumext$v2$adapt$$($remove_snap$jscomp$1$$),$APP.$rumext$v2$adapt$$($modifiers$jscomp$138_props_81501$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$461$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$171$$)],function(){return $subject$jscomp$2$$.next(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1619$shapes$$,$shapes$jscomp$242$$,$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$461$$,$cljs$cst$6026$remove_snap$$,$remove_snap$jscomp$1$$,$APP.$cljs$cst$2204$zoom$$,$zoom$jscomp$171$$],null))});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"snap-feedback",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$239$$,$p__81510_to_point$jscomp$2$$){var $from_point$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81510_to_point$jscomp$2$$,0,null);$p__81510_to_point$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81510_to_point$jscomp$2$$,1,null);$out_arr__44092__auto__$jscomp$239$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_line_STAR_$$,
{snap:$from_point$jscomp$3$$,point:$p__81510_to_point$jscomp$2$$,zoom:$zoom$jscomp$171$$},["line-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($from_point$jscomp$3$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($from_point$jscomp$3$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p__81510_to_point$jscomp$2$$)),
"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p__81510_to_point$jscomp$2$$)),"-"].join("")));return $out_arr__44092__auto__$jscomp$239$$},[],$snap_lines$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$240$$,$point$jscomp$95$$){$out_arr__44092__auto__$jscomp$240$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_point_STAR_$$,{point:$point$jscomp$95$$,
zoom:$zoom$jscomp$171$$},["point-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$95$$)),"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($point$jscomp$95$$))].join("")));return $out_arr__44092__auto__$jscomp$240$$},[],$snap_points$jscomp$2$$)]})};
$app$main$ui$workspace$viewport$path_actions$check_enabled$$=function($content$jscomp$271$$,$is_curve_QMARK__selected_points$jscomp$8$$){if($APP.$cljs$core$truth_$$($content$jscomp$271$$)){var $segments$jscomp$16_segments_selected_QMARK_$$=$APP.$app$common$types$path$segment$get_segments_with_points$$($content$jscomp$271$$,$is_curve_QMARK__selected_points$jscomp$8$$),$num_segments$$=$APP.$cljs$core$count$$($segments$jscomp$16_segments_selected_QMARK_$$),$num_points$$=$APP.$cljs$core$count$$($is_curve_QMARK__selected_points$jscomp$8$$),
$points_selected_QMARK_$$=$APP.$cljs$core$seq$$($is_curve_QMARK__selected_points$jscomp$8$$);$segments$jscomp$16_segments_selected_QMARK_$$=$APP.$cljs$core$seq$$($segments$jscomp$16_segments_selected_QMARK_$$);var $max_segments$$=$num_points$$*($num_points$$-1)/2;$is_curve_QMARK__selected_points$jscomp$8$$=$APP.$cljs$core$some$$(function($p1__81518_SHARP_$$){return $app$common$types$path$segment$is_curve_QMARK_$$($content$jscomp$271$$,$p1__81518_SHARP_$$)},$is_curve_QMARK__selected_points$jscomp$8$$);
return new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$APP.$cljs$cst$5419$make_corner$$,$points_selected_QMARK_$$?$is_curve_QMARK__selected_points$jscomp$8$$:$points_selected_QMARK_$$,$APP.$cljs$cst$5425$make_curve$$,$points_selected_QMARK_$$&&$APP.$cljs$core$not$$($is_curve_QMARK__selected_points$jscomp$8$$),$APP.$cljs$cst$5426$add_node$$,$segments$jscomp$16_segments_selected_QMARK_$$,$cljs$cst$6027$remove_node$$,$points_selected_QMARK_$$,$APP.$cljs$cst$5423$merge_nodes$$,$segments$jscomp$16_segments_selected_QMARK_$$,
$APP.$cljs$cst$5418$join_nodes$$,$points_selected_QMARK_$$&&$num_points$$>=2&&$num_segments$$<$max_segments$$,$APP.$cljs$cst$5424$separate_nodes$$,$segments$jscomp$16_segments_selected_QMARK_$$],null)}return null};
$app$main$ui$workspace$viewport$path_actions$path_actions_STAR_$$=function($edit_mode$jscomp$3_props_81519$$){var $on_select_draw_mode_shape$jscomp$1110$$=$edit_mode$jscomp$3_props_81519$$.shape,$map__81520__$1_snap_toggled$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($edit_mode$jscomp$3_props_81519$$.state);$edit_mode$jscomp$3_props_81519$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81520__$1_snap_toggled$jscomp$4$$,$APP.$cljs$cst$4290$edit_mode$$);var $selected_points$jscomp$9$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81520__$1_snap_toggled$jscomp$4$$,$APP.$cljs$cst$4308$selected_points$$);$map__81520__$1_snap_toggled$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81520__$1_snap_toggled$jscomp$4$$,$APP.$cljs$cst$4269$snap_toggled$$);var $content$jscomp$272$$=$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($on_select_draw_mode_shape$jscomp$1110$$),$enabled_buttons$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$272$$),
$APP.$rumext$v2$adapt$$($selected_points$jscomp$9$$)],function(){return $app$main$ui$workspace$viewport$path_actions$check_enabled$$($content$jscomp$272$$,$selected_points$jscomp$9$$)});$on_select_draw_mode_shape$jscomp$1110$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$drawing$change_edit_mode$$($APP.$cljs$cst$4291$draw$$))});var $on_select_edit_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$drawing$change_edit_mode$$($APP.$cljs$cst$1804$move$$))}),
$on_add_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5426$add_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5426$add_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$add_node$$()):null}),$on_remove_node$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cljs$cst$6027$remove_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($cljs$cst$6027$remove_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$remove_nodes$$)):null}),$on_merge_nodes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5423$merge_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5423$merge_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$merge_nodes$$)):null}),$on_join_nodes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5418$join_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5418$join_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$join_nodes$$)):null}),$on_separate_nodes$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5424$separate_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5424$separate_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$process_path_tool$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$APP.$app$common$types$path$separate_nodes$$)):null}),$on_make_corner$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5419$make_corner$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],
function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5419$make_corner$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_corner$$.$cljs$core$IFn$_invoke$arity$0$()):null}),$on_make_curve$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$5425$make_curve$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5425$make_curve$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$))?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$make_curve$$.$cljs$core$IFn$_invoke$arity$0$()):null}),$on_toggle_snap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$path$tools$toggle_snap$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",{"data-dont-clear-path":!0,className:"main_ui_workspace_viewport_path_actions__sub-actions",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",children:[(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.draw-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5420$draw_nodes$$)])),onClick:$on_select_draw_mode_shape$jscomp$1110$$,className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$3_props_81519$$,
$APP.$cljs$cst$4291$draw$$)?"main_ui_workspace_viewport_path_actions__is-toggled":"")+" main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$pentool_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.move-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5427$move_nodes$$)])),
onClick:$on_select_edit_mode$$,className:($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_mode$jscomp$3_props_81519$$,$APP.$cljs$cst$1804$move$$)?"main_ui_workspace_viewport_path_actions__is-toggled":"")+" main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$move_icon$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5426$add_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.add-node",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5426$add_node$$)])),onClick:$on_add_node$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$add_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($cljs$cst$6027$remove_node$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.delete-node",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5421$delete_node$$)])),onClick:$on_remove_node$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$remove_icon$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5423$merge_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.merge-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5423$merge_nodes$$)])),onClick:$on_merge_nodes$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",
children:$app$main$ui$workspace$viewport$path_actions$merge_nodes_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5418$join_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.join-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5418$join_nodes$$)])),onClick:$on_join_nodes$$,
className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$join_nodes_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5424$separate_nodes$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.separate-nodes",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5424$separate_nodes$$)])),
onClick:$on_separate_nodes$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$separate_nodes_icon$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5419$make_corner$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.make-corner",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5419$make_corner$$)])),onClick:$on_make_corner$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$to_corner_icon$$}),(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$not$$($APP.$cljs$cst$5425$make_curve$$.$cljs$core$IFn$_invoke$arity$1$($enabled_buttons$$)),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.make-curve",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5425$make_curve$$)])),onClick:$on_make_curve$$,className:"main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$to_curve_icon$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_path_actions__sub-actions-group",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.path.actions.snap-nodes",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$path$shortcuts$get_tooltip$$($APP.$cljs$cst$5422$snap_nodes$$)])),onClick:$on_toggle_snap$$,className:($APP.$cljs$core$truth_$$($map__81520__$1_snap_toggled$jscomp$4$$)?"main_ui_workspace_viewport_path_actions__is-toggled":"")+" main_ui_workspace_viewport_path_actions__topbar-btn",children:$app$main$ui$workspace$viewport$path_actions$snap_nodes_icon$$})})]})};
$app$main$ui$workspace$viewport$top_bar$view_only_bar_STAR_$$=function(){var $on_close$jscomp$41$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$layout$set_options_mode$$($APP.$cljs$cst$3782$design$$),$APP.$app$main$data$workspace$common$set_workspace_read_only$$(!1)]))}),
$render_context_lost_QMARK_$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$render_context_lost_QMARK_$$);return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_top_bar__viewport-actions",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_top_bar__viewport-actions-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_top_bar__viewport-actions-title",children:$APP.$rumext$v2$jsx$$($APP.$app$util$i18n$tr_html_STAR_$$,
{tagName:"span",content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$truth_$$($render_context_lost_QMARK_$jscomp$1$$)?"workspace.top-bar.webgl-context-lost":"workspace.top-bar.view-only")})}),$APP.$cljs$core$truth_$$($render_context_lost_QMARK_$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"primary",onClick:function(){return location.reload()},children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.top-bar.webgl-context-lost.reload")}):
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$on_close$jscomp$41$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.top-bar.read-only.done")})]})})};
$app$main$ui$workspace$viewport$top_bar$path_edition_bar_STAR_$$=function($class$$jscomp$83_props_81523$$){var $edit_path_state$jscomp$1$$=$class$$jscomp$83_props_81523$$.editPathState,$shape$jscomp$1111$$=$class$$jscomp$83_props_81523$$.shape;$class$$jscomp$83_props_81523$$="main_ui_workspace_viewport_top_bar__viewport-actions-path "+($APP.$cljs$core$contains_QMARK_$$($class$$jscomp$83_props_81523$$.layout,$APP.$cljs$cst$2219$rulers$$)?"":"main_ui_workspace_viewport_top_bar__viewport-actions-no-rulers");
return(0,$APP.$rumext$v2$jsx$$)("div",{className:$class$$jscomp$83_props_81523$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$path_actions$path_actions_STAR_$$,{shape:$shape$jscomp$1111$$,state:$edit_path_state$jscomp$1$$})})};$app$main$ui$workspace$viewport$top_bar$grid_edition_bar_STAR_$$=function($props_81524$$){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$grid_edition_actions$$,{shape:$props_81524$$.shape})};
$app$main$ui$workspace$viewport$widgets$pixel_grid_STAR_$$=function($props_81526_vbox$jscomp$72$$){var $zoom$jscomp$173$$=$props_81526_vbox$jscomp$72$$.zoom,$clip_rulers$jscomp$1$$=$props_81526_vbox$jscomp$72$$.clipRulers??!1;$props_81526_vbox$jscomp$72$$=$props_81526_vbox$jscomp$72$$.vbox;var $custom_alpha_page$jscomp$174$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page$$),$custom_color$$=$APP.$cljs$cst$2067$pixel_grid_color$$.$cljs$core$IFn$_invoke$arity$1$($custom_alpha_page$jscomp$174$$);
$custom_alpha_page$jscomp$174$$=$APP.$cljs$cst$2068$pixel_grid_opacity$$.$cljs$core$IFn$_invoke$arity$1$($custom_alpha_page$jscomp$174$$);var $debug_QMARK_$jscomp$1$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3091$pixel_grid$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"pixel-grid",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("pattern",{id:"pixel-grid",viewBox:"0 0 1 1",width:1,height:1,patternUnits:"userSpaceOnUse",children:(0,$APP.$rumext$v2$jsx$$)("path",
{d:"M 1 0 L 0 0 0 1",style:{fill:"none",stroke:$debug_QMARK_$jscomp$1$$?"red":$APP.$cljs$core$truth_$$($custom_color$$)?$custom_color$$:"var(--status-color-info-500)",strokeOpacity:$debug_QMARK_$jscomp$1$$?1:$custom_alpha_page$jscomp$174$$!=null?$custom_alpha_page$jscomp$174$$:.2,strokeWidth:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(1/$zoom$jscomp$173$$)}})})}),$APP.$cljs$core$truth_$$($clip_rulers$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers_clip_path_STAR_$$,
{id:"clip-pixel-grid",vbox:$props_81526_vbox$jscomp$72$$,zoom:$zoom$jscomp$173$$}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($props_81526_vbox$jscomp$72$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($props_81526_vbox$jscomp$72$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($props_81526_vbox$jscomp$72$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($props_81526_vbox$jscomp$72$$),fill:"url(#pixel-grid)",
clipPath:$APP.$cljs$core$truth_$$($clip_rulers$jscomp$1$$)?"url(#clip-pixel-grid)":null,style:{pointerEvents:"none"}})]})};
$app$main$ui$workspace$viewport$widgets$cursor_tooltip_STAR_$$=function($pos_x$jscomp$7_props_81527_zoom$jscomp$174$$){var $tooltip$jscomp$1$$=$pos_x$jscomp$7_props_81527_zoom$jscomp$174$$.tooltip;$pos_x$jscomp$7_props_81527_zoom$jscomp$174$$=$pos_x$jscomp$7_props_81527_zoom$jscomp$174$$.zoom;var $G__81528$jscomp$inline_9542_coords$jscomp$4_pos_y$jscomp$7$$=$app$main$ui$hooks$use_rxsub$$();$G__81528$jscomp$inline_9542_coords$jscomp$4_pos_y$jscomp$7$$=$G__81528$jscomp$inline_9542_coords$jscomp$4_pos_y$jscomp$7$$==
null?null:$APP.$app$common$geom$point$divide$$($G__81528$jscomp$inline_9542_coords$jscomp$4_pos_y$jscomp$7$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($pos_x$jscomp$7_props_81527_zoom$jscomp$174$$,$pos_x$jscomp$7_props_81527_zoom$jscomp$174$$));$pos_x$jscomp$7_props_81527_zoom$jscomp$174$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($G__81528$jscomp$inline_9542_coords$jscomp$4_pos_y$jscomp$7$$)-100;$G__81528$jscomp$inline_9542_coords$jscomp$4_pos_y$jscomp$7$$=
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($G__81528$jscomp$inline_9542_coords$jscomp$4_pos_y$jscomp$7$$)+30;return(0,$APP.$rumext$v2$jsx$$)("g",{transform:["translate(",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($pos_x$jscomp$7_props_81527_zoom$jscomp$174$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__81528$jscomp$inline_9542_coords$jscomp$4_pos_y$jscomp$7$$),")"].join(""),children:(0,$APP.$rumext$v2$jsx$$)("foreignObject",{width:200,height:100,style:{textAlign:"center"},
children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$tooltip$jscomp$1$$})})})};
$app$main$ui$workspace$viewport$widgets$frame_flow_STAR_$$=function($is_selected$jscomp$16_props_81539$$){var $zoom$jscomp$178$$=$is_selected$jscomp$16_props_81539$$.zoom,$on_frame_select$jscomp$2_on_pointer_down$jscomp$21$$=$is_selected$jscomp$16_props_81539$$.onFrameSelect,$flow_name_frame$jscomp$106$$=$is_selected$jscomp$16_props_81539$$.frame,$on_frame_enter$jscomp$2$$=$is_selected$jscomp$16_props_81539$$.onFrameEnter,$on_frame_leave$jscomp$2$$=$is_selected$jscomp$16_props_81539$$.onFrameLeave,
$flow$jscomp$11_on_pointer_enter$jscomp$17$$=$is_selected$jscomp$16_props_81539$$.flow;$is_selected$jscomp$16_props_81539$$=$is_selected$jscomp$16_props_81539$$.isSelected;var $pos$jscomp$165_x$jscomp$1302$$=$flow_name_frame$jscomp$106$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flow_name_frame$jscomp$106$$,$APP.$cljs$cst$1515$x$$),$on_pointer_leave$jscomp$17_y$jscomp$525$$=$flow_name_frame$jscomp$106$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($flow_name_frame$jscomp$106$$,
$APP.$cljs$cst$1516$y$$);$pos$jscomp$165_x$jscomp$1302$$=$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($pos$jscomp$165_x$jscomp$1302$$,$on_pointer_leave$jscomp$17_y$jscomp$525$$-35/$zoom$jscomp$178$$);var $frame_id$jscomp$168$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($flow_name_frame$jscomp$106$$);$flow_name_frame$jscomp$106$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$11_on_pointer_enter$jscomp$17$$);$on_frame_select$jscomp$2_on_pointer_down$jscomp$21$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$168$$),$APP.$rumext$v2$adapt$$($on_frame_select$jscomp$2_on_pointer_down$jscomp$21$$)],function($event$jscomp$738$$){var $params$jscomp$436$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1371$section$$,"interactions",$APP.$cljs$cst$1612$frame_id$$,$frame_id$jscomp$168$$],null);return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$738$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$738$$),
$APP.$app$util$dom$stop_propagation$$($event$jscomp$738$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_viewer$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$params$jscomp$436$$])))):null});$flow$jscomp$11_on_pointer_enter$jscomp$17$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$168$$),$APP.$rumext$v2$adapt$$($on_frame_enter$jscomp$2$$)],
function(){return $APP.$cljs$core$fn_QMARK_$$($on_frame_enter$jscomp$2$$)?$on_frame_enter$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_enter$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$168$$):$on_frame_enter$jscomp$2$$($frame_id$jscomp$168$$):null});$on_pointer_leave$jscomp$17_y$jscomp$525$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$168$$),$APP.$rumext$v2$adapt$$($on_frame_leave$jscomp$2$$)],function(){return $APP.$cljs$core$fn_QMARK_$$($on_frame_leave$jscomp$2$$)?
$on_frame_leave$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_leave$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$168$$):$on_frame_leave$jscomp$2$$($frame_id$jscomp$168$$):null});return(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:0,y:-15,width:1E5,height:24,transform:$app$main$ui$workspace$viewport$utils$text_transform$$($pos$jscomp$165_x$jscomp$1302$$,$zoom$jscomp$178$$),children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_widgets__frame-flow-badge-wrapper",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{onPointerDown:$on_frame_select$jscomp$2_on_pointer_down$jscomp$21$$,onPointerEnter:$flow$jscomp$11_on_pointer_enter$jscomp$17$$,onPointerLeave:$on_pointer_leave$jscomp$17_y$jscomp$525$$,className:"main_ui_workspace_viewport_widgets__frame-flow-badge-content "+($APP.$cljs$core$truth_$$($is_selected$jscomp$16_props_81539$$)?"main_ui_workspace_viewport_widgets__selected":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"play",size:"s"}),(0,$APP.$rumext$v2$jsx$$)("span",{children:$flow_name_frame$jscomp$106$$})]})})})};
$app$main$ui$workspace$viewport$widgets$frame_flows_STAR_$$=function($props_81540$$){var $zoom$jscomp$179$$=$props_81540$$.zoom,$selected$jscomp$211$$=$props_81540$$.selected,$on_frame_select$jscomp$3$$=$props_81540$$.onFrameSelect,$on_frame_enter$jscomp$3$$=$props_81540$$.onFrameEnter,$objects$jscomp$842$$=$props_81540$$.objects,$on_frame_leave$jscomp$3$$=$props_81540$$.onFrameLeave;return(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-flows",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$242$$,
$JSCompiler_temp_const$jscomp$1977_p__81541$$){var $JSCompiler_inline_result$jscomp$1979_flow_id$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1977_p__81541$$,0,null),$flow$jscomp$12$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1977_p__81541$$,1,null);$JSCompiler_temp_const$jscomp$1977_p__81541$$=$out_arr__44092__auto__$jscomp$242$$.push;var $frame$jscomp$inline_9553$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$842$$,
$APP.$cljs$cst$2061$starting_frame$$.$cljs$core$IFn$_invoke$arity$1$($flow$jscomp$12$$)),$frame_id$jscomp$inline_9554$$=$frame$jscomp$inline_9553$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$inline_9553$$,$APP.$cljs$cst$266$id$$);$JSCompiler_inline_result$jscomp$1979_flow_id$jscomp$12$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_flow_STAR_$$,{flow:$flow$jscomp$12$$,frame:$frame$jscomp$inline_9553$$,isSelected:$APP.$cljs$core$contains_QMARK_$$($selected$jscomp$211$$,
$frame_id$jscomp$inline_9554$$),zoom:$zoom$jscomp$179$$,onFrameEnter:$on_frame_enter$jscomp$3$$,onFrameLeave:$on_frame_leave$jscomp$3$$,onFrameSelect:$on_frame_select$jscomp$3$$},""+($frame_id$jscomp$inline_9554$$??"")+"-"+($JSCompiler_inline_result$jscomp$1979_flow_id$jscomp$12$$??""));$JSCompiler_temp_const$jscomp$1977_p__81541$$.call($out_arr__44092__auto__$jscomp$242$$,$JSCompiler_inline_result$jscomp$1979_flow_id$jscomp$12$$);return $out_arr__44092__auto__$jscomp$242$$},[],$props_81540$$.flows)})};
$app$main$ui$workspace$viewport$widgets$button_add_STAR_$$=function($map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$){var $icon_sz_zoom$jscomp$180$$=$map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$.zoom,$on_click$jscomp$60$$=$map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$.onClick;$map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$.shape);var $height$jscomp$220_map__81546__$1_rect_sz$$=
$APP.$cljs$core$__destructure_map$$($map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$),$rect_y$jscomp$3_x2$jscomp$48$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$220_map__81546__$1_rect_sz$$,$APP.$cljs$cst$1530$x2$$);$map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$220_map__81546__$1_rect_sz$$,$APP.$cljs$cst$1531$y2$$);$height$jscomp$220_map__81546__$1_rect_sz$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$220_map__81546__$1_rect_sz$$,
$APP.$cljs$cst$1527$height$$);var $center_x$jscomp$2_icon_x$jscomp$1$$=$rect_y$jscomp$3_x2$jscomp$48$$+22/$icon_sz_zoom$jscomp$180$$,$center_y$jscomp$2_icon_y$jscomp$1$$=$map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$-$height$jscomp$220_map__81546__$1_rect_sz$$/2;$map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$=$center_x$jscomp$2_icon_x$jscomp$1$$-16/$icon_sz_zoom$jscomp$180$$;$rect_y$jscomp$3_x2$jscomp$48$$=$center_y$jscomp$2_icon_y$jscomp$1$$-16/$icon_sz_zoom$jscomp$180$$;$height$jscomp$220_map__81546__$1_rect_sz$$=
32/$icon_sz_zoom$jscomp$180$$;var $rect_r$$=8/$icon_sz_zoom$jscomp$180$$;$center_x$jscomp$2_icon_x$jscomp$1$$-=8/$icon_sz_zoom$jscomp$180$$;$center_y$jscomp$2_icon_y$jscomp$1$$-=8/$icon_sz_zoom$jscomp$180$$;$icon_sz_zoom$jscomp$180$$=16/$icon_sz_zoom$jscomp$180$$;var $handle_click$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$60$$)],function(){return $APP.$cljs$core$fn_QMARK_$$($on_click$jscomp$60$$)?$on_click$jscomp$60$$.$cljs$core$IFn$_invoke$arity$0$?
$on_click$jscomp$60$$.$cljs$core$IFn$_invoke$arity$0$():$on_click$jscomp$60$$():null});return(0,$APP.$rumext$v2$jsxs$$)("g",{onClick:$handle_click$jscomp$7$$,className:"main_ui_workspace_viewport_widgets__button-add-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__81546_props_81545_rect_x$jscomp$3_y2$jscomp$50$$,y:$rect_y$jscomp$3_x2$jscomp$48$$,width:$height$jscomp$220_map__81546__$1_rect_sz$$,height:$height$jscomp$220_map__81546__$1_rect_sz$$,rx:$rect_r$$,ry:$rect_r$$}),(0,$APP.$rumext$v2$jsx$$)("use",
{x:$center_x$jscomp$2_icon_x$jscomp$1$$,y:$center_y$jscomp$2_icon_y$jscomp$1$$,width:$icon_sz_zoom$jscomp$180$$,height:$icon_sz_zoom$jscomp$180$$,href:"#icon-add",className:"main_ui_workspace_viewport_widgets__button-add-icon"})]})};
$app$main$ui$workspace$viewport_wasm$apply_modifiers_to_objects$$=function($objects$jscomp$843$$,$modifiers$jscomp$139$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objs$jscomp$20$$,$p__81547_t$jscomp$102$$){var $id$jscomp$1062$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81547_t$jscomp$102$$,0,null);$p__81547_t$jscomp$102$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81547_t$jscomp$102$$,1,null);return $APP.$cljs$core$contains_QMARK_$$($objs$jscomp$20$$,
$id$jscomp$1062$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($objs$jscomp$20$$,$id$jscomp$1062$$,$APP.$app$common$geom$shapes$apply_transform$$,$p__81547_t$jscomp$102$$):$objs$jscomp$20$$},$objects$jscomp$843$$,$modifiers$jscomp$139$$)};
$app$main$ui$workspace$viewport_wasm$apply_wasm_modifiers_to_ids$$=function($objects$jscomp$845$$,$wasm_modifiers$jscomp$1$$,$id_set$$){return $APP.$cljs$core$empty_QMARK_$$($wasm_modifiers$jscomp$1$$)||$APP.$cljs$core$empty_QMARK_$$($id_set$$)?$objects$jscomp$845$$:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objs$jscomp$21$$,$id$jscomp$1063$$){var $temp__5823__auto__$jscomp$252$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($wasm_modifiers$jscomp$1$$,$id$jscomp$1063$$);
return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$252$$)?$APP.$cljs$core$contains_QMARK_$$($objs$jscomp$21$$,$id$jscomp$1063$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($objs$jscomp$21$$,$id$jscomp$1063$$,$APP.$app$common$geom$shapes$apply_transform$$,$temp__5823__auto__$jscomp$252$$):$objs$jscomp$21$$:$objs$jscomp$21$$},$objects$jscomp$845$$,$id_set$$)};
$app$main$ui$workspace$viewport_wasm$outline_wasm_source_ids$$=function($base_objects$jscomp$6$$,$G__81553_selected$jscomp$213$$,$highlighted$jscomp$6$$,$edition$jscomp$18$$,$hover_ids$jscomp$7$$,$G__81553__$1_hover$jscomp$12$$,$G__81553__$2_frame_hover$jscomp$2$$){var $G__81553__$3_outlined_frame_id$$=$APP.$cljs$core$last$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($G__81553_selected$jscomp$213$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81551_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$6$$,
$p1__81551_SHARP_$$))},$hover_ids$jscomp$7$$)));$G__81553_selected$jscomp$213$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$truth_$$($G__81553_selected$jscomp$213$$)?$G__81553_selected$jscomp$213$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$),$APP.$cljs$core$truth_$$($highlighted$jscomp$6$$)?$highlighted$jscomp$6$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$),
$APP.$cljs$core$truth_$$($hover_ids$jscomp$7$$)?$hover_ids$jscomp$7$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$);$G__81553__$1_hover$jscomp$12$$=$APP.$cljs$core$uuid_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__81553__$1_hover$jscomp$12$$))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__81553_selected$jscomp$213$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($G__81553__$1_hover$jscomp$12$$)):$G__81553_selected$jscomp$213$$;$G__81553__$2_frame_hover$jscomp$2$$=
$APP.$cljs$core$uuid_QMARK_$$($G__81553__$2_frame_hover$jscomp$2$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__81553__$1_hover$jscomp$12$$,$G__81553__$2_frame_hover$jscomp$2$$):$G__81553__$1_hover$jscomp$12$$;$G__81553__$3_outlined_frame_id$$=$APP.$cljs$core$uuid_QMARK_$$($G__81553__$3_outlined_frame_id$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__81553__$2_frame_hover$jscomp$2$$,$G__81553__$3_outlined_frame_id$$):$G__81553__$2_frame_hover$jscomp$2$$;return $APP.$cljs$core$uuid_QMARK_$$($edition$jscomp$18$$)?
$APP.$cljs$core$disj$$.$cljs$core$IFn$_invoke$arity$2$($G__81553__$3_outlined_frame_id$$,$edition$jscomp$18$$):$G__81553__$3_outlined_frame_id$$};
$app$main$ui$workspace$viewport_wasm$transition_overlay_STAR_$$=function($props_81554$$){var $clip_path$jscomp$1$$=$props_81554$$.clipPath,$image$jscomp$39$$=$props_81554$$.image,$canvas_ref$jscomp$7$$=(0,$APP.$rumext$v2$use_ref$$)(null),$bitmap_QMARK_$$=typeof $image$jscomp$39$$!=="string";$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($image$jscomp$39$$)],function(){if($bitmap_QMARK_$$){var $temp__5825__auto__$jscomp$457$$=$APP.$rumext$v2$ref_val$$($canvas_ref$jscomp$7$$);
if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$457$$)&&$image$jscomp$39$$.width>0)return $temp__5825__auto__$jscomp$457$$.width=$image$jscomp$39$$.width,$temp__5825__auto__$jscomp$457$$.height=$image$jscomp$39$$.height,$temp__5825__auto__$jscomp$457$$.getContext("2d").drawImage($image$jscomp$39$$,0,0)}return null});return $bitmap_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("canvas",{"data-testid":"canvas-wasm-transition",ref:$canvas_ref$jscomp$7$$,style:{position:"absolute",inset:0,width:"100%",height:"100%",
objectFit:"cover",pointerEvents:"none",clipPath:$clip_path$jscomp$1$$}}):(0,$APP.$rumext$v2$jsx$$)("img",{"data-testid":"canvas-wasm-transition",src:$image$jscomp$39$$,draggable:!1,style:{position:"absolute",inset:0,width:"100%",height:"100%",objectFit:"cover",pointerEvents:"none",clipPath:$clip_path$jscomp$1$$}})};
$app$main$ui$workspace$viewport_wasm$viewport_STAR_$$=function($props_81558$$){var $palete_size$$=$props_81558$$.paleteSize,$selected$jscomp$214$$=$props_81558$$.selected,$layout$jscomp$34$$=$props_81558$$.layout,$file$jscomp$183$$=$props_81558$$.file,$page$jscomp$175$$=$props_81558$$.page,$wglobal$jscomp$2$$=$props_81558$$.wglobal,$map__81559$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_local$$),$map__81559__$1$$=$APP.$cljs$core$__destructure_map$$($map__81559$$),$edition$jscomp$19$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,$APP.$cljs$cst$2207$edition$$),$selrect$jscomp$98$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,$APP.$cljs$cst$1610$selrect$$),$panning$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,$APP.$cljs$cst$3110$panning$$),$zoom$jscomp$181$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,$APP.$cljs$cst$2204$zoom$$),$transform$jscomp$125$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,
$APP.$cljs$cst$1294$transform$$),$vbox$jscomp$73$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,$APP.$cljs$cst$1942$vbox$$),$edit_path$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,$APP.$cljs$cst$1940$edit_path$$),$highlighted$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,$APP.$cljs$cst$4366$highlighted$$),$vport$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81559__$1$$,$APP.$cljs$cst$2211$vport$$),
$map__81560__$1$$=$APP.$cljs$core$__destructure_map$$($wglobal$jscomp$2$$),$options_mode$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81560__$1$$,$APP.$cljs$cst$2208$options_mode$$),$tooltip$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81560__$1$$,$APP.$cljs$cst$2957$tooltip$$),$show_distances_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81560__$1$$,$APP.$cljs$cst$4561$show_distances_QMARK_$$),$preview_id$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81560__$1$$,
$APP.$cljs$cst$5134$preview_id$$),$picking_color_QMARK_$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81560__$1$$,$APP.$cljs$cst$4197$picking_color_QMARK_$$),$permissions$jscomp$38$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$),$read_only_QMARK_$jscomp$37$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$drawing$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_drawing$$),$focus$jscomp$26$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),
$wasm_modifiers$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_wasm_modifiers$$),$workspace_editor_state$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$),$file_id$jscomp$436$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$183$$,$APP.$cljs$cst$266$id$$),$vern$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$183$$,$APP.$cljs$cst$2588$vern$$),$objects$jscomp$846$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$175$$,
$APP.$cljs$cst$1636$objects$$),$page_id$jscomp$463$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$175$$,$APP.$cljs$cst$266$id$$),$background$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$175$$,$APP.$cljs$cst$2066$background$$,"#E8E9EA"),$guides$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$175$$,$APP.$cljs$cst$2065$guides$$),$base_objects$jscomp$7$$=$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$846$$,
$focus$jscomp$26$$),$objects_modified$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_objects$jscomp$7$$),$APP.$rumext$v2$adapt$$($wasm_modifiers$jscomp$2$$)],function(){return $app$main$ui$workspace$viewport_wasm$apply_modifiers_to_objects$$($base_objects$jscomp$7$$,$APP.$cljs$core$select_keys$$($wasm_modifiers$jscomp$2$$,$selected$jscomp$214$$))}),$selected_shapes$jscomp$39$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects_modified$$)),$selected$jscomp$214$$)),$alt_QMARK_$jscomp$21$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$shift_QMARK_$jscomp$43$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$mod_QMARK_$jscomp$15$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$space_QMARK_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$z_QMARK_$jscomp$5$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$cursor$jscomp$13$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6013$pointer_inner$$)),$hover_ids$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover$jscomp$13$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$measure_hover$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$hover_disabled_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$hover_top_frame_id$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$frame_hover$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$active_frames$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$canvas_init_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$initialized_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_guide_id_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$guide_hover_axis_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$on_guide_drag$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__81555_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($dragging_guide_id_STAR_$$,$p1__81555_SHARP_$$)}),$on_guide_hover$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__81556_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($guide_hover_axis_STAR_$$,$p1__81556_SHARP_$$)}),$vec__81561$$=$app$main$ui$workspace$viewport$viewport_ref$create_viewport_ref$$(),$viewport_ref$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81561$$,0,null),$on_viewport_ref$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81561$$,1,null),$canvas_ref$jscomp$8$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$text_editor_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$last_vern_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$prev_hover_grid_shown_QMARK__ref$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$disable_paste_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$in_viewport_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$move_stream$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$guide_frame$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$)),
$APP.$rumext$v2$adapt$$($base_objects$jscomp$7$$)],function(){var $parent_id$jscomp$110$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$root_frame_QMARK_$$,$base_objects$jscomp$7$$),$APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$));return $parent_id$jscomp$110$$!=null?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$7$$,$parent_id$jscomp$110$$):null}),$outline_wasm_ids$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_objects$jscomp$7$$),$APP.$rumext$v2$adapt$$($selected$jscomp$214$$),$APP.$rumext$v2$adapt$$($highlighted$jscomp$7$$),$APP.$rumext$v2$adapt$$($edition$jscomp$19$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover$jscomp$13$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$))],function(){return $app$main$ui$workspace$viewport_wasm$outline_wasm_source_ids$$($base_objects$jscomp$7$$,
$selected$jscomp$214$$,$highlighted$jscomp$7$$,$edition$jscomp$19$$,$APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$),$APP.$cljs$core$_deref$$($hover$jscomp$13$$),$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$))}),$objects_for_outlines$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_objects$jscomp$7$$),$APP.$rumext$v2$adapt$$($wasm_modifiers$jscomp$2$$),$APP.$rumext$v2$adapt$$($outline_wasm_ids$$)],function(){return $APP.$cljs$core$seq$$($wasm_modifiers$jscomp$2$$)?
$app$main$ui$workspace$viewport_wasm$apply_wasm_modifiers_to_ids$$($base_objects$jscomp$7$$,$wasm_modifiers$jscomp$2$$,$outline_wasm_ids$$):$base_objects$jscomp$7$$}),$zoom__$1$jscomp$6$$=$APP.$app$common$math$finite$$($zoom$jscomp$181$$,1),$drawing_tool$jscomp$7$$=$APP.$cljs$cst$2205$tool$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$5$$),$drawing_obj$$=$APP.$cljs$cst$2206$object$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$5$$),$selected_frames$jscomp$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1612$frame_id$$),$selected_shapes$jscomp$39$$),$selected_frame$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_frames$jscomp$3$$),1)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$7$$,$APP.$cljs$core$first$$($selected_frames$jscomp$3$$)):null,$edit_path_state$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path$$,$edition$jscomp$19$$),
$edit_path_mode$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_state$jscomp$2$$,$APP.$cljs$cst$4290$edit_mode$$),$path_editing_QMARK_$jscomp$3$$=$edit_path_state$jscomp$2$$!=null,$path_drawing_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_mode$$,$APP.$cljs$cst$4291$draw$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($drawing_obj$$,$APP.$cljs$cst$139$type$$))&&
$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2060$curve$$,$drawing_tool$jscomp$7$$),$editing_shape$jscomp$1$$=$APP.$cljs$core$truth_$$($edition$jscomp$19$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$7$$,$edition$jscomp$19$$):null,$editing_shape__$1$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_shape$jscomp$1$$),$APP.$rumext$v2$adapt$$($path_editing_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($base_objects$jscomp$7$$)],
function(){return $path_editing_QMARK_$jscomp$3$$?$APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($editing_shape$jscomp$1$$,$base_objects$jscomp$7$$):$editing_shape$jscomp$1$$}),$create_comment_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3489$comments$$,$drawing_tool$jscomp$7$$),$text_editing_QMARK_$jscomp$3$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$1$$),$grid_editing_QMARK_$jscomp$2$$=
$APP.$cljs$core$truth_$$($edition$jscomp$19$$)?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$7$$,$edition$jscomp$19$$):$edition$jscomp$19$$,$mode_inspect_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$3$$,$APP.$cljs$cst$2683$inspect$$),$page_transition_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$),$context_loss_overlay_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$context_loss_overlay_QMARK_$$),
$transition_reveal_rulers_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$transition_reveal_rulers_QMARK_$$),$on_click$jscomp$61$$=$app$main$ui$workspace$viewport$actions$on_click$$($hover$jscomp$13$$,$selected$jscomp$214$$,$edition$jscomp$19$$,$path_drawing_QMARK_$$,$drawing_tool$jscomp$7$$,$space_QMARK_$jscomp$5$$,$selrect$jscomp$98$$,$z_QMARK_$jscomp$5$$),$on_context_menu$jscomp$29$$=$app$main$ui$workspace$viewport$actions$on_context_menu$$($hover$jscomp$13$$,$hover_ids$jscomp$8$$,$read_only_QMARK_$jscomp$37$$),
$on_double_click$jscomp$8$$=$app$main$ui$workspace$viewport$actions$on_double_click$$($hover$jscomp$13$$,$hover_ids$jscomp$8$$,$selected$jscomp$214$$,$hover_top_frame_id$jscomp$7$$,$path_drawing_QMARK_$$,$base_objects$jscomp$7$$,$edition$jscomp$19$$,$drawing_tool$jscomp$7$$,$z_QMARK_$jscomp$5$$,$read_only_QMARK_$jscomp$37$$),$comp_inst_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$on_drag_enter$jscomp$8$$=$app$main$ui$workspace$viewport$actions$on_drag_enter$$($comp_inst_ref$jscomp$3$$),$on_drag_over$jscomp$2$$=
$app$main$ui$workspace$viewport$actions$on_drag_over$$($move_stream$jscomp$4$$),$on_drag_end$jscomp$2$$=$app$main$ui$workspace$viewport$actions$on_drag_over$$($comp_inst_ref$jscomp$3$$),$on_drop$jscomp$19$$=$app$main$ui$workspace$viewport$actions$on_drop$$($file$jscomp$183$$,$comp_inst_ref$jscomp$3$$),$on_pointer_down$jscomp$22$$=$app$main$ui$workspace$viewport$actions$on_pointer_down$$($APP.$cljs$core$_deref$$($hover$jscomp$13$$),$selected$jscomp$214$$,$edition$jscomp$19$$,$drawing_tool$jscomp$7$$,
$text_editing_QMARK_$jscomp$3$$,$path_editing_QMARK_$jscomp$3$$,$grid_editing_QMARK_$jscomp$2$$,$path_drawing_QMARK_$$,$create_comment_QMARK_$jscomp$1$$,$space_QMARK_$jscomp$5$$,$panning$jscomp$2$$,$z_QMARK_$jscomp$5$$,$read_only_QMARK_$jscomp$37$$),$on_pointer_up$jscomp$8$$=$app$main$ui$workspace$viewport$actions$on_pointer_up$$($disable_paste_ref$jscomp$3$$),$on_pointer_enter$jscomp$18$$=$app$main$ui$workspace$viewport$actions$on_pointer_enter$$($in_viewport_ref$jscomp$4$$),$on_pointer_leave$jscomp$18$$=
$app$main$ui$workspace$viewport$actions$on_pointer_leave$$($in_viewport_ref$jscomp$4$$),$on_pointer_move$jscomp$16$$=$app$main$ui$workspace$viewport$actions$on_pointer_move$$($move_stream$jscomp$4$$),$on_move_selected$jscomp$11$$=$app$main$ui$workspace$viewport$actions$on_move_selected$$($hover$jscomp$13$$,$hover_ids$jscomp$8$$,$selected$jscomp$214$$,$space_QMARK_$jscomp$5$$,$z_QMARK_$jscomp$5$$,$read_only_QMARK_$jscomp$37$$),$on_menu_selected$$=$app$main$ui$workspace$viewport$actions$on_menu_selected$$($hover$jscomp$13$$,
$hover_ids$jscomp$8$$,$selected$jscomp$214$$,$read_only_QMARK_$jscomp$37$$),$on_frame_enter$jscomp$4$$=$app$main$ui$workspace$viewport$actions$on_frame_enter$$($frame_hover$jscomp$3$$),$on_frame_leave$jscomp$4$$=$app$main$ui$workspace$viewport$actions$on_frame_leave$$($frame_hover$jscomp$3$$),$on_frame_select$jscomp$4$$=$app$main$ui$workspace$viewport$actions$on_frame_select$$($selected$jscomp$214$$,$read_only_QMARK_$jscomp$37$$),$disable_events_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,
$APP.$cljs$cst$3489$comments$$),$show_comments_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$7$$,$APP.$cljs$cst$3489$comments$$)||$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,$APP.$cljs$cst$3771$display_comments$$),$show_gradient_handlers_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$214$$),1),$show_grids_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,$APP.$cljs$cst$3775$display_guides$$)&&
$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_frame_outline_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$125$$,$APP.$cljs$cst$1804$move$$)&&$APP.$cljs$core$not$$($panning$jscomp$2$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_outlines_QMARK_$$=$transform$jscomp$125$$==null&&$APP.$cljs$core$not$$($panning$jscomp$2$$)&&$APP.$cljs$core$not$$($edition$jscomp$19$$)&&$APP.$cljs$core$not$$($drawing_obj$$)&&$APP.$cljs$core$not$$(function(){var $fexpr__81564$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$3489$comments$$,null,$APP.$cljs$cst$2060$curve$$,null],null),null);return $fexpr__81564$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__81564$$.$cljs$core$IFn$_invoke$arity$1$($drawing_tool$jscomp$7$$):$fexpr__81564$$($drawing_tool$jscomp$7$$)}())&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_pixel_grid_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,
$APP.$cljs$cst$3766$show_pixel_grid$$)&&$zoom__$1$jscomp$6$$>=8&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_text_editor_QMARK_$$=$APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$1$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$1$$))&&$APP.$cljs$core$not$$($page_transition_QMARK_$$):$editing_shape__$1$jscomp$1$$,$has_grid_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$1013$$=
$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$)!=null;return $and__5023__auto__$jscomp$1013$$?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$846$$,$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$)):$and__5023__auto__$jscomp$1013$$}(),$hover_grid_QMARK_$$=$APP.$cljs$core$truth_$$($has_grid_QMARK_$jscomp$1$$)?$APP.$cljs$core$not$$($page_transition_QMARK_$$):$has_grid_QMARK_$jscomp$1$$,$show_grid_editor_QMARK_$$=$APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$1$$)?
$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$1$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$):$editing_shape__$1$jscomp$1$$,$show_presence_QMARK_$$=$APP.$cljs$core$truth_$$($page_id$jscomp$463$$)?$APP.$cljs$core$not$$($page_transition_QMARK_$$):$page_id$jscomp$463$$,$show_prototypes_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$3$$,$APP.$cljs$cst$3781$prototype$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),
$show_selection_handlers_QMARK_$$=$APP.$cljs$core$seq$$($selected$jscomp$214$$)&&$APP.$cljs$core$not$$($show_text_editor_QMARK_$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$show_snap_distance_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,$APP.$cljs$cst$3774$dynamic_alignment$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$125$$,$APP.$cljs$cst$1804$move$$)&&$APP.$cljs$core$seq$$($selected$jscomp$214$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),
$show_snap_points_QMARK_$$=function(){var $and__5023__auto__$jscomp$1017_and__5023__auto____$1$jscomp$166$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,$APP.$cljs$cst$3774$dynamic_alignment$$)||$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,$APP.$cljs$cst$3769$snap_guides$$);return $and__5023__auto__$jscomp$1017_and__5023__auto____$1$jscomp$166$$?($and__5023__auto__$jscomp$1017_and__5023__auto____$1$jscomp$166$$=$APP.$cljs$core$truth_$$($drawing_obj$$)?$drawing_obj$$:$transform$jscomp$125$$,
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1017_and__5023__auto____$1$jscomp$166$$)?$APP.$cljs$core$not$$($page_transition_QMARK_$$):$and__5023__auto__$jscomp$1017_and__5023__auto____$1$jscomp$166$$):$and__5023__auto__$jscomp$1017_and__5023__auto____$1$jscomp$166$$}(),$show_selrect_QMARK_$$=$APP.$cljs$core$truth_$$($selrect$jscomp$98$$)?$APP.$cljs$core$empty_QMARK_$$($drawing$jscomp$5$$)&&!$text_editing_QMARK_$jscomp$3$$&&$APP.$cljs$core$not$$($page_transition_QMARK_$$):$selrect$jscomp$98$$,
$show_measures_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$1019_and__5023__auto____$1$jscomp$167_and__5023__auto____$2$jscomp$54$$=$APP.$cljs$core$not$$($transform$jscomp$125$$);return $and__5023__auto__$jscomp$1019_and__5023__auto____$1$jscomp$167_and__5023__auto____$2$jscomp$54$$?($and__5023__auto__$jscomp$1019_and__5023__auto____$1$jscomp$167_and__5023__auto____$2$jscomp$54$$=!$path_editing_QMARK_$jscomp$3$$)?($and__5023__auto__$jscomp$1019_and__5023__auto____$1$jscomp$167_and__5023__auto____$2$jscomp$54$$=
$APP.$cljs$core$truth_$$($show_distances_QMARK_$$)?$show_distances_QMARK_$$:$mode_inspect_QMARK_$jscomp$1$$?$mode_inspect_QMARK_$jscomp$1$$:$read_only_QMARK_$jscomp$37$$,$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1019_and__5023__auto____$1$jscomp$167_and__5023__auto____$2$jscomp$54$$)?$APP.$cljs$core$not$$($page_transition_QMARK_$$):$and__5023__auto__$jscomp$1019_and__5023__auto____$1$jscomp$167_and__5023__auto____$2$jscomp$54$$):$and__5023__auto__$jscomp$1019_and__5023__auto____$1$jscomp$167_and__5023__auto____$2$jscomp$54$$:
$and__5023__auto__$jscomp$1019_and__5023__auto____$1$jscomp$167_and__5023__auto____$2$jscomp$54$$}(),$show_artboard_names_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,$APP.$cljs$cst$3772$display_artboard_names$$)&&$APP.$cljs$core$not$$($page_transition_QMARK_$$),$hide_ui_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,$APP.$cljs$cst$3046$hide_ui$$),$rulers_ui$$=$app$render_wasm$rulers_state$display_state$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1620$layout$$,
$layout$jscomp$34$$,$APP.$cljs$cst$3050$selected_shapes$$,$selected_shapes$jscomp$39$$,$APP.$cljs$cst$3051$base_objects$$,$base_objects$jscomp$7$$],null)),$show_rulers_QMARK_$jscomp$2$$=$APP.$cljs$cst$3047$show_rulers_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rulers_ui$$),$frame_visible_QMARK_$jscomp$1$$=$APP.$cljs$cst$3048$frame_visible_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($rulers_ui$$),$offset_x$jscomp$19$$=$APP.$cljs$cst$1655$offset_x$$.$cljs$core$IFn$_invoke$arity$1$($rulers_ui$$),$offset_y$jscomp$20$$=
$APP.$cljs$cst$1656$offset_y$$.$cljs$core$IFn$_invoke$arity$1$($rulers_ui$$),$ruler_selection$jscomp$1$$=$APP.$cljs$cst$3049$ruler_selection$$.$cljs$core$IFn$_invoke$arity$1$($rulers_ui$$),$disabled_guides_QMARK_$jscomp$2$$=$APP.$cljs$core$truth_$$($drawing_tool$jscomp$7$$)?$drawing_tool$jscomp$7$$:$APP.$cljs$core$truth_$$($transform$jscomp$125$$)?$transform$jscomp$125$$:$path_drawing_QMARK_$$||$path_editing_QMARK_$jscomp$3$$||$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$34$$,$APP.$cljs$cst$3770$lock_guides$$),
$wasm_guides$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($guides$jscomp$16$$),$APP.$rumext$v2$adapt$$($focus$jscomp$26$$),$APP.$rumext$v2$adapt$$($show_rulers_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($show_grids_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($dragging_guide_id_STAR_$$))],function(){return $app$main$ui$workspace$viewport$guides$wasm_visible_guides$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2065$guides$$,
$guides$jscomp$16$$,$cljs$cst$5968$visible_QMARK_$$,$APP.$cljs$core$truth_$$($show_rulers_QMARK_$jscomp$2$$)?$show_grids_QMARK_$jscomp$2$$:$show_rulers_QMARK_$jscomp$2$$,$APP.$cljs$cst$4824$focused$$,$focus$jscomp$26$$,$cljs$cst$5969$dragging_id$$,$APP.$cljs$core$_deref$$($dragging_guide_id_STAR_$$)],null))}),$single_select_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$39$$),1),$first_shape$jscomp$13$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$39$$),
$show_add_variant_QMARK_$$=$single_select_QMARK_$$&&($APP.$app$common$types$component$is_variant_container_QMARK_$$($first_shape$jscomp$13$$)||$APP.$app$common$types$component$is_variant_QMARK_$$($first_shape$jscomp$13$$)),$show_scrollbar_QMARK_$$=$APP.$cljs$core$not$$($page_transition_QMARK_$$),$add_variant$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($first_shape$jscomp$13$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$)))}),
$show_padding_QMARK_$$=$transform$jscomp$125$$==null&&$single_select_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$),$APP.$cljs$cst$1611$frame$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$),$APP.$cljs$cst$1665$flex$$)&&$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$)===
0,$show_margin_QMARK_$$=$transform$jscomp$125$$==null&&$single_select_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$6$$),$APP.$cljs$cst$1665$flex$$)&&$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$13$$)===0,$rule_area_size$jscomp$1$$=22/$zoom__$1$jscomp$6$$,$preview_blend$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_preview_blend$$),$shapes_loading_QMARK_$$=
$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$shapes_loading_QMARK_$$),$transition_image$$=$APP.$rumext$v2$deref$$($APP.$app$render_wasm$api$transition_image_STAR_$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$463$$)],function(){var $temp__5825__auto__$jscomp$458$$=$APP.$rumext$v2$ref_val$$($canvas_ref$jscomp$8$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$458$$)){var $timeout_id_ref$$=$APP.$cljs$core$volatile_BANG_$$(null),
$unmounted_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!1),$modal_shown_QMARK_$$=$APP.$cljs$core$volatile_BANG_$$(!1),$show_unavailable$$=function(){var $JSCompiler_inline_result$jscomp$1980_or__5025__auto__$jscomp$inline_9556$$=$APP.$cljs$core$_deref$$($unmounted_QMARK_$$);$JSCompiler_inline_result$jscomp$1980_or__5025__auto__$jscomp$inline_9556$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1980_or__5025__auto__$jscomp$inline_9556$$)?$JSCompiler_inline_result$jscomp$1980_or__5025__auto__$jscomp$inline_9556$$:
$APP.$cljs$core$_deref$$($modal_shown_QMARK_$$);if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1980_or__5025__auto__$jscomp$inline_9556$$))return null;$APP.$cljs$core$_vreset_BANG_$$($modal_shown_QMARK_$$,!0);$APP.$cljs$core$reset_BANG_$$($canvas_init_QMARK_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$cljs$cst$6028$webgl_unavailable$$],
null)))},$try_init$$=function $app$main$ui$workspace$viewport_wasm$viewport_STAR__$_try_init$$($retries$jscomp$2$$){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($unmounted_QMARK_$$)))return null;try{var $init_QMARK_$$=$APP.$app$render_wasm$api$init_canvas_context$$($temp__5825__auto__$jscomp$458$$)}catch($e81565$jscomp$inline_9558$$){console.error("Error initializing canvas context:",$e81565$jscomp$inline_9558$$),$init_QMARK_$$=!1}return $APP.$cljs$core$truth_$$($init_QMARK_$$)?$APP.$cljs$core$reset_BANG_$$($canvas_init_QMARK_$$,
!0):$retries$jscomp$2$$>0?$APP.$cljs$core$vreset_BANG_$$($timeout_id_ref$$,setTimeout(function(){return $app$main$ui$workspace$viewport_wasm$viewport_STAR__$_try_init$$($retries$jscomp$2$$-1)},200)):$show_unavailable$$()};$APP.$cljs$core$reset_BANG_$$($canvas_init_QMARK_$$,!1);$APP.$promesa$core$fmap$cljs$0core$0IFn$0_invoke$0arity$02$$(function($ready_QMARK_$jscomp$3$$){return $APP.$cljs$core$truth_$$($ready_QMARK_$jscomp$3$$)?$try_init$$(3):null},$APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$module$$));
return function(){$APP.$cljs$core$_vreset_BANG_$$($unmounted_QMARK_$$,!0);var $temp__5825__auto___81607__$1$$=$APP.$cljs$core$_deref$$($timeout_id_ref$$);$APP.$cljs$core$truth_$$($temp__5825__auto___81607__$1$$)&&clearTimeout($temp__5825__auto___81607__$1$$);return $APP.$app$render_wasm$api$clear_canvas$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)}}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_text_editor_QMARK_$$),
$APP.$rumext$v2$adapt$$($workspace_editor_state$jscomp$1$$),$APP.$rumext$v2$adapt$$($edition$jscomp$19$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($initialized_QMARK_$$))],function(){var $active_editor_state$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($workspace_editor_state$jscomp$1$$,$edition$jscomp$19$$);if($APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($show_text_editor_QMARK_$$)){if($APP.$cljs$core$truth_$$($active_editor_state$$)){var $and__5023__auto____$2$jscomp$55$$=
$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);return $APP.$cljs$core$truth_$$($and__5023__auto____$2$jscomp$55$$)?$APP.$cljs$core$_deref$$($initialized_QMARK_$$):$and__5023__auto____$2$jscomp$55$$}return $active_editor_state$$}return $show_text_editor_QMARK_$$}())){var $content$jscomp$273_dimension$jscomp$1$$=$app$util$text_editor$export_content$$($active_editor_state$$.getCurrentContent());$APP.$app$render_wasm$api$use_shape$$($edition$jscomp$19$$);$APP.$app$render_wasm$api$set_shape_text_content$$($edition$jscomp$19$$,
$content$jscomp$273_dimension$jscomp$1$$);$content$jscomp$273_dimension$jscomp$1$$=$APP.$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$00$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$resize_text_editor$$($edition$jscomp$19$$,$content$jscomp$273_dimension$jscomp$1$$));return $APP.$app$render_wasm$api$request_render$$("content")}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))],
function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))){var $canvas$jscomp$31$$=$APP.$rumext$v2$ref_val$$($canvas_ref$jscomp$8$$);return $APP.$app$util$webapi$on_dpr_change$$(function($new_dpr$jscomp$2$$){$APP.$app$render_wasm$api$resize_canvas_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($canvas$jscomp$31$$,$new_dpr$jscomp$2$$);$app$render_wasm$api$render_ui_only$$();return(0,$APP.$app$util$timers$request_animation_frame$$)(function(){if($APP.$app$render_wasm$api$initialized_QMARK_$$()){var $JSCompiler_inline_result$jscomp$1550_cause53824_54620$jscomp$inline_9561_fn_53823_54619$jscomp$inline_9560$$=
$APP.$app$render_wasm$wasm$internal_module$$._render_sync;try{$JSCompiler_inline_result$jscomp$1550_cause53824_54620$jscomp$inline_9561_fn_53823_54619$jscomp$inline_9560$$()}catch($e53826$jscomp$inline_9566$$){$JSCompiler_inline_result$jscomp$1550_cause53824_54620$jscomp$inline_9561_fn_53823_54619$jscomp$inline_9560$$=$e53826$jscomp$inline_9566$$;var $code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$=
$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$=$APP.$cljs$core$truth_$$($code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$)?$code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$.$cljs$core$IFn$_invoke$arity$0$?
$code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$():null;$code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,
$code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto___54624$jscomp$inline_9565$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___54624$jscomp$inline_9565$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_render_sync",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___54624$jscomp$inline_9565$$,$APP.$cljs$cst$273$code$$,$code__53067__auto___54623$jscomp$inline_9564_code_num__53066__auto___54622$jscomp$inline_9563_read_code_fn__53065__auto___54621$jscomp$inline_9562$$],null),$JSCompiler_inline_result$jscomp$1550_cause53824_54620$jscomp$inline_9561_fn_53823_54619$jscomp$inline_9560$$);
}$JSCompiler_inline_result$jscomp$1550_cause53824_54620$jscomp$inline_9561_fn_53823_54619$jscomp$inline_9560$$=$APP.$app$render_wasm$wasm$internal_frame_id$$=null}else $JSCompiler_inline_result$jscomp$1550_cause53824_54620$jscomp$inline_9561_fn_53823_54619$jscomp$inline_9560$$=null;return $JSCompiler_inline_result$jscomp$1550_cause53824_54620$jscomp$inline_9561_fn_53823_54619$jscomp$inline_9560$$})})}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vport$jscomp$14$$)],
function(){var $JSCompiler_inline_result$jscomp$1981_and__5023__auto__$jscomp$inline_9568$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);$JSCompiler_inline_result$jscomp$1981_and__5023__auto__$jscomp$inline_9568$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1981_and__5023__auto__$jscomp$inline_9568$$)?$APP.$cljs$core$_deref$$($initialized_QMARK_$$):$JSCompiler_inline_result$jscomp$1981_and__5023__auto__$jscomp$inline_9568$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1981_and__5023__auto__$jscomp$inline_9568$$)?
($APP.$app$render_wasm$api$resize_canvas_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($canvas_ref$jscomp$8$$),$APP.$app$render_wasm$api$get_dpr$$()),$APP.$app$render_wasm$api$set_view_box$$($zoom__$1$jscomp$6$$,$vbox$jscomp$73$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($preview_blend$$)],function(){var $and__5023__auto__$jscomp$inline_9572$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9572$$)?$preview_blend$$:$and__5023__auto__$jscomp$inline_9572$$)?$APP.$app$render_wasm$api$request_render$$("with-effect"):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($vern$jscomp$4$$),$APP.$rumext$v2$adapt$$($zoom__$1$jscomp$6$$),$APP.$rumext$v2$adapt$$($vbox$jscomp$73$$),$APP.$rumext$v2$adapt$$($background$jscomp$13$$)],
function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))){if($APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($initialized_QMARK_$$)))return $APP.$rumext$v2$set_ref_val_BANG_$$($last_vern_ref$$,$vern$jscomp$4$$),$app$render_wasm$api$start_initial_load_transition_BANG_$$($background$jscomp$13$$),$APP.$app$render_wasm$api$initialize_viewport$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_objects$jscomp$7$$,$zoom__$1$jscomp$6$$,$vbox$jscomp$73$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2066$background$$,
$background$jscomp$13$$,$APP.$cljs$cst$3117$on_shapes_ready$$,function(){$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($APP.$app$render_wasm$api$page_transition_QMARK_$$))&&$app$render_wasm$api$set_transition_tiles_complete_handler_BANG_$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$update_page_position_data$cljs$0core$0IFn$0_invoke$0arity$02$$())}])),$APP.$cljs$core$reset_BANG_$$($initialized_QMARK_$$,!0);if($vern$jscomp$4$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($vern$jscomp$4$$,
$APP.$rumext$v2$ref_val$$($last_vern_ref$$)))return $APP.$app$render_wasm$api$initialize_viewport$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($base_objects$jscomp$7$$,$zoom__$1$jscomp$6$$,$vbox$jscomp$73$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$2066$background$$,$background$jscomp$13$$])),$APP.$rumext$v2$set_ref_val_BANG_$$($last_vern_ref$$,$vern$jscomp$4$$)}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($focus$jscomp$26$$)],
function(){return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1024$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1024$$)?$APP.$cljs$core$_deref$$($initialized_QMARK_$$):$and__5023__auto__$jscomp$1024$$}())?$APP.$app$util$timers$asap$$(function(){if($APP.$cljs$core$empty_QMARK_$$($focus$jscomp$26$$)){var $JSCompiler_temp$jscomp$1644_cause54376_55138$jscomp$inline_9576_fn_54375_55137$jscomp$inline_9575$$=$APP.$app$render_wasm$wasm$internal_module$$._clear_focus_mode;
try{$JSCompiler_temp$jscomp$1644_cause54376_55138$jscomp$inline_9576_fn_54375_55137$jscomp$inline_9575$$()}catch($e54377$jscomp$inline_9581$$){$JSCompiler_temp$jscomp$1644_cause54376_55138$jscomp$inline_9576_fn_54375_55137$jscomp$inline_9575$$=$e54377$jscomp$inline_9581$$;var $code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$=
$APP.$cljs$core$truth_$$($code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$)?$code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$.$cljs$core$IFn$_invoke$arity$0$():
$code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$():null;$code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$,
$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto___55142$jscomp$inline_9580$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___55142$jscomp$inline_9580$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_clear_focus_mode",
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___55142$jscomp$inline_9580$$,$APP.$cljs$cst$273$code$$,$code__53067__auto___55141$jscomp$inline_9579_code_num__53066__auto___55140$jscomp$inline_9578_read_code_fn__53065__auto___55139$jscomp$inline_9577$$],null),$JSCompiler_temp$jscomp$1644_cause54376_55138$jscomp$inline_9576_fn_54375_55137$jscomp$inline_9575$$);}$JSCompiler_temp$jscomp$1644_cause54376_55138$jscomp$inline_9576_fn_54375_55137$jscomp$inline_9575$$=
$APP.$app$render_wasm$api$request_render$$("clear-focus-mode")}else $JSCompiler_temp$jscomp$1644_cause54376_55138$jscomp$inline_9576_fn_54375_55137$jscomp$inline_9575$$=$app$render_wasm$api$set_focus_mode$$($focus$jscomp$26$$);return $JSCompiler_temp$jscomp$1644_cause54376_55138$jscomp$inline_9576_fn_54375_55137$jscomp$inline_9575$$}):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($background$jscomp$13$$)],function(){var $JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$=
$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);$JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$)?$APP.$cljs$core$_deref$$($initialized_QMARK_$$):$JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$;
if($APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$)){$JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$=$APP.$app$render_wasm$serializers$color$hex__GT_u32argb$$($background$jscomp$13$$,1);var $code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$=
$APP.$app$render_wasm$wasm$internal_module$$._set_canvas_background;try{$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$($JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$)}catch($e54411$jscomp$inline_14060$$){$JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$=
$e54411$jscomp$inline_14060$$;$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$=$APP.$cljs$core$truth_$$($code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$)?
$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$():
null;$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$,$APP.$cljs$cst$2982$wasm_critical$$);
var $hint__53068__auto___55183$jscomp$inline_14059$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___55183$jscomp$inline_14059$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_canvas_background",
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___55183$jscomp$inline_14059$$,$APP.$cljs$cst$273$code$$,$code__53067__auto___55182$jscomp$inline_14058_code_num__53066__auto___55181$jscomp$inline_14057_fn_54409_55177$jscomp$inline_14054_read_code_fn__53065__auto___55180$jscomp$inline_14056$$],null),$JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$);
}$JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$=$APP.$app$render_wasm$api$request_render$$("set-canvas-background")}else $JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$=null;return $JSCompiler_inline_result$jscomp$1983_JSCompiler_temp$jscomp$11259_and__5023__auto__$jscomp$inline_9583_cause54410_55179$jscomp$inline_14055_rgba$jscomp$inline_14053$$});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($hover_grid_QMARK_$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))){var $and__5023__auto__$jscomp$inline_9585_cause54530_55427$jscomp$inline_14063_fn_54529_55426$jscomp$inline_14062$$=$APP.$cljs$core$not$$($hover_grid_QMARK_$$);if($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9585_cause54530_55427$jscomp$inline_14063_fn_54529_55426$jscomp$inline_14062$$?
$APP.$rumext$v2$ref_val$$($prev_hover_grid_shown_QMARK__ref$$):$and__5023__auto__$jscomp$inline_9585_cause54530_55427$jscomp$inline_14063_fn_54529_55426$jscomp$inline_14062$$)){$and__5023__auto__$jscomp$inline_9585_cause54530_55427$jscomp$inline_14063_fn_54529_55426$jscomp$inline_14062$$=$APP.$app$render_wasm$wasm$internal_module$$._hide_grid;try{$and__5023__auto__$jscomp$inline_9585_cause54530_55427$jscomp$inline_14063_fn_54529_55426$jscomp$inline_14062$$()}catch($e54531$jscomp$inline_14068$$){$and__5023__auto__$jscomp$inline_9585_cause54530_55427$jscomp$inline_14063_fn_54529_55426$jscomp$inline_14062$$=
$e54531$jscomp$inline_14068$$;var $code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$=$APP.$cljs$core$truth_$$($code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$)?
$code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$():
null;$code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto___55432$jscomp$inline_14067$$=["WASM Error (",
$APP.$app$common$data$name$$($code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___55432$jscomp$inline_14067$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_hide_grid",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___55432$jscomp$inline_14067$$,
$APP.$cljs$cst$273$code$$,$code__53067__auto___55431$jscomp$inline_14066_code_num__53066__auto___55430$jscomp$inline_14065_read_code_fn__53065__auto___55429$jscomp$inline_14064$$],null),$and__5023__auto__$jscomp$inline_9585_cause54530_55427$jscomp$inline_14063_fn_54529_55426$jscomp$inline_14062$$);}$APP.$app$render_wasm$api$request_render$$("clear-grid")}return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_hover_grid_shown_QMARK__ref$$,$hover_grid_QMARK_$$)}return null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),
$APP.$rumext$v2$adapt$$($has_grid_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($hover_grid_QMARK_$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($has_grid_QMARK_$jscomp$1$$)?$hover_grid_QMARK_$$:$has_grid_QMARK_$jscomp$1$$)?$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$):$cljs$cst$6029$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_wasm_SLASH_no_grid_hover_id$$)],function(){var $JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$=
$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$)?$hover_grid_QMARK_$$:$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$)){$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$=
$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$);$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$=$APP.$app$common$uuid$get_u32$$($JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$);var $code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$=
$APP.$app$render_wasm$wasm$internal_module$$._show_grid;try{$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$($JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$[0],$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$[1],
$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$[2],$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$[3])}catch($e54510$jscomp$inline_14078$$){$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$=
$e54510$jscomp$inline_14078$$;$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$=$APP.$cljs$core$truth_$$($code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$)?
$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$():
null;$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$,$APP.$cljs$cst$2982$wasm_critical$$);
var $hint__53068__auto___55390$jscomp$inline_14077$$=["WASM Error (",$APP.$app$common$data$name$$($code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___55390$jscomp$inline_14077$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_show_grid",
$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___55390$jscomp$inline_14077$$,$APP.$cljs$cst$273$code$$,$code__53067__auto___55389$jscomp$inline_14076_code_num__53066__auto___55388$jscomp$inline_14075_fn_54508_55385$jscomp$inline_14072_read_code_fn__53065__auto___55387$jscomp$inline_14074$$],null),$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$);
}$JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$=$APP.$app$render_wasm$api$request_render$$("show-grid")}else $JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$=null;return $JSCompiler_temp$jscomp$11258_and__5023__auto__$jscomp$inline_9587_buffer_55384$jscomp$inline_14071_cause54509_55386$jscomp$inline_14073_id$jscomp$inline_14070$$});
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))?($APP.$app$render_wasm$api$push_ruler_theme_colors_BANG_$$(),$app$util$theme$add_color_scheme_listener_BANG_$$(function(){$APP.$app$render_wasm$api$push_ruler_theme_colors_BANG_$$();return $APP.$app$render_wasm$api$request_render$$("rulers-colors-theme")})):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),
$APP.$rumext$v2$adapt$$($frame_visible_QMARK_$jscomp$1$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))?($APP.$app$render_wasm$api$set_rulers_frame_visible_BANG_$$($frame_visible_QMARK_$jscomp$1$$),$app$render_wasm$api$render_from_cache_BANG_$$()):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($show_rulers_QMARK_$jscomp$2$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))?
($APP.$app$render_wasm$api$set_rulers_visible_BANG_$$($show_rulers_QMARK_$jscomp$2$$),$app$render_wasm$api$render_from_cache_BANG_$$()):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($show_rulers_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($offset_x$jscomp$19$$),$APP.$rumext$v2$adapt$$($offset_y$jscomp$20$$)],function(){var $and__5023__auto__$jscomp$inline_9589$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);
return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9589$$)?$show_rulers_QMARK_$jscomp$2$$:$and__5023__auto__$jscomp$inline_9589$$)?$APP.$app$render_wasm$api$set_rulers_offsets_BANG_$$($offset_x$jscomp$19$$,$offset_y$jscomp$20$$):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($show_rulers_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($ruler_selection$jscomp$1$$==
null?null:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($ruler_selection$jscomp$1$$)),$APP.$rumext$v2$adapt$$($ruler_selection$jscomp$1$$==null?null:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($ruler_selection$jscomp$1$$)),$APP.$rumext$v2$adapt$$($ruler_selection$jscomp$1$$==null?null:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($ruler_selection$jscomp$1$$)),$APP.$rumext$v2$adapt$$($ruler_selection$jscomp$1$$==null?null:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($ruler_selection$jscomp$1$$))],
function(){var $and__5023__auto__$jscomp$inline_9591$$=$APP.$cljs$core$_deref$$($canvas_init_QMARK_$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9591$$)?$show_rulers_QMARK_$jscomp$2$$:$and__5023__auto__$jscomp$inline_9591$$)?($APP.$app$render_wasm$api$set_rulers_selection_BANG_$$($ruler_selection$jscomp$1$$),$app$render_wasm$api$render_from_cache_BANG_$$()):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),
$APP.$rumext$v2$adapt$$($page_id$jscomp$463$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))?$app$render_wasm$api$render_ui_only$$():null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$)),$APP.$rumext$v2$adapt$$($wasm_guides$jscomp$3$$),$APP.$rumext$v2$adapt$$($objects$jscomp$846$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($canvas_init_QMARK_$$))){var $JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$=
4+$APP.$cljs$core$count$$($APP.$cljs$core$truth_$$($wasm_guides$jscomp$3$$)?$wasm_guides$jscomp$3$$:$APP.$cljs$core$PersistentArrayMap$EMPTY$$)*20;$JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$=$APP.$app$render_wasm$mem$alloc__GT_offset_32$$($JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$);$app$render_wasm$serializers$write_guides$$($wasm_guides$jscomp$3$$,
$objects$jscomp$846$$,$JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$);$JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$=$APP.$app$render_wasm$wasm$internal_module$$._set_guides;try{$JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$()}catch($e54534$jscomp$inline_9603$$){$JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$=
$e54534$jscomp$inline_9603$$;var $code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$=$APP.$app$render_wasm$wasm$internal_module$$._read_error_code;$code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$=$APP.$cljs$core$truth_$$($code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$)?
$code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$.$cljs$core$IFn$_invoke$arity$0$?$code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$.$cljs$core$IFn$_invoke$arity$0$():$code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$():
null;$code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$render_wasm$helpers$error_code$$,$code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$,$APP.$cljs$cst$2982$wasm_critical$$);var $hint__53068__auto___55449$jscomp$inline_9602$$=["WASM Error (",
$APP.$app$common$data$name$$($code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$),")"].join("");throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$($hint__53068__auto___55449$jscomp$inline_9602$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$516$fn$$,"_set_guides",$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2983$wasm_error$$,$APP.$cljs$cst$275$hint$$,$hint__53068__auto___55449$jscomp$inline_9602$$,
$APP.$cljs$cst$273$code$$,$code__53067__auto___55448$jscomp$inline_9601_code_num__53066__auto___55447$jscomp$inline_9600_read_code_fn__53065__auto___55446$jscomp$inline_9599$$],null),$JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$);}$JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$=$APP.$app$render_wasm$api$request_render$$("set-guides")}else $JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$=
null;return $JSCompiler_temp$jscomp$1643_cause54533_55445$jscomp$inline_9598_fn_54532_55444$jscomp$inline_9597_offset$jscomp$inline_9596_size$jscomp$inline_9595$$});$app$main$ui$workspace$viewport$hooks$setup_dom_events$$($zoom__$1$jscomp$6$$,$disable_paste_ref$jscomp$3$$,$in_viewport_ref$jscomp$4$$,$read_only_QMARK_$jscomp$37$$,$drawing_tool$jscomp$7$$,$path_drawing_QMARK_$$);$app$main$ui$workspace$viewport$hooks$setup_viewport_size$$($vport$jscomp$14$$,$viewport_ref$jscomp$3$$);$app$main$ui$workspace$viewport$hooks$setup_cursor$$($cursor$jscomp$13$$,
$alt_QMARK_$jscomp$21$$,$mod_QMARK_$jscomp$15$$,$space_QMARK_$jscomp$5$$,$panning$jscomp$2$$,$drawing_tool$jscomp$7$$,$path_drawing_QMARK_$$,$path_editing_QMARK_$jscomp$3$$,$z_QMARK_$jscomp$5$$,$read_only_QMARK_$jscomp$37$$);$app$main$ui$workspace$viewport$hooks$setup_keyboard$$($alt_QMARK_$jscomp$21$$,$mod_QMARK_$jscomp$15$$,$space_QMARK_$jscomp$5$$,$z_QMARK_$jscomp$5$$,$shift_QMARK_$jscomp$43$$);$app$main$ui$workspace$viewport$hooks$setup_hover_shapes$$($page_id$jscomp$463$$,$move_stream$jscomp$4$$,
$base_objects$jscomp$7$$,$selected$jscomp$214$$,$mod_QMARK_$jscomp$15$$,$hover$jscomp$13$$,$measure_hover$jscomp$1$$,$hover_ids$jscomp$8$$,$hover_top_frame_id$jscomp$7$$,$APP.$cljs$core$_deref$$($hover_disabled_QMARK_$jscomp$1$$),$focus$jscomp$26$$,$zoom__$1$jscomp$6$$,$show_measures_QMARK_$jscomp$1$$,$read_only_QMARK_$jscomp$37$$,$transform$jscomp$125$$);$app$main$ui$workspace$viewport$hooks$setup_shortcuts$$($path_editing_QMARK_$jscomp$3$$,$path_drawing_QMARK_$$,$text_editing_QMARK_$jscomp$3$$,
$grid_editing_QMARK_$jscomp$2$$);$app$main$ui$workspace$viewport$hooks$setup_active_frames$$($base_objects$jscomp$7$$,$hover_ids$jscomp$8$$,$selected$jscomp$214$$,$active_frames$jscomp$3$$,$zoom__$1$jscomp$6$$,$transform$jscomp$125$$,$vbox$jscomp$73$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--zoom":$zoom__$1$jscomp$6$$},"data-testid":"viewport",className:"main_ui_workspace_viewport_wasm__viewport",children:[$preview_id$$!=null?null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$37$$)?
$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$38$$):$read_only_QMARK_$jscomp$37$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$view_only_bar_STAR_$$,{}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$hide_ui_QMARK_$jscomp$1$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$top_toolbar$top_toolbar_STAR_$$,{layout:$layout$jscomp$34$$}),$path_editing_QMARK_$jscomp$3$$&&$single_select_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$path_edition_bar_STAR_$$,
{shape:$editing_shape__$1$jscomp$1$$,editPathState:$edit_path_state$jscomp$2$$,layout:$layout$jscomp$34$$}):null,$grid_editing_QMARK_$jscomp$2$$&&$single_select_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$grid_edition_bar_STAR_$$,{shape:$editing_shape__$1$jscomp$1$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport_wasm__viewport-overlays",children:[$show_comments_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$comments$comments_layer_STAR_$$,
{vbox:$vbox$jscomp$73$$,pageId:$page_id$jscomp$463$$,fileId:$file_id$jscomp$436$$,vport:$vport$jscomp$14$$,zoom:$zoom__$1$jscomp$6$$}):null,$APP.$cljs$core$truth_$$($picking_color_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_wasm_STAR_$$,{viewportRef:$viewport_ref$jscomp$3$$,canvasRef:$canvas_ref$jscomp$8$$}):null]}),(0,$APP.$rumext$v2$jsx$$)("canvas",{id:"render","data-testid":"canvas-wasm-shapes",ref:$canvas_ref$jscomp$8$$,style:{backgroundColor:$background$jscomp$13$$,
pointerEvents:"none"},className:"main_ui_workspace_viewport_wasm__render-shapes"},"render"+($page_id$jscomp$463$$??"")),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1032$$=$APP.$cljs$core$truth_$$($page_transition_QMARK_$$)?$page_transition_QMARK_$$:$context_loss_overlay_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1032$$)?$transition_image$$!=null:$and__5023__auto__$jscomp$1032$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport_wasm$transition_overlay_STAR_$$,
{image:$transition_image$$,clipPath:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($transition_reveal_rulers_QMARK_$$)?$frame_visible_QMARK_$jscomp$1$$:$transition_reveal_rulers_QMARK_$$)?function(){var $strip$$=$APP.$cljs$core$truth_$$($show_rulers_QMARK_$jscomp$2$$)?22:0;return"inset("+($strip$$??"")+"px 0 0 "+($strip$$??"")+"px round 12px)"}():null}):null,(0,$APP.$rumext$v2$jsxs$$)("svg",{onDoubleClick:$on_double_click$jscomp$8$$,onDragEnter:$on_drag_enter$jscomp$8$$,xmlns:"http://www.w3.org/2000/svg",
className:"viewport-controls "+(($APP.$cljs$core$_deref$$($cursor$jscomp$13$$)??"")+" "+(($APP.$cljs$core$truth_$$($drawing_tool$jscomp$7$$)?"drawing":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($guide_hover_axis_STAR_$$),$APP.$cljs$cst$1515$x$$)?"cursor-resize-ew-0":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($guide_hover_axis_STAR_$$),$APP.$cljs$cst$1516$y$$)?"cursor-resize-ns-0":"")+" main_ui_workspace_viewport_wasm__viewport-controls")),
children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:"clip-handlers",children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$73$$)+$rule_area_size$jscomp$1$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$73$$)+$rule_area_size$jscomp$1$$,width:function(){var $y__5111__auto__$jscomp$193$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$73$$)-$rule_area_size$jscomp$1$$;
return 0>$y__5111__auto__$jscomp$193$$?0:$y__5111__auto__$jscomp$193$$}(),height:function(){var $y__5111__auto__$jscomp$194$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$73$$)-$rule_area_size$jscomp$1$$;return 0>$y__5111__auto__$jscomp$194$$?0:$y__5111__auto__$jscomp$194$$}()})})}),(0,$APP.$rumext$v2$jsxs$$)("g",{style:{pointerEvents:$APP.$cljs$core$truth_$$($disable_events_QMARK_$$?$disable_events_QMARK_$$:$shapes_loading_QMARK_$$)?"none":"auto"},children:[$APP.$cljs$core$truth_$$($show_text_editor_QMARK_$$)?
$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor-wasm/v1")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$v3_editor$text_editor_STAR_$$,{shape:$editing_shape__$1$jscomp$1$$,canvasRef:$canvas_ref$jscomp$8$$,ref:$text_editor_ref$$}):$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$v2_editor$text_editor$$,
{shape:$editing_shape__$1$jscomp$1$$,"canvas-ref":$canvas_ref$jscomp$8$$,ref:$text_editor_ref$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$editor$text_editor_svg$$,{shape:$editing_shape__$1$jscomp$1$$,ref:$text_editor_ref$$}):null,$show_frame_outline_QMARK_$$?function(){var $outlined_frame_id$jscomp$1$$=$APP.$cljs$core$last$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$214$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81557_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$7$$,
$p1__81557_SHARP_$$))},$APP.$cljs$core$_deref$$($hover_ids$jscomp$8$$)))),$outlined_frame$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$846$$,$outlined_frame_id$jscomp$1$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines_STAR_$$,{objects:$objects_for_outlines$$,hover:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$outlined_frame_id$jscomp$1$$]),zoom:$zoom__$1$jscomp$6$$}),
$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($outlined_frame$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"ghost-outline blurrable",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines_STAR_$$,{objects:$objects_for_outlines$$,selected:$selected$jscomp$214$$,zoom:$zoom__$1$jscomp$6$$})}):null]})}():null,$show_outlines_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines_STAR_$$,{objects:$objects_for_outlines$$,
selected:$selected$jscomp$214$$,hover:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($hover$jscomp$13$$)),$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$)]),highlighted:$highlighted$jscomp$7$$,edition:$edition$jscomp$19$$,zoom:$zoom__$1$jscomp$6$$}):null,$APP.$cljs$core$truth_$$($show_selection_handlers_QMARK_$$?$selected_shapes$jscomp$39$$:$show_selection_handlers_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$area_STAR_$$,
{shapes:$selected_shapes$jscomp$39$$,zoom:$zoom__$1$jscomp$6$$,edition:$edition$jscomp$19$$,disabled:function(){if($APP.$cljs$core$truth_$$($drawing_tool$jscomp$7$$))return $drawing_tool$jscomp$7$$;if($APP.$cljs$core$truth_$$($edition$jscomp$19$$))return $edition$jscomp$19$$;var $or__5025__auto____$2$jscomp$39$$=$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$5$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$2$jscomp$39$$)?$or__5025__auto____$2$jscomp$39$$:$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$15$$)}(),
onMoveSelected:$on_move_selected$jscomp$11$$,onContextMenu:$on_menu_selected$$}):null,$APP.$cljs$core$truth_$$($show_text_editor_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$text_edition_outline$text_edition_outline_STAR_$$,{shape:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$7$$,$edition$jscomp$19$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$cljs$core$seq$$($selected_shapes$jscomp$39$$)&&$APP.$cljs$core$not$$($transform$jscomp$125$$)&&!$text_editing_QMARK_$jscomp$3$$&&
$APP.$cljs$core$not$$($edition$jscomp$19$$)&&!$mode_inspect_QMARK_$jscomp$1$$&&$APP.$cljs$core$not$$($page_transition_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$measurements$selection_size_badge_STAR_$$,{shapes:$selected_shapes$jscomp$39$$,zoom:$zoom__$1$jscomp$6$$}):null,$APP.$cljs$core$truth_$$($show_measures_QMARK_$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$measurement_STAR_$$,{bounds:$vbox$jscomp$73$$,selectedShapes:$selected_shapes$jscomp$39$$,frame:$selected_frame$jscomp$6$$,
hoverShape:$APP.$cljs$core$_deref$$($measure_hover$jscomp$1$$),zoom:$zoom__$1$jscomp$6$$}):null,$show_padding_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$padding$padding_control_STAR_$$,{frame:$first_shape$jscomp$13$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$),zoom:$zoom__$1$jscomp$6$$,isAlt:$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$21$$),isShift:$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$43$$),onMoveSelected:$on_move_selected$jscomp$11$$,onContextMenu:$on_menu_selected$$}):
null,$show_padding_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$gap$gap_control_STAR_$$,{frame:$first_shape$jscomp$13$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$),zoom:$zoom__$1$jscomp$6$$,isAlt:$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$21$$),isShift:$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$43$$),onMoveSelected:$on_move_selected$jscomp$11$$,onContextMenu:$on_menu_selected$$}):null,$show_margin_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$margin$margin_control_STAR_$$,
{shape:$first_shape$jscomp$13$$,parent:$selected_frame$jscomp$6$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$3$$),zoom:$zoom__$1$jscomp$6$$,isAlt:$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$21$$),isShift:$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$43$$)}):null,$APP.$cljs$core$truth_$$($shapes_loading_QMARK_$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_titles_STAR_$$,{objects:$objects_modified$$,selected:$selected$jscomp$214$$,zoom:$zoom__$1$jscomp$6$$,
isShowArtboardNames:$show_artboard_names_QMARK_$$,onFrameEnter:$on_frame_enter$jscomp$4$$,onFrameLeave:$on_frame_leave$jscomp$4$$,onFrameSelect:$on_frame_select$jscomp$4$$,focus:$focus$jscomp$26$$}),$show_prototypes_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_flows_STAR_$$,{flows:$APP.$cljs$cst$2064$flows$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$175$$),objects:$objects_modified$$,selected:$selected$jscomp$214$$,zoom:$zoom__$1$jscomp$6$$,onFrameEnter:$on_frame_enter$jscomp$4$$,
onFrameLeave:$on_frame_leave$jscomp$4$$,onFrameSelect:$on_frame_select$jscomp$4$$}):null,$drawing_obj$$&&$APP.$app$common$types$shape$shape_QMARK_$$($drawing_obj$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$drawarea$draw_area_STAR_$$,{shape:$drawing_obj$$,zoom:$zoom__$1$jscomp$6$$,tool:$drawing_tool$jscomp$7$$}):null,$show_grids_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$frame_grid$frame_grid_STAR_$$,{zoom:$zoom__$1$jscomp$6$$,selected:$selected$jscomp$214$$,
transform:$transform$jscomp$125$$,focus:$focus$jscomp$26$$,vbox:$vbox$jscomp$73$$,clipRulers:$show_rulers_QMARK_$jscomp$2$$}):null,$show_pixel_grid_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$pixel_grid_STAR_$$,{vbox:$vbox$jscomp$73$$,zoom:$zoom__$1$jscomp$6$$,clipRulers:$show_rulers_QMARK_$jscomp$2$$}):null,$APP.$cljs$core$truth_$$($show_snap_points_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_points_STAR_$$,{layout:$layout$jscomp$34$$,
transform:$transform$jscomp$125$$,drawing:$drawing_obj$$,zoom:$zoom__$1$jscomp$6$$,pageId:$page_id$jscomp$463$$,selected:$selected$jscomp$214$$,objects:$objects_modified$$,focus:$focus$jscomp$26$$}):null,$show_snap_distance_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$snap_distances_STAR_$$,{layout:$layout$jscomp$34$$,zoom:$zoom__$1$jscomp$6$$,transform:$transform$jscomp$125$$,selected:$selected$jscomp$214$$,selectedShapes:$selected_shapes$jscomp$39$$,pageId:$page_id$jscomp$463$$}):
null,$APP.$cljs$core$truth_$$($tooltip$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$cursor_tooltip_STAR_$$,{zoom:$zoom__$1$jscomp$6$$,tooltip:$tooltip$jscomp$2$$}):null,$APP.$cljs$core$truth_$$($show_selrect_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$selection_rect_STAR_$$,{data:$selrect$jscomp$98$$,zoom:$zoom__$1$jscomp$6$$}):null,$APP.$cljs$core$truth_$$($show_presence_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$presence$active_cursors$$,
{"page-id":$page_id$jscomp$463$$}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_rulers_QMARK_$jscomp$2$$)?$show_grids_QMARK_$jscomp$2$$:$show_rulers_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$viewport_guides_STAR_$$,{disabledGuides:$disabled_guides_QMARK_$jscomp$2$$,zoom:$zoom__$1$jscomp$6$$,vbox:$vbox$jscomp$73$$,hoverFrame:$guide_frame$$,onGuideDrag:$on_guide_drag$jscomp$3$$,modifiers:$wasm_modifiers$jscomp$2$$,onGuideHover:$on_guide_hover$jscomp$3$$,
guides:$guides$jscomp$16$$,wasmGuides:$wasm_guides$jscomp$3$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3080$layout_drop_zones$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_drop_zones_STAR_$$,{selectedShapes:$selected_shapes$jscomp$39$$,objects:$base_objects$jscomp$7$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3079$layout_content_bounds$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_content_bounds_STAR_$$,{selectedShapes:$selected_shapes$jscomp$39$$,objects:$base_objects$jscomp$7$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3075$layout_lines$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_layout_lines_STAR_$$,{selectedShapes:$selected_shapes$jscomp$39$$,objects:$base_objects$jscomp$7$$,
hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3081$parent_bounds$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_parent_bounds_STAR_$$,{selectedShapes:$selected_shapes$jscomp$39$$,objects:$base_objects$jscomp$7$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3073$grid_layout$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_grid_layout_STAR_$$,{selectedShapes:$selected_shapes$jscomp$39$$,objects:$base_objects$jscomp$7$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$),zoom:$zoom__$1$jscomp$6$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3089$text_outline$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_text_wasm_position_data_STAR_$$,{selectedShapes:$selected_shapes$jscomp$39$$,objects:$base_objects$jscomp$7$$,
zoom:$zoom__$1$jscomp$6$$}):null,$show_selection_handlers_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-handlers",clipPath:"url(#clip-handlers)",children:[$text_editing_QMARK_$jscomp$3$$?null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$1$$)?$path_editing_QMARK_$jscomp$3$$:$editing_shape__$1$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$,{shape:$editing_shape__$1$jscomp$1$$,state:$edit_path_state$jscomp$2$$,
zoom:$zoom__$1$jscomp$6$$}):$APP.$cljs$core$truth_$$($selected_shapes$jscomp$39$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$handlers_STAR_$$,{selected:$selected$jscomp$214$$,shapes:$selected_shapes$jscomp$39$$,zoom:$zoom__$1$jscomp$6$$,disabled:$APP.$cljs$core$truth_$$($drawing_tool$jscomp$7$$)?$drawing_tool$jscomp$7$$:$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$5$$)}):null,$show_prototypes_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interactions_STAR_$$,
{selected:$selected$jscomp$214$$,pageId:$page_id$jscomp$463$$,zoom:$zoom__$1$jscomp$6$$,objects:$objects_modified$$,currentTransform:$transform$jscomp$125$$,isHoverDisabled:$hover_disabled_QMARK_$jscomp$1$$}):null]}):null,$show_gradient_handlers_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_handlers_STAR_$$,{id:$APP.$cljs$core$first$$($selected$jscomp$214$$),zoom:$zoom__$1$jscomp$6$$}):null,$show_add_variant_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$button_add_STAR_$$,
{shape:$first_shape$jscomp$13$$,zoom:$zoom__$1$jscomp$6$$,onClick:$add_variant$$}):null,(0,$APP.$rumext$v2$jsx$$)("g",{className:"grid-layout-editor",clipPath:"url(#clip-handlers)",children:$APP.$cljs$core$truth_$$($show_grid_editor_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$editor$$,{zoom:$zoom__$1$jscomp$6$$,objects:$objects_modified$$,shape:function(){var $or__5025__auto__$jscomp$1437$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects_modified$$,
$edition$jscomp$19$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1437$$)?$or__5025__auto__$jscomp$1437$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects_modified$$,$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$7$$))}(),"view-only":$APP.$cljs$core$not$$($show_grid_editor_QMARK_$$)}):null}),$show_scrollbar_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("g",{className:"scrollbar-wrapper",clipPath:"url(#clip-handlers)",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$scroll_bars$viewport_scrollbars_STAR_$$,
{objects:$base_objects$jscomp$7$$,zoom:$zoom__$1$jscomp$6$$,vbox:$vbox$jscomp$73$$,bottomPadding:$APP.$cljs$core$truth_$$($palete_size$$)?$palete_size$$+8:null})}):null]})],id:"viewport-controls",viewBox:$app$main$ui$workspace$viewport$utils$format_viewbox$$($vbox$jscomp$73$$),onPointerUp:$on_pointer_up$jscomp$8$$,onContextMenu:$on_context_menu$jscomp$29$$,onDrop:$on_drop$jscomp$19$$,preserveAspectRatio:"xMidYMid meet",style:{touchAction:"none"},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",
onDragOver:$on_drag_over$jscomp$2$$,onDragEnd:$on_drag_end$jscomp$2$$,onClick:$on_click$jscomp$61$$,onPointerMove:$on_pointer_move$jscomp$16$$,ref:$on_viewport_ref$$,onPointerDown:$on_pointer_down$jscomp$22$$,onPointerLeave:$on_pointer_leave$jscomp$18$$,onPointerEnter:$on_pointer_enter$jscomp$18$$},["viewport",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$463$$)].join(""))]})};
$app$main$ui$workspace$viewport$apply_modifiers_to_selected$$=function($selected$jscomp$215$$,$objects$jscomp$847$$,$text_modifiers$jscomp$4$$,$modifiers$jscomp$141$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($objects__$1$jscomp$42$$,$id$jscomp$1064$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($objects__$1$jscomp$42$$,$id$jscomp$1064$$,function($G__81580__$1_shape$jscomp$1115$$){$G__81580__$1_shape$jscomp$1115$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($G__81580__$1_shape$jscomp$1115$$)&&
$APP.$cljs$core$contains_QMARK_$$($text_modifiers$jscomp$4$$,$id$jscomp$1064$$)?$APP.$app$main$data$workspace$modifiers$apply_text_modifier$$($G__81580__$1_shape$jscomp$1115$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_modifiers$jscomp$4$$,$id$jscomp$1064$$)):$G__81580__$1_shape$jscomp$1115$$;return $APP.$cljs$core$contains_QMARK_$$($modifiers$jscomp$141$$,$id$jscomp$1064$$)?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__81580__$1_shape$jscomp$1115$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$141$$,$id$jscomp$1064$$),$APP.$cljs$cst$1816$modifiers$$)):$G__81580__$1_shape$jscomp$1115$$})},$objects$jscomp$847$$,$selected$jscomp$215$$)};
$app$main$ui$workspace$viewport$viewport_classic_STAR_$$=function($props_81587$$){var $palete_size$jscomp$1$$=$props_81587$$.paleteSize,$selected$jscomp$216$$=$props_81587$$.selected,$layout$jscomp$35$$=$props_81587$$.layout,$file$jscomp$184$$=$props_81587$$.file,$page$jscomp$176$$=$props_81587$$.page,$wglobal$jscomp$3$$=$props_81587$$.wglobal,$map__81598$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_local$$),$map__81598__$1$$=$APP.$cljs$core$__destructure_map$$($map__81598$$),$edition$jscomp$20$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$2207$edition$$),$selrect$jscomp$99$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$1610$selrect$$),$zoom_inverse$jscomp$9$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$3630$zoom_inverse$$),$panning$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$3110$panning$$),$zoom$jscomp$182$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$2204$zoom$$),$transform$jscomp$126$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$1294$transform$$),$vbox$jscomp$74$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$1942$vbox$$),$edit_path$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$1940$edit_path$$),$highlighted$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,
$APP.$cljs$cst$4366$highlighted$$),$vport$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81598__$1$$,$APP.$cljs$cst$2211$vport$$),$map__81599__$1$$=$APP.$cljs$core$__destructure_map$$($wglobal$jscomp$3$$),$options_mode$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81599__$1$$,$APP.$cljs$cst$2208$options_mode$$),$tooltip$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81599__$1$$,$APP.$cljs$cst$2957$tooltip$$),$preview_id$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81599__$1$$,$APP.$cljs$cst$5134$preview_id$$),$show_distances_QMARK_$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81599__$1$$,$APP.$cljs$cst$4561$show_distances_QMARK_$$),$picking_color_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81599__$1$$,$APP.$cljs$cst$4197$picking_color_QMARK_$$),$vbox_SINGLEQUOTE_$jscomp$1$$=$rumext$v2$use_debounce$$($vbox$jscomp$74$$),$permissions$jscomp$39$$=
(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$),$read_only_QMARK_$jscomp$38$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$drawing$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_drawing$$),$focus$jscomp$27$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),$file_id$jscomp$437$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$184$$,$APP.$cljs$cst$266$id$$),$vern$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$184$$,
$APP.$cljs$cst$2588$vern$$),$page_id$jscomp$464$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$176$$,$APP.$cljs$cst$266$id$$),$objects$jscomp$848$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$176$$,$APP.$cljs$cst$1636$objects$$),$background$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($page$jscomp$176$$,$APP.$cljs$cst$2066$background$$,"#E8E9EA"),$base_objects$jscomp$8$$=$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($objects$jscomp$848$$,
$focus$jscomp$27$$),$modifiers$jscomp$142$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$),$text_modifiers$jscomp$5$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_text_modifier$$),$objects_modified$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_objects$jscomp$8$$),$APP.$rumext$v2$adapt$$($text_modifiers$jscomp$5$$),$APP.$rumext$v2$adapt$$($modifiers$jscomp$142$$)],function(){return $app$main$ui$workspace$viewport$apply_modifiers_to_selected$$($selected$jscomp$216$$,
$base_objects$jscomp$8$$,$text_modifiers$jscomp$5$$,$modifiers$jscomp$142$$)}),$selected_shapes$jscomp$40$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects_modified$jscomp$1$$)),$selected$jscomp$216$$)),$alt_QMARK_$jscomp$22$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$shift_QMARK_$jscomp$44$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$mod_QMARK_$jscomp$16$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$space_QMARK_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$z_QMARK_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$cursor$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$ui$workspace$viewport$utils$get_cursor$$($cljs$cst$6013$pointer_inner$$)}),$hover_ids$jscomp$9$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),
$hover$jscomp$14$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$measure_hover$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$hover_disabled_QMARK_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$hover_top_frame_id$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$frame_hover$jscomp$4$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$active_frames$jscomp$4$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentHashSet$EMPTY$$),$vec__81600$$=$app$main$ui$workspace$viewport$viewport_ref$create_viewport_ref$$(),$viewport_ref$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81600$$,0,null),$on_viewport_ref$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($vec__81600$$,1,null),$canvas_ref$jscomp$9$$=(0,$APP.$rumext$v2$use_ref$$)(null),$disable_paste_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(!1),
$in_viewport_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$move_stream$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$beicon$v2$core$subject$$()}),$guide_frame$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($hover_ids$jscomp$9$$)),$APP.$rumext$v2$adapt$$($base_objects$jscomp$8$$)],function(){var $parent_id$jscomp$111$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$files$helpers$root_frame_QMARK_$$,
$base_objects$jscomp$8$$),$APP.$cljs$core$_deref$$($hover_ids$jscomp$9$$));return $parent_id$jscomp$111$$!=null?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$8$$,$parent_id$jscomp$111$$):null}),$zoom__$1$jscomp$7$$=$APP.$app$common$math$finite$$($zoom$jscomp$182$$,1),$drawing_tool$jscomp$8$$=$APP.$cljs$cst$2205$tool$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$6$$),$drawing_obj$jscomp$1$$=$APP.$cljs$cst$2206$object$$.$cljs$core$IFn$_invoke$arity$1$($drawing$jscomp$6$$),
$selected_frames$jscomp$4$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1612$frame_id$$),$selected_shapes$jscomp$40$$),$selected_frame$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_frames$jscomp$4$$),1)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$8$$,$APP.$cljs$core$first$$($selected_frames$jscomp$4$$)):
null,$edit_path_state$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path$jscomp$1$$,$edition$jscomp$20$$),$edit_path_mode$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_state$jscomp$3$$,$APP.$cljs$cst$4290$edit_mode$$),$path_editing_QMARK_$jscomp$4$$=$edit_path_state$jscomp$3$$!=null,$path_drawing_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edit_path_mode$jscomp$1$$,$APP.$cljs$cst$4291$draw$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$296$path$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($drawing_obj$jscomp$1$$,$APP.$cljs$cst$139$type$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2060$curve$$,$drawing_tool$jscomp$8$$),$editing_shape$jscomp$2$$=$APP.$cljs$core$truth_$$($edition$jscomp$20$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$8$$,$edition$jscomp$20$$):null,$editing_shape__$1$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($editing_shape$jscomp$2$$),
$APP.$rumext$v2$adapt$$($path_editing_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($base_objects$jscomp$8$$)],function(){return $path_editing_QMARK_$jscomp$4$$?$APP.$app$common$types$path$convert_to_path$$.$cljs$core$IFn$_invoke$arity$2$($editing_shape$jscomp$2$$,$base_objects$jscomp$8$$):$editing_shape$jscomp$2$$}),$create_comment_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3489$comments$$,$drawing_tool$jscomp$8$$),$text_editing_QMARK_$jscomp$4$$=$APP.$app$common$files$helpers$text_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$2$$),
$grid_editing_QMARK_$jscomp$3$$=$APP.$cljs$core$truth_$$($edition$jscomp$20$$)?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$8$$,$edition$jscomp$20$$):$edition$jscomp$20$$,$mode_inspect_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$4$$,$APP.$cljs$cst$2683$inspect$$),$on_click$jscomp$62$$=$app$main$ui$workspace$viewport$actions$on_click$$($hover$jscomp$14$$,$selected$jscomp$216$$,$edition$jscomp$20$$,
$path_drawing_QMARK_$jscomp$1$$,$drawing_tool$jscomp$8$$,$space_QMARK_$jscomp$6$$,$selrect$jscomp$99$$,$z_QMARK_$jscomp$6$$),$on_context_menu$jscomp$30$$=$app$main$ui$workspace$viewport$actions$on_context_menu$$($hover$jscomp$14$$,$hover_ids$jscomp$9$$,$read_only_QMARK_$jscomp$38$$),$on_double_click$jscomp$9$$=$app$main$ui$workspace$viewport$actions$on_double_click$$($hover$jscomp$14$$,$hover_ids$jscomp$9$$,$selected$jscomp$216$$,$hover_top_frame_id$jscomp$8$$,$path_drawing_QMARK_$jscomp$1$$,$base_objects$jscomp$8$$,
$edition$jscomp$20$$,$drawing_tool$jscomp$8$$,$z_QMARK_$jscomp$6$$,$read_only_QMARK_$jscomp$38$$),$comp_inst_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$on_drag_enter$jscomp$9$$=$app$main$ui$workspace$viewport$actions$on_drag_enter$$($comp_inst_ref$jscomp$4$$),$on_drag_over$jscomp$3$$=$app$main$ui$workspace$viewport$actions$on_drag_over$$($move_stream$jscomp$5$$),$on_drag_end$jscomp$3$$=$app$main$ui$workspace$viewport$actions$on_drag_over$$($comp_inst_ref$jscomp$4$$),$on_drop$jscomp$20$$=$app$main$ui$workspace$viewport$actions$on_drop$$($file$jscomp$184$$,
$comp_inst_ref$jscomp$4$$),$on_pointer_down$jscomp$23$$=$app$main$ui$workspace$viewport$actions$on_pointer_down$$($APP.$cljs$core$_deref$$($hover$jscomp$14$$),$selected$jscomp$216$$,$edition$jscomp$20$$,$drawing_tool$jscomp$8$$,$text_editing_QMARK_$jscomp$4$$,$path_editing_QMARK_$jscomp$4$$,$grid_editing_QMARK_$jscomp$3$$,$path_drawing_QMARK_$jscomp$1$$,$create_comment_QMARK_$jscomp$2$$,$space_QMARK_$jscomp$6$$,$panning$jscomp$3$$,$z_QMARK_$jscomp$6$$,$read_only_QMARK_$jscomp$38$$),$on_pointer_up$jscomp$9$$=
$app$main$ui$workspace$viewport$actions$on_pointer_up$$($disable_paste_ref$jscomp$4$$),$on_pointer_enter$jscomp$19$$=$app$main$ui$workspace$viewport$actions$on_pointer_enter$$($in_viewport_ref$jscomp$5$$),$on_pointer_leave$jscomp$19$$=$app$main$ui$workspace$viewport$actions$on_pointer_leave$$($in_viewport_ref$jscomp$5$$),$on_pointer_move$jscomp$17$$=$app$main$ui$workspace$viewport$actions$on_pointer_move$$($move_stream$jscomp$5$$),$on_move_selected$jscomp$12$$=$app$main$ui$workspace$viewport$actions$on_move_selected$$($hover$jscomp$14$$,
$hover_ids$jscomp$9$$,$selected$jscomp$216$$,$space_QMARK_$jscomp$6$$,$z_QMARK_$jscomp$6$$,$read_only_QMARK_$jscomp$38$$),$on_menu_selected$jscomp$1$$=$app$main$ui$workspace$viewport$actions$on_menu_selected$$($hover$jscomp$14$$,$hover_ids$jscomp$9$$,$selected$jscomp$216$$,$read_only_QMARK_$jscomp$38$$),$on_frame_enter$jscomp$5$$=$app$main$ui$workspace$viewport$actions$on_frame_enter$$($frame_hover$jscomp$4$$),$on_frame_leave$jscomp$5$$=$app$main$ui$workspace$viewport$actions$on_frame_leave$$($frame_hover$jscomp$4$$),
$on_frame_select$jscomp$5$$=$app$main$ui$workspace$viewport$actions$on_frame_select$$($selected$jscomp$216$$,$read_only_QMARK_$jscomp$38$$),$disable_events_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3489$comments$$),$show_comments_QMARK_$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawing_tool$jscomp$8$$,$APP.$cljs$cst$3489$comments$$)||$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3771$display_comments$$),$show_gradient_handlers_QMARK_$jscomp$1$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$216$$),1),$show_grids_QMARK_$jscomp$3$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3775$display_guides$$),$show_frame_outline_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$126$$,$APP.$cljs$cst$1804$move$$),$show_outlines_QMARK_$jscomp$1$$=$transform$jscomp$126$$==null&&$APP.$cljs$core$not$$($edition$jscomp$20$$)&&$APP.$cljs$core$not$$($drawing_obj$jscomp$1$$)&&
$APP.$cljs$core$not$$(function(){var $fexpr__81610$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$2060$curve$$,null],null),null);return $fexpr__81610$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__81610$$.$cljs$core$IFn$_invoke$arity$1$($drawing_tool$jscomp$8$$):$fexpr__81610$$($drawing_tool$jscomp$8$$)}()),$show_pixel_grid_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3766$show_pixel_grid$$)&&
$zoom__$1$jscomp$7$$>=8,$show_text_editor_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$2$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$2$$)):$editing_shape__$1$jscomp$2$$,$hover_grid_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$1039$$=$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$)!=null;return $and__5023__auto__$jscomp$1039$$?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$848$$,
$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$)):$and__5023__auto__$jscomp$1039$$}(),$show_grid_editor_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$2$$)?$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($editing_shape__$1$jscomp$2$$):$editing_shape__$1$jscomp$2$$,$show_prototypes_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$4$$,$APP.$cljs$cst$3781$prototype$$),$show_selection_handlers_QMARK_$jscomp$1$$=
$APP.$cljs$core$seq$$($selected$jscomp$216$$)&&$APP.$cljs$core$not$$($show_text_editor_QMARK_$jscomp$1$$),$show_snap_distance_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3774$dynamic_alignment$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$126$$,$APP.$cljs$cst$1804$move$$)&&$APP.$cljs$core$seq$$($selected$jscomp$216$$),$show_snap_points_QMARK_$jscomp$1$$=function(){var $and__5023__auto__$jscomp$1041$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,
$APP.$cljs$cst$3774$dynamic_alignment$$)||$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3769$snap_guides$$);return $and__5023__auto__$jscomp$1041$$?$APP.$cljs$core$truth_$$($drawing_obj$jscomp$1$$)?$drawing_obj$jscomp$1$$:$transform$jscomp$126$$:$and__5023__auto__$jscomp$1041$$}(),$show_selrect_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($selrect$jscomp$99$$)?$APP.$cljs$core$empty_QMARK_$$($drawing$jscomp$6$$)&&!$text_editing_QMARK_$jscomp$4$$:$selrect$jscomp$99$$,$show_measures_QMARK_$jscomp$2$$=
function(){var $and__5023__auto__$jscomp$1043_and__5023__auto____$1$jscomp$169$$=$APP.$cljs$core$not$$($transform$jscomp$126$$);return $and__5023__auto__$jscomp$1043_and__5023__auto____$1$jscomp$169$$?($and__5023__auto__$jscomp$1043_and__5023__auto____$1$jscomp$169$$=!$path_editing_QMARK_$jscomp$4$$)?$APP.$cljs$core$truth_$$($show_distances_QMARK_$jscomp$1$$)?$show_distances_QMARK_$jscomp$1$$:$mode_inspect_QMARK_$jscomp$2$$?$mode_inspect_QMARK_$jscomp$2$$:$read_only_QMARK_$jscomp$38$$:$and__5023__auto__$jscomp$1043_and__5023__auto____$1$jscomp$169$$:
$and__5023__auto__$jscomp$1043_and__5023__auto____$1$jscomp$169$$}(),$show_artboard_names_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3772$display_artboard_names$$),$hide_ui_QMARK_$jscomp$2$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3046$hide_ui$$),$show_rulers_QMARK_$jscomp$3$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$2219$rulers$$)&&!$hide_ui_QMARK_$jscomp$2$$,$disabled_guides_QMARK_$jscomp$3$$=function(){if($APP.$cljs$core$truth_$$($drawing_tool$jscomp$8$$))return $drawing_tool$jscomp$8$$;
if($APP.$cljs$core$truth_$$($transform$jscomp$126$$))return $transform$jscomp$126$$;if($path_drawing_QMARK_$jscomp$1$$)return $path_drawing_QMARK_$jscomp$1$$;if($path_editing_QMARK_$jscomp$4$$)return $path_editing_QMARK_$jscomp$4$$;var $or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$=$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$6$$);if($APP.$cljs$core$truth_$$($or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$))return $or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$;
$or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$=$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$16$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$)?$or__5025__auto____$4$jscomp$7_or__5025__auto____$5$jscomp$4$$:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$35$$,$APP.$cljs$cst$3770$lock_guides$$)}(),$single_select_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$40$$),
1),$first_shape$jscomp$14$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$40$$),$show_add_variant_QMARK_$jscomp$1$$=$single_select_QMARK_$jscomp$1$$&&($APP.$app$common$types$component$is_variant_container_QMARK_$$($first_shape$jscomp$14$$)||$APP.$app$common$types$component$is_variant_QMARK_$$($first_shape$jscomp$14$$)),$show_padding_QMARK_$jscomp$1$$=$transform$jscomp$126$$==null&&$single_select_QMARK_$jscomp$1$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$14$$),
$APP.$cljs$cst$1611$frame$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$14$$),$APP.$cljs$cst$1665$flex$$)&&$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$14$$)===0,$show_margin_QMARK_$jscomp$1$$=$transform$jscomp$126$$==null&&$single_select_QMARK_$jscomp$1$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$7$$),
$APP.$cljs$cst$1665$flex$$)&&$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$14$$)===0,$selecting_first_level_frame_QMARK_$jscomp$1$$=$single_select_QMARK_$jscomp$1$$&&$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$14$$),$offset_x$jscomp$20$$=$selecting_first_level_frame_QMARK_$jscomp$1$$?$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$14$$):$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$7$$),
$offset_y$jscomp$21$$=$selecting_first_level_frame_QMARK_$jscomp$1$$?$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$14$$):$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($selected_frame$jscomp$7$$),$rule_area_size$jscomp$2$$=22/$zoom__$1$jscomp$7$$,$add_variant$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($first_shape$jscomp$14$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$variants$add_new_variant$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($first_shape$jscomp$14$$)))});
$app$main$ui$workspace$viewport$hooks$setup_dom_events$$($zoom__$1$jscomp$7$$,$disable_paste_ref$jscomp$4$$,$in_viewport_ref$jscomp$5$$,$read_only_QMARK_$jscomp$38$$,$drawing_tool$jscomp$8$$,$path_drawing_QMARK_$jscomp$1$$);$app$main$ui$workspace$viewport$hooks$setup_viewport_size$$($vport$jscomp$15$$,$viewport_ref$jscomp$4$$);$app$main$ui$workspace$viewport$hooks$setup_cursor$$($cursor$jscomp$14$$,$alt_QMARK_$jscomp$22$$,$mod_QMARK_$jscomp$16$$,$space_QMARK_$jscomp$6$$,$panning$jscomp$3$$,$drawing_tool$jscomp$8$$,
$path_drawing_QMARK_$jscomp$1$$,$path_editing_QMARK_$jscomp$4$$,$z_QMARK_$jscomp$6$$,$read_only_QMARK_$jscomp$38$$);$app$main$ui$workspace$viewport$hooks$setup_keyboard$$($alt_QMARK_$jscomp$22$$,$mod_QMARK_$jscomp$16$$,$space_QMARK_$jscomp$6$$,$z_QMARK_$jscomp$6$$,$shift_QMARK_$jscomp$44$$);$app$main$ui$workspace$viewport$hooks$setup_hover_shapes$$($page_id$jscomp$464$$,$move_stream$jscomp$5$$,$base_objects$jscomp$8$$,$selected$jscomp$216$$,$mod_QMARK_$jscomp$16$$,$hover$jscomp$14$$,$measure_hover$jscomp$2$$,
$hover_ids$jscomp$9$$,$hover_top_frame_id$jscomp$8$$,$APP.$cljs$core$_deref$$($hover_disabled_QMARK_$jscomp$2$$),$focus$jscomp$27$$,$zoom__$1$jscomp$7$$,$show_measures_QMARK_$jscomp$2$$,$read_only_QMARK_$jscomp$38$$,$transform$jscomp$126$$);$app$main$ui$workspace$viewport$hooks$setup_viewport_modifiers$$($modifiers$jscomp$142$$,$base_objects$jscomp$8$$);$app$main$ui$workspace$viewport$hooks$setup_shortcuts$$($path_editing_QMARK_$jscomp$4$$,$path_drawing_QMARK_$jscomp$1$$,$text_editing_QMARK_$jscomp$4$$,
$grid_editing_QMARK_$jscomp$3$$);$app$main$ui$workspace$viewport$hooks$setup_active_frames$$($base_objects$jscomp$8$$,$hover_ids$jscomp$9$$,$selected$jscomp$216$$,$active_frames$jscomp$4$$,$zoom__$1$jscomp$7$$,$transform$jscomp$126$$,$vbox$jscomp$74$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--zoom":$zoom__$1$jscomp$7$$},"data-testid":"viewport",className:"main_ui_workspace_viewport__viewport",children:[$preview_id$jscomp$1$$!=null?null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$38$$)?
$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$39$$):$read_only_QMARK_$jscomp$38$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$view_only_bar_STAR_$$,{}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$hide_ui_QMARK_$jscomp$2$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$top_toolbar$top_toolbar_STAR_$$,{layout:$layout$jscomp$35$$}),$path_editing_QMARK_$jscomp$4$$&&$single_select_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$path_edition_bar_STAR_$$,
{shape:$editing_shape__$1$jscomp$2$$,editPathState:$edit_path_state$jscomp$3$$,layout:$layout$jscomp$35$$}):null,$grid_editing_QMARK_$jscomp$3$$&&$single_select_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$top_bar$grid_edition_bar_STAR_$$,{shape:$editing_shape__$1$jscomp$2$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_viewport__viewport-overlays",children:[(0,$APP.$rumext$v2$jsx$$)("svg",{style:{top:0,left:0,position:"fixed",width:"100%",
height:"100%",opacity:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3096$html_text$$)?null:0},children:(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:0,y:0,width:"100%",height:"100%",children:(0,$APP.$rumext$v2$jsx$$)("div",{style:{pointerEvents:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3096$html_text$$)?null:"none",opacity:.6},children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1045$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$39$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1045$$)?$APP.$cljs$core$not$$($read_only_QMARK_$jscomp$38$$):$and__5023__auto__$jscomp$1045$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$viewport_texts$$,{"page-id":$page_id$jscomp$464$$,objects:$objects$jscomp$848$$,modifiers:$modifiers$jscomp$142$$,edition:$edition$jscomp$20$$},"viewport-texts-"+($page_id$jscomp$464$$??"")+"-"+($vern$jscomp$5$$??"")):null})})}),$show_comments_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$comments$comments_layer_STAR_$$,
{vbox:$vbox$jscomp$74$$,pageId:$page_id$jscomp$464$$,fileId:$file_id$jscomp$437$$,vport:$vport$jscomp$15$$,zoom:$zoom__$1$jscomp$7$$}):null,$APP.$cljs$core$truth_$$($picking_color_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$pixel_overlay$pixel_overlay_STAR_$$,{vport:$vport$jscomp$15$$,viewportRef:$viewport_ref$jscomp$4$$}):null]}),(0,$APP.$rumext$v2$jsxs$$)("svg",{"xmlns:penpot":"https://penpot.app/xmlns",width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($vport$jscomp$15$$,
0),xmlns:"http://www.w3.org/2000/svg",height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$2$($vport$jscomp$15$$,0),className:"main_ui_workspace_viewport__render-shapes",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsxs$$)("linearGradient",{id:"frame-placeholder-gradient",children:[(0,$APP.$rumext$v2$jsx$$)("animateTransform",{attributeName:"gradientTransform",type:"translate",from:"-1 0",to:"1 0",dur:"2s",repeatCount:"indefinite"}),(0,$APP.$rumext$v2$jsx$$)("stop",
{offset:"0%",stopColor:["color-mix(in srgb-linear, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($background$jscomp$14$$)," 90%, #777)"].join(""),stopOpacity:1}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"50%",stopColor:["color-mix(in srgb-linear, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($background$jscomp$14$$)," 80%, #777)"].join(""),stopOpacity:1}),(0,$APP.$rumext$v2$jsx$$)("stop",{offset:"100%",stopColor:["color-mix(in srgb-linear, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($background$jscomp$14$$),
" 90%, #777)"].join(""),stopOpacity:1})]})}),$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3092$show_export_metadata$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$shapes$export$0$export_page$$,{page:$page$jscomp$176$$}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$74$$,0),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$74$$,0),x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$74$$,
0),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$74$$,0),fill:$background$jscomp$14$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_vbox$$),{value:$vbox_SINGLEQUOTE_$jscomp$1$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$shapes$export$0$include_metadata_ctx$$),{value:$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3092$show_export_metadata$$),children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$shapes$root_shape$$,
{objects:$base_objects$jscomp$8$$,"active-frames":$APP.$cljs$core$_deref$$($active_frames$jscomp$4$$),"disable-thumbnails":$preview_id$jscomp$1$$!=null},$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$464$$))})})],id:"render",viewBox:$app$main$ui$workspace$viewport$utils$format_viewbox$$($vbox$jscomp$74$$),preserveAspectRatio:"xMidYMid meet",style:{backgroundColor:$background$jscomp$14$$,pointerEvents:"none"},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none"},"viewport-svg-"+
($page_id$jscomp$464$$??"")+"-"+($vern$jscomp$5$$??"")),(0,$APP.$rumext$v2$jsxs$$)("svg",{onDoubleClick:$on_double_click$jscomp$9$$,onDragEnter:$on_drag_enter$jscomp$9$$,xmlns:"http://www.w3.org/2000/svg",className:"viewport-controls "+(""+($APP.$cljs$core$_deref$$($cursor$jscomp$14$$)??"")+(($APP.$cljs$core$truth_$$($drawing_tool$jscomp$8$$)?" drawing":null)??"")+" main_ui_workspace_viewport__viewport-controls"),children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",
{id:"clip-handlers",children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$74$$)+$rule_area_size$jscomp$2$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$74$$)+$rule_area_size$jscomp$2$$,width:function(){var $y__5111__auto__$jscomp$195$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$74$$)-$rule_area_size$jscomp$2$$;return 0>$y__5111__auto__$jscomp$195$$?0:$y__5111__auto__$jscomp$195$$}(),
height:function(){var $y__5111__auto__$jscomp$196$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$74$$)-$rule_area_size$jscomp$2$$;return 0>$y__5111__auto__$jscomp$196$$?0:$y__5111__auto__$jscomp$196$$}()})})}),(0,$APP.$rumext$v2$jsxs$$)("g",{style:{pointerEvents:$disable_events_QMARK_$jscomp$1$$?"none":"auto"},children:[$APP.$cljs$core$truth_$$($show_text_editor_QMARK_$jscomp$1$$)?$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"text-editor/v2")?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$v2_editor$text_editor$$,{shape:$editing_shape__$1$jscomp$2$$,"canvas-ref":$canvas_ref$jscomp$9$$,modifiers:$modifiers$jscomp$142$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$editor$text_editor_svg$$,{shape:$editing_shape__$1$jscomp$2$$,modifiers:$modifiers$jscomp$142$$}):null,$show_frame_outline_QMARK_$jscomp$1$$?function(){var $outlined_frame_id$jscomp$2$$=$APP.$cljs$core$last$$($APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$216$$,
$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81585_SHARP_$$){return $APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$8$$,$p1__81585_SHARP_$$))},$APP.$cljs$core$_deref$$($hover_ids$jscomp$9$$)))),$outlined_frame$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$848$$,$outlined_frame_id$jscomp$2$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines_STAR_$$,{objects:$base_objects$jscomp$8$$,hover:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$outlined_frame_id$jscomp$2$$]),zoom:$zoom__$1$jscomp$7$$,modifiers:$modifiers$jscomp$142$$}),$APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($outlined_frame$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"ghost-outline",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines_STAR_$$,
{objects:$base_objects$jscomp$8$$,selected:$selected$jscomp$216$$,zoom:$zoom__$1$jscomp$7$$})}):null]})}():null,$show_outlines_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$shape_outlines_STAR_$$,{objects:$base_objects$jscomp$8$$,selected:$selected$jscomp$216$$,hover:$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($hover$jscomp$14$$)),$APP.$cljs$core$_deref$$($frame_hover$jscomp$4$$)]),
highlighted:$highlighted$jscomp$8$$,edition:$edition$jscomp$20$$,zoom:$zoom__$1$jscomp$7$$,modifiers:$modifiers$jscomp$142$$}):null,$APP.$cljs$core$truth_$$($show_selection_handlers_QMARK_$jscomp$1$$?$selected_shapes$jscomp$40$$:$show_selection_handlers_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$area_STAR_$$,{shapes:$selected_shapes$jscomp$40$$,zoom:$zoom__$1$jscomp$7$$,edition:$edition$jscomp$20$$,disabled:function(){if($APP.$cljs$core$truth_$$($drawing_tool$jscomp$8$$))return $drawing_tool$jscomp$8$$;
if($APP.$cljs$core$truth_$$($edition$jscomp$20$$))return $edition$jscomp$20$$;var $or__5025__auto____$2$jscomp$41$$=$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$6$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$2$jscomp$41$$)?$or__5025__auto____$2$jscomp$41$$:$APP.$cljs$core$_deref$$($mod_QMARK_$jscomp$16$$)}(),onMoveSelected:$on_move_selected$jscomp$12$$,onContextMenu:$on_menu_selected$jscomp$1$$}):null,$APP.$cljs$core$truth_$$($show_text_editor_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$text_edition_outline$text_edition_outline_STAR_$$,
{shape:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$8$$,$edition$jscomp$20$$),zoom:$zoom__$1$jscomp$7$$,modifiers:$modifiers$jscomp$142$$}):null,$APP.$cljs$core$seq$$($selected_shapes$jscomp$40$$)&&$APP.$cljs$core$not$$($transform$jscomp$126$$)&&!$text_editing_QMARK_$jscomp$4$$&&$APP.$cljs$core$not$$($edition$jscomp$20$$)&&!$mode_inspect_QMARK_$jscomp$2$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$measurements$selection_size_badge_STAR_$$,{shapes:$selected_shapes$jscomp$40$$,
zoom:$zoom__$1$jscomp$7$$}):null,$APP.$cljs$core$truth_$$($show_measures_QMARK_$jscomp$2$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$measurement_STAR_$$,{bounds:$vbox$jscomp$74$$,selectedShapes:$selected_shapes$jscomp$40$$,frame:$selected_frame$jscomp$7$$,hoverShape:$APP.$cljs$core$_deref$$($measure_hover$jscomp$2$$),zoom:$zoom__$1$jscomp$7$$}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1047_and__5023__auto____$1$jscomp$170$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$126$$,
$APP.$cljs$cst$1804$move$$);return $and__5023__auto__$jscomp$1047_and__5023__auto____$1$jscomp$170$$?($and__5023__auto__$jscomp$1047_and__5023__auto____$1$jscomp$170$$=$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$22$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1047_and__5023__auto____$1$jscomp$170$$)?$APP.$cljs$core$seq$$($selected_shapes$jscomp$40$$):$and__5023__auto__$jscomp$1047_and__5023__auto____$1$jscomp$170$$):$and__5023__auto__$jscomp$1047_and__5023__auto____$1$jscomp$170$$}())?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$measurement_STAR_$$,
{bounds:$vbox$jscomp$74$$,selectedShapes:$selected_shapes$jscomp$40$$,frame:$selected_frame$jscomp$7$$,hoverShape:$APP.$cljs$core$_deref$$($hover$jscomp$14$$),zoom:$zoom__$1$jscomp$7$$}):null,function(){var $state_var$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(typeof $app$$!=="undefined"&&typeof $app$main$$!=="undefined"&&typeof $app$main$store$$!=="undefined"&&typeof $APP.$app$main$store$state$$!=="undefined"?new $APP.$cljs$core$Var$$(function(){return $APP.$app$main$store$state$$},
$APP.$cljs$core$with_meta$$($cljs$cst$6030$app_DOT_main_DOT_store_SLASH_state$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$269$cljs_DOT_analyzer_SLASH_no_resolve$$,!0],null)),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1484$arglists$$,$APP.$cljs$cst$1485$doc$$,$APP.$cljs$cst$171$test$$],
[$cljs$cst$6031$app_DOT_main_DOT_store$$,$APP.$cljs$cst$44$state$$,"app/main/store.cljs",15,1,71,71,$APP.$cljs$core$List$EMPTY$$,null,$APP.$cljs$core$truth_$$($APP.$app$main$store$state$$)?$APP.$app$main$store$state$$.$cljs$lang$test$:null])):null),$duplicated_info$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$deref$$($APP.$cljs$core$_deref$$($state_var$$)),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,
$APP.$cljs$cst$3664$duplicated$$],null));return $APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1048_and__5023__auto____$1$jscomp$171$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($transform$jscomp$126$$,$APP.$cljs$cst$1804$move$$);return $and__5023__auto__$jscomp$1048_and__5023__auto____$1$jscomp$171$$?($and__5023__auto__$jscomp$1048_and__5023__auto____$1$jscomp$171$$=$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$22$$),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1048_and__5023__auto____$1$jscomp$171$$)?
$duplicated_info$$:$and__5023__auto__$jscomp$1048_and__5023__auto____$1$jscomp$171$$):$and__5023__auto__$jscomp$1048_and__5023__auto____$1$jscomp$171$$}())?(0,$APP.$rumext$v2$jsx$$)("g",{className:"duplicated-distance",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$measurements$distance_display_STAR_$$,{from:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($duplicated_info$$,$cljs$cst$6032$selrect_original$$),to:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($duplicated_info$$,$cljs$cst$6033$selrect_duplicated$$),
zoom:$zoom__$1$jscomp$7$$,bounds:$vbox$jscomp$74$$})}):null}(),$show_padding_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$padding$padding_control_STAR_$$,{frame:$first_shape$jscomp$14$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$4$$),zoom:$zoom__$1$jscomp$7$$,isAlt:$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$22$$),isShift:$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$44$$),onMoveSelected:$on_move_selected$jscomp$12$$,onContextMenu:$on_menu_selected$jscomp$1$$}):null,
$show_padding_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$gap$gap_control_STAR_$$,{frame:$first_shape$jscomp$14$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$4$$),zoom:$zoom__$1$jscomp$7$$,isAlt:$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$22$$),isShift:$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$44$$),onMoveSelected:$on_move_selected$jscomp$12$$,onContextMenu:$on_menu_selected$jscomp$1$$}):null,$show_margin_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$flex_controls$margin$margin_control_STAR_$$,
{shape:$first_shape$jscomp$14$$,parent:$selected_frame$jscomp$7$$,hover:$APP.$cljs$core$_deref$$($frame_hover$jscomp$4$$),zoom:$zoom__$1$jscomp$7$$,isAlt:$APP.$cljs$core$_deref$$($alt_QMARK_$jscomp$22$$),isShift:$APP.$cljs$core$_deref$$($shift_QMARK_$jscomp$44$$)}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_titles_STAR_$$,{objects:$base_objects$jscomp$8$$,selected:$selected$jscomp$216$$,zoom:$zoom__$1$jscomp$7$$,isShowArtboardNames:$show_artboard_names_QMARK_$jscomp$1$$,
onFrameEnter:$on_frame_enter$jscomp$5$$,onFrameLeave:$on_frame_leave$jscomp$5$$,onFrameSelect:$on_frame_select$jscomp$5$$,focus:$focus$jscomp$27$$}),$show_prototypes_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_flows_STAR_$$,{flows:$APP.$cljs$cst$2064$flows$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$176$$),objects:$objects_modified$jscomp$1$$,selected:$selected$jscomp$216$$,zoom:$zoom__$1$jscomp$7$$,onFrameEnter:$on_frame_enter$jscomp$5$$,onFrameLeave:$on_frame_leave$jscomp$5$$,
onFrameSelect:$on_frame_select$jscomp$5$$}):null,$drawing_obj$jscomp$1$$&&$APP.$app$common$types$shape$shape_QMARK_$$($drawing_obj$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$drawarea$draw_area_STAR_$$,{shape:$drawing_obj$jscomp$1$$,zoom:$zoom__$1$jscomp$7$$,tool:$drawing_tool$jscomp$8$$}):null,$show_grids_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$frame_grid$frame_grid_STAR_$$,{zoom:$zoom__$1$jscomp$7$$,selected:$selected$jscomp$216$$,transform:$transform$jscomp$126$$,
focus:$focus$jscomp$27$$}):null,$show_pixel_grid_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$pixel_grid_STAR_$$,{vbox:$vbox$jscomp$74$$,zoom:$zoom__$1$jscomp$7$$}):null,$APP.$cljs$core$truth_$$($show_snap_points_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_points_STAR_$$,{layout:$layout$jscomp$35$$,transform:$transform$jscomp$126$$,drawing:$drawing_obj$jscomp$1$$,zoom:$zoom__$1$jscomp$7$$,pageId:$page_id$jscomp$464$$,
selected:$selected$jscomp$216$$,objects:$objects_modified$jscomp$1$$,focus:$focus$jscomp$27$$}):null,$show_snap_distance_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_distances$snap_distances_STAR_$$,{layout:$layout$jscomp$35$$,zoom:$zoom__$1$jscomp$7$$,transform:$transform$jscomp$126$$,selected:$selected$jscomp$216$$,selectedShapes:$selected_shapes$jscomp$40$$,pageId:$page_id$jscomp$464$$}):null,$APP.$cljs$core$truth_$$($tooltip$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$cursor_tooltip_STAR_$$,
{zoom:$zoom__$1$jscomp$7$$,tooltip:$tooltip$jscomp$3$$}):null,$APP.$cljs$core$truth_$$($show_selrect_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$selection_rect_STAR_$$,{data:$selrect$jscomp$99$$,zoom:$zoom__$1$jscomp$7$$}):null,$show_add_variant_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$button_add_STAR_$$,{shape:$first_shape$jscomp$14$$,zoom:$zoom__$1$jscomp$7$$,onClick:$add_variant$jscomp$1$$}):null,$APP.$cljs$core$truth_$$($page_id$jscomp$464$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$presence$active_cursors$$,{"page-id":$page_id$jscomp$464$$}):null,$hide_ui_QMARK_$jscomp$2$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers_STAR_$$,{zoom:$zoom__$1$jscomp$7$$,zoomInverse:$zoom_inverse$jscomp$9$$,vbox:$vbox$jscomp$74$$,selectedShapes:$selected_shapes$jscomp$40$$,offsetX:$offset_x$jscomp$20$$,offsetY:$offset_y$jscomp$21$$,showRulers:$show_rulers_QMARK_$jscomp$3$$}),$show_rulers_QMARK_$jscomp$3$$&&
$show_grids_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$viewport_guides_STAR_$$,{zoom:$zoom__$1$jscomp$7$$,vbox:$vbox$jscomp$74$$,guides:$APP.$cljs$cst$2065$guides$$.$cljs$core$IFn$_invoke$arity$1$($page$jscomp$176$$),hoverFrame:$guide_frame$jscomp$1$$,disabledGuides:$disabled_guides_QMARK_$jscomp$3$$,modifiers:$modifiers$jscomp$142$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3080$layout_drop_zones$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_drop_zones_STAR_$$,
{selectedShapes:$selected_shapes$jscomp$40$$,objects:$base_objects$jscomp$8$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),zoom:$zoom__$1$jscomp$7$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3079$layout_content_bounds$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_content_bounds_STAR_$$,{selectedShapes:$selected_shapes$jscomp$40$$,objects:$base_objects$jscomp$8$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),
zoom:$zoom__$1$jscomp$7$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3075$layout_lines$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_layout_lines_STAR_$$,{selectedShapes:$selected_shapes$jscomp$40$$,objects:$base_objects$jscomp$8$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),zoom:$zoom__$1$jscomp$7$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3081$parent_bounds$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_parent_bounds_STAR_$$,
{selectedShapes:$selected_shapes$jscomp$40$$,objects:$base_objects$jscomp$8$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),zoom:$zoom__$1$jscomp$7$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3073$grid_layout$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$debug$debug_grid_layout_STAR_$$,{selectedShapes:$selected_shapes$jscomp$40$$,objects:$base_objects$jscomp$8$$,hoverTopFrameId:$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),zoom:$zoom__$1$jscomp$7$$}):
null,$show_selection_handlers_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"selection-handlers",clipPath:"url(#clip-handlers)",children:[$text_editing_QMARK_$jscomp$4$$?null:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($editing_shape__$1$jscomp$2$$)?$path_editing_QMARK_$jscomp$4$$:$editing_shape__$1$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$path$editor$path_editor_STAR_$$,{shape:$editing_shape__$1$jscomp$2$$,state:$edit_path_state$jscomp$3$$,zoom:$zoom__$1$jscomp$7$$}):
$APP.$cljs$core$truth_$$($selected_shapes$jscomp$40$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$selection$handlers_STAR_$$,{selected:$selected$jscomp$216$$,shapes:$selected_shapes$jscomp$40$$,zoom:$zoom__$1$jscomp$7$$,disabled:$APP.$cljs$core$truth_$$($drawing_tool$jscomp$8$$)?$drawing_tool$jscomp$8$$:$APP.$cljs$core$_deref$$($space_QMARK_$jscomp$6$$)}):null,$show_prototypes_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$interactions$interactions_STAR_$$,
{selected:$selected$jscomp$216$$,pageId:$page_id$jscomp$464$$,zoom:$zoom__$1$jscomp$7$$,objects:$objects_modified$jscomp$1$$,currentTransform:$transform$jscomp$126$$,isHoverDisabled:$hover_disabled_QMARK_$jscomp$2$$}):null]}):null,$show_gradient_handlers_QMARK_$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_handlers_STAR_$$,{id:$APP.$cljs$core$first$$($selected$jscomp$216$$),zoom:$zoom__$1$jscomp$7$$}):null,(0,$APP.$rumext$v2$jsxs$$)("g",{className:"grid-layout-editor",
clipPath:"url(#clip-handlers)",children:[$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($show_grid_editor_QMARK_$jscomp$1$$)?$show_grid_editor_QMARK_$jscomp$1$$:$hover_grid_QMARK_$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$editor$$,{zoom:$zoom__$1$jscomp$7$$,objects:$base_objects$jscomp$8$$,modifiers:$modifiers$jscomp$142$$,shape:function(){var $or__5025__auto__$jscomp$1444$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$8$$,
$edition$jscomp$20$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1444$$)?$or__5025__auto__$jscomp$1444$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_objects$jscomp$8$$,$APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$))}(),"view-only":$APP.$cljs$core$not$$($show_grid_editor_QMARK_$jscomp$1$$)}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$243$$,$frame$jscomp$108$$){$out_arr__44092__auto__$jscomp$243$$.push($APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$108$$)&&
$APP.$cljs$core$empty_QMARK_$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$108$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$20$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$108$$))&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($hover_top_frame_id$jscomp$8$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$108$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$editor$$,
{zoom:$zoom__$1$jscomp$7$$,objects:$base_objects$jscomp$8$$,modifiers:$modifiers$jscomp$142$$,shape:$frame$jscomp$108$$,"view-only":!0},"viewport-frame-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$108$$)??"")):null);return $out_arr__44092__auto__$jscomp$243$$},[],$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$1$($objects$jscomp$848$$))]}),(0,$APP.$rumext$v2$jsx$$)("g",{className:"scrollbar-wrapper",clipPath:"url(#clip-handlers)",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$scroll_bars$viewport_scrollbars_STAR_$$,
{objects:$base_objects$jscomp$8$$,zoom:$zoom__$1$jscomp$7$$,vbox:$vbox$jscomp$74$$,bottomPadding:$APP.$cljs$core$truth_$$($palete_size$jscomp$1$$)?$palete_size$jscomp$1$$+8:null})})]})],viewBox:$app$main$ui$workspace$viewport$utils$format_viewbox$$($vbox$jscomp$74$$),onPointerUp:$on_pointer_up$jscomp$9$$,onContextMenu:$on_context_menu$jscomp$30$$,onDrop:$on_drop$jscomp$20$$,preserveAspectRatio:"xMidYMid meet",style:{touchAction:"none"},xmlnsXlink:"http://www.w3.org/1999/xlink",fill:"none",onDragOver:$on_drag_over$jscomp$3$$,
onDragEnd:$on_drag_end$jscomp$3$$,onClick:$on_click$jscomp$62$$,onPointerMove:$on_pointer_move$jscomp$17$$,ref:$on_viewport_ref$jscomp$1$$,onPointerDown:$on_pointer_down$jscomp$23$$,onPointerLeave:$on_pointer_leave$jscomp$19$$,onPointerEnter:$on_pointer_enter$jscomp$19$$},"viewport-controls-"+($page_id$jscomp$464$$??"")+"-"+($vern$jscomp$5$$??""))]})};
$app$main$ui$workspace$viewport$viewport_STAR_$$=function($props_81632$$){var $page$jscomp$177_page_id$jscomp$465$$=$props_81632$$.page,$vern$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_81632$$.file,$APP.$cljs$cst$2588$vern$$);$page$jscomp$177_page_id$jscomp$465$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$177_page_id$jscomp$465$$,$APP.$cljs$cst$266$id$$);var $render_wasm_QMARK_$jscomp$12$$=$APP.$app$main$features$use_feature$$("render-wasm/v1");
return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$render_wasm_QMARK_$jscomp$12$$?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport_wasm$viewport_STAR_$$,$props_81632$$):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$viewport_classic_STAR_$$,$props_81632$$)},"viewport-"+($page$jscomp$177_page_id$jscomp$465$$??"")+"-"+($vern$jscomp$6$$??""))};
$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$=function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$modal$hide$$(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$common$go_to_dashboard_recent$$()]))};
$app$main$ui$workspace$webgl_unavailable_modal$webgl_unavailable_modal_STAR_$$=function(){function $handle_keydown$jscomp$5$$($event$jscomp$739$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$739$$))?($APP.$app$util$dom$stop_propagation$$($event$jscomp$739$$),$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$()):null}$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key$jscomp$430$$=$APP.$goog$events$listen$$(document,
"keydown",$handle_keydown$jscomp$5$$);return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$430$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_webgl_unavailable_modal__modal-overlay",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_webgl_unavailable_modal__modal-dialog",children:[(0,$APP.$rumext$v2$jsxs$$)("header",{className:"main_ui_workspace_webgl_unavailable_modal__modal-header",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{onClick:$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$,className:"main_ui_workspace_webgl_unavailable_modal__modal-close-btn",icon:"close",variant:"action",size:"medium","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$heading$heading_STAR_$$,{level:2,typography:"title-medium",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.title")})]}),
(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_workspace_webgl_unavailable_modal__modal-content",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,{as:"p",typography:"body-large",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.message")}),(0,$APP.$rumext$v2$jsx$$)("hr",{className:"main_ui_workspace_webgl_unavailable_modal__modal-divider"}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$ds$foundations$typography$text$text_STAR_$$,
{as:"p",typography:"body-medium",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.troubleshooting.before"),(0,$APP.$rumext$v2$jsx$$)("a",{href:"https://help.penpot.app/user-guide/first-steps/troubleshooting-webgl/",target:"_blank",rel:"noopener noreferrer",className:"main_ui_workspace_webgl_unavailable_modal__link",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.troubleshooting.link")}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.troubleshooting.after")]})]}),
(0,$APP.$rumext$v2$jsxs$$)("footer",{className:"main_ui_workspace_webgl_unavailable_modal__modal-footer",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{onClick:$app$main$ui$workspace$webgl_unavailable_modal$close_and_go_dashboard$$,variant:"secondary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.cta-dashboard")}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{to:"https://help.penpot.app/user-guide/first-steps/troubleshooting-webgl/",
target:"_blank",variant:"primary",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("webgl.modals.webgl-unavailable.cta-troubleshooting")})]})]})})};
$app$main$ui$workspace$workspace_content_STAR_$$=function($props_81652_wglobal$jscomp$4$$){var $layout$jscomp$36$$=$props_81652_wglobal$jscomp$4$$.layout,$file$jscomp$186$$=$props_81652_wglobal$jscomp$4$$.file,$page$jscomp$178$$=$props_81652_wglobal$jscomp$4$$.page;$props_81652_wglobal$jscomp$4$$=$props_81652_wglobal$jscomp$4$$.wglobal;var $palete_size$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$selected$jscomp$217$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$),
$page_id$jscomp$466$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($page$jscomp$178$$,$APP.$cljs$cst$266$id$$),$vport$jscomp$16$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_vport$$),$map__81653__$1_options_mode$jscomp$5$$=$APP.$cljs$core$__destructure_map$$($props_81652_wglobal$jscomp$4$$);$map__81653__$1_options_mode$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81653__$1_options_mode$jscomp$5$$,$APP.$cljs$cst$2208$options_mode$$);var $drawing$jscomp$7$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_drawing$$),$colorpalette_QMARK_$$=$APP.$cljs$cst$3764$colorpalette$$.$cljs$core$IFn$_invoke$arity$1$($layout$jscomp$36$$),$textpalette_QMARK_$$=$APP.$cljs$cst$3790$textpalette$$.$cljs$core$IFn$_invoke$arity$1$($layout$jscomp$36$$),$hide_ui_QMARK_$jscomp$3$$=$APP.$cljs$cst$3046$hide_ui$$.$cljs$core$IFn$_invoke$arity$1$($layout$jscomp$36$$),$node_ref$jscomp$5_on_resize$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vport$jscomp$16$$)],
function($resize_type$jscomp$4$$,$size$jscomp$169$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($vport$jscomp$16$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($size$jscomp$169$$,$vport$jscomp$16$$):$vport$jscomp$16$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$viewport$update_viewport_size$$($resize_type$jscomp$4$$,$size$jscomp$169$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$viewport$sync_wasm_workspace_viewport$$()])):
null}),$on_resize_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($size$jscomp$170$$){return $APP.$cljs$core$reset_BANG_$$($palete_size$jscomp$2$$,$size$jscomp$170$$)});$node_ref$jscomp$5_on_resize$jscomp$6$$=$app$main$ui$hooks$resize$use_resize_observer$$($node_ref$jscomp$5_on_resize$jscomp$6$$);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$hide_ui_QMARK_$jscomp$3$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$palette$palette_STAR_$$,
{layout:$layout$jscomp$36$$,onChangeSize:$on_resize_palette$$}),(0,$APP.$rumext$v2$jsx$$)("section",{ref:$node_ref$jscomp$5_on_resize$jscomp$6$$,className:"main_ui_workspace__workspace-content",children:(0,$APP.$rumext$v2$jsxs$$)("section",{className:"main_ui_workspace__workspace-viewport",children:[$APP.$app$util$debug$enabled_QMARK_$$($cljs$cst$6034$coordinates$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$coordinates$coordinates_STAR_$$,{isColorpalette:$colorpalette_QMARK_$$}):null,$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3084$history_overlay$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace__history-debug-overlay",children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$reinitialize_undo$$)},children:"CLEAR"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history$history_toolbox_STAR_$$,{})]}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$viewport_STAR_$$,{file:$file$jscomp$186$$,
page:$page$jscomp$178$$,wglobal:$props_81652_wglobal$jscomp$4$$,selected:$selected$jscomp$217$$,layout:$layout$jscomp$36$$,paleteSize:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1051$$=$APP.$cljs$core$truth_$$($colorpalette_QMARK_$$)?$colorpalette_QMARK_$$:$textpalette_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1051$$)?$APP.$cljs$core$not$$($hide_ui_QMARK_$jscomp$3$$):$and__5023__auto__$jscomp$1051$$}())?$APP.$cljs$core$_deref$$($palete_size$jscomp$2$$):
null})]})},"workspace-"+($page_id$jscomp$466$$??"")),$APP.$cljs$core$truth_$$($hide_ui_QMARK_$jscomp$3$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sidebar_STAR_$$,{layout:$layout$jscomp$36$$,fileId:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$186$$,$APP.$cljs$cst$266$id$$),pageId:$page_id$jscomp$466$$,file:$file$jscomp$186$$,selected:$selected$jscomp$217$$,section:$map__81653__$1_options_mode$jscomp$5$$,drawingTool:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($drawing$jscomp$7$$,
$APP.$cljs$cst$2205$tool$$)})]})};$app$main$ui$workspace$workspace_loader_STAR_$$=function(){return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$product$loader$loader_STAR_$$,{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.loading"),className:"main_ui_workspace__workspace-loader",overlay:!0,fileLoading:!0})};
$app$main$ui$workspace$make_team_ref$$=function($team_id$jscomp$164$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1243_teams$jscomp$20$$){$state$jscomp$1243_teams$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1243_teams$jscomp$20$$,$APP.$cljs$cst$2181$teams$$);return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1243_teams$jscomp$20$$,$team_id$jscomp$164$$)},$APP.$app$main$store$state$$)};
$app$main$ui$workspace$make_file_ref$$=function($file_id$jscomp$438$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($file$jscomp$187_files$jscomp$33_state$jscomp$1244$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$187_files$jscomp$33_state$jscomp$1244$$,$APP.$cljs$cst$1934$current_file_id$$),$file_id$jscomp$438$$)?($file$jscomp$187_files$jscomp$33_state$jscomp$1244$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$187_files$jscomp$33_state$jscomp$1244$$,
$APP.$cljs$cst$1933$files$$),$file$jscomp$187_files$jscomp$33_state$jscomp$1244$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$187_files$jscomp$33_state$jscomp$1244$$,$file_id$jscomp$438$$),$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$187_files$jscomp$33_state$jscomp$1244$$,$APP.$cljs$cst$142$data$$),$cljs$cst$6035$app_DOT_main_DOT_ui_DOT_workspace_SLASH_has_data$$,$APP.$cljs$core$contains_QMARK_$$($file$jscomp$187_files$jscomp$33_state$jscomp$1244$$,
$APP.$cljs$cst$142$data$$))):null},$APP.$app$main$store$state$$,$APP.$cljs$core$_EQ_$$)};
$app$main$ui$workspace$make_page_ref$$=function($file_id$jscomp$439$$,$page_id$jscomp$467$$){return $APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($state$jscomp$1245$$){var $current_page_id$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$1245$$,$APP.$cljs$cst$1935$current_page_id$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($current_page_id$jscomp$8$$,$page_id$jscomp$467$$)?$APP.$app$main$data$helpers$lookup_page$$.$cljs$core$IFn$_invoke$arity$3$($state$jscomp$1245$$,
$file_id$jscomp$439$$,$page_id$jscomp$467$$):null},$APP.$app$main$store$state$$)};
$app$main$ui$workspace$workspace_inner_STAR_$$=function($props_81658_wglobal$jscomp$5$$){var $file_id$jscomp$440$$=$props_81658_wglobal$jscomp$5$$.fileId,$layout$jscomp$37$$=$props_81658_wglobal$jscomp$5$$.layout,$file$jscomp$188$$=$props_81658_wglobal$jscomp$5$$.file,$page_id$jscomp$468$$=$props_81658_wglobal$jscomp$5$$.pageId;$props_81658_wglobal$jscomp$5$$=$props_81658_wglobal$jscomp$5$$.wglobal;var $page$jscomp$179_page_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$440$$),
$APP.$rumext$v2$adapt$$($page_id$jscomp$468$$)],function(){return $app$main$ui$workspace$make_page_ref$$($file_id$jscomp$440$$,$page_id$jscomp$468$$)});$page$jscomp$179_page_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($page$jscomp$179_page_ref$jscomp$1$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key$jscomp$431$$=$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"blur",function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$workspace_focus_lost$$())});
return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$goog$events$unlistenByKey$$,$key$jscomp$431$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$440$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$468$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$pages$initialize_page$$($file_id$jscomp$440$$,$page_id$jscomp$468$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$pages$finalize_page$$($file_id$jscomp$440$$,
$page_id$jscomp$468$$))}});return $page$jscomp$179_page_ref$jscomp$1$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$workspace_content_STAR_$$,{file:$file$jscomp$188$$,page:$page$jscomp$179_page_ref$jscomp$1$$,wglobal:$props_81658_wglobal$jscomp$5$$,layout:$layout$jscomp$37$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$workspace_loader_STAR_$$,{})};
$APP.$app$main$ui$workspace$workspace_page_STAR_$$=function($props_81678$$){return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$workspace_STAR_$$,$props_81678$$)};
$cljs$core$CHAR_MAP$$={"]":"_RBRACK_","'":"_SINGLEQUOTE_","\x3d":"_EQ_",'"':"_DOUBLEQUOTE_","!":"_BANG_","*":"_STAR_","%":"_PERCENT_","|":"_BAR_","~":"_TILDE_","/":"_SLASH_","\\":"_BSLASH_","-":"_","?":"_QMARK_","\x26":"_AMPERSAND_",":":"_COLON_","\x3c":"_LT_","{":"_LBRACE_","}":"_RBRACE_","[":"_LBRACK_","#":"_SHARP_","^":"_CARET_","+":"_PLUS_","@":"_CIRCA_","\x3e":"_GT_"};$cljs$core$js_reserved_arr$$="arguments abstract await boolean break byte case catch char class const continue debugger default delete do double else enum export extends final finally float for function goto if implements import in instanceof int interface let long native new package private protected public return short static super switch synchronized this throw throws transient try typeof var void volatile while with yield methods null constructor".split(" ");
$cljs$core$js_reserved$$=null;$cljs$core$NS_CACHE$$=null;$cljs$tools$reader$READ_EOF$$={};$cljs$tools$reader$READ_FINISHED$$={};$cljs$tools$reader$_STAR_read_delim_STAR_$$=!1;$cljs$tools$reader$_STAR_suppress_read_STAR_$$=!1;$cljs$tools$reader$NO_MATCH$$={};$cljs$tools$reader$arg_env$$=null;$cljs$tools$reader$gensym_env$$=null;$app$$={};$app$main$$={};$app$main$store$$={};$cljs$core$Namespace$$.prototype.$getName$=function(){return this.name};$cljs$core$Namespace$$.prototype.toString=function(){return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.name)};
$cljs$core$Namespace$$.prototype.$cljs$core$IEquiv$_equiv$arity$2$=function($_$jscomp$160$$,$other$jscomp$119$$){return $other$jscomp$119$$ instanceof $cljs$core$Namespace$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.name,$other$jscomp$119$$.name):!1};$cljs$core$Namespace$$.prototype.$cljs$core$IHash$_hash$arity$1$=function(){return $APP.$cljs$core$hash$$(this.name)};$APP.$JSCompiler_prototypeAlias$$=$cljs$core$TaggedLiteral$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$(this)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this$$jscomp$131$$,$other$jscomp$118$$){return $other$jscomp$118$$ instanceof $cljs$core$TaggedLiteral$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.tag,$other$jscomp$118$$.tag)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.form,$other$jscomp$118$$.form)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return 31*$APP.$cljs$core$hash$$(this.tag)+$APP.$cljs$core$hash$$(this.form)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this$$jscomp$133$$,$v$jscomp$78$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$v$jscomp$78$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this$$jscomp$134$$,$v$jscomp$79$$,$not_found$jscomp$60$$){switch($v$jscomp$79$$ instanceof $APP.$cljs$core$Keyword$$?$v$jscomp$79$$.$fqn$:null){case "tag":return this.tag;case "form":return this.form;default:return $not_found$jscomp$60$$}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($o$jscomp$132$$,$writer$jscomp$59$$,$opts$jscomp$56$$){$APP.$cljs$core$_write$$($writer$jscomp$59$$,["#",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(this.tag)," "].join(""));return $APP.$cljs$core$pr_writer$$(this.form,$writer$jscomp$59$$,$opts$jscomp$56$$)};
var $malli$error$_push_in$$=function $malli$error$_push_in$$($a$jscomp$261$$,$G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$,$G__35396_first__35386_p__35383$$,$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$){var $JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$=$APP.$cljs$core$seq$$($G__35396_first__35386_p__35383$$);$G__35396_first__35386_p__35383$$=$APP.$cljs$core$first$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$);
var $seq__35385__$1$$=$APP.$cljs$core$next$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$),$v_SINGLEQUOTE_$jscomp$2$$=$malli$error$_get$$($G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$,$G__35396_first__35386_p__35383$$);$JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$=$APP.$cljs$core$truth_$$($a$jscomp$261$$)?$a$jscomp$261$$:$APP.$cljs$core$sequential_QMARK_$$($G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$)?
$APP.$cljs$core$PersistentVector$EMPTY$$:$APP.$cljs$core$record_QMARK_$$($G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$)?$APP.$cljs$core$PersistentArrayMap$EMPTY$$:$APP.$cljs$core$empty$$($G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($G__35396_first__35386_p__35383$$)?$APP.$cljs$cst$886$malli_DOT_error_SLASH_error$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$)):
$G__35396_first__35386_p__35383$$)?$a$jscomp$261$$:$APP.$cljs$core$truth_$$($G__35396_first__35386_p__35383$$)?($G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$=$malli$error$_get$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$,$G__35396_first__35386_p__35383$$),$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$=$malli$error$_push_in$$.$cljs$core$IFn$_invoke$arity$4$?$malli$error$_push_in$$.$cljs$core$IFn$_invoke$arity$4$($G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$,
$v_SINGLEQUOTE_$jscomp$2$$,$seq__35385__$1$$,$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$):$malli$error$_push_in$$($G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$,$v_SINGLEQUOTE_$jscomp$2$$,$seq__35385__$1$$,$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$),$APP.$cljs$core$int_QMARK_$$($G__35396_first__35386_p__35383$$)&&$APP.$cljs$core$sequential_QMARK_$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$)&&
$G__35396_first__35386_p__35383$$>$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$)&&($G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$=$APP.$cljs$core$repeat$cljs$0core$0IFn$0_invoke$0arity$02$$($G__35396_first__35386_p__35383$$-$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$),null),$G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$=
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$,$G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$),$JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$=$JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$==null||$APP.$cljs$core$seq_QMARK_$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$)?
$G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$:$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$empty$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$),$G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$)),$JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$==null||$APP.$cljs$core$associative_QMARK_$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$,$G__35396_first__35386_p__35383$$,$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$):$APP.$cljs$core$set_QMARK_$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$)?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$,
$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$):$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$list$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$vec$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$),$G__35396_first__35386_p__35383$$,$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$))):$APP.$cljs$core$map_QMARK_$$($a$jscomp$261$$)?($G__35396_first__35386_p__35383$$=new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$887$malli_SLASH_error$$],null),$malli$error$_push_in$$.$cljs$core$IFn$_invoke$arity$4$?$malli$error$_push_in$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$,$G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$,$G__35396_first__35386_p__35383$$,$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$):$malli$error$_push_in$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$,
$G__35361$jscomp$inline_15083_G__35390$jscomp$inline_13422_v$jscomp$217_y$jscomp$inline_15082$$,$G__35396_first__35386_p__35383$$,$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$)):$APP.$cljs$core$truth_$$($APP.$cljs$cst$886$malli_DOT_error_SLASH_error$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$meta$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$)))?$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$,
$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$):$APP.$cljs$core$vector_QMARK_$$($APP.$cljs$core$not_empty$$($JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$))?$JSCompiler_temp$jscomp$15007_a_SINGLEQUOTE__seq__35385_x_SINGLEQUOTE_$jscomp$inline_14844$$:$APP.$cljs$core$with_meta$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$JSCompiler_inline_result$jscomp$11231_e$jscomp$175$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$886$malli_DOT_error_SLASH_error$$,!0],null))},$app$common$types$token$update_token_value_references$$=function $app$common$types$token$update_token_value_references$$($value$jscomp$431$$,$old_name$$,$new_name$$){return typeof $value$jscomp$431$$==="string"?$APP.$cuerdas$core$replace$$($value$jscomp$431$$,$APP.$cljs$core$re_pattern$$(["\\{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$replace$$($old_name$$,".","\\.")),"\\}"].join("")),["{",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($new_name$$),
"}"].join("")):$APP.$cljs$core$map_QMARK_$$($value$jscomp$431$$)?$APP.$app$common$data$update_vals$$($value$jscomp$431$$,function($p1__49047_SHARP_$$){return $app$common$types$token$update_token_value_references$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$types$token$update_token_value_references$$.$cljs$core$IFn$_invoke$arity$3$($p1__49047_SHARP_$$,$old_name$$,$new_name$$):$app$common$types$token$update_token_value_references$$($p1__49047_SHARP_$$,$old_name$$,$new_name$$)}):$APP.$cljs$core$sequential_QMARK_$$($value$jscomp$431$$)?
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__49048_SHARP_$$){return $app$common$types$token$update_token_value_references$$.$cljs$core$IFn$_invoke$arity$3$?$app$common$types$token$update_token_value_references$$.$cljs$core$IFn$_invoke$arity$3$($p1__49048_SHARP_$$,$old_name$$,$new_name$$):$app$common$types$token$update_token_value_references$$($p1__49048_SHARP_$$,$old_name$$,$new_name$$)},$value$jscomp$431$$):$value$jscomp$431$$},$app$common$path_names$build_tree_node$$=function $app$common$path_names$build_tree_node$$($segment_name$$,
$remaining_segments$jscomp$1$$,$separator$jscomp$10$$,$is_leaf_QMARK__parent_path$jscomp$1$$,$depth$jscomp$12$$){var $current_path$$=$APP.$cljs$core$truth_$$($is_leaf_QMARK__parent_path$jscomp$1$$)?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($is_leaf_QMARK__parent_path$jscomp$1$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($segment_name$$)].join(""):$segment_name$$,$leaf_segment$$=($is_leaf_QMARK__parent_path$jscomp$1$$=$APP.$cljs$core$seq$$($remaining_segments$jscomp$1$$)&&
$APP.$cljs$core$every_QMARK_$$(function($remaining_segment_name_segment$jscomp$41$$){$remaining_segment_name_segment$jscomp$41$$=$APP.$cljs$core$first$$($APP.$app$common$path_names$split_path$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($remaining_segment_name_segment$jscomp$41$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1477$separator$$,$separator$jscomp$10$$])));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($segment_name$$,
$remaining_segment_name_segment$jscomp$41$$)},$remaining_segments$jscomp$1$$))?$APP.$cljs$core$first$$($remaining_segments$jscomp$1$$):null;return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$725$name$$,$segment_name$$,$APP.$cljs$cst$296$path$$,$current_path$$,$APP.$cljs$cst$839$depth$$,$depth$jscomp$12$$,$APP.$cljs$cst$2015$leaf$$,$leaf_segment$$,$APP.$cljs$cst$342$children$$,$is_leaf_QMARK__parent_path$jscomp$1$$?null:function(){var $grouped_elements$$=$app$common$path_names$sort_and_group_segments$$($remaining_segments$jscomp$1$$,
$separator$jscomp$10$$);return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p__49174_remaining_child_segments$$){var $child_segment_name$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49174_remaining_child_segments$$,0,null);$p__49174_remaining_child_segments$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__49174_remaining_child_segments$$,1,null);var $G__49182$$=$depth$jscomp$12$$+1;return $app$common$path_names$build_tree_node$$.$cljs$core$IFn$_invoke$arity$5$?
$app$common$path_names$build_tree_node$$.$cljs$core$IFn$_invoke$arity$5$($child_segment_name$$,$p__49174_remaining_child_segments$$,$separator$jscomp$10$$,$current_path$$,$G__49182$$):$app$common$path_names$build_tree_node$$($child_segment_name$$,$p__49174_remaining_child_segments$$,$separator$jscomp$10$$,$current_path$$,$G__49182$$)},$grouped_elements$$)}()],null)},$app$main$data$persistence$run_persistence_task$$=function $app$main$data$persistence$run_persistence_task$$(){typeof $app$main$data$persistence$run_persistence_task_55403$$===
"undefined"&&($app$main$data$persistence$run_persistence_task_55403$$=function($meta55404$$){this.$meta55404$=$meta55404$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$persistence$run_persistence_task_55403$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$run_persistence_task_55403$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3185$app_DOT_main_DOT_data_DOT_persistence_SLASH_run_persistence_task$$},
$app$main$data$persistence$run_persistence_task_55403$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_55405$$,$meta55404__$1$$){return new $app$main$data$persistence$run_persistence_task_55403$$($meta55404__$1$$)},$app$main$data$persistence$run_persistence_task_55403$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta55404$},$app$main$data$persistence$run_persistence_task_55403$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$persistence$run_persistence_task_55403$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$1661_queue$jscomp$1_stoper_s$$,$state$jscomp$192$$,$stream$jscomp$28$$){$_$jscomp$1661_queue$jscomp$1_stoper_s$$=$APP.$cljs$cst$1489$queue$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2186$persistence$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$192$$));var $temp__5823__auto__$jscomp$157$$=$APP.$cljs$core$peek$$($_$jscomp$1661_queue$jscomp$1_stoper_s$$);return $APP.$cljs$core$truth_$$($temp__5823__auto__$jscomp$157$$)?($_$jscomp$1661_queue$jscomp$1_stoper_s$$=$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3185$app_DOT_main_DOT_data_DOT_persistence_SLASH_run_persistence_task$$),
$stream$jscomp$28$$),$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3182$app_DOT_main_DOT_data_DOT_persistence_SLASH_error$$),$stream$jscomp$28$$)),$APP.$app$common$logging$enabled_QMARK_$$("app.main.data.persistence",$APP.$cljs$cst$1160$debug$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$275$hint$$,"run-persistence-task"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3170$commit_id$$,""+($temp__5823__auto__$jscomp$157$$??"")],null)],null)}),null,"app.main.data.persistence",$APP.$cljs$cst$1160$debug$$,!1),$APP.$beicon$v2$core$take_until$$($_$jscomp$1661_queue$jscomp$1_stoper_s$$,$APP.$beicon$v2$core$merge$$((0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$persist_commit$$($temp__5823__auto__$jscomp$157$$)),
$APP.$beicon$v2$core$mapcat$$(function(){return(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$discard_commit$$($temp__5823__auto__$jscomp$157$$),$app$main$data$persistence$run_persistence_task$$.$cljs$core$IFn$_invoke$arity$0$?$app$main$data$persistence$run_persistence_task$$.$cljs$core$IFn$_invoke$arity$0$():$app$main$data$persistence$run_persistence_task$$())},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__55395_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($temp__5823__auto__$jscomp$157$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__55395_SHARP_$$))},$APP.$beicon$v2$core$map$$($APP.$cljs$core$deref$$,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3184$app_DOT_main_DOT_data_DOT_persistence_SLASH_commit_persisted$$),$stream$jscomp$28$$)))))))):(0,$APP.$beicon$v2$core$of$$)($app$main$data$persistence$update_status$$($APP.$cljs$cst$3172$saved$$))});return new $app$main$data$persistence$run_persistence_task_55403$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$APP.$JSCompiler_prototypeAlias$$=$cljs$tools$reader$impl$utils$ReaderConditional$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$$,$k__5324__auto__$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$$,$k24321$$,$else__5326__auto__$$){switch($k24321$$ instanceof $APP.$cljs$core$Keyword$$?$k24321$$.$fqn$:null){case "splicing?":return this.$splicing_QMARK_$;case "form":return this.form;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k24321$$,$else__5326__auto__$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$$,$f__5344__auto__$$,$init__5345__auto__$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$$,$p__24331_v__5348__auto__$$){var $k__5347__auto__$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__24331_v__5348__auto__$$,0,null);$p__24331_v__5348__auto__$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__24331_v__5348__auto__$$,
1,null);return $f__5344__auto__$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$$,$k__5347__auto__$$,$p__24331_v__5348__auto__$$):$f__5344__auto__$$($ret__5346__auto__$$,$k__5347__auto__$$,$p__24331_v__5348__auto__$$)},$init__5345__auto__$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$$,$writer__5339__auto__$$,$opts__5340__auto__$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$$,function($keyval__5342__auto__$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$$,$keyval__5342__auto__$$)},"#cljs.tools.reader.impl.utils.ReaderConditional{",", ","}",$opts__5340__auto__$$,
$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$178$splicing_QMARK_$$,this.$splicing_QMARK_$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$179$form$$,this.form],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$178$splicing_QMARK_$$,$APP.$cljs$cst$179$form$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,this.form,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$26_h__5134__auto____$1$jscomp$26$$=this.$__hash$;return $h__5134__auto__$jscomp$26_h__5134__auto____$1$jscomp$26$$!=null?$h__5134__auto__$jscomp$26_h__5134__auto____$1$jscomp$26$$:this.$__hash$=$h__5134__auto__$jscomp$26_h__5134__auto____$1$jscomp$26$$=-209062840^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this24322$$,$other24323$$){return $other24323$$!=null&&this.constructor===$other24323$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$splicing_QMARK_$,$other24323$$.$splicing_QMARK_$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.form,$other24323$$.form)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other24323$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$$,$k__5334__auto__$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$178$splicing_QMARK_$$,null,$APP.$cljs$cst$179$form$$,null],null),null),$k__5334__auto__$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$$):new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,this.form,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$$,$k24321$jscomp$1$$){switch($k24321$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k24321$jscomp$1$$.$fqn$:null){case "splicing?":case "form":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k24321$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$$,$k__5332__auto__$$,$G__24320$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$178$splicing_QMARK_$$,$k__5332__auto__$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$178$splicing_QMARK_$$,$k__5332__auto__$$))?new $cljs$tools$reader$impl$utils$ReaderConditional$$($G__24320$jscomp$1$$,
this.form,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$179$form$$,$k__5332__auto__$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$179$form$$,$k__5332__auto__$$))?new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,$G__24320$jscomp$1$$,this.$__meta$,this.$__extmap$,null):new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,
this.form,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$$,$G__24320$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$178$splicing_QMARK_$$,this.$splicing_QMARK_$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$179$form$$,this.form,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$$,$G__24320$jscomp$2$$){return new $cljs$tools$reader$impl$utils$ReaderConditional$$(this.$splicing_QMARK_$,this.form,$G__24320$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$$,$entry__5329__auto__$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($coll$jscomp$819$$,$writer$jscomp$60$$,$opts$jscomp$57$$){$APP.$cljs$core$_write$$($writer$jscomp$60$$,["#?",$APP.$cljs$core$truth_$$(this.$splicing_QMARK_$)?"@":null].join(""));return $APP.$cljs$core$pr_writer$$(this.form,$writer$jscomp$60$$,$opts$jscomp$57$$)};
var $app$main$data$workspace$texts$update_text_modifier$$=function $app$main$data$workspace$texts$update_text_modifier$$($id$jscomp$633$$,$props$jscomp$188$$){var $cur_event$jscomp$6$$=Symbol();typeof $app$main$data$workspace$texts$update_text_modifier_70462$$==="undefined"&&($app$main$data$workspace$texts$update_text_modifier_70462$$=function($id$jscomp$634$$,$props$jscomp$189$$,$cur_event$jscomp$7$$,$meta70463$$){this.id=$id$jscomp$634$$;this.props=$props$jscomp$189$$;this.$cur_event$=$cur_event$jscomp$7$$;
this.$meta70463$=$meta70463$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_text_modifier_70462$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_modifier_70462$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4093$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier$$},$app$main$data$workspace$texts$update_text_modifier_70462$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=
function($_70464$$,$meta70463__$1$$){return new $app$main$data$workspace$texts$update_text_modifier_70462$$(this.id,this.props,this.$cur_event$,$meta70463__$1$$)},$app$main$data$workspace$texts$update_text_modifier_70462$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70463$},$app$main$data$workspace$texts$update_text_modifier_70462$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_modifier_70462$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=
function($G__70476__$jscomp$2200$$,$state$jscomp$591$$){$G__70476__$jscomp$2200$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$591$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2246$workspace_text_modifier$$,this.id],null),$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),
this.props),$APP.$cljs$cst$4092$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_ids$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$conj$$,$APP.$cljs$core$PersistentHashSet$EMPTY$$),this.id);return $APP.$cljs$cst$4094$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$591$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70476__$jscomp$2200$$,
$APP.$cljs$cst$4094$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$,this.$cur_event$):$G__70476__$jscomp$2200$$},$app$main$data$workspace$texts$update_text_modifier_70462$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_text_modifier_70462$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2201_stopper$jscomp$18$$,$state$jscomp$592$$,$stream$jscomp$62$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4094$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$592$$),
this.$cur_event$)?($_$jscomp$2201_stopper$jscomp$18$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3963$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize$$),$stream$jscomp$62$$),$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2201_stopper$jscomp$18$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$texts$commit_update_text_modifier$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$debounce$$(50,
$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4093$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier$$),$stream$jscomp$62$$))))),(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$texts$update_text_modifier$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$texts$update_text_modifier$$.$cljs$core$IFn$_invoke$arity$2$(this.id,this.props):$app$main$data$workspace$texts$update_text_modifier$$(this.id,
this.props))),(0,$APP.$beicon$v2$core$of$$)(function($p1__70459_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__70459_SHARP_$$,$APP.$cljs$cst$4094$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_event$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4092$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_text_modifier_debounce_ids$$]))}))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$texts$update_text_modifier_70462$$($id$jscomp$633$$,
$props$jscomp$188$$,$cur_event$jscomp$6$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},$app$main$worker$ask_buffered_BANG_$$=function $app$main$worker$ask_buffered_BANG_$$($var_args$jscomp$1149$$){switch(arguments.length){case 1:return $app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$1$=function($message$jscomp$77$$){return $APP.$cljs$core$truth_$$($APP.$app$main$worker$instance$$)?$app$util$worker$ask_buffered_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$77$$,null):$APP.$beicon$v2$core$empty$$()};
$app$main$worker$ask_buffered_BANG_$$.$cljs$core$IFn$_invoke$arity$2$=function($message$jscomp$78$$,$transfer$jscomp$11$$){return $APP.$cljs$core$truth_$$($APP.$app$main$worker$instance$$)?$app$util$worker$ask_buffered_BANG_$cljs$0core$0IFn$0_invoke$0arity$03$$($message$jscomp$78$$,$transfer$jscomp$11$$):$APP.$beicon$v2$core$empty$$()};$app$main$worker$ask_buffered_BANG_$$.$cljs$lang$maxFixedArity$=2;
var $app$common$types$tokens_lib$get_tokens_of_unknown_type$$=function $app$common$types$tokens_lib$get_tokens_of_unknown_type$$($decoded_json$jscomp$7$$,$json_format$jscomp$1_p__50097$$){var $map__50098__$1$$=$APP.$cljs$core$__destructure_map$$($json_format$jscomp$1_p__50097$$);$json_format$jscomp$1_p__50097$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50098__$1$$,$APP.$cljs$cst$2143$json_format$$,$app$common$types$tokens_lib$get_json_format$cljs$0core$0IFn$0_invoke$0arity$03$$($decoded_json$jscomp$7$$));
var $parent_path$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50098__$1$$,$APP.$cljs$cst$2125$parent_path$$,""),$process_token_type$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($map__50098__$1$$,$APP.$cljs$cst$2144$process_token_type$$,$APP.$cljs$core$identity$$),$type_key$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($json_format$jscomp$1_p__50097$$,$APP.$cljs$cst$2140$json_format_SLASH_dtcg$$)?"$type":"type";return $APP.$cljs$core$reduce_kv$$(function($unknown_tokens$$,
$k$jscomp$603_nested_unknown_tokens$$,$v$jscomp$539$$){var $child_path$jscomp$2$$=$APP.$cljs$core$empty_QMARK_$$($parent_path$jscomp$6$$)?$APP.$cljs$core$name$$($k$jscomp$603_nested_unknown_tokens$$):[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($parent_path$jscomp$6$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($k$jscomp$603_nested_unknown_tokens$$)].join("");if($APP.$cljs$core$map_QMARK_$$($v$jscomp$539$$)&&!$APP.$cljs$core$contains_QMARK_$$($v$jscomp$539$$,$type_key$jscomp$1$$))return $k$jscomp$603_nested_unknown_tokens$$=
function(){var $G__50100$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__50098__$1$$,$APP.$cljs$cst$2125$parent_path$$,$child_path$jscomp$2$$);return $app$common$types$tokens_lib$get_tokens_of_unknown_type$$.$cljs$core$IFn$_invoke$arity$2$?$app$common$types$tokens_lib$get_tokens_of_unknown_type$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$539$$,$G__50100$$):$app$common$types$tokens_lib$get_tokens_of_unknown_type$$($v$jscomp$539$$,$G__50100$$)}(),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$unknown_tokens$$,
$k$jscomp$603_nested_unknown_tokens$$]));var $token_type_str$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($v$jscomp$539$$,$type_key$jscomp$1$$);return function(){var $G__50101$$=$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$.$cljs$core$IFn$_invoke$arity$1$($token_type_str$$):(0,$APP.$app$common$types$token$dtcg_token_type__GT_token_type$$)($token_type_str$$);return $process_token_type$$.$cljs$core$IFn$_invoke$arity$1$?
$process_token_type$$.$cljs$core$IFn$_invoke$arity$1$($G__50101$$):$process_token_type$$($G__50101$$)}()==null&&$token_type_str$$!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($unknown_tokens$$,$child_path$jscomp$2$$,$token_type_str$$):$unknown_tokens$$},null,$decoded_json$jscomp$7$$)},$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$=function $app$common$logic$libraries$generate_sync_shape_inverse_recursive$$($changes$jscomp$123$$,$container$jscomp$52$$,$shape_inst$jscomp$7$$,
$component$jscomp$68$$,$library$jscomp$21$$,$file$jscomp$55$$,$libraries$jscomp$53$$,$shape_main$jscomp$7$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$,$initial_root_QMARK_$jscomp$3$$){function $check_local$$($change$jscomp$23$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($change$jscomp$23$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$7$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($change$jscomp$23$$,
$APP.$cljs$cst$3593$local_change_QMARK_$$,!0):$change$jscomp$23$$}function $moved$jscomp$1$$($changes__$2$jscomp$18$$,$G__66615_child_inst$jscomp$7$$,$child_main$jscomp$7$$){var $G__66614$$=$APP.$app$common$data$index_of$$($children_main$jscomp$1$$,$child_main$jscomp$7$$);$G__66615_child_inst$jscomp$7$$=$APP.$app$common$data$index_of$$($children_inst$jscomp$1$$,$G__66615_child_inst$jscomp$7$$);return $APP.$app$common$logic$libraries$move_shape$$.$cljs$core$IFn$_invoke$arity$6$?$APP.$app$common$logic$libraries$move_shape$$.$cljs$core$IFn$_invoke$arity$6$($changes__$2$jscomp$18$$,
$child_main$jscomp$7$$,$G__66614$$,$G__66615_child_inst$jscomp$7$$,$component_container$jscomp$2$$,!1):$APP.$app$common$logic$libraries$move_shape$$($changes__$2$jscomp$18$$,$child_main$jscomp$7$$,$G__66614$$,$G__66615_child_inst$jscomp$7$$,$component_container$jscomp$2$$,!1)}function $swapped$jscomp$1$$($changes__$2$jscomp$17$$,$child_inst$jscomp$6$$,$child_main$jscomp$6$$){$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$6$$),
$container$jscomp$52$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,"Match slot"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$3589$child_inst$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$6$$))," ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_inst$jscomp$6$$))].join("")],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3591$child_main$$,[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$6$$)),
" ",$APP.$app$common$logic$libraries$pretty_uuid$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($child_main$jscomp$6$$))].join("")],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);return $changes__$2$jscomp$17$$}function $both$jscomp$1$$($changes__$2$jscomp$16$$,$child_inst$jscomp$5$$,$child_main$jscomp$5$$){return $app$common$logic$libraries$generate_sync_shape_inverse_recursive$$.$cljs$core$IFn$_invoke$arity$11$?$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$.$cljs$core$IFn$_invoke$arity$11$($changes__$2$jscomp$16$$,
$container$jscomp$52$$,$child_inst$jscomp$5$$,$component$jscomp$68$$,$library$jscomp$21$$,$file$jscomp$55$$,$libraries$jscomp$53$$,$child_main$jscomp$5$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$,$initial_root_QMARK_$jscomp$3$$):$app$common$logic$libraries$generate_sync_shape_inverse_recursive$$($changes__$2$jscomp$16$$,$container$jscomp$52$$,$child_inst$jscomp$5$$,$component$jscomp$68$$,$library$jscomp$21$$,$file$jscomp$55$$,$libraries$jscomp$53$$,$child_main$jscomp$5$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$,
$initial_root_QMARK_$jscomp$3$$)}function $only_main$jscomp$1$$($changes__$2$jscomp$15$$,$child_main$jscomp$4$$){return $APP.$app$common$logic$libraries$remove_shape$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$common$logic$libraries$remove_shape$$.$cljs$core$IFn$_invoke$arity$4$($changes__$2$jscomp$15$$,$child_main$jscomp$4$$,$component_container$jscomp$2$$,!1):$APP.$app$common$logic$libraries$remove_shape$$($changes__$2$jscomp$15$$,$child_main$jscomp$4$$,$component_container$jscomp$2$$,!1)}function $only_inst$jscomp$1$$($changes__$2$jscomp$14$$,
$child_inst$jscomp$4$$){var $G__66606$$=$APP.$app$common$data$index_of$$($children_inst$jscomp$1$$,$child_inst$jscomp$4$$);return $app$common$logic$libraries$add_shape_to_main$$.$cljs$core$IFn$_invoke$arity$8$?$app$common$logic$libraries$add_shape_to_main$$.$cljs$core$IFn$_invoke$arity$8$($changes__$2$jscomp$14$$,$child_inst$jscomp$4$$,$G__66606$$,$component$jscomp$68$$,$component_container$jscomp$2$$,$container$jscomp$52$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$):$app$common$logic$libraries$add_shape_to_main$$($changes__$2$jscomp$14$$,
$child_inst$jscomp$4$$,$G__66606$$,$component$jscomp$68$$,$component_container$jscomp$2$$,$container$jscomp$52$$,$root_inst$jscomp$3$$,$root_main$jscomp$3$$)}$APP.$app$common$logic$libraries$enabled_shape_QMARK_$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$7$$),$container$jscomp$52$$)&&$APP.$app$common$logging$enabled_QMARK_$$("app.common.logic.libraries",$APP.$cljs$cst$144$trace$$)&&$APP.$app$common$logging$emit_log$$(new $APP.$cljs$core$Delay$$(function(){return new $APP.$cljs$core$PersistentVector$$(null,
3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1551$msg$$,"Sync shape inverse recursive"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1817$shape$$,$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$7$$))],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1630$component$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$68$$)],null)],null)}),null,"app.common.logic.libraries",$APP.$cljs$cst$144$trace$$,!1);if($shape_main$jscomp$7$$==null)return $changes$jscomp$123$$;var $component_container$jscomp$2$$=$APP.$app$common$types$file$get_component_container$$($library$jscomp$21$$,$component$jscomp$68$$),$set_remote_synced_QMARK_$jscomp$1$$=$APP.$cljs$core$not$$($initial_root_QMARK_$jscomp$3$$),
$changes__$1$jscomp$28_changes__$2$jscomp$13$$=function(){var $G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$=$APP.$app$common$logic$libraries$update_attrs$$.$cljs$core$IFn$_invoke$arity$7$?$APP.$app$common$logic$libraries$update_attrs$$.$cljs$core$IFn$_invoke$arity$7$($changes$jscomp$123$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$root_main$jscomp$3$$,$root_inst$jscomp$3$$,$component_container$jscomp$2$$,!1):$APP.$app$common$logic$libraries$update_attrs$$($changes$jscomp$123$$,
$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$root_main$jscomp$3$$,$root_inst$jscomp$3$$,$component_container$jscomp$2$$,!1);var $G__66598$jscomp$inline_13590_G__66603$jscomp$inline_13589$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3588$reset_touched_QMARK_$$,!0],null);$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$=$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$?$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,
$shape_inst$jscomp$7$$,$shape_main$jscomp$7$$,$container$jscomp$52$$,$G__66598$jscomp$inline_13590_G__66603$jscomp$inline_13589$$):$APP.$app$common$logic$libraries$change_touched$$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_inst$jscomp$7$$,$shape_main$jscomp$7$$,$container$jscomp$52$$,$G__66598$jscomp$inline_13590_G__66603$jscomp$inline_13589$$);$G__66598$jscomp$inline_13590_G__66603$jscomp$inline_13589$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$3592$copy_touched_QMARK_$$,!0],null);$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$=$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$?$APP.$app$common$logic$libraries$change_touched$$.$cljs$core$IFn$_invoke$arity$5$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,
$G__66598$jscomp$inline_13590_G__66603$jscomp$inline_13589$$):$APP.$app$common$logic$libraries$change_touched$$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,$G__66598$jscomp$inline_13590_G__66603$jscomp$inline_13589$$);$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$7$$)?
$app$common$logic$libraries$update_flex_child_main_attrs$$.$cljs$core$IFn$_invoke$arity$6$?$app$common$logic$libraries$update_flex_child_main_attrs$$.$cljs$core$IFn$_invoke$arity$6$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,$container$jscomp$52$$,!1):$app$common$logic$libraries$update_flex_child_main_attrs$$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,
$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,$container$jscomp$52$$,!1):$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$;$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$7$$)?$app$common$logic$libraries$update_grid_main_attrs$$.$cljs$core$IFn$_invoke$arity$6$?
$app$common$logic$libraries$update_grid_main_attrs$$.$cljs$core$IFn$_invoke$arity$6$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,$component_container$jscomp$2$$,$container$jscomp$52$$,!1):$app$common$logic$libraries$update_grid_main_attrs$$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_main$jscomp$7$$,$shape_inst$jscomp$7$$,
$component_container$jscomp$2$$,$container$jscomp$52$$,!1):$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$;$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$=$APP.$cljs$core$truth_$$($initial_root_QMARK_$jscomp$3$$)?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,
$shape_inst$jscomp$7$$,$container$jscomp$52$$,null):$APP.$app$common$logic$libraries$change_remote_synced$$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_inst$jscomp$7$$,$container$jscomp$52$$,null):$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$;return $set_remote_synced_QMARK_$jscomp$1$$?$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$?
$APP.$app$common$logic$libraries$change_remote_synced$$.$cljs$core$IFn$_invoke$arity$4$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_inst$jscomp$7$$,$container$jscomp$52$$,!0):$APP.$app$common$logic$libraries$change_remote_synced$$($G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$,$shape_inst$jscomp$7$$,$container$jscomp$52$$,!0):$G__66593__$1_G__66593__$2_G__66593__$3_G__66593__$4_G__66594$jscomp$inline_13587_G__66599$jscomp$inline_13588$$}(),
$children_inst$jscomp$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66588_SHARP_$$){return $APP.$app$common$types$container$get_shape$$($container$jscomp$52$$,$p1__66588_SHARP_$$)},$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape_inst$jscomp$7$$)),$children_main$jscomp$1$$=$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__66589_SHARP_$$){return $APP.$app$common$types$container$get_shape$$($component_container$jscomp$2$$,$p1__66589_SHARP_$$)},
$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($shape_main$jscomp$7$$));$changes__$1$jscomp$28_changes__$2$jscomp$13$$=$APP.$app$common$logic$libraries$compare_children$$.$cljs$core$IFn$_invoke$arity$15$?$APP.$app$common$logic$libraries$compare_children$$.$cljs$core$IFn$_invoke$arity$15$($changes__$1$jscomp$28_changes__$2$jscomp$13$$,$shape_inst$jscomp$7$$,$children_inst$jscomp$1$$,$children_main$jscomp$1$$,$container$jscomp$52$$,$component_container$jscomp$2$$,$file$jscomp$55$$,$libraries$jscomp$53$$,
$only_inst$jscomp$1$$,$only_main$jscomp$1$$,$both$jscomp$1$$,$swapped$jscomp$1$$,$moved$jscomp$1$$,!0,!0):$APP.$app$common$logic$libraries$compare_children$$($changes__$1$jscomp$28_changes__$2$jscomp$13$$,$shape_inst$jscomp$7$$,$children_inst$jscomp$1$$,$children_main$jscomp$1$$,$container$jscomp$52$$,$component_container$jscomp$2$$,$file$jscomp$55$$,$libraries$jscomp$53$$,$only_inst$jscomp$1$$,$only_main$jscomp$1$$,$both$jscomp$1$$,$swapped$jscomp$1$$,$moved$jscomp$1$$,!0,!0);return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($changes__$1$jscomp$28_changes__$2$jscomp$13$$,
$APP.$cljs$cst$3157$redo_changes$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$mapv$$,$check_local$$)),$APP.$cljs$cst$3161$undo_changes$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$map$$,$check_local$$))},$app$main$data$workspace$texts$update_position_data$$=function $app$main$data$workspace$texts$update_position_data$$($id$jscomp$639$$,$position_data$jscomp$10$$){var $cur_event$jscomp$8$$=Symbol();typeof $app$main$data$workspace$texts$update_position_data_70522$$===
"undefined"&&($app$main$data$workspace$texts$update_position_data_70522$$=function($id$jscomp$640$$,$position_data$jscomp$11$$,$cur_event$jscomp$9$$,$meta70523$$){this.id=$id$jscomp$640$$;this.$position_data$=$position_data$jscomp$11$$;this.$cur_event$=$cur_event$jscomp$9$$;this.$meta70523$=$meta70523$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$update_position_data_70522$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$update_position_data_70522$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$},$app$main$data$workspace$texts$update_position_data_70522$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70524$$,$meta70523__$1$$){return new $app$main$data$workspace$texts$update_position_data_70522$$(this.id,this.$position_data$,this.$cur_event$,$meta70523__$1$$)},
$app$main$data$workspace$texts$update_position_data_70522$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70523$},$app$main$data$workspace$texts$update_position_data_70522$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_position_data_70522$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2207_state__$1$jscomp$27$$,$state$jscomp$597$$){$_$jscomp$2207_state__$1$jscomp$27$$=$APP.$cljs$core$assoc_in$$($state$jscomp$597$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2246$workspace_text_modifier$$,this.id,$APP.$cljs$cst$1899$position_data$$],null),this.$position_data$);return $APP.$cljs$cst$4099$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$.$cljs$core$IFn$_invoke$arity$1$($_$jscomp$2207_state__$1$jscomp$27$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($_$jscomp$2207_state__$1$jscomp$27$$,$APP.$cljs$cst$4099$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$,
this.$cur_event$):$APP.$cljs$core$assoc_in$$($_$jscomp$2207_state__$1$jscomp$27$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$,this.id],null),this.$position_data$)},$app$main$data$workspace$texts$update_position_data_70522$$.prototype.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$update_position_data_70522$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=
function($_$jscomp$2208_stopper$jscomp$19$$,$state$jscomp$598$$,$stream$jscomp$63$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4099$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data_debounce$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$598$$),this.$cur_event$)?($_$jscomp$2208_stopper$jscomp$19$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3963$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize$$),
$stream$jscomp$63$$),$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2208_stopper$jscomp$19$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$texts$commit_position_data$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$debounce$$(50,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4098$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_update_position_data$$),$stream$jscomp$63$$))))),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$texts$update_position_data$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$data$workspace$texts$update_position_data$$.$cljs$core$IFn$_invoke$arity$2$(this.id,this.$position_data$):$app$main$data$workspace$texts$update_position_data$$(this.id,this.$position_data$)))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$texts$update_position_data_70522$$($id$jscomp$639$$,$position_data$jscomp$10$$,$cur_event$jscomp$8$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)},
$app$main$data$workspace$texts$resize_text$$=function $app$main$data$workspace$texts$resize_text$$($id$jscomp$631$$,$new_width$jscomp$5$$,$new_height$jscomp$5$$){var $cur_event$jscomp$4$$=Symbol();typeof $app$main$data$workspace$texts$resize_text_70418$$==="undefined"&&($app$main$data$workspace$texts$resize_text_70418$$=function($id$jscomp$632$$,$new_width$jscomp$6$$,$new_height$jscomp$6$$,$cur_event$jscomp$5$$,$meta70419$$){this.id=$id$jscomp$632$$;this.$new_width$=$new_width$jscomp$6$$;this.$new_height$=
$new_height$jscomp$6$$;this.$cur_event$=$cur_event$jscomp$5$$;this.$meta70419$=$meta70419$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$texts$resize_text_70418$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$resize_text_70418$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$4088$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text$$},
$app$main$data$workspace$texts$resize_text_70418$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_70420$$,$meta70419__$1$$){return new $app$main$data$workspace$texts$resize_text_70418$$(this.id,this.$new_width$,this.$new_height$,this.$cur_event$,$meta70419__$1$$)},$app$main$data$workspace$texts$resize_text_70418$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta70419$},$app$main$data$workspace$texts$resize_text_70418$$.prototype.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,
$app$main$data$workspace$texts$resize_text_70418$$.prototype.$potok$v2$core$UpdateEvent$update$arity$2$=function($G__70426__$jscomp$2196$$,$state$jscomp$587$$){$G__70426__$jscomp$2196$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($state$jscomp$587$$,$APP.$cljs$cst$4087$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_props$$,$APP.$cljs$core$fnil$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$assoc$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$),this.id,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[this.$new_width$,this.$new_height$],null));return $APP.$cljs$cst$4089$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$587$$)==null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__70426__$jscomp$2196$$,$APP.$cljs$cst$4089$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$,this.$cur_event$):$G__70426__$jscomp$2196$$},$app$main$data$workspace$texts$resize_text_70418$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$texts$resize_text_70418$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2197_stopper$jscomp$17$$,$state$jscomp$588$$,$stream$jscomp$61$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4089$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$588$$),this.$cur_event$)?($_$jscomp$2197_stopper$jscomp$17$$=$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$3963$app_DOT_main_DOT_data_DOT_workspace_SLASH_finalize$$),
$stream$jscomp$61$$),$APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($_$jscomp$2197_stopper$jscomp$17$$,$APP.$beicon$v2$core$map$$(function(){return $app$main$data$workspace$texts$commit_resize_text$$()},$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$debounce$$(50,$APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4088$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text$$),$stream$jscomp$61$$))))),
(0,$APP.$beicon$v2$core$of$$)($app$main$data$workspace$texts$resize_text$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$data$workspace$texts$resize_text$$.$cljs$core$IFn$_invoke$arity$3$(this.id,this.$new_width$,this.$new_height$):$app$main$data$workspace$texts$resize_text$$(this.id,this.$new_width$,this.$new_height$))),(0,$APP.$beicon$v2$core$of$$)(function($p1__70412_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__70412_SHARP_$$,$APP.$cljs$cst$4087$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_props$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4089$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_resize_text_debounce_event$$]))}))):$APP.$beicon$v2$core$empty$$()});return new $app$main$data$workspace$texts$resize_text_70418$$($id$jscomp$631$$,$new_width$jscomp$5$$,$new_height$jscomp$5$$,$cur_event$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};$APP.$JSCompiler_prototypeAlias$$=$app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69261$$.prototype;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69263$$,$meta69262__$1$$){return new $app$main$data$workspace$transforms$t_app$0main$0data$0workspace$0transforms69261$$(this.handler,this.ids,this.shape,this.resize,this.$normalize_proportion_lock$,$meta69262__$1$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69262$};$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$UpdateEvent$update$arity$2$=function($_$jscomp$2066$$,$state$jscomp$464$$){return $APP.$cljs$core$assoc_in$$($state$jscomp$464$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1937$workspace_local$$,$APP.$cljs$cst$1294$transform$$],null),$APP.$cljs$cst$1805$resize$$)};$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$potok$v2$core$WatchEvent$watch$arity$3$=function($_$jscomp$2067$$,$state$jscomp$465$$,$stream$jscomp$48$$){var $self__$jscomp$4625$$=this;if($APP.$cljs$core$truth_$$($APP.$cljs$cst$1628$blocked$$.$cljs$core$IFn$_invoke$arity$1$($self__$jscomp$4625$$.shape)))return $APP.$beicon$v2$core$empty$$();var $initial_position$$=$APP.$cljs$core$_deref$$($APP.$app$main$streams$mouse_position$$),$stopper$jscomp$11$$=$APP.$app$util$mouse$drag_stopper$cljs$0core$0IFn$0_invoke$0arity$02$$($stream$jscomp$48$$,
null),$layout$jscomp$13$$=$APP.$cljs$cst$2217$workspace_layout$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$465$$),$page_id$jscomp$172$$=$APP.$cljs$cst$1935$current_page_id$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$465$$),$focus$jscomp$12$$=$APP.$cljs$cst$2234$workspace_focus_selected$$.$cljs$core$IFn$_invoke$arity$1$($state$jscomp$465$$),$zoom$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$465$$,$APP.$cljs$cst$1937$workspace_local$$),
$APP.$cljs$cst$2204$zoom$$,1),$objects$jscomp$485$$=$APP.$app$main$data$helpers$lookup_page_objects$$.$cljs$core$IFn$_invoke$arity$2$($state$jscomp$465$$,$page_id$jscomp$172$$),$shape_ids$jscomp$5$$=$APP.$cljs$core$filterv$$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$not$$,$APP.$cljs$cst$1628$blocked$$,$APP.$app$common$data$getf$$($objects$jscomp$485$$)),$self__$jscomp$4625$$.ids);if($APP.$cljs$core$empty_QMARK_$$($shape_ids$jscomp$5$$))return $APP.$beicon$v2$core$empty$$();
var $shapes$jscomp$96$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$485$$),$shape_ids$jscomp$5$$),$resize_events_stream$$=$APP.$beicon$v2$core$share$$($APP.$beicon$v2$core$map$$(function($p1__69162_SHARP_$$){return $self__$jscomp$4625$$.resize.$cljs$core$IFn$_invoke$arity$5$?$self__$jscomp$4625$$.resize.$cljs$core$IFn$_invoke$arity$5$($self__$jscomp$4625$$.shape,$initial_position$$,$layout$jscomp$13$$,$objects$jscomp$485$$,$p1__69162_SHARP_$$):
$self__$jscomp$4625$$.resize($self__$jscomp$4625$$.shape,$initial_position$$,$layout$jscomp$13$$,$objects$jscomp$485$$,$p1__69162_SHARP_$$)},$APP.$beicon$v2$core$switch_map$$(function($p__69275$$){var $point$jscomp$61$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69275$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69275$$,1,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__69275$$,2,null);return $APP.$beicon$v2$core$map$$(function($p1__69160_SHARP_$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($p__69275$$,
$p1__69160_SHARP_$$)},$APP.$app$main$snap$closest_snap_point$$($page_id$jscomp$172$$,$shapes$jscomp$96$$,$objects$jscomp$485$$,$layout$jscomp$13$$,$zoom$jscomp$23$$,$focus$jscomp$12$$,$point$jscomp$61$$))},$APP.$beicon$v2$core$map$$($self__$jscomp$4625$$.$normalize_proportion_lock$,$APP.$beicon$v2$core$with_latest_from$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$sub$jscomp$inline_5658$$,$APP.$sub$jscomp$inline_5661$$,$APP.$beicon$v2$core$filter$$($APP.$cljs$core$some_QMARK_$$,$APP.$app$main$streams$mouse_position$$)))))),
$modifiers_stream$$=$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$465$$,"render-wasm/v1")?$APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($stopper$jscomp$11$$,$APP.$beicon$v2$core$mapcat$$(function($modif_tree$jscomp$53_modifiers$jscomp$80$$){$modif_tree$jscomp$53_modifiers$jscomp$80$$=$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($shape_ids$jscomp$5$$,$modif_tree$jscomp$53_modifiers$jscomp$80$$);return(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$set_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($modif_tree$jscomp$53_modifiers$jscomp$80$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3885$ignore_constraints$$,$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$13$$,$APP.$cljs$cst$3765$scale_text$$)])))},$APP.$beicon$v2$core$sample$$(16,$resize_events_stream$$))),$APP.$beicon$v2$core$map$$(function($p1__69166_SHARP_$$){return $APP.$app$main$data$workspace$modifiers$apply_wasm_modifiers$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$app$main$data$workspace$modifiers$create_modif_tree$$($shape_ids$jscomp$5$$,
$p1__69166_SHARP_$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$3885$ignore_constraints$$,$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$13$$,$APP.$cljs$cst$3765$scale_text$$)]))},$APP.$beicon$v2$core$last$$($APP.$beicon$v2$core$take_until$$($stopper$jscomp$11$$,$resize_events_stream$$)))):function(){function $emit_modifiers$$($JSCompiler_inline_result$jscomp$11255_modif_tree$jscomp$inline_13639_modifiers$jscomp$81$$){$JSCompiler_inline_result$jscomp$11255_modif_tree$jscomp$inline_13639_modifiers$jscomp$81$$=
$APP.$app$main$data$workspace$modifiers$create_modif_tree$$($shape_ids$jscomp$5$$,$JSCompiler_inline_result$jscomp$11255_modif_tree$jscomp$inline_13639_modifiers$jscomp$81$$);var $ignore_constraints$jscomp$inline_13640$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$13$$,$APP.$cljs$cst$3765$scale_text$$);$JSCompiler_inline_result$jscomp$11255_modif_tree$jscomp$inline_13639_modifiers$jscomp$81$$=$APP.$app$main$data$workspace$modifiers$set_modifiers$cljs$0core$0IFn$0_invoke$0arity$04$$($JSCompiler_inline_result$jscomp$11255_modif_tree$jscomp$inline_13639_modifiers$jscomp$81$$,
$ignore_constraints$jscomp$inline_13640$$,!1,null);return(0,$APP.$beicon$v2$core$of$$)($JSCompiler_inline_result$jscomp$11255_modif_tree$jscomp$inline_13639_modifiers$jscomp$81$$)}return $APP.$beicon$v2$core$merge$$($APP.$beicon$v2$core$take_until$$($stopper$jscomp$11$$,$APP.$beicon$v2$core$mapcat$$($emit_modifiers$$,$APP.$beicon$v2$core$sample$$(16,$resize_events_stream$$))),$APP.$beicon$v2$core$mapcat$$($emit_modifiers$$,$APP.$beicon$v2$core$last$$($APP.$beicon$v2$core$take_until$$($stopper$jscomp$11$$,
$resize_events_stream$$))))}();return $APP.$beicon$v2$core$concat$$($APP.$beicon$v2$core$mapcat$$(function(){return $modifiers_stream$$},$APP.$beicon$v2$core$take_until$$($stopper$jscomp$11$$,$APP.$beicon$v2$core$take$$($APP.$beicon$v2$core$filter$$(function($p1__69169_SHARP_$$){return $p1__69169_SHARP_$$>10/$zoom$jscomp$23$$},$APP.$beicon$v2$core$map$$(function($p1__69168_SHARP_$$){return $APP.$app$common$geom$point$length$$($p1__69168_SHARP_$$)},$APP.$beicon$v2$core$map$$(function($p1__69167_SHARP_$$){return $APP.$app$common$geom$point$subtract$$($p1__69167_SHARP_$$,
$initial_position$$)},$APP.$app$main$streams$mouse_position$$)))))),$APP.$app$main$features$active_feature_QMARK_$$($state$jscomp$465$$,"render-wasm/v1")?(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$transforms$finish_transform$$()):(0,$APP.$beicon$v2$core$of$$)($APP.$app$main$data$workspace$modifiers$apply_modifiers$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$APP.$app$main$data$workspace$transforms$finish_transform$$()))};
var $app$main$data$workspace$libraries$duplicate_component$$=function $app$main$data$workspace$libraries$duplicate_component$$($var_args$jscomp$1281$$){switch(arguments.length){case 2:return $app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$2$=function($library_id$jscomp$34$$,$component_id$jscomp$49$$){return $app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$3$($library_id$jscomp$34$$,$component_id$jscomp$49$$,$APP.$app$common$uuid$next$$())};
$app$main$data$workspace$libraries$duplicate_component$$.$cljs$core$IFn$_invoke$arity$3$=function($library_id$jscomp$35$$,$component_id$jscomp$50$$,$new_component_id$jscomp$4$$){typeof $app$main$data$workspace$libraries$duplicate_component_69769$$==="undefined"&&($app$main$data$workspace$libraries$duplicate_component_69769$$=function($library_id$jscomp$36$$,$component_id$jscomp$51$$,$new_component_id$jscomp$5$$,$meta69770$$){this.$library_id$=$library_id$jscomp$36$$;this.$component_id$=$component_id$jscomp$51$$;
this.$new_component_id$=$new_component_id$jscomp$5$$;this.$meta69770$=$meta69770$$;this.$cljs$lang$protocol_mask$partition0$$=393216;this.$cljs$lang$protocol_mask$partition1$$=0},$app$main$data$workspace$libraries$duplicate_component_69769$$.prototype.$potok$v2$core$Event$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_component_69769$$.prototype.$potok$v2$core$Event$_type$arity$1$=function(){return $APP.$cljs$cst$3993$app_DOT_main_DOT_data_DOT_workspace_DOT_libraries_SLASH_duplicate_component$$},
$app$main$data$workspace$libraries$duplicate_component_69769$$.prototype.$cljs$core$IWithMeta$_with_meta$arity$2$=function($_69771$$,$meta69770__$1$$){return new $app$main$data$workspace$libraries$duplicate_component_69769$$(this.$library_id$,this.$component_id$,this.$new_component_id$,$meta69770__$1$$)},$app$main$data$workspace$libraries$duplicate_component_69769$$.prototype.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$meta69770$},$app$main$data$workspace$libraries$duplicate_component_69769$$.prototype.$potok$v2$core$WatchEvent$$=
$APP.$cljs$core$PROTOCOL_SENTINEL$$,$app$main$data$workspace$libraries$duplicate_component_69769$$.prototype.$potok$v2$core$WatchEvent$watch$arity$3$=function($it$jscomp$193_libraries$jscomp$72_library$jscomp$23_main_instance$jscomp$1$$,$changes$jscomp$212_state$jscomp$514_vec__69772$$){$it$jscomp$193_libraries$jscomp$72_library$jscomp$23_main_instance$jscomp$1$$=$APP.$app$main$data$helpers$lookup_libraries$$($changes$jscomp$212_state$jscomp$514_vec__69772$$);$it$jscomp$193_libraries$jscomp$72_library$jscomp$23_main_instance$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($it$jscomp$193_libraries$jscomp$72_library$jscomp$23_main_instance$jscomp$1$$,this.$library_id$);$changes$jscomp$212_state$jscomp$514_vec__69772$$=$app$common$logic$libraries$generate_duplicate_component$$($APP.$app$common$files$changes_builder$empty_changes$cljs$0core$0IFn$0_invoke$0arity$02$$(this,null),$it$jscomp$193_libraries$jscomp$72_library$jscomp$23_main_instance$jscomp$1$$,this.$component_id$,this.$new_component_id$);$it$jscomp$193_libraries$jscomp$72_library$jscomp$23_main_instance$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$212_state$jscomp$514_vec__69772$$,0,null);$changes$jscomp$212_state$jscomp$514_vec__69772$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($changes$jscomp$212_state$jscomp$514_vec__69772$$,1,null);return(0,$APP.$beicon$v2$core$of$$)($APP.$potok$v2$core$data_event$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3676$layout_SLASH_update$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1729$ids$$,new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($it$jscomp$193_libraries$jscomp$72_library$jscomp$23_main_instance$jscomp$1$$)],null)],null)),$APP.$app$main$data$changes$commit_changes$$($changes$jscomp$212_state$jscomp$514_vec__69772$$))});return new $app$main$data$workspace$libraries$duplicate_component_69769$$($library_id$jscomp$35$$,$component_id$jscomp$50$$,$new_component_id$jscomp$4$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)};
$app$main$data$workspace$libraries$duplicate_component$$.$cljs$lang$maxFixedArity$=3;
var $cljs$cst$5780$dragging$$=new $APP.$cljs$core$Keyword$$(null,"dragging","dragging",1185097613),$cljs$cst$5643$bin_char$$=new $APP.$cljs$core$Keyword$$(null,"bin-char","bin-char",-1662780697),$cljs$cst$6020$mouse_down_picker$$=new $APP.$cljs$core$Keyword$$(null,"mouse-down-picker","mouse-down-picker",-418905630),$cljs$cst$5793$set_alignment$$=new $APP.$cljs$core$Keyword$$(null,"set-alignment","set-alignment",-2128681649),$cljs$cst$6006$create_rectangle$$=new $APP.$cljs$core$Keyword$$(null,"create-rectangle",
"create-rectangle",-773298875),$cljs$cst$6005$create_artboard$$=new $APP.$cljs$core$Keyword$$(null,"create-artboard","create-artboard",-183459146),$cljs$cst$5848$localized_date_time$$=new $APP.$cljs$core$Keyword$$(null,"localized-date-time","localized-date-time",358812429),$cljs$cst$6028$webgl_unavailable$$=new $APP.$cljs$core$Keyword$$(null,"webgl-unavailable","webgl-unavailable",2080127405),$cljs$cst$5613$paren$$=new $APP.$cljs$core$Keyword$$(null,"paren","paren",-294107600),$cljs$cst$5957$width_p$$=
new $APP.$cljs$core$Keyword$$(null,"width-p","width-p",371756625),$cljs$cst$5827$focused_id_STAR_$$=new $APP.$cljs$core$Keyword$$(null,"focused-id*","focused-id*",664819594),$cljs$cst$5874$all_selected_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"all-selected?","all-selected?",998306472),$cljs$cst$5686$active_tokens$$=new $APP.$cljs$core$Keyword$$(null,"active-tokens","active-tokens",1939368755),$cljs$cst$5955$line_y2$$=new $APP.$cljs$core$Keyword$$(null,"line-y2","line-y2",1362883497),$cljs$cst$5953$line_y1$$=
new $APP.$cljs$core$Keyword$$(null,"line-y1","line-y1",-790998869),$cljs$cst$5952$line_x1$$=new $APP.$cljs$core$Keyword$$(null,"line-x1","line-x1",-1747192142),$cljs$cst$5954$line_x2$$=new $APP.$cljs$core$Keyword$$(null,"line-x2","line-x2",678649845),$cljs$cst$5739$multi_assets_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"multi-assets?","multi-assets?",-1126822393),$cljs$cst$5747$backends$$=new $APP.$cljs$core$Keyword$$(null,"backends","backends",-1041162533),$cljs$cst$6007$create_ellipse$$=new $APP.$cljs$core$Keyword$$(null,
"create-ellipse","create-ellipse",-403794363),$cljs$cst$5557$start_production$$=new $APP.$cljs$core$Keyword$$(null,"start-production","start-production",687546537),$cljs$cst$5620$reader$$=new $APP.$cljs$core$Symbol$$(null,"reader","reader",1810192380,null),$cljs$cst$5785$presets$$=new $APP.$cljs$core$Keyword$$(null,"presets","presets",-345857391),$cljs$cst$5915$zip$$=new $APP.$cljs$core$Keyword$$(null,"zip","zip",678448180),$cljs$cst$5632$DQUOTE$$=new $APP.$cljs$core$Keyword$$(null,"DQUOTE","DQUOTE",
-571169808),$cljs$cst$5749$rename_typography$$=new $APP.$cljs$core$Keyword$$(null,"rename-typography","rename-typography",-1476102726),$cljs$cst$5789$full_name$$=new $APP.$cljs$core$Keyword$$(null,"full-name","full-name",408178550),$cljs$cst$6002$cancel_edit$$=new $APP.$cljs$core$Keyword$$(null,"cancel-edit","cancel-edit",-1598330442),$cljs$cst$6022$inside$$=new $APP.$cljs$core$Keyword$$(null,"inside","inside",1972503011),$cljs$cst$5578$msg_cache$$=new $APP.$cljs$core$Keyword$$(null,"msg-cache","msg-cache",
-733775070),$cljs$cst$6025$last_resize_direction$$=new $APP.$cljs$core$Keyword$$(null,"last-resize-direction","last-resize-direction",-1738384379),$cljs$cst$5758$rect_render$$=new $APP.$cljs$core$Keyword$$(null,"rect-render","rect-render",164934616),$cljs$cst$5766$num_items$$=new $APP.$cljs$core$Keyword$$(null,"num-items","num-items",-887909266),$cljs$cst$5734$on_asset_click$$=new $APP.$cljs$core$Keyword$$(null,"on-asset-click","on-asset-click",1164784669),$cljs$cst$5567$string_ci$$=new $APP.$cljs$core$Keyword$$(null,
"string-ci","string-ci",374631805),$cljs$cst$5732$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_list_style$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.assets","list-style","app.main.data.workspace.assets/list-style",-1347397902),$cljs$cst$5833$layer$$=new $APP.$cljs$core$Keyword$$(null,"layer","layer",-1601820589),$cljs$cst$5939$empty_themes$$=new $APP.$cljs$core$Keyword$$(null,"empty-themes","empty-themes",-1383438187),$cljs$cst$5621$pending_forms$$=new $APP.$cljs$core$Symbol$$(null,
"pending-forms","pending-forms",-1225172071,null),$cljs$cst$5741$open_groups$$=new $APP.$cljs$core$Keyword$$(null,"open-groups","open-groups",1010222446),$cljs$cst$5992$on_guide_hover$$=new $APP.$cljs$core$Keyword$$(null,"on-guide-hover","on-guide-hover",1955902847),$cljs$cst$5911$left_sidebar$$=new $APP.$cljs$core$Keyword$$(null,"left-sidebar","left-sidebar",-1413634357),$cljs$cst$5685$applied_token$$=new $APP.$cljs$core$Keyword$$(null,"applied-token","applied-token",-1808287379),$cljs$cst$5798$easing_ease_in_out$$=
new $APP.$cljs$core$Keyword$$(null,"easing-ease-in-out","easing-ease-in-out",33260603),$cljs$cst$5990$drag$$=new $APP.$cljs$core$Keyword$$(null,"drag","drag",449951290),$cljs$cst$6032$selrect_original$$=new $APP.$cljs$core$Keyword$$(null,"selrect-original","selrect-original",-1319150208),$cljs$cst$5786$vert$$=new $APP.$cljs$core$Keyword$$(null,"vert","vert",-360932977),$cljs$cst$5913$coce$$=new $APP.$cljs$core$Keyword$$(null,"coce","coce",-1135173234),$cljs$cst$6001$commit_edit$$=new $APP.$cljs$core$Keyword$$(null,
"commit-edit","commit-edit",158638976),$cljs$cst$5694$on_clear_selection$$=new $APP.$cljs$core$Keyword$$(null,"on-clear-selection","on-clear-selection",-1065562127),$cljs$cst$5757$shape_link$$=new $APP.$cljs$core$Keyword$$(null,"shape-link","shape-link",-1110484325),$cljs$cst$5639$hide_tag$$=new $APP.$cljs$core$Keyword$$(null,"hide-tag","hide-tag",1347642501),$cljs$cst$5707$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_color_tab$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker",
"color-tab","app.main.ui.workspace.colorpicker/color-tab",-1957999841),$cljs$cst$5614$alt_or_ord$$=new $APP.$cljs$core$Keyword$$(null,"alt-or-ord","alt-or-ord",310249425),$cljs$cst$5579$nodes$$=new $APP.$cljs$core$Keyword$$(null,"nodes","nodes",-2099585805),$cljs$cst$5748$multiple_variants$$=new $APP.$cljs$core$Keyword$$(null,"multiple-variants","multiple-variants",-1555709443),$cljs$cst$5765$show_search$$=new $APP.$cljs$core$Keyword$$(null,"show-search","show-search",266138187),$cljs$cst$5759$shape_list$$=
new $APP.$cljs$core$Keyword$$(null,"shape-list","shape-list",-226178330),$cljs$cst$5738$force_open_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"force-open?","force-open?",514305058),$cljs$cst$5842$bassics$$=new $APP.$cljs$core$Keyword$$(null,"bassics","bassics",1660356961),$cljs$cst$5681$cljs_DOT_spec_DOT_alpha$$=new $APP.$cljs$core$Symbol$$(null,"cljs.spec.alpha","cljs.spec.alpha",505122844,null),$cljs$cst$5875$selected_pred$$=new $APP.$cljs$core$Keyword$$(null,"selected-pred","selected-pred",-1733167808),
$cljs$cst$5933$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_typography_SLASH_set_base_font_size$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.typography","set-base-font-size","app.main.data.workspace.tokens.typography/set-base-font-size",196229846),$cljs$cst$5575$next_stack$$=new $APP.$cljs$core$Keyword$$(null,"next-stack","next-stack",-481930728),$cljs$cst$5663$optimize$$=new $APP.$cljs$core$Keyword$$(null,"optimize","optimize",-1912349448),$cljs$cst$5696$path_filter$$=new $APP.$cljs$core$Keyword$$(null,
"path-filter","path-filter",352001580),$cljs$cst$5712$disable_booleans$$=new $APP.$cljs$core$Keyword$$(null,"disable-booleans","disable-booleans",1692419768),$cljs$cst$5803$option_highlighted_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"option-highlighted?","option-highlighted?",2074036831),$cljs$cst$5947$selrect_width$$=new $APP.$cljs$core$Keyword$$(null,"selrect-width","selrect-width",-24370965),$cljs$cst$5634$CR$$=new $APP.$cljs$core$Keyword$$(null,"CR","CR",-1654295403),$cljs$cst$5648$defined_as$$=
new $APP.$cljs$core$Keyword$$(null,"defined-as","defined-as",-474679152),$cljs$cst$5653$dec_val$$=new $APP.$cljs$core$Keyword$$(null,"dec-val","dec-val",-1263870894),$cljs$cst$5736$selected_full$$=new $APP.$cljs$core$Keyword$$(null,"selected-full","selected-full",-948180416),$cljs$cst$5536$paths$$=new $APP.$cljs$core$Keyword$$(null,"paths","paths",-1807389588),$cljs$cst$5626$LF$$=new $APP.$cljs$core$Keyword$$(null,"LF","LF",1177033158),$cljs$cst$5921$ready_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,
"ready?","ready?",-105765697),$cljs$cst$5807$absolute_position$$=new $APP.$cljs$core$Keyword$$(null,"absolute-position","absolute-position",397125855),$cljs$cst$5876$allowed_shape_attributes$$=new $APP.$cljs$core$Keyword$$(null,"allowed-shape-attributes","allowed-shape-attributes",-11621484),$cljs$cst$5629$SP$$=new $APP.$cljs$core$Keyword$$(null,"SP","SP",124290284),$cljs$cst$5813$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_add_frame_grid$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid",
"add-frame-grid","app.main.data.workspace.grid/add-frame-grid",-1083498650),$cljs$cst$5878$attribute_labels$$=new $APP.$cljs$core$Keyword$$(null,"attribute-labels","attribute-labels",-1728954592),$cljs$cst$5553$regexp$$=new $APP.$cljs$core$Keyword$$(null,"regexp","regexp",-541372782),$cljs$cst$5740$on_ungroup$$=new $APP.$cljs$core$Keyword$$(null,"on-ungroup","on-ungroup",-1285143350),$cljs$cst$5688$sidebar$$=new $APP.$cljs$core$Keyword$$(null,"sidebar","sidebar",35784458),$cljs$cst$5879$on_update_shape_all$$=
new $APP.$cljs$core$Keyword$$(null,"on-update-shape-all","on-update-shape-all",421199428),$cljs$cst$5828$on_key_down$$=new $APP.$cljs$core$Keyword$$(null,"on-key-down","on-key-down",-1374733765),$cljs$cst$5656$repetition$$=new $APP.$cljs$core$Keyword$$(null,"repetition","repetition",1938392115),$cljs$cst$5840$sub_sec$$=new $APP.$cljs$core$Keyword$$(null,"sub-sec","sub-sec",1680069611),$cljs$cst$5958$board_name$$=new $APP.$cljs$core$Keyword$$(null,"board-name","board-name",-677515056),$cljs$cst$5577$negative_listeners$$=
new $APP.$cljs$core$Keyword$$(null,"negative-listeners","negative-listeners",55241092),$cljs$cst$5984$l2_y2$$=new $APP.$cljs$core$Keyword$$(null,"l2-y2","l2-y2",1349041214),$cljs$cst$5985$l2_y1$$=new $APP.$cljs$core$Keyword$$(null,"l2-y1","l2-y1",503329823),$cljs$cst$5592$listeners$$=new $APP.$cljs$core$Keyword$$(null,"listeners","listeners",394544445),$cljs$cst$5801$centerh$$=new $APP.$cljs$core$Keyword$$(null,"centerh","centerh",463637087),$cljs$cst$5800$centerv$$=new $APP.$cljs$core$Keyword$$(null,
"centerv","centerv",-45511012),$cljs$cst$5918$is_open_STAR_$$=new $APP.$cljs$core$Keyword$$(null,"is-open*","is-open*",-1513780270),$cljs$cst$5862$matching_aliases$$=new $APP.$cljs$core$Keyword$$(null,"matching-aliases","matching-aliases",-889687368),$cljs$cst$5692$ordering$$=new $APP.$cljs$core$Keyword$$(null,"ordering","ordering",1096406705),$cljs$cst$5854$attribute$$=new $APP.$cljs$core$Keyword$$(null,"attribute","attribute",-2074029119),$cljs$cst$5938$themes_overview$$=new $APP.$cljs$core$Keyword$$(null,
"themes-overview","themes-overview",1335300928),$cljs$cst$5910$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_SLASH_sitemap_collapsed$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.sidebar","sitemap-collapsed","app.main.ui.workspace.sidebar/sitemap-collapsed",-1053391535),$cljs$cst$5962$on_drag_position$$=new $APP.$cljs$core$Keyword$$(null,"on-drag-position","on-drag-position",1447756755),$cljs$cst$5661$low$$=new $APP.$cljs$core$Keyword$$(null,"low","low",-1601362409),$cljs$cst$5560$expecting$$=
new $APP.$cljs$core$Keyword$$(null,"expecting","expecting",-57706705),$cljs$cst$5752$open_menu$$=new $APP.$cljs$core$Keyword$$(null,"open-menu","open-menu",1078280881),$cljs$cst$5677$standard$$=new $APP.$cljs$core$Keyword$$(null,"standard","standard",-1769206695),$cljs$cst$5619$read_string_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"read-string*","read-string*",1046768315,null),$cljs$cst$5974$l2_x2$$=new $APP.$cljs$core$Keyword$$(null,"l2-x2","l2-x2",-962595741),$cljs$cst$5982$l2_x1$$=new $APP.$cljs$core$Keyword$$(null,
"l2-x1","l2-x1",1119885113),$cljs$cst$5742$on_group$$=new $APP.$cljs$core$Keyword$$(null,"on-group","on-group",1496733713),$cljs$cst$6018$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_path$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport.hooks","path","app.main.ui.workspace.viewport.hooks/path",1642934739),$cljs$cst$5670$ebnf$$=new $APP.$cljs$core$Keyword$$(null,"ebnf","ebnf",31967825),$cljs$cst$5899$tokens_SLASH_remapping_confirmation$$=new $APP.$cljs$core$Keyword$$("tokens",
"remapping-confirmation","tokens/remapping-confirmation",-1629837152),$cljs$cst$5905$new_node_name$$=new $APP.$cljs$core$Keyword$$(null,"new-node-name","new-node-name",-842262898),$cljs$cst$5711$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_colorpicker$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker","colorpicker","app.main.ui.workspace.colorpicker/colorpicker",1197429294),$cljs$cst$5968$visible_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"visible?","visible?",2129863715),
$cljs$cst$5571$neg$$=new $APP.$cljs$core$Keyword$$(null,"neg","neg",1800032960),$cljs$cst$5683$on_token_change$$=new $APP.$cljs$core$Keyword$$(null,"on-token-change","on-token-change",-504087325),$cljs$cst$5907$tokens_SLASH_export$$=new $APP.$cljs$core$Keyword$$("tokens","export","tokens/export",-125347700),$cljs$cst$5964$handle_lost_pointer_capture$$=new $APP.$cljs$core$Keyword$$(null,"handle-lost-pointer-capture","handle-lost-pointer-capture",-895460559),$cljs$cst$5762$search_text$$=new $APP.$cljs$core$Keyword$$(null,
"search-text","search-text",1559451259),$cljs$cst$5594$results$$=new $APP.$cljs$core$Keyword$$(null,"results","results",-1134170113),$cljs$cst$5781$maybe_dragging$$=new $APP.$cljs$core$Keyword$$(null,"maybe-dragging","maybe-dragging",-1551372643),$cljs$cst$5872$applied_refs$$=new $APP.$cljs$core$Keyword$$(null,"applied-refs","applied-refs",-956375371),$cljs$cst$5826$focused_id$$=new $APP.$cljs$core$Keyword$$(null,"focused-id","focused-id",-788291297),$cljs$cst$5926$prev_token$$=new $APP.$cljs$core$Keyword$$(null,
"prev-token","prev-token",2072559436),$cljs$cst$5730$app_DOT_main_DOT_data_DOT_workspace_DOT_history_SLASH_initialize_history$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.history","initialize-history","app.main.data.workspace.history/initialize-history",-627816697),$cljs$cst$5713$disable_flatten$$=new $APP.$cljs$core$Keyword$$(null,"disable-flatten","disable-flatten",570467597),$cljs$cst$5646$char_val$$=new $APP.$cljs$core$Keyword$$(null,"char-val","char-val",1408617933),$cljs$cst$5960$on_drag_end$$=
new $APP.$cljs$core$Keyword$$(null,"on-drag-end","on-drag-end",520272671),$cljs$cst$5556$grammar$$=new $APP.$cljs$core$Keyword$$(null,"grammar","grammar",1881328267),$cljs$cst$5642$hide_tag_rule$$=new $APP.$cljs$core$Keyword$$(null,"hide-tag-rule","hide-tag-rule",150267589),$cljs$cst$5811$token_colors$$=new $APP.$cljs$core$Keyword$$(null,"token-colors","token-colors",-1209312666),$cljs$cst$5961$on_drag_delta$$=new $APP.$cljs$core$Keyword$$(null,"on-drag-delta","on-drag-delta",-81646512),$cljs$cst$5919$toggle_dropdown$$=
new $APP.$cljs$core$Keyword$$(null,"toggle-dropdown","toggle-dropdown",291806362),$cljs$cst$5880$all_attr_labels$$=new $APP.$cljs$core$Keyword$$(null,"all-attr-labels","all-attr-labels",-1560265704),$cljs$cst$5834$ignore$$=new $APP.$cljs$core$Keyword$$(null,"ignore","ignore",-1631542033),$cljs$cst$5625$LWSP$$=new $APP.$cljs$core$Keyword$$(null,"LWSP","LWSP",782998598),$cljs$cst$5866$old_name$$=new $APP.$cljs$core$Keyword$$(null,"old-name","old-name",1289683869),$cljs$cst$6029$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_wasm_SLASH_no_grid_hover_id$$=
new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport-wasm","no-grid-hover-id","app.main.ui.workspace.viewport-wasm/no-grid-hover-id",83390537),$cljs$cst$5662$high$$=new $APP.$cljs$core$Keyword$$(null,"high","high",2027297808),$cljs$cst$5640$whitespace$$=new $APP.$cljs$core$Keyword$$(null,"whitespace","whitespace",-1340035483),$cljs$cst$5881$horizontal_attr_labels$$=new $APP.$cljs$core$Keyword$$(null,"horizontal-attr-labels","horizontal-attr-labels",641068751),$cljs$cst$5659$hex_val$$=new $APP.$cljs$core$Keyword$$(null,
"hex-val","hex-val",1267737401),$cljs$cst$5562$enlive$$=new $APP.$cljs$core$Keyword$$(null,"enlive","enlive",1679023921),$cljs$cst$5928$indexed$$=new $APP.$cljs$core$Keyword$$(null,"indexed","indexed",390758624),$cljs$cst$5849$snapshots$$=new $APP.$cljs$core$Keyword$$(null,"snapshots","snapshots",941363956),$cljs$cst$5940$prev_type$$=new $APP.$cljs$core$Keyword$$(null,"prev-type","prev-type",212113111),$cljs$cst$5641$element$$=new $APP.$cljs$core$Keyword$$(null,"element","element",1974019749),$cljs$cst$5917$color_result$$=
new $APP.$cljs$core$Keyword$$(null,"color-result","color-result",-859632008),$cljs$cst$5925$token_description$$=new $APP.$cljs$core$Keyword$$(null,"token-description","token-description",-1559156482),$cljs$cst$6034$coordinates$$=new $APP.$cljs$core$Keyword$$(null,"coordinates","coordinates",-1225332668),$cljs$cst$5684$disable_image$$=new $APP.$cljs$core$Keyword$$(null,"disable-image","disable-image",-1920778139),$cljs$cst$5727$show_menu$$=new $APP.$cljs$core$Keyword$$(null,"show-menu","show-menu",
14072792),$cljs$cst$5967$current_pt$$=new $APP.$cljs$core$Keyword$$(null,"current-pt","current-pt",-693448391),$cljs$cst$5941$resize_negate_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"resize-negate?","resize-negate?",-1130986046),$cljs$cst$5604$lookahead$$=new $APP.$cljs$core$Keyword$$(null,"lookahead","lookahead",-400102393),$cljs$cst$5883$is_selected_inside_layout$$=new $APP.$cljs$core$Keyword$$(null,"is-selected-inside-layout","is-selected-inside-layout",-932422043),$cljs$cst$5980$l3_y2$$=new $APP.$cljs$core$Keyword$$(null,
"l3-y2","l3-y2",-331288200),$cljs$cst$5979$l3_y1$$=new $APP.$cljs$core$Keyword$$(null,"l3-y1","l3-y1",-159671272),$cljs$cst$5976$l3_x2$$=new $APP.$cljs$core$Keyword$$(null,"l3-x2","l3-x2",-949175405),$cljs$cst$5977$l3_x1$$=new $APP.$cljs$core$Keyword$$(null,"l3-x1","l3-x1",-228486922),$cljs$cst$6010$pen$$=new $APP.$cljs$core$Keyword$$(null,"pen","pen",2006675445),$cljs$cst$5610$hide_nt$$=new $APP.$cljs$core$Keyword$$(null,"hide-nt","hide-nt",-228813845),$cljs$cst$5784$clip_content$$=new $APP.$cljs$core$Keyword$$(null,
"clip-content","clip-content",-1393212533),$cljs$cst$5574$node_builder$$=new $APP.$cljs$core$Keyword$$(null,"node-builder","node-builder",-1956562605),$cljs$cst$5852$locked_by$$=new $APP.$cljs$core$Keyword$$(null,"locked-by","locked-by",-545502839),$cljs$cst$5679$cljs_DOT_spec_DOT_alpha_SLASH__STAR_runtime_asserts_STAR_$$=new $APP.$cljs$core$Symbol$$("cljs.spec.alpha","*runtime-asserts*","cljs.spec.alpha/*runtime-asserts*",-1060443587,null),$cljs$cst$5877$selected_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,
"selected?","selected?",-742502788),$cljs$cst$5710$color_selection$$=new $APP.$cljs$core$Keyword$$(null,"color-selection","color-selection",923516039),$cljs$cst$5858$containers_count$$=new $APP.$cljs$core$Keyword$$(null,"containers-count","containers-count",-2090453936),$cljs$cst$5726$nudge_option$$=new $APP.$cljs$core$Keyword$$(null,"nudge-option","nudge-option",-726591721),$cljs$cst$5857$referenced_token_name$$=new $APP.$cljs$core$Keyword$$(null,"referenced-token-name","referenced-token-name",462027675),
$cljs$cst$5853$own$$=new $APP.$cljs$core$Keyword$$(null,"own","own",-286380473),$cljs$cst$6000$frame_offset$$=new $APP.$cljs$core$Keyword$$(null,"frame-offset","frame-offset",-1070008651),$cljs$cst$5645$NUM$$=new $APP.$cljs$core$Keyword$$(null,"NUM","NUM",-218662260),$cljs$cst$5796$easing_ease_in$$=new $APP.$cljs$core$Keyword$$(null,"easing-ease-in","easing-ease-in",-842794625),$cljs$cst$5547$ord$$=new $APP.$cljs$core$Keyword$$(null,"ord","ord",1142548323),$cljs$cst$5937$theme_info$$=new $APP.$cljs$core$Keyword$$(null,
"theme-info","theme-info",1015163604),$cljs$cst$5558$NOT$$=new $APP.$cljs$core$Keyword$$(null,"NOT","NOT",-1689245341),$cljs$cst$5568$char$$=new $APP.$cljs$core$Keyword$$(null,"char","char",-641587586),$cljs$cst$6035$app_DOT_main_DOT_ui_DOT_workspace_SLASH_has_data$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace","has-data","app.main.ui.workspace/has-data",-1439290016),$cljs$cst$5761$operation$$=new $APP.$cljs$core$Keyword$$(null,"operation","operation",-1267664310),$cljs$cst$5812$library_colors$$=
new $APP.$cljs$core$Keyword$$(null,"library-colors","library-colors",-1244860886),$cljs$cst$5754$matrix_render$$=new $APP.$cljs$core$Keyword$$(null,"matrix-render","matrix-render",278382090),$cljs$cst$5764$filters$$=new $APP.$cljs$core$Keyword$$(null,"filters","filters",974726919),$cljs$cst$5818$show_more_options$$=new $APP.$cljs$core$Keyword$$(null,"show-more-options","show-more-options",-1066587564),$cljs$cst$5972$on_pointer_leave$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-leave","on-pointer-leave",
253985380),$cljs$cst$5944$resize_type$$=new $APP.$cljs$core$Keyword$$(null,"resize-type","resize-type",-1850768191),$cljs$cst$5660$dec_char$$=new $APP.$cljs$core$Keyword$$(null,"dec-char","dec-char",-646625154),$cljs$cst$5930$tokens_SLASH_boolean$$=new $APP.$cljs$core$Keyword$$("tokens","boolean","tokens/boolean",1104647026),$cljs$cst$5704$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_id$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker.libraries","id","app.main.ui.workspace.colorpicker.libraries/id",
-2085412349),$cljs$cst$5997$wasm_guides_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"wasm-guides?","wasm-guides?",-1550192011),$cljs$cst$5864$total_references$$=new $APP.$cljs$core$Keyword$$(null,"total-references","total-references",1857252869),$cljs$cst$5657$rulename_left$$=new $APP.$cljs$core$Keyword$$(null,"rulename-left","rulename-left",-1824251564),$cljs$cst$5873$alias_refs$$=new $APP.$cljs$core$Keyword$$(null,"alias-refs","alias-refs",665806110),$cljs$cst$5804$preview_complete_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,
"preview-complete?","preview-complete?",-1244024070),$cljs$cst$5650$hex_char$$=new $APP.$cljs$core$Keyword$$(null,"hex-char","hex-char",764443568),$cljs$cst$5787$variants_help_modal$$=new $APP.$cljs$core$Keyword$$(null,"variants-help-modal","variants-help-modal",1413487149),$cljs$cst$5595$full_results$$=new $APP.$cljs$core$Keyword$$(null,"full-results","full-results",-1500225407),$cljs$cst$5609$rule$$=new $APP.$cljs$core$Keyword$$(null,"rule","rule",729973257),$cljs$cst$5809$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_menus_DOT_shadow_SLASH_index$$=
new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.sidebar.options.menus.shadow","index","app.main.ui.workspace.sidebar.options.menus.shadow/index",-1426814770),$cljs$cst$5934$change_view$$=new $APP.$cljs$core$Keyword$$(null,"change-view","change-view",-1206699831),$cljs$cst$5606$Epsilon$$=new $APP.$cljs$core$Keyword$$(null,"Epsilon","Epsilon",133418452),$cljs$cst$5735$on_rename_group$$=new $APP.$cljs$core$Keyword$$(null,"on-rename-group","on-rename-group",-1516017186),$cljs$cst$5900$remap_data$$=
new $APP.$cljs$core$Keyword$$(null,"remap-data","remap-data",-916716403),$cljs$cst$5615$factor$$=new $APP.$cljs$core$Keyword$$(null,"factor","factor",-2103172748),$cljs$cst$5988$rect_width$$=new $APP.$cljs$core$Keyword$$(null,"rect-width","rect-width",1414450590),$cljs$cst$5705$delete_stop$$=new $APP.$cljs$core$Keyword$$(null,"delete-stop","delete-stop",-1177718181),$cljs$cst$6021$outside$$=new $APP.$cljs$core$Keyword$$(null,"outside","outside",-13164995),$cljs$cst$5737$on_assets_delete$$=new $APP.$cljs$core$Keyword$$(null,
"on-assets-delete","on-assets-delete",-1367349600),$cljs$cst$5808$color_row$$=new $APP.$cljs$core$Keyword$$(null,"color-row","color-row",804190296),$cljs$cst$6012$create_shape$$=new $APP.$cljs$core$Keyword$$(null,"create-shape","create-shape",-897512870),$cljs$cst$5989$rect_height$$=new $APP.$cljs$core$Keyword$$(null,"rect-height","rect-height",1948275951),$cljs$cst$5791$render$$=new $APP.$cljs$core$Keyword$$(null,"render","render",-1408033454),$cljs$cst$5861$total_alias_refs$$=new $APP.$cljs$core$Keyword$$(null,
"total-alias-refs","total-alias-refs",369704626),$cljs$cst$5605$negative_lookahead$$=new $APP.$cljs$core$Keyword$$(null,"negative-lookahead","negative-lookahead",874382387),$cljs$cst$5956$display_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"display?","display?",-1189123617),$cljs$cst$5769$is_open$$=new $APP.$cljs$core$Keyword$$(null,"is-open","is-open",1660707069),$cljs$cst$6026$remove_snap$$=new $APP.$cljs$core$Keyword$$(null,"remove-snap","remove-snap",-526912307),$cljs$cst$5991$wasm_guides$$=new $APP.$cljs$core$Keyword$$(null,
"wasm-guides","wasm-guides",-1394369539),$cljs$cst$5647$num_val$$=new $APP.$cljs$core$Keyword$$(null,"num-val","num-val",1497434478),$cljs$cst$5533$rgb$$=new $APP.$cljs$core$Keyword$$(null,"rgb","rgb",1432123467),$cljs$cst$5566$rep$$=new $APP.$cljs$core$Keyword$$(null,"rep","rep",-1226820564),$cljs$cst$5699$shortcut$$=new $APP.$cljs$core$Keyword$$(null,"shortcut","shortcut",-431647697),$cljs$cst$5635$OCTET$$=new $APP.$cljs$core$Keyword$$(null,"OCTET","OCTET",-743420682),$cljs$cst$6009$zoom_out$$=
new $APP.$cljs$core$Keyword$$(null,"zoom-out","zoom-out",681508467),$cljs$cst$5716$is_empty$$=new $APP.$cljs$core$Keyword$$(null,"is-empty","is-empty",-1040302908),$cljs$cst$5837$control$$=new $APP.$cljs$core$Keyword$$(null,"control","control",1892578036),$cljs$cst$5838$translation$$=new $APP.$cljs$core$Keyword$$(null,"translation","translation",-701621547),$cljs$cst$5936$edit_theme$$=new $APP.$cljs$core$Keyword$$(null,"edit-theme","edit-theme",1508129664),$cljs$cst$5724$v2_info_shown$$=new $APP.$cljs$core$Keyword$$(null,
"v2-info-shown","v2-info-shown",1459219808),$cljs$cst$5698$for_design_tab_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"for-design-tab?","for-design-tab?",-900372392),$cljs$cst$5674$input_format$$=new $APP.$cljs$core$Keyword$$(null,"input-format","input-format",-422703481),$cljs$cst$5636$ALPHA$$=new $APP.$cljs$core$Keyword$$(null,"ALPHA","ALPHA",-1463859144),$cljs$cst$6027$remove_node$$=new $APP.$cljs$core$Keyword$$(null,"remove-node","remove-node",-1450759511),$cljs$cst$5695$delete_events$$=new $APP.$cljs$core$Keyword$$(null,
"delete-events","delete-events",-1125716977),$cljs$cst$5637$CHAR$$=new $APP.$cljs$core$Keyword$$(null,"CHAR","CHAR",-1280338086),$cljs$cst$5717$library_file_ids$$=new $APP.$cljs$core$Keyword$$(null,"library-file-ids","library-file-ids",65064728),$cljs$cst$5824$searchable$$=new $APP.$cljs$core$Keyword$$(null,"searchable","searchable",1089311247),$cljs$cst$5725$v2_info$$=new $APP.$cljs$core$Keyword$$(null,"v2-info","v2-info",1679610198),$cljs$cst$5760$modify$$=new $APP.$cljs$core$Keyword$$(null,"modify",
"modify",-1261040869),$cljs$cst$5971$on_pointer_enter$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-enter","on-pointer-enter",199832041),$cljs$cst$5563$epsilon$$=new $APP.$cljs$core$Keyword$$(null,"epsilon","epsilon",-730158570),$cljs$cst$5887$submenu_offset$$=new $APP.$cljs$core$Keyword$$(null,"submenu-offset","submenu-offset",1888650638),$cljs$cst$5675$allow_namespaced_nts$$=new $APP.$cljs$core$Keyword$$(null,"allow-namespaced-nts","allow-namespaced-nts",-507534966),$cljs$cst$5924$token_value$$=
new $APP.$cljs$core$Keyword$$(null,"token-value","token-value",1433419008),$cljs$cst$5817$show_advanced_options$$=new $APP.$cljs$core$Keyword$$(null,"show-advanced-options","show-advanced-options",-561220032),$cljs$cst$5576$generation$$=new $APP.$cljs$core$Keyword$$(null,"generation","generation",-2132542044),$cljs$cst$5923$error_SLASH_unknown_error$$=new $APP.$cljs$core$Keyword$$("error","unknown-error","error/unknown-error",843694167),$cljs$cst$5731$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_ordering$$=
new $APP.$cljs$core$Keyword$$("app.main.data.workspace.assets","ordering","app.main.data.workspace.assets/ordering",-515349399),$cljs$cst$5832$measure$$=new $APP.$cljs$core$Keyword$$(null,"measure","measure",-1857519826),$cljs$cst$5841$sec$$=new $APP.$cljs$core$Keyword$$(null,"sec","sec",-1580376553),$cljs$cst$5859$total_applied_refs$$=new $APP.$cljs$core$Keyword$$(null,"total-applied-refs","total-applied-refs",1091146793),$cljs$cst$5559$char_range$$=new $APP.$cljs$core$Keyword$$(null,"char-range",
"char-range",1443391389),$cljs$cst$5973$on_pointer_up$$=new $APP.$cljs$core$Keyword$$(null,"on-pointer-up","on-pointer-up",385194E3),$cljs$cst$5564$plus$$=new $APP.$cljs$core$Keyword$$(null,"plus","plus",211540661),$cljs$cst$5855$token_alias$$=new $APP.$cljs$core$Keyword$$(null,"token-alias","token-alias",2012298055),$cljs$cst$5860$matching_applied$$=new $APP.$cljs$core$Keyword$$(null,"matching-applied","matching-applied",-1367639331),$cljs$cst$5882$vertical_attr_labels$$=new $APP.$cljs$core$Keyword$$(null,
"vertical-attr-labels","vertical-attr-labels",1255704246),$cljs$cst$5709$checked$$=new $APP.$cljs$core$Keyword$$(null,"checked","checked",-50955819),$cljs$cst$5909$tokens_SLASH_settings$$=new $APP.$cljs$core$Keyword$$("tokens","settings","tokens/settings",150998605),$cljs$cst$5733$thumbs$$=new $APP.$cljs$core$Keyword$$(null,"thumbs","thumbs",-1134286339),$cljs$cst$5535$expand_token_sets$$=new $APP.$cljs$core$Keyword$$(null,"expand-token-sets","expand-token-sets",1253386),$cljs$cst$5948$selrect_height$$=
new $APP.$cljs$core$Keyword$$(null,"selrect-height","selrect-height",1129317331),$cljs$cst$5867$new_name$$=new $APP.$cljs$core$Keyword$$(null,"new-name","new-name",1288355058),$cljs$cst$5779$idle$$=new $APP.$cljs$core$Keyword$$(null,"idle","idle",-2007156861),$cljs$cst$5884$submenu$$=new $APP.$cljs$core$Keyword$$(null,"submenu","submenu",2142563344),$cljs$cst$5831$layout_item$$=new $APP.$cljs$core$Keyword$$(null,"layout-item","layout-item",-1207087322),$cljs$cst$6004$hand$$=new $APP.$cljs$core$Keyword$$(null,
"hand","hand",791601933),$cljs$cst$5561$hiccup$$=new $APP.$cljs$core$Keyword$$(null,"hiccup","hiccup",1218876238),$cljs$cst$5843$empty_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"empty?","empty?",-1564122972),$cljs$cst$5608$rule_separator$$=new $APP.$cljs$core$Keyword$$(null,"rule-separator","rule-separator",1539322213),$cljs$cst$5638$BIT$$=new $APP.$cljs$core$Keyword$$(null,"BIT","BIT",-1854474115),$cljs$cst$5799$is_column$$=new $APP.$cljs$core$Keyword$$(null,"is-column","is-column",1610131457),
$cljs$cst$5810$all_colors$$=new $APP.$cljs$core$Keyword$$(null,"all-colors","all-colors",541687080),$cljs$cst$5906$tokens_SLASH_themes$$=new $APP.$cljs$core$Keyword$$("tokens","themes","tokens/themes",31381800),$cljs$cst$5593$full_listeners$$=new $APP.$cljs$core$Keyword$$(null,"full-listeners","full-listeners",50621827),$cljs$cst$5792$is_col_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"is-col?","is-col?",-405323997),$cljs$cst$5903$tokens_SLASH_rename_node$$=new $APP.$cljs$core$Keyword$$("tokens",
"rename-node","tokens/rename-node",1328536617),$cljs$cst$5628$DIGIT$$=new $APP.$cljs$core$Keyword$$(null,"DIGIT","DIGIT",341251338),$cljs$cst$6023$resize_side$$=new $APP.$cljs$core$Keyword$$(null,"resize-side","resize-side",-532712885),$cljs$cst$5963$handle_pointer_down$$=new $APP.$cljs$core$Keyword$$(null,"handle-pointer-down","handle-pointer-down",761659029),$cljs$cst$5795$easing_ease$$=new $APP.$cljs$core$Keyword$$(null,"easing-ease","easing-ease",-1909581280),$cljs$cst$5902$on_rename$$=new $APP.$cljs$core$Keyword$$(null,
"on-rename","on-rename",2102721909),$cljs$cst$5868$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_remapping_SLASH_bulk_remap_tokens$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.remapping","bulk-remap-tokens","app.main.data.workspace.tokens.remapping/bulk-remap-tokens",-1620752236),$cljs$cst$5680$dynamic$$=new $APP.$cljs$core$Keyword$$(null,"dynamic","dynamic",704819571),$cljs$cst$5805$static$$=new $APP.$cljs$core$Keyword$$(null,"static","static",1214358571),$cljs$cst$5790$listing_thumbs_QMARK_$$=
new $APP.$cljs$core$Keyword$$(null,"listing-thumbs?","listing-thumbs?",1714462360),$cljs$cst$5856$source_token_id$$=new $APP.$cljs$core$Keyword$$(null,"source-token-id","source-token-id",-86861571),$cljs$cst$5943$initial_value$$=new $APP.$cljs$core$Keyword$$(null,"initial-value","initial-value",470619381),$cljs$cst$6016$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_workspace$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport.hooks","workspace","app.main.ui.workspace.viewport.hooks/workspace",
1534742616),$cljs$cst$5715$tokens_SLASH_import_from_library$$=new $APP.$cljs$core$Keyword$$("tokens","import-from-library","tokens/import-from-library",2060878099),$cljs$cst$5750$detail_open_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"detail-open?","detail-open?",-1192975497),$cljs$cst$5714$deletable_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"deletable?","deletable?",2134719819),$cljs$cst$5631$CTL$$=new $APP.$cljs$core$Keyword$$(null,"CTL","CTL",-9995632),$cljs$cst$5664$memory$$=new $APP.$cljs$core$Keyword$$(null,
"memory","memory",-1449401430),$cljs$cst$5802$selected_blend_mode$$=new $APP.$cljs$core$Keyword$$(null,"selected-blend-mode","selected-blend-mode",67585278),$cljs$cst$5794$easing_linear$$=new $APP.$cljs$core$Keyword$$(null,"easing-linear","easing-linear",-1638484978),$cljs$cst$5537$token_type$$=new $APP.$cljs$core$Keyword$$(null,"token-type","token-type",-835337612),$cljs$cst$5821$focusable_ids$$=new $APP.$cljs$core$Keyword$$(null,"focusable-ids","focusable-ids",806934951),$cljs$cst$5788$from_pos$$=
new $APP.$cljs$core$Keyword$$(null,"from-pos","from-pos",1141953080),$cljs$cst$5603$end_of_string$$=new $APP.$cljs$core$Keyword$$(null,"end-of-string","end-of-string",1567354241),$cljs$cst$5768$current_match_idx$$=new $APP.$cljs$core$Keyword$$(null,"current-match-idx","current-match-idx",-711161636),$cljs$cst$5986$rect_x$$=new $APP.$cljs$core$Keyword$$(null,"rect-x","rect-x",2027933546),$cljs$cst$5987$rect_y$$=new $APP.$cljs$core$Keyword$$(null,"rect-y","rect-y",-234175138),$cljs$cst$5922$recalculate$$=
new $APP.$cljs$core$Keyword$$(null,"recalculate","recalculate",633935398),$cljs$cst$5565$star$$=new $APP.$cljs$core$Keyword$$(null,"star","star",279424429),$cljs$cst$5863$token_aliases$$=new $APP.$cljs$core$Keyword$$(null,"token-aliases","token-aliases",-1660509197),$cljs$cst$6019$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_text$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport.hooks","text","app.main.ui.workspace.viewport.hooks/text",409069194),$cljs$cst$5690$hsl_saturation$$=
new $APP.$cljs$core$Keyword$$(null,"hsl-saturation","hsl-saturation",-612594896),$cljs$cst$5719$connected_to$$=new $APP.$cljs$core$Keyword$$(null,"connected-to","connected-to",-1930163150),$cljs$cst$5746$input_class$$=new $APP.$cljs$core$Keyword$$(null,"input-class","input-class",-62053138),$cljs$cst$5755$cells_render$$=new $APP.$cljs$core$Keyword$$(null,"cells-render","cells-render",-828771788),$cljs$cst$5959$on_drag_start$$=new $APP.$cljs$core$Keyword$$(null,"on-drag-start","on-drag-start",-47712205),
$cljs$cst$5570$look$$=new $APP.$cljs$core$Keyword$$(null,"look","look",-539441433),$cljs$cst$5996$on_guide_change$$=new $APP.$cljs$core$Keyword$$(null,"on-guide-change","on-guide-change",-355971373),$cljs$cst$5904$tokens_in_active_set$$=new $APP.$cljs$core$Keyword$$(null,"tokens-in-active-set","tokens-in-active-set",569743731),$cljs$cst$5966$start_pt$$=new $APP.$cljs$core$Keyword$$(null,"start-pt","start-pt",1358226507),$cljs$cst$5728$app_DOT_main_DOT_ui_DOT_workspace_DOT_color_palette_ctx_menu_SLASH_id$$=
new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.color-palette-ctx-menu","id","app.main.ui.workspace.color-palette-ctx-menu/id",-1642411096),$cljs$cst$5931$tokens_SLASH_other$$=new $APP.$cljs$core$Keyword$$("tokens","other","tokens/other",-552061926),$cljs$cst$5767$replace_text$$=new $APP.$cljs$core$Keyword$$(null,"replace-text","replace-text",-137527916),$cljs$cst$5573$fail_index$$=new $APP.$cljs$core$Keyword$$(null,"fail-index","fail-index",248726923),$cljs$cst$5836$esc$$=new $APP.$cljs$core$Keyword$$(null,
"esc","esc",-1671924121),$cljs$cst$5945$gap_type$$=new $APP.$cljs$core$Keyword$$(null,"gap-type","gap-type",-691516251),$cljs$cst$6017$app_DOT_main_DOT_ui_DOT_workspace_DOT_viewport_DOT_hooks_SLASH_grid$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.viewport.hooks","grid","app.main.ui.workspace.viewport.hooks/grid",-1939984239),$cljs$cst$5951$text_y$$=new $APP.$cljs$core$Keyword$$(null,"text-y","text-y",-1680264360),$cljs$cst$5950$text_x$$=new $APP.$cljs$core$Keyword$$(null,"text-x","text-x",
-1791964043),$cljs$cst$5616$rules_or_parser$$=new $APP.$cljs$core$Keyword$$(null,"rules-or-parser","rules-or-parser",-314380386),$cljs$cst$5814$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_remove_frame_grid$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid","remove-frame-grid","app.main.data.workspace.grid/remove-frame-grid",-1269415708),$cljs$cst$6031$app_DOT_main_DOT_store$$=new $APP.$cljs$core$Symbol$$(null,"app.main.store","app.main.store",-1614373036,null),$cljs$cst$5999$on_up$$=
new $APP.$cljs$core$Keyword$$(null,"on-up","on-up",-127496699),$cljs$cst$6015$update$$=new $APP.$cljs$core$Keyword$$(null,"update","update",1045576396),$cljs$cst$5965$handle_pointer_move$$=new $APP.$cljs$core$Keyword$$(null,"handle-pointer-move","handle-pointer-move",1990039805),$cljs$cst$5981$l1_y2$$=new $APP.$cljs$core$Keyword$$(null,"l1-y2","l1-y2",1399825048),$cljs$cst$5978$l1_y1$$=new $APP.$cljs$core$Keyword$$(null,"l1-y1","l1-y1",-946090345),$cljs$cst$6011$pencil$$=new $APP.$cljs$core$Keyword$$(null,
"pencil","pencil",-217778832),$cljs$cst$5975$l1_x2$$=new $APP.$cljs$core$Keyword$$(null,"l1-x2","l1-x2",-1981212693),$cljs$cst$5983$l1_x1$$=new $APP.$cljs$core$Keyword$$(null,"l1-x1","l1-x1",867974042),$cljs$cst$5916$folder$$=new $APP.$cljs$core$Keyword$$(null,"folder","folder",1515881736),$cljs$cst$5835$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_shapes_DOT_multiple_SLASH_not_found$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.sidebar.options.shapes.multiple","not-found",
"app.main.ui.workspace.sidebar.options.shapes.multiple/not-found",-1070649517),$cljs$cst$5729$collapse_left_sidebar$$=new $APP.$cljs$core$Keyword$$(null,"collapse-left-sidebar","collapse-left-sidebar",-1883177143),$cljs$cst$5946$align_center$$=new $APP.$cljs$core$Keyword$$(null,"align-center","align-center",-99300755),$cljs$cst$5743$multi_colors_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"multi-colors?","multi-colors?",-2136724074),$cljs$cst$5914$unknown_tokens$$=new $APP.$cljs$core$Keyword$$(null,
"unknown-tokens","unknown-tokens",-366587692),$cljs$cst$6013$pointer_inner$$=new $APP.$cljs$core$Keyword$$(null,"pointer-inner","pointer-inner",1173575841),$cljs$cst$5549$hi$$=new $APP.$cljs$core$Keyword$$(null,"hi","hi",-1821422114),$cljs$cst$5655$alternation$$=new $APP.$cljs$core$Keyword$$(null,"alternation","alternation",-1162147630),$cljs$cst$5942$resize_axis$$=new $APP.$cljs$core$Keyword$$(null,"resize-axis","resize-axis",-1746101927),$cljs$cst$5550$parser1$$=new $APP.$cljs$core$Keyword$$(null,
"parser1","parser1",-439601422),$cljs$cst$5551$parser2$$=new $APP.$cljs$core$Keyword$$(null,"parser2","parser2",1013754688),$cljs$cst$5644$rulename_right$$=new $APP.$cljs$core$Keyword$$(null,"rulename-right","rulename-right",1125609193),$cljs$cst$5617$cljs_DOT_tools_DOT_reader_SLASH_read_string_STAR_$$=new $APP.$cljs$core$Symbol$$("cljs.tools.reader","read-string*","cljs.tools.reader/read-string*",1492661621,null),$cljs$cst$5697$name_group_dialog$$=new $APP.$cljs$core$Keyword$$(null,"name-group-dialog",
"name-group-dialog",1853050356),$cljs$cst$5994$get_hover_frame$$=new $APP.$cljs$core$Keyword$$(null,"get-hover-frame","get-hover-frame",-2054826737),$cljs$cst$5920$get_selected_id$$=new $APP.$cljs$core$Keyword$$(null,"get-selected-id","get-selected-id",1885455750),$cljs$cst$5658$rulelist$$=new $APP.$cljs$core$Keyword$$(null,"rulelist","rulelist",-1871218473),$cljs$cst$5552$parsers$$=new $APP.$cljs$core$Keyword$$(null,"parsers","parsers",-804353827),$cljs$cst$5569$nt$$=new $APP.$cljs$core$Keyword$$(null,
"nt","nt",-835425781),$cljs$cst$5548$lo$$=new $APP.$cljs$core$Keyword$$(null,"lo","lo",-931799889),$cljs$cst$5687$color_origin$$=new $APP.$cljs$core$Keyword$$(null,"color-origin","color-origin",-216238828),$cljs$cst$5830$constraint$$=new $APP.$cljs$core$Keyword$$(null,"constraint","constraint",1725147424),$cljs$cst$5601$instaparse_DOT_gll_SLASH_end_index$$=new $APP.$cljs$core$Keyword$$("instaparse.gll","end-index","instaparse.gll/end-index",-1851404441),$cljs$cst$5865$app_DOT_main_DOT_data_DOT_workspace_DOT_tokens_DOT_remapping_SLASH_remap_tokens$$=
new $APP.$cljs$core$Keyword$$("app.main.data.workspace.tokens.remapping","remap-tokens","app.main.data.workspace.tokens.remapping/remap-tokens",-1766049516),$cljs$cst$5703$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_DOT_libraries_SLASH_view_mode$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker.libraries","view-mode","app.main.ui.workspace.colorpicker.libraries/view-mode",-1722731842),$cljs$cst$5886$no_selectable$$=new $APP.$cljs$core$Keyword$$(null,"no-selectable","no-selectable",
-504485148),$cljs$cst$5815$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_set_frame_grid$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid","set-frame-grid","app.main.data.workspace.grid/set-frame-grid",577735205),$cljs$cst$5689$hover_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"hover?","hover?",-1201331489),$cljs$cst$5829$more_options$$=new $APP.$cljs$core$Keyword$$(null,"more-options","more-options",1399478268),$cljs$cst$5993$on_guide_drag$$=new $APP.$cljs$core$Keyword$$(null,"on-guide-drag",
"on-guide-drag",1824403053),$cljs$cst$5850$snapshot$$=new $APP.$cljs$core$Keyword$$(null,"snapshot","snapshot",-1274785710),$cljs$cst$5624$HTAB$$=new $APP.$cljs$core$Keyword$$(null,"HTAB","HTAB",11392612),$cljs$cst$5580$trace_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"trace?","trace?",1730690679),$cljs$cst$5839$sc$$=new $APP.$cljs$core$Keyword$$(null,"sc","sc",1148023032),$cljs$cst$5908$tokens_SLASH_import$$=new $APP.$cljs$core$Keyword$$("tokens","import","tokens/import",-1680554363),$cljs$cst$6033$selrect_duplicated$$=
new $APP.$cljs$core$Keyword$$(null,"selrect-duplicated","selrect-duplicated",-729086709),$cljs$cst$5622$output_format$$=new $APP.$cljs$core$Keyword$$(null,"output-format","output-format",-1826382676),$cljs$cst$5671$unhide$$=new $APP.$cljs$core$Keyword$$(null,"unhide","unhide",-413983695),$cljs$cst$5554$reduction_type$$=new $APP.$cljs$core$Keyword$$(null,"reduction-type","reduction-type",-488293450),$cljs$cst$5627$VCHAR$$=new $APP.$cljs$core$Keyword$$(null,"VCHAR","VCHAR",1962437706),$cljs$cst$5701$asset_name$$=
new $APP.$cljs$core$Keyword$$(null,"asset-name","asset-name",-1412454368),$cljs$cst$5763$search_scope$$=new $APP.$cljs$core$Keyword$$(null,"search-scope","search-scope",-202937614),$cljs$cst$5753$debug_panel$$=new $APP.$cljs$core$Keyword$$(null,"debug-panel","debug-panel",-1624930518),$cljs$cst$5633$WSP$$=new $APP.$cljs$core$Keyword$$(null,"WSP","WSP",-1046948716),$cljs$cst$5935$create_theme$$=new $APP.$cljs$core$Keyword$$(null,"create-theme","create-theme",279233432),$cljs$cst$5825$search_input_ref$$=
new $APP.$cljs$core$Keyword$$(null,"search-input-ref","search-input-ref",290307476),$cljs$cst$5927$composite$$=new $APP.$cljs$core$Keyword$$(null,"composite","composite",-257118970),$cljs$cst$5600$instaparse_DOT_gll_SLASH_start_index$$=new $APP.$cljs$core$Keyword$$("instaparse.gll","start-index","instaparse.gll/start-index",404653620),$cljs$cst$5998$on_move$$=new $APP.$cljs$core$Keyword$$(null,"on-move","on-move",-1779179710),$cljs$cst$5995$disabled_guides_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,
"disabled-guides?","disabled-guides?",1230225296),$cljs$cst$5816$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_SLASH_set_default_grid$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid","set-default-grid","app.main.data.workspace.grid/set-default-grid",1437308643),$cljs$cst$5651$rulename$$=new $APP.$cljs$core$Keyword$$(null,"rulename","rulename",948914160),$cljs$cst$5932$tokens_SLASH_string$$=new $APP.$cljs$core$Keyword$$("tokens","string","tokens/string",-576029544),$cljs$cst$5783$show_in_viewer$$=
new $APP.$cljs$core$Keyword$$(null,"show-in-viewer","show-in-viewer",1111782209),$cljs$cst$5756$points_render$$=new $APP.$cljs$core$Keyword$$(null,"points-render","points-render",-2103762292),$cljs$cst$5851$iso_date$$=new $APP.$cljs$core$Keyword$$(null,"iso-date","iso-date",-1889998156),$cljs$cst$5782$expand_border_radius$$=new $APP.$cljs$core$Keyword$$(null,"expand-border-radius","expand-border-radius",-352780098),$cljs$cst$5888$popup$$=new $APP.$cljs$core$Keyword$$(null,"popup","popup",635890211),
$cljs$cst$5623$CRLF$$=new $APP.$cljs$core$Keyword$$(null,"CRLF","CRLF",11418756),$cljs$cst$5654$concatenation$$=new $APP.$cljs$core$Keyword$$(null,"concatenation","concatenation",-951369614),$cljs$cst$6008$zoom_in$$=new $APP.$cljs$core$Keyword$$(null,"zoom-in","zoom-in",1242180949),$cljs$cst$5652$bin_val$$=new $APP.$cljs$core$Keyword$$(null,"bin-val","bin-val",1705209105),$cljs$cst$5676$auto_whitespace$$=new $APP.$cljs$core$Keyword$$(null,"auto-whitespace","auto-whitespace",741152317),$cljs$cst$5744$on_delete_group$$=
new $APP.$cljs$core$Keyword$$(null,"on-delete-group","on-delete-group",1508715928),$cljs$cst$6003$app_DOT_main_DOT_data_DOT_workspace_DOT_grid_layout_DOT_shortcuts_SLASH_esc_pressed$$=new $APP.$cljs$core$Keyword$$("app.main.data.workspace.grid-layout.shortcuts","esc-pressed","app.main.data.workspace.grid-layout.shortcuts/esc-pressed",-1690439930),$cljs$cst$5607$opt_whitespace$$=new $APP.$cljs$core$Keyword$$(null,"opt-whitespace","opt-whitespace",1115207927),$cljs$cst$6024$resize_point$$=new $APP.$cljs$core$Keyword$$(null,
"resize-point","resize-point",-1472965451),$cljs$cst$5822$nodes_ref$$=new $APP.$cljs$core$Keyword$$(null,"nodes-ref","nodes-ref",-1499462517),$cljs$cst$5630$HEXDIG$$=new $APP.$cljs$core$Keyword$$(null,"HEXDIG","HEXDIG",-200221072),$cljs$cst$5649$option$$=new $APP.$cljs$core$Keyword$$(null,"option","option",65132272),$cljs$cst$5949$migrate$$=new $APP.$cljs$core$Keyword$$(null,"migrate","migrate",-207110743),$cljs$cst$5531$hsl_l$$=new $APP.$cljs$core$Keyword$$(null,"hsl-l","hsl-l",-1679291119),$cljs$cst$5702$recent$$=
new $APP.$cljs$core$Keyword$$(null,"recent","recent",449517715),$cljs$cst$5532$hsl_s$$=new $APP.$cljs$core$Keyword$$(null,"hsl-s","hsl-s",113070461),$cljs$cst$5530$hsb$$=new $APP.$cljs$core$Keyword$$(null,"hsb","hsb",-753472031),$cljs$cst$5700$last_path$$=new $APP.$cljs$core$Keyword$$(null,"last-path","last-path",-143957020),$cljs$cst$5534$hsl$$=new $APP.$cljs$core$Keyword$$(null,"hsl","hsl",-1282948596),$cljs$cst$5823$on_enter$$=new $APP.$cljs$core$Keyword$$(null,"on-enter","on-enter",-928988216),
$cljs$cst$5885$on_delete_token$$=new $APP.$cljs$core$Keyword$$(null,"on-delete-token","on-delete-token",-1548486919),$cljs$cst$5618$cljs_DOT_tools_DOT_reader$$=new $APP.$cljs$core$Symbol$$(null,"cljs.tools.reader","cljs.tools.reader",-831293977,null),$cljs$cst$5969$dragging_id$$=new $APP.$cljs$core$Keyword$$(null,"dragging-id","dragging-id",-1523936464),$cljs$cst$6014$clip_children_QMARK_$$=new $APP.$cljs$core$Keyword$$(null,"clip-children?","clip-children?",-1668191047),$cljs$cst$5708$app_DOT_main_DOT_ui_DOT_workspace_DOT_colorpicker_SLASH_hsb_mode$$=
new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.colorpicker","hsb-mode","app.main.ui.workspace.colorpicker/hsb-mode",-859331609),$cljs$cst$5706$direct_color$$=new $APP.$cljs$core$Keyword$$(null,"direct-color","direct-color",1226799117),$cljs$cst$5745$renaming$$=new $APP.$cljs$core$Keyword$$(null,"renaming","renaming",619763182),$cljs$cst$5912$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_SLASH_history_sidebar$$=new $APP.$cljs$core$Keyword$$("app.main.ui.workspace.sidebar","history-sidebar","app.main.ui.workspace.sidebar/history-sidebar",
214720554),$cljs$cst$5797$easing_ease_out$$=new $APP.$cljs$core$Keyword$$(null,"easing-ease-out","easing-ease-out",-82935390),$cljs$cst$5970$new_position$$=new $APP.$cljs$core$Keyword$$(null,"new-position","new-position",-102281521),$cljs$cst$6030$app_DOT_main_DOT_store_SLASH_state$$=new $APP.$cljs$core$Symbol$$("app.main.store","state","app.main.store/state",-1030608881,null),$cljs$cst$5611$inside_comment$$=new $APP.$cljs$core$Keyword$$(null,"inside-comment","inside-comment",1258069708),$cljs$cst$5892$selected_inside_layout_QMARK_$$=
new $APP.$cljs$core$Keyword$$(null,"selected-inside-layout?","selected-inside-layout?",-1748414769),$cljs$cst$5806$static_position$$=new $APP.$cljs$core$Keyword$$(null,"static-position","static-position",-2066619638),$cljs$cst$5682$_STAR_runtime_asserts_STAR_$$=new $APP.$cljs$core$Symbol$$(null,"*runtime-asserts*","*runtime-asserts*",1632801956,null),$cljs$cst$5693$title_button$$=new $APP.$cljs$core$Keyword$$(null,"title-button","title-button",-634326965),$cljs$cst$5718$connected_to_names$$=new $APP.$cljs$core$Keyword$$(null,
"connected-to-names","connected-to-names",-2033861740),$cljs$cst$5602$instaparse_SLASH_failure$$=new $APP.$cljs$core$Keyword$$("instaparse","failure","instaparse/failure",1422918607),$cljs$cst$5901$on_remap$$=new $APP.$cljs$core$Keyword$$(null,"on-remap","on-remap",143137190);$APP.$JSCompiler_prototypeAlias$$=$instaparse$auto_flatten_seq$AutoFlattenSeq$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($self$jscomp$85$$,$key$jscomp$405$$){return this.v.$cljs$core$ILookup$_lookup$arity$2$(null,$key$jscomp$405$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($self$jscomp$86$$,$key$jscomp$406$$,$not_found$jscomp$84$$){return this.v.$cljs$core$ILookup$_lookup$arity$3$(null,$key$jscomp$406$$,$not_found$jscomp$84$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return $APP.$cljs$core$meta$$(this.v)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$INext$_next$arity$1$=function(){return $APP.$cljs$core$next$$($APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return this.$hashcode$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($self$jscomp$91$$,$other$jscomp$201$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$hashcode$,$APP.$cljs$core$hash$$($other$jscomp$201$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$cnt$,$APP.$cljs$core$count$$($other$jscomp$201$$))&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$cnt$,0)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$(this),
$other$jscomp$201$$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$with_meta$$($instaparse$auto_flatten_seq$EMPTY$$,$APP.$cljs$core$meta$$(this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_first$arity$1$=function(){return $APP.$cljs$core$first$$($APP.$cljs$core$seq$$(this))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeq$_rest$arity$1$=function(){return $APP.$cljs$core$rest$$($APP.$cljs$core$seq$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){if(!$APP.$cljs$core$truth_$$(this.$cached_seq$)){if(this.$dirty$){var $JSCompiler_temp$jscomp$1714_v$jscomp$inline_8694$$=this.v;$JSCompiler_temp$jscomp$1714_v$jscomp$inline_8694$$=$APP.$cljs$core$count$$($JSCompiler_temp$jscomp$1714_v$jscomp$inline_8694$$)>0?$instaparse$auto_flatten_seq$flat_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp$jscomp$1714_v$jscomp$inline_8694$$,$instaparse$auto_flatten_seq$delve$$($JSCompiler_temp$jscomp$1714_v$jscomp$inline_8694$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[0],null))):null}else $JSCompiler_temp$jscomp$1714_v$jscomp$inline_8694$$=$APP.$cljs$core$seq$$(this.v);this.$cached_seq$=$JSCompiler_temp$jscomp$1714_v$jscomp$inline_8694$$}return this.$cached_seq$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($self$jscomp$96$$,$metamap$$){return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($APP.$cljs$core$with_meta$$(this.v,$metamap$$),this.$premix_hashcode$,this.$hashcode$,this.$cnt$,this.$dirty$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($self$jscomp$97$$,$o$jscomp$272$$){return $APP.$cljs$core$cons$$($o$jscomp$272$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$instaparse$auto_flatten_seq$ConjFlat$conj_flat$arity$2$=function($phc_self$jscomp$98$$,$obj$jscomp$213$$){if($obj$jscomp$213$$==null)return this;if($APP.$cljs$core$truth_$$($instaparse$auto_flatten_seq$afs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$auto_flatten_seq$afs_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$213$$):$instaparse$auto_flatten_seq$afs_QMARK_$$($obj$jscomp$213$$))){if(this.$cnt$===0)return $obj$jscomp$213$$;if($APP.$cljs$core$count$$($obj$jscomp$213$$)<=
32){$phc_self$jscomp$98$$=$instaparse$auto_flatten_seq$hash_cat$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$auto_flatten_seq$hash_cat$$.$cljs$core$IFn$_invoke$arity$2$(this,$obj$jscomp$213$$):$instaparse$auto_flatten_seq$hash_cat$$(this,$obj$jscomp$213$$);var $new_cnt$$=this.$cnt$+$APP.$cljs$core$count$$($obj$jscomp$213$$),$JSCompiler_temp_const$jscomp$1717$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(this.v,$obj$jscomp$213$$),$or__5025__auto__$jscomp$inline_8696$$=this.$dirty$;return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($JSCompiler_temp_const$jscomp$1717$$,
$phc_self$jscomp$98$$,$APP.$cljs$core$mix_collection_hash$$($phc_self$jscomp$98$$,$new_cnt$$),$new_cnt$$,$or__5025__auto__$jscomp$inline_8696$$?$or__5025__auto__$jscomp$inline_8696$$:$obj$jscomp$213$$.$dirty$)}$phc_self$jscomp$98$$=$instaparse$auto_flatten_seq$hash_cat$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$auto_flatten_seq$hash_cat$$.$cljs$core$IFn$_invoke$arity$2$(this,$obj$jscomp$213$$):$instaparse$auto_flatten_seq$hash_cat$$(this,$obj$jscomp$213$$);$new_cnt$$=this.$cnt$+$APP.$cljs$core$count$$($obj$jscomp$213$$);
return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(this.v,$obj$jscomp$213$$),$phc_self$jscomp$98$$,$APP.$cljs$core$mix_collection_hash$$($phc_self$jscomp$98$$,$new_cnt$$),$new_cnt$$,!0)}$phc_self$jscomp$98$$=(0,$APP.$cljs$core$imul$$)(31,this.$premix_hashcode$)+$APP.$cljs$core$hash$$($obj$jscomp$213$$);$new_cnt$$=this.$cnt$+1;return new $instaparse$auto_flatten_seq$AutoFlattenSeq$$($APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$(this.v,
$obj$jscomp$213$$),$phc_self$jscomp$98$$,$APP.$cljs$core$mix_collection_hash$$($phc_self$jscomp$98$$,$new_cnt$$),$new_cnt$$,this.$dirty$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($afs$$,$writer$jscomp$170$$,$opts$jscomp$308$$){return $APP.$cljs$core$_pr_writer$$($APP.$cljs$core$seq$$(this),$writer$jscomp$170$$,$opts$jscomp$308$$)};
var $instaparse$auto_flatten_seq$EMPTY$$=$instaparse$auto_flatten_seq$auto_flatten_seq$$($APP.$cljs$core$PersistentVector$EMPTY$$),$instaparse$auto_flatten_seq$flat_vec_helper$$=function $instaparse$auto_flatten_seq$flat_vec_helper$$($G__76228_G__76230_acc$jscomp$155$$,$G__76229_G__76231_v$jscomp$647$$){for(;;)if($APP.$cljs$core$seq$$($G__76229_G__76231_v$jscomp$647$$)){var $fst$jscomp$2$$=$APP.$cljs$core$first$$($G__76229_G__76231_v$jscomp$647$$);$instaparse$auto_flatten_seq$afs_QMARK_$$($fst$jscomp$2$$)?
($G__76228_G__76230_acc$jscomp$155$$=$instaparse$auto_flatten_seq$flat_vec_helper$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$auto_flatten_seq$flat_vec_helper$$.$cljs$core$IFn$_invoke$arity$2$($G__76228_G__76230_acc$jscomp$155$$,$fst$jscomp$2$$):$instaparse$auto_flatten_seq$flat_vec_helper$$($G__76228_G__76230_acc$jscomp$155$$,$fst$jscomp$2$$),$G__76229_G__76231_v$jscomp$647$$=$APP.$cljs$core$next$$($G__76229_G__76231_v$jscomp$647$$)):($G__76228_G__76230_acc$jscomp$155$$=$APP.$cljs$core$conj_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__76228_G__76230_acc$jscomp$155$$,
$fst$jscomp$2$$),$G__76229_G__76231_v$jscomp$647$$=$APP.$cljs$core$next$$($G__76229_G__76231_v$jscomp$647$$))}else return $G__76228_G__76230_acc$jscomp$155$$};$APP.$JSCompiler_prototypeAlias$$=$instaparse$auto_flatten_seq$FlattenOnDemandVector$$.prototype;$APP.$JSCompiler_prototypeAlias$$.toString=function(){return $APP.$cljs$core$pr_str_STAR_$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($self$jscomp$103$$,$key$jscomp$407$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$ILookup$_lookup$arity$2$(null,$key$jscomp$407$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($self$jscomp$104$$,$key$jscomp$408$$,$not_found$jscomp$85$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$ILookup$_lookup$arity$3$(null,$key$jscomp$408$$,$not_found$jscomp$85$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($self$jscomp$106$$,$f$jscomp$857$$,$init$jscomp$60$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IKVReduce$_kv_reduce$arity$3$(null,$f$jscomp$857$$,$init$jscomp$60$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$2$=function($self$jscomp$107$$,$i$jscomp$516$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IIndexed$_nth$arity$2$(null,$i$jscomp$516$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIndexed$_nth$arity$3$=function($self$jscomp$108$$,$i$jscomp$517$$,$not_found$jscomp$86$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IIndexed$_nth$arity$3$(null,$i$jscomp$517$$,$not_found$jscomp$86$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IVector$_assoc_n$arity$3$=function($self$jscomp$109$$,$i$jscomp$518$$,$val$jscomp$205$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IVector$_assoc_n$arity$3$(null,$i$jscomp$518$$,$val$jscomp$205$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$(this.flat))?$APP.$cljs$core$meta$$($APP.$cljs$core$_deref$$(this.flat)):$APP.$cljs$core$meta$$($APP.$cljs$core$_deref$$(this.v))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return this.$cnt$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_peek$arity$1$=function(){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IStack$_peek$arity$1$(null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IStack$_pop$arity$1$=function(){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IStack$_pop$arity$1$(null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IReversible$_rseq$arity$1$=function(){if(this.$cnt$>0){var $JSCompiler_temp$jscomp$10920_rev$jscomp$inline_13667$$=$JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this);$JSCompiler_temp$jscomp$10920_rev$jscomp$inline_13667$$=$APP.$cljs$core$_rseq$$($JSCompiler_temp$jscomp$10920_rev$jscomp$inline_13667$$)}else $JSCompiler_temp$jscomp$10920_rev$jscomp$inline_13667$$=null;return $JSCompiler_temp$jscomp$10920_rev$jscomp$inline_13667$$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){return this.$hashcode$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($self$jscomp$116$$,$other$jscomp$202$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$hashcode$,$APP.$cljs$core$hash$$($other$jscomp$202$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$cnt$,$APP.$cljs$core$count$$($other$jscomp$202$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$other$jscomp$202$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEmptyableCollection$_empty$arity$1$=function(){return $APP.$cljs$core$with_meta$$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$meta$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($self$jscomp$118$$,$i$jscomp$519$$,$val$jscomp$206$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$i$jscomp$519$$,$val$jscomp$206$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($self$jscomp$119$$,$k$jscomp$675$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$(null,$k$jscomp$675$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($self$jscomp$121$$,$metamap$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$(this.flat))?new $instaparse$auto_flatten_seq$FlattenOnDemandVector$$($APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$(this.v)),this.$hashcode$,this.$cnt$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$with_meta$$($APP.$cljs$core$_deref$$(this.flat),$metamap$jscomp$1$$))):
new $instaparse$auto_flatten_seq$FlattenOnDemandVector$$($APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$with_meta$$($APP.$cljs$core$_deref$$(this.v),$metamap$jscomp$1$$)),this.$hashcode$,this.$cnt$,$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$_deref$$(this.flat)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($self$jscomp$122$$,$obj$jscomp$214$$){return $APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$obj$jscomp$214$$)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14279__auto__$jscomp$31$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 2:return this.$cljs$core$IFn$_invoke$arity$2$(arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$7400$$,$args76110$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args76110$$)))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($arg$jscomp$33$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IFn$_invoke$arity$2$(null,$arg$jscomp$33$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$2$=function($arg$jscomp$34$$,$not_found$jscomp$87$$){return $JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this).$cljs$core$IFn$_invoke$arity$3$(null,$arg$jscomp$34$$,$not_found$jscomp$87$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IComparable$_compare$arity$2$=function($self$jscomp$125$$,$that$$){return $APP.$cljs$core$_compare$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$that$$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($v$jscomp$651$$,$writer$jscomp$171$$,$opts$jscomp$309$$){return $APP.$cljs$core$_pr_writer$$($JSCompiler_StaticMethods_instaparse$auto_flatten_seq$GetVec$get_vec$arity$1$$(this),$writer$jscomp$171$$,$opts$jscomp$309$$)};var $instaparse$print$paren_for_compound$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$print$paren_for_tags$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$594$cat$$,null,$cljs$cst$5547$ord$$,null,$APP.$cljs$cst$717$alt$$,null],null),null));var $instaparse$reduction$raw_non_terminal_reduction$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null),$instaparse$reduction$reduction_types$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5561$hiccup$$,function($key$jscomp$409$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$key$jscomp$409$$],null)},$cljs$cst$5562$enlive$$,function($key$jscomp$410$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5562$enlive$$,$APP.$cljs$cst$302$key$$,$key$jscomp$410$$],null)}],null),$instaparse$reduction$node_builders$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5562$enlive$$,function($tag$jscomp$90$$,$item$jscomp$123$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$tag$jscomp$90$$,$APP.$cljs$cst$1642$content$$,new $APP.$cljs$core$List$$(null,$item$jscomp$123$$,null,1,null)],null)},$cljs$cst$5561$hiccup$$,function($tag$jscomp$91$$,
$item$jscomp$124$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$tag$jscomp$91$$,$item$jscomp$124$$],null)}],null);var $instaparse$combinators_source$Epsilon$$=new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5563$epsilon$$],null),$instaparse$combinators_source$alt$$=function $instaparse$combinators_source$alt$$($var_args$jscomp$1431$$){for(var $args__5755__auto__$jscomp$247$$=[],$len__5749__auto___76320$$=arguments.length,$i__5750__auto___76321$$=0;;)if($i__5750__auto___76321$$<$len__5749__auto___76320$$)$args__5755__auto__$jscomp$247$$.push(arguments[$i__5750__auto___76321$$]),
$i__5750__auto___76321$$+=1;else break;return $instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$247$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$247$$.slice(0),0,null):null)};
$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$=function($parsers$jscomp$7$$){return $APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_EQ_$$,$instaparse$combinators_source$Epsilon$$),$parsers$jscomp$7$$)?$instaparse$combinators_source$Epsilon$$:$instaparse$reduction$singleton_QMARK_$$($parsers$jscomp$7$$)?$APP.$cljs$core$first$$($parsers$jscomp$7$$):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,$parsers$jscomp$7$$],null)};$instaparse$combinators_source$alt$$.$cljs$lang$maxFixedArity$=0;$instaparse$combinators_source$alt$$.$cljs$lang$applyTo$=function($seq76263$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq76263$$))};
var $instaparse$combinators_source$ord$$=function $instaparse$combinators_source$ord$$($var_args$jscomp$1432$$){switch(arguments.length){case 0:return $instaparse$combinators_source$ord$$.$cljs$core$IFn$_invoke$arity$0$();default:for(var $args_arr__5774__auto__$jscomp$106$$=[],$len__5749__auto___76324$$=arguments.length,$i__5750__auto___76325$$=0;;)if($i__5750__auto___76325$$<$len__5749__auto___76324$$)$args_arr__5774__auto__$jscomp$106$$.push(arguments[$i__5750__auto___76325$$]),$i__5750__auto___76325$$+=
1;else break;return $instaparse$combinators_source$ord$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],1<$args_arr__5774__auto__$jscomp$106$$.length?new $APP.$cljs$core$IndexedSeq$$($args_arr__5774__auto__$jscomp$106$$.slice(1),0,null):null)}};$instaparse$combinators_source$ord$$.$cljs$core$IFn$_invoke$arity$0$=function(){return $instaparse$combinators_source$Epsilon$$};
$instaparse$combinators_source$ord$$.$cljs$core$IFn$_invoke$arity$variadic$=function($JSCompiler_temp$jscomp$1728_parser1$jscomp$2$$,$parser2$jscomp$inline_8731_parsers$jscomp$8_parsers__$1$$){$parser2$jscomp$inline_8731_parsers$jscomp$8_parsers__$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1728_parser1$jscomp$2$$,$instaparse$combinators_source$Epsilon$$)?$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$instaparse$combinators_source$Epsilon$$]),
$parser2$jscomp$inline_8731_parsers$jscomp$8_parsers__$1$$):$parser2$jscomp$inline_8731_parsers$jscomp$8_parsers__$1$$;$APP.$cljs$core$seq$$($parser2$jscomp$inline_8731_parsers$jscomp$8_parsers__$1$$)&&($parser2$jscomp$inline_8731_parsers$jscomp$8_parsers__$1$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$ord$$,$parser2$jscomp$inline_8731_parsers$jscomp$8_parsers__$1$$),$JSCompiler_temp$jscomp$1728_parser1$jscomp$2$$=new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5547$ord$$,$cljs$cst$5550$parser1$$,$JSCompiler_temp$jscomp$1728_parser1$jscomp$2$$,$cljs$cst$5551$parser2$$,$parser2$jscomp$inline_8731_parsers$jscomp$8_parsers__$1$$],null));return $JSCompiler_temp$jscomp$1728_parser1$jscomp$2$$};
$instaparse$combinators_source$ord$$.$cljs$lang$applyTo$=function($seq76265_seq76265__$1$$){var $G__76266$$=$APP.$cljs$core$first$$($seq76265_seq76265__$1$$);$seq76265_seq76265__$1$$=$APP.$cljs$core$next$$($seq76265_seq76265__$1$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__76266$$,$seq76265_seq76265__$1$$)};$instaparse$combinators_source$ord$$.$cljs$lang$maxFixedArity$=1;
var $instaparse$combinators_source$cat$$=function $instaparse$combinators_source$cat$$($var_args$jscomp$1433$$){for(var $args__5755__auto__$jscomp$248$$=[],$len__5749__auto___76327$$=arguments.length,$i__5750__auto___76328$$=0;;)if($i__5750__auto___76328$$<$len__5749__auto___76327$$)$args__5755__auto__$jscomp$248$$.push(arguments[$i__5750__auto___76328$$]),$i__5750__auto___76328$$+=1;else break;return $instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$248$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$248$$.slice(0),0,null):null)};
$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$=function($parsers$jscomp$9_parsers__$1$jscomp$1$$){if($APP.$cljs$core$every_QMARK_$$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$_EQ_$$,$instaparse$combinators_source$Epsilon$$),$parsers$jscomp$9_parsers__$1$jscomp$1$$))return $instaparse$combinators_source$Epsilon$$;$parsers$jscomp$9_parsers__$1$jscomp$1$$=$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$instaparse$combinators_source$Epsilon$$]),
$parsers$jscomp$9_parsers__$1$jscomp$1$$);return $instaparse$reduction$singleton_QMARK_$$($parsers$jscomp$9_parsers__$1$jscomp$1$$)?$APP.$cljs$core$first$$($parsers$jscomp$9_parsers__$1$jscomp$1$$):new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,$parsers$jscomp$9_parsers__$1$jscomp$1$$],null)};$instaparse$combinators_source$cat$$.$cljs$lang$maxFixedArity$=0;$instaparse$combinators_source$cat$$.$cljs$lang$applyTo$=function($seq76268$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq76268$$))};
var $instaparse$combinators_source$unhide_content$$=function $instaparse$combinators_source$unhide_content$$($parser$jscomp$31$$){var $parser__$1$$=$APP.$cljs$core$truth_$$($APP.$cljs$cst$2356$hide$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$31$$))?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$31$$,$APP.$cljs$cst$2356$hide$$):$parser$jscomp$31$$;return $APP.$cljs$core$truth_$$($APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser__$1$$,
$APP.$cljs$cst$646$parser$$,function(){var $G__76271$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$);return $instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$($G__76271$$):$instaparse$combinators_source$unhide_content$$($G__76271$$)}()):$APP.$cljs$core$truth_$$($cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser__$1$$,
$cljs$cst$5552$parsers$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$unhide_content$$,$cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$),$cljs$cst$5547$ord$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($parser__$1$$,$cljs$cst$5550$parser1$$,function(){var $G__76272$$=$cljs$cst$5550$parser1$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$);
return $instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$($G__76272$$):$instaparse$combinators_source$unhide_content$$($G__76272$$)}(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5551$parser2$$,function(){var $G__76273$$=$cljs$cst$5551$parser2$$.$cljs$core$IFn$_invoke$arity$1$($parser__$1$$);return $instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$?
$instaparse$combinators_source$unhide_content$$.$cljs$core$IFn$_invoke$arity$1$($G__76273$$):$instaparse$combinators_source$unhide_content$$($G__76273$$)}()])):$parser__$1$$},$instaparse$combinators_source$auto_whitespace_parser$$=function $instaparse$combinators_source$auto_whitespace_parser$$($parser$jscomp$32$$,$ws_parser$$){var $G__76305_G__76305__$1$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$);$G__76305_G__76305__$1$$=$G__76305_G__76305__$1$$ instanceof $APP.$cljs$core$Keyword$$?
$G__76305_G__76305__$1$$.$fqn$:null;switch($G__76305_G__76305__$1$$){case "nt":case "epsilon":return $parser$jscomp$32$$;case "opt":case "plus":case "star":case "rep":case "look":case "neg":return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($parser$jscomp$32$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$646$parser$$],null),$instaparse$combinators_source$auto_whitespace_parser$$,$ws_parser$$);case "alt":case "cat":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parser$jscomp$32$$,
$cljs$cst$5552$parsers$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__76304_SHARP_$$){return $instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$($p1__76304_SHARP_$$,$ws_parser$$):$instaparse$combinators_source$auto_whitespace_parser$$($p1__76304_SHARP_$$,$ws_parser$$)},$cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$)));case "ord":return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($parser$jscomp$32$$,
$cljs$cst$5550$parser1$$,function(){var $G__76306$$=$cljs$cst$5550$parser1$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$);return $instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$($G__76306$$,$ws_parser$$):$instaparse$combinators_source$auto_whitespace_parser$$($G__76306$$,$ws_parser$$)}(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5551$parser2$$,
function(){var $G__76308$$=$cljs$cst$5551$parser2$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$);return $instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$combinators_source$auto_whitespace_parser$$.$cljs$core$IFn$_invoke$arity$2$($G__76308$$,$ws_parser$$):$instaparse$combinators_source$auto_whitespace_parser$$($G__76308$$,$ws_parser$$)}()]));case "string":case "string-ci":case "regexp":return $APP.$cljs$core$truth_$$($APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$))?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ws_parser$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($parser$jscomp$32$$,$APP.$cljs$cst$5555$red$$)])),$APP.$cljs$cst$5555$red$$,$APP.$cljs$cst$5555$red$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$32$$)):$instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$ws_parser$$,
$parser$jscomp$32$$]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__76305_G__76305__$1$$)].join(""));}};/*

 Copyright The Closure Library Authors.
 SPDX-License-Identifier: Apache-2.0
*/
$APP.$JSCompiler_prototypeAlias$$=$instaparse$gll$Failure$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$35$$,$k__5324__auto__$jscomp$35$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$35$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$35$$,$k77135$$,$else__5326__auto__$jscomp$35$$){switch($k77135$$ instanceof $APP.$cljs$core$Keyword$$?$k77135$$.$fqn$:null){case "index":return this.index;case "reason":return this.reason;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k77135$$,$else__5326__auto__$jscomp$35$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$35$$,$f__5344__auto__$jscomp$35$$,$init__5345__auto__$jscomp$35$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$35$$,$p__77148_v__5348__auto__$jscomp$35$$){var $k__5347__auto__$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77148_v__5348__auto__$jscomp$35$$,0,null);$p__77148_v__5348__auto__$jscomp$35$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77148_v__5348__auto__$jscomp$35$$,
1,null);return $f__5344__auto__$jscomp$35$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$35$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$35$$,$k__5347__auto__$jscomp$35$$,$p__77148_v__5348__auto__$jscomp$35$$):$f__5344__auto__$jscomp$35$$($ret__5346__auto__$jscomp$35$$,$k__5347__auto__$jscomp$35$$,$p__77148_v__5348__auto__$jscomp$35$$)},$init__5345__auto__$jscomp$35$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$35$$,$writer__5339__auto__$jscomp$35$$,$opts__5340__auto__$jscomp$35$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$35$$,function($keyval__5342__auto__$jscomp$35$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$35$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$35$$,$keyval__5342__auto__$jscomp$35$$)},"#instaparse.gll.Failure{",
", ","}",$opts__5340__auto__$jscomp$35$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1801$index$$,this.index],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$984$reason$$,this.reason],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,2,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1801$index$$,$APP.$cljs$cst$984$reason$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $instaparse$gll$Failure$$(this.index,this.reason,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 2+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$65_h__5134__auto____$1$jscomp$65$$=this.$__hash$;return $h__5134__auto__$jscomp$65_h__5134__auto____$1$jscomp$65$$!=null?$h__5134__auto__$jscomp$65_h__5134__auto____$1$jscomp$65$$:this.$__hash$=$h__5134__auto__$jscomp$65_h__5134__auto____$1$jscomp$65$$=-1140991288^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this77136$$,$other77137$$){return $other77137$$!=null&&this.constructor===$other77137$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.index,$other77137$$.index)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.reason,$other77137$$.reason)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other77137$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$35$$,$k__5334__auto__$jscomp$35$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1801$index$$,null,$APP.$cljs$cst$984$reason$$,null],null),null),$k__5334__auto__$jscomp$35$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$35$$):new $instaparse$gll$Failure$$(this.index,this.reason,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$35$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$35$$,$k77135$jscomp$1$$){switch($k77135$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k77135$jscomp$1$$.$fqn$:null){case "index":case "reason":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k77135$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$35$$,$k__5332__auto__$jscomp$35$$,$G__77134$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1801$index$$,$k__5332__auto__$jscomp$35$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1801$index$$,$k__5332__auto__$jscomp$35$$))?
new $instaparse$gll$Failure$$($G__77134$jscomp$1$$,this.reason,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$984$reason$$,$k__5332__auto__$jscomp$35$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$984$reason$$,$k__5332__auto__$jscomp$35$$))?new $instaparse$gll$Failure$$(this.index,$G__77134$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $instaparse$gll$Failure$$(this.index,this.reason,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$35$$,$G__77134$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1801$index$$,this.index,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$984$reason$$,this.reason,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$35$$,$G__77134$jscomp$2$$){return new $instaparse$gll$Failure$$(this.index,this.reason,$G__77134$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$35$$,$entry__5329__auto__$jscomp$35$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$35$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$35$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$35$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$35$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($fail$jscomp$2$$,$writer$jscomp$172$$){var $fail__$1$$=this;return $APP.$cljs$core$_write$$($writer$jscomp$172$$,function(){var $sb__5670__auto__$jscomp$9$$=new $APP.$goog$string$StringBuffer$$,$_STAR_print_newline_STAR__orig_val__77160_77282$$=$APP.$cljs$core$_STAR_print_newline_STAR_$$,$_STAR_print_fn_STAR__orig_val__77161_77283$$=$APP.$cljs$core$_STAR_print_fn_STAR_$$;$APP.$cljs$core$_STAR_print_newline_STAR_$$=
!0;$APP.$cljs$core$_STAR_print_fn_STAR_$$=function($x__5671__auto__$jscomp$10$$){return $sb__5670__auto__$jscomp$9$$.append($x__5671__auto__$jscomp$10$$)};try{$instaparse$failure$pprint_failure$$($fail__$1$$)}finally{$APP.$cljs$core$_STAR_print_fn_STAR_$$=$_STAR_print_fn_STAR__orig_val__77161_77283$$,$APP.$cljs$core$_STAR_print_newline_STAR_$$=$_STAR_print_newline_STAR__orig_val__77160_77282$$}return $APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sb__5670__auto__$jscomp$9$$)}())};
var $instaparse$gll$failure_type$$=$APP.$cljs$core$type$$(new $instaparse$gll$Failure$$(null,null,null,null,null));$APP.$JSCompiler_prototypeAlias$$=$instaparse$gll$Tramp$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$36$$,$k__5324__auto__$jscomp$36$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$36$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$36$$,$k77165$$,$else__5326__auto__$jscomp$36$$){switch($k77165$$ instanceof $APP.$cljs$core$Keyword$$?$k77165$$.$fqn$:null){case "grammar":return this.$grammar$;case "text":return this.text;case "segment":return this.segment;case "fail-index":return this.$fail_index$;case "node-builder":return this.$node_builder$;case "stack":return this.stack;case "next-stack":return this.$next_stack$;case "generation":return this.$generation$;
case "negative-listeners":return this.$negative_listeners$;case "msg-cache":return this.$msg_cache$;case "nodes":return this.$nodes$;case "success":return this.$success$;case "failure":return this.$failure$;case "trace?":return this.$trace_QMARK_$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k77165$$,$else__5326__auto__$jscomp$36$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$36$$,$f__5344__auto__$jscomp$36$$,$init__5345__auto__$jscomp$36$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$36$$,$p__77170_v__5348__auto__$jscomp$36$$){var $k__5347__auto__$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77170_v__5348__auto__$jscomp$36$$,0,null);$p__77170_v__5348__auto__$jscomp$36$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77170_v__5348__auto__$jscomp$36$$,
1,null);return $f__5344__auto__$jscomp$36$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$36$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$36$$,$k__5347__auto__$jscomp$36$$,$p__77170_v__5348__auto__$jscomp$36$$):$f__5344__auto__$jscomp$36$$($ret__5346__auto__$jscomp$36$$,$k__5347__auto__$jscomp$36$$,$p__77170_v__5348__auto__$jscomp$36$$)},$init__5345__auto__$jscomp$36$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$36$$,$writer__5339__auto__$jscomp$36$$,$opts__5340__auto__$jscomp$36$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$36$$,function($keyval__5342__auto__$jscomp$36$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$36$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$36$$,$keyval__5342__auto__$jscomp$36$$)},"#instaparse.gll.Tramp{",
", ","}",$opts__5340__auto__$jscomp$36$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5556$grammar$$,this.$grammar$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1593$text$$,this.text],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1867$segment$$,this.segment],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5573$fail_index$$,this.$fail_index$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5574$node_builder$$,this.$node_builder$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$3735$stack$$,
this.stack],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5575$next_stack$$,this.$next_stack$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5576$generation$$,this.$generation$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5577$negative_listeners$$,this.$negative_listeners$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5578$msg_cache$$,this.$msg_cache$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5579$nodes$$,this.$nodes$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2355$success$$,this.$success$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$847$failure$$,
this.$failure$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5580$trace_QMARK_$$,this.$trace_QMARK_$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,14,new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5556$grammar$$,$APP.$cljs$cst$1593$text$$,$APP.$cljs$cst$1867$segment$$,$cljs$cst$5573$fail_index$$,$cljs$cst$5574$node_builder$$,$APP.$cljs$cst$3735$stack$$,$cljs$cst$5575$next_stack$$,$cljs$cst$5576$generation$$,$cljs$cst$5577$negative_listeners$$,$cljs$cst$5578$msg_cache$$,
$cljs$cst$5579$nodes$$,$APP.$cljs$cst$2355$success$$,$APP.$cljs$cst$847$failure$$,$cljs$cst$5580$trace_QMARK_$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 14+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$66_h__5134__auto____$1$jscomp$66$$=this.$__hash$;return $h__5134__auto__$jscomp$66_h__5134__auto____$1$jscomp$66$$!=null?$h__5134__auto__$jscomp$66_h__5134__auto____$1$jscomp$66$$:this.$__hash$=$h__5134__auto__$jscomp$66_h__5134__auto____$1$jscomp$66$$=166878148^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this77166$$,$other77167$$){return $other77167$$!=null&&this.constructor===$other77167$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$grammar$,$other77167$$.$grammar$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.text,$other77167$$.text)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.segment,$other77167$$.segment)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$fail_index$,
$other77167$$.$fail_index$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$node_builder$,$other77167$$.$node_builder$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.stack,$other77167$$.stack)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$next_stack$,$other77167$$.$next_stack$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$generation$,$other77167$$.$generation$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$negative_listeners$,
$other77167$$.$negative_listeners$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$msg_cache$,$other77167$$.$msg_cache$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$nodes$,$other77167$$.$nodes$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$success$,$other77167$$.$success$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$failure$,$other77167$$.$failure$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$trace_QMARK_$,$other77167$$.$trace_QMARK_$)&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other77167$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$36$$,$k__5334__auto__$jscomp$36$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,14,[$cljs$cst$5578$msg_cache$$,null,$cljs$cst$5577$negative_listeners$$,null,$cljs$cst$5576$generation$$,null,$APP.$cljs$cst$847$failure$$,null,$cljs$cst$5573$fail_index$$,null,$cljs$cst$5556$grammar$$,null,$APP.$cljs$cst$2355$success$$,
null,$cljs$cst$5579$nodes$$,null,$cljs$cst$5574$node_builder$$,null,$APP.$cljs$cst$1867$segment$$,null,$APP.$cljs$cst$3735$stack$$,null,$cljs$cst$5580$trace_QMARK_$$,null,$cljs$cst$5575$next_stack$$,null,$APP.$cljs$cst$1593$text$$,null],null),null),$k__5334__auto__$jscomp$36$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),this.$__meta$),$k__5334__auto__$jscomp$36$$):
new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$36$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$36$$,$k77165$jscomp$1$$){switch($k77165$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k77165$jscomp$1$$.$fqn$:null){case "grammar":case "text":case "segment":case "fail-index":case "node-builder":case "stack":case "next-stack":case "generation":case "negative-listeners":case "msg-cache":case "nodes":case "success":case "failure":case "trace?":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,
$k77165$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$36$$,$k__5332__auto__$jscomp$36$$,$G__77164$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5556$grammar$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5556$grammar$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$($G__77164$jscomp$1$$,
this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1593$text$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1593$text$$,
$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,$G__77164$jscomp$1$$,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1867$segment$$,
$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$1867$segment$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,$G__77164$jscomp$1$$,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5573$fail_index$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5573$fail_index$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,$G__77164$jscomp$1$$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,
this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5574$node_builder$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5574$node_builder$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,$G__77164$jscomp$1$$,this.stack,this.$next_stack$,this.$generation$,
this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$3735$stack$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$3735$stack$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,
this.text,this.segment,this.$fail_index$,this.$node_builder$,$G__77164$jscomp$1$$,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5575$next_stack$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5575$next_stack$$,
$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,$G__77164$jscomp$1$$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5576$generation$$,
$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5576$generation$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,$G__77164$jscomp$1$$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5577$negative_listeners$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5577$negative_listeners$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,$G__77164$jscomp$1$$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,
this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5578$msg_cache$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5578$msg_cache$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,
this.$generation$,this.$negative_listeners$,$G__77164$jscomp$1$$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5579$nodes$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5579$nodes$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,
this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,$G__77164$jscomp$1$$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2355$success$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$2355$success$$,
$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,$G__77164$jscomp$1$$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$847$failure$$,
$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($APP.$cljs$cst$847$failure$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,$G__77164$jscomp$1$$,this.$trace_QMARK_$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?
$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5580$trace_QMARK_$$,$k__5332__auto__$jscomp$36$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5580$trace_QMARK_$$,$k__5332__auto__$jscomp$36$$))?new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,$G__77164$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$36$$,$G__77164$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$5556$grammar$$,this.$grammar$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1593$text$$,this.text,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$1867$segment$$,this.segment,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5573$fail_index$$,
this.$fail_index$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5574$node_builder$$,this.$node_builder$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$3735$stack$$,this.stack,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5575$next_stack$$,this.$next_stack$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5576$generation$$,this.$generation$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5577$negative_listeners$$,this.$negative_listeners$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5578$msg_cache$$,
this.$msg_cache$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5579$nodes$$,this.$nodes$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$2355$success$$,this.$success$,null),new $APP.$cljs$core$MapEntry$$($APP.$cljs$cst$847$failure$$,this.$failure$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5580$trace_QMARK_$$,this.$trace_QMARK_$,null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$36$$,$G__77164$jscomp$2$$){return new $instaparse$gll$Tramp$$(this.$grammar$,this.text,this.segment,this.$fail_index$,this.$node_builder$,this.stack,this.$next_stack$,this.$generation$,this.$negative_listeners$,this.$msg_cache$,this.$nodes$,this.$success$,this.$failure$,this.$trace_QMARK_$,$G__77164$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$36$$,$entry__5329__auto__$jscomp$36$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$36$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$36$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$36$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$36$$)};
$APP.$JSCompiler_prototypeAlias$$=$instaparse$gll$Node$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$37$$,$k__5324__auto__$jscomp$37$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$37$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$37$$,$k77182$$,$else__5326__auto__$jscomp$37$$){switch($k77182$$ instanceof $APP.$cljs$core$Keyword$$?$k77182$$.$fqn$:null){case "listeners":return this.$listeners$;case "full-listeners":return this.$full_listeners$;case "results":return this.results;case "full-results":return this.$full_results$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k77182$$,$else__5326__auto__$jscomp$37$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$37$$,$f__5344__auto__$jscomp$37$$,$init__5345__auto__$jscomp$37$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$37$$,$p__77187_v__5348__auto__$jscomp$37$$){var $k__5347__auto__$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77187_v__5348__auto__$jscomp$37$$,0,null);$p__77187_v__5348__auto__$jscomp$37$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77187_v__5348__auto__$jscomp$37$$,
1,null);return $f__5344__auto__$jscomp$37$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$37$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$37$$,$k__5347__auto__$jscomp$37$$,$p__77187_v__5348__auto__$jscomp$37$$):$f__5344__auto__$jscomp$37$$($ret__5346__auto__$jscomp$37$$,$k__5347__auto__$jscomp$37$$,$p__77187_v__5348__auto__$jscomp$37$$)},$init__5345__auto__$jscomp$37$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$37$$,$writer__5339__auto__$jscomp$37$$,$opts__5340__auto__$jscomp$37$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$37$$,function($keyval__5342__auto__$jscomp$37$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$37$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$37$$,$keyval__5342__auto__$jscomp$37$$)},"#instaparse.gll.Node{",
", ","}",$opts__5340__auto__$jscomp$37$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5592$listeners$$,this.$listeners$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5593$full_listeners$$,this.$full_listeners$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5594$results$$,this.results],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5595$full_results$$,this.$full_results$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,4,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5592$listeners$$,$cljs$cst$5593$full_listeners$$,$cljs$cst$5594$results$$,$cljs$cst$5595$full_results$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,this.$full_results$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 4+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$67_h__5134__auto____$1$jscomp$67$$=this.$__hash$;return $h__5134__auto__$jscomp$67_h__5134__auto____$1$jscomp$67$$!=null?$h__5134__auto__$jscomp$67_h__5134__auto____$1$jscomp$67$$:this.$__hash$=$h__5134__auto__$jscomp$67_h__5134__auto____$1$jscomp$67$$=-1610074144^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this77183$$,$other77184$$){return $other77184$$!=null&&this.constructor===$other77184$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$listeners$,$other77184$$.$listeners$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$full_listeners$,$other77184$$.$full_listeners$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.results,$other77184$$.results)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$full_results$,
$other77184$$.$full_results$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$other77184$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$37$$,$k__5334__auto__$jscomp$37$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$5595$full_results$$,null,$cljs$cst$5593$full_listeners$$,null,$cljs$cst$5592$listeners$$,null,$cljs$cst$5594$results$$,null],null),null),$k__5334__auto__$jscomp$37$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
this),this.$__meta$),$k__5334__auto__$jscomp$37$$):new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,this.$full_results$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$37$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$37$$,$k77182$jscomp$1$$){switch($k77182$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k77182$jscomp$1$$.$fqn$:null){case "listeners":case "full-listeners":case "results":case "full-results":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k77182$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$37$$,$k__5332__auto__$jscomp$37$$,$G__77181$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5592$listeners$$,$k__5332__auto__$jscomp$37$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5592$listeners$$,$k__5332__auto__$jscomp$37$$))?
new $instaparse$gll$Node$$($G__77181$jscomp$1$$,this.$full_listeners$,this.results,this.$full_results$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5593$full_listeners$$,$k__5332__auto__$jscomp$37$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5593$full_listeners$$,$k__5332__auto__$jscomp$37$$))?new $instaparse$gll$Node$$(this.$listeners$,
$G__77181$jscomp$1$$,this.results,this.$full_results$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5594$results$$,$k__5332__auto__$jscomp$37$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5594$results$$,$k__5332__auto__$jscomp$37$$))?new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,$G__77181$jscomp$1$$,
this.$full_results$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5595$full_results$$,$k__5332__auto__$jscomp$37$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5595$full_results$$,$k__5332__auto__$jscomp$37$$))?new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,$G__77181$jscomp$1$$,this.$__meta$,
this.$__extmap$,null):new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,this.$full_results$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$37$$,$G__77181$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$5592$listeners$$,this.$listeners$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5593$full_listeners$$,this.$full_listeners$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5594$results$$,this.results,
null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5595$full_results$$,this.$full_results$,null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$37$$,$G__77181$jscomp$2$$){return new $instaparse$gll$Node$$(this.$listeners$,this.$full_listeners$,this.results,this.$full_results$,$G__77181$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$37$$,$entry__5329__auto__$jscomp$37$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$37$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$37$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$37$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$37$$)};
var $instaparse$gll$merge_negative_listeners$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$merge_with$$,$APP.$cljs$core$into$$),$instaparse$gll$CatListener$$=function $instaparse$gll$CatListener$$($results_so_far$$,$parser_sequence$$,$node_key$jscomp$11$$,$tramp$jscomp$20$$){return function($JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$){var $JSCompiler_temp_const$jscomp$1737_continue_index_map__77236__$1$$=
$APP.$cljs$core$__destructure_map$$($JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$);$JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1737_continue_index_map__77236__$1$$,$APP.$cljs$cst$828$result$$);$JSCompiler_temp_const$jscomp$1737_continue_index_map__77236__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1737_continue_index_map__77236__$1$$,
$APP.$cljs$cst$1801$index$$);$JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$$,$JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$);if($APP.$cljs$core$seq$$($parser_sequence$$)){$JSCompiler_temp_const$jscomp$1737_continue_index_map__77236__$1$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$JSCompiler_temp_const$jscomp$1737_continue_index_map__77236__$1$$,$APP.$cljs$core$first$$($parser_sequence$$)],null);var $G__77238$jscomp$inline_8765$$=$APP.$cljs$core$next$$($parser_sequence$$);$JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$=$instaparse$gll$CatListener$$.$cljs$core$IFn$_invoke$arity$4$?$instaparse$gll$CatListener$$.$cljs$core$IFn$_invoke$arity$4$($JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$,
$G__77238$jscomp$inline_8765$$,$node_key$jscomp$11$$,$tramp$jscomp$20$$):$instaparse$gll$CatListener$$($JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$,$G__77238$jscomp$inline_8765$$,$node_key$jscomp$11$$,$tramp$jscomp$20$$);$JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$=$instaparse$gll$push_listener$$($tramp$jscomp$20$$,$JSCompiler_temp_const$jscomp$1737_continue_index_map__77236__$1$$,
$JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$)}else $JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$=$instaparse$gll$push_result$$($tramp$jscomp$20$$,$node_key$jscomp$11$$,$instaparse$gll$make_success$$($JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$,$JSCompiler_temp_const$jscomp$1737_continue_index_map__77236__$1$$));
return $JSCompiler_inline_result$jscomp$1738_JSCompiler_temp$jscomp$1736_new_results_so_far_parsed_result_result$jscomp$357$$}},$instaparse$gll$CatFullListener$$=function $instaparse$gll$CatFullListener$$($results_so_far$jscomp$1$$,$parser_sequence$jscomp$1$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$){return function($parsed_result$jscomp$1_result$jscomp$358$$){var $continue_index$jscomp$1_map__77241__$1$$=$APP.$cljs$core$__destructure_map$$($parsed_result$jscomp$1_result$jscomp$358$$);$parsed_result$jscomp$1_result$jscomp$358$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$1_map__77241__$1$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$1_map__77241__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$1_map__77241__$1$$,$APP.$cljs$cst$1801$index$$);var $new_results_so_far$jscomp$1$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$1$$,$parsed_result$jscomp$1_result$jscomp$358$$);return $instaparse$reduction$singleton_QMARK_$$($parser_sequence$jscomp$1$$)?
$instaparse$gll$push_full_listener$$($tramp$jscomp$21$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$1_map__77241__$1$$,$APP.$cljs$core$first$$($parser_sequence$jscomp$1$$)],null),function(){var $G__77243$$=$APP.$cljs$core$next$$($parser_sequence$jscomp$1$$);return $instaparse$gll$CatFullListener$$.$cljs$core$IFn$_invoke$arity$4$?$instaparse$gll$CatFullListener$$.$cljs$core$IFn$_invoke$arity$4$($new_results_so_far$jscomp$1$$,
$G__77243$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$):$instaparse$gll$CatFullListener$$($new_results_so_far$jscomp$1$$,$G__77243$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$)}()):$APP.$cljs$core$seq$$($parser_sequence$jscomp$1$$)?$instaparse$gll$push_listener$$($tramp$jscomp$21$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$1_map__77241__$1$$,$APP.$cljs$core$first$$($parser_sequence$jscomp$1$$)],null),function(){var $G__77247$$=
$APP.$cljs$core$next$$($parser_sequence$jscomp$1$$);return $instaparse$gll$CatFullListener$$.$cljs$core$IFn$_invoke$arity$4$?$instaparse$gll$CatFullListener$$.$cljs$core$IFn$_invoke$arity$4$($new_results_so_far$jscomp$1$$,$G__77247$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$):$instaparse$gll$CatFullListener$$($new_results_so_far$jscomp$1$$,$G__77247$$,$node_key$jscomp$12$$,$tramp$jscomp$21$$)}()):$instaparse$gll$push_result$$($tramp$jscomp$21$$,$node_key$jscomp$12$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$1$$,
$continue_index$jscomp$1_map__77241__$1$$))}},$instaparse$gll$PlusListener$$=function $instaparse$gll$PlusListener$$($results_so_far$jscomp$2$$,$parser$jscomp$38$$,$prev_index$jscomp$2$$,$node_key$jscomp$13$$,$tramp$jscomp$22$$){return function($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$359$$){var $continue_index$jscomp$2_map__77250__$1$$=$APP.$cljs$core$__destructure_map$$($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$359$$);$new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$359$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$2_map__77250__$1$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$2_map__77250__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$2_map__77250__$1$$,$APP.$cljs$cst$1801$index$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$2_map__77250__$1$$,$prev_index$jscomp$2$$))return $APP.$cljs$core$count$$($results_so_far$jscomp$2$$)===0?$instaparse$gll$push_result$$($tramp$jscomp$22$$,
$node_key$jscomp$13$$,$instaparse$gll$make_success$$(null,$continue_index$jscomp$2_map__77250__$1$$)):null;$new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$359$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$2$$,$new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$359$$);$instaparse$gll$push_listener$$($tramp$jscomp$22$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$2_map__77250__$1$$,
$parser$jscomp$38$$],null),$instaparse$gll$PlusListener$$.$cljs$core$IFn$_invoke$arity$5$?$instaparse$gll$PlusListener$$.$cljs$core$IFn$_invoke$arity$5$($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$359$$,$parser$jscomp$38$$,$continue_index$jscomp$2_map__77250__$1$$,$node_key$jscomp$13$$,$tramp$jscomp$22$$):$instaparse$gll$PlusListener$$($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$359$$,$parser$jscomp$38$$,$continue_index$jscomp$2_map__77250__$1$$,$node_key$jscomp$13$$,
$tramp$jscomp$22$$));return $instaparse$gll$push_result$$($tramp$jscomp$22$$,$node_key$jscomp$13$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$2_parsed_result$jscomp$2_result$jscomp$359$$,$continue_index$jscomp$2_map__77250__$1$$))}},$instaparse$gll$PlusFullListener$$=function $instaparse$gll$PlusFullListener$$($results_so_far$jscomp$3$$,$parser$jscomp$39$$,$prev_index$jscomp$3$$,$node_key$jscomp$14$$,$tramp$jscomp$23$$){return function($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$360$$){var $continue_index$jscomp$3_map__77251__$1$$=
$APP.$cljs$core$__destructure_map$$($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$360$$);$new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$360$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$3_map__77251__$1$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$3_map__77251__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$3_map__77251__$1$$,$APP.$cljs$cst$1801$index$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$3_map__77251__$1$$,
$prev_index$jscomp$3$$))return $APP.$cljs$core$count$$($results_so_far$jscomp$3$$)===0?$instaparse$gll$push_result$$($tramp$jscomp$23$$,$node_key$jscomp$14$$,$instaparse$gll$make_success$$(null,$continue_index$jscomp$3_map__77251__$1$$)):null;$new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$360$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$3$$,$new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$360$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$3_map__77251__$1$$,
$APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$23$$)))?$instaparse$gll$push_result$$($tramp$jscomp$23$$,$node_key$jscomp$14$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$360$$,$continue_index$jscomp$3_map__77251__$1$$)):$instaparse$gll$push_listener$$($tramp$jscomp$23$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$3_map__77251__$1$$,
$parser$jscomp$39$$],null),$instaparse$gll$PlusFullListener$$.$cljs$core$IFn$_invoke$arity$5$?$instaparse$gll$PlusFullListener$$.$cljs$core$IFn$_invoke$arity$5$($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$360$$,$parser$jscomp$39$$,$continue_index$jscomp$3_map__77251__$1$$,$node_key$jscomp$14$$,$tramp$jscomp$23$$):$instaparse$gll$PlusFullListener$$($new_results_so_far$jscomp$3_parsed_result$jscomp$3_result$jscomp$360$$,$parser$jscomp$39$$,$continue_index$jscomp$3_map__77251__$1$$,
$node_key$jscomp$14$$,$tramp$jscomp$23$$))}},$instaparse$gll$RepListener$$=function $instaparse$gll$RepListener$$($results_so_far$jscomp$4$$,$n_results_so_far$$,$parser$jscomp$40$$,$m$jscomp$225$$,$n$jscomp$295$$,$prev_index$jscomp$4$$,$node_key$jscomp$15$$,$tramp$jscomp$24$$){return function($continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$){$continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$=$APP.$cljs$core$__destructure_map$$($continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$);
var $new_results_so_far$jscomp$4_parsed_result$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$,$APP.$cljs$cst$1801$index$$);$new_results_so_far$jscomp$4_parsed_result$jscomp$4$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$4$$,
$new_results_so_far$jscomp$4_parsed_result$jscomp$4$$);var $new_n_results_so_far$$=$n_results_so_far$$+1;$m$jscomp$225$$<=$new_n_results_so_far$$&&$new_n_results_so_far$$<=$n$jscomp$295$$&&$instaparse$gll$push_result$$($tramp$jscomp$24$$,$node_key$jscomp$15$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$4_parsed_result$jscomp$4$$,$continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$));return $new_n_results_so_far$$<$n$jscomp$295$$?$instaparse$gll$push_listener$$($tramp$jscomp$24$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$,$parser$jscomp$40$$],null),$instaparse$gll$RepListener$$.$cljs$core$IFn$_invoke$arity$8$?$instaparse$gll$RepListener$$.$cljs$core$IFn$_invoke$arity$8$($new_results_so_far$jscomp$4_parsed_result$jscomp$4$$,$new_n_results_so_far$$,$parser$jscomp$40$$,$m$jscomp$225$$,$n$jscomp$295$$,$continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$,$node_key$jscomp$15$$,
$tramp$jscomp$24$$):$instaparse$gll$RepListener$$($new_results_so_far$jscomp$4_parsed_result$jscomp$4$$,$new_n_results_so_far$$,$parser$jscomp$40$$,$m$jscomp$225$$,$n$jscomp$295$$,$continue_index$jscomp$4_map__77252__$1_result$jscomp$361$$,$node_key$jscomp$15$$,$tramp$jscomp$24$$)):null}},$instaparse$gll$RepFullListener$$=function $instaparse$gll$RepFullListener$$($results_so_far$jscomp$5$$,$n_results_so_far$jscomp$1$$,$parser$jscomp$41$$,$m$jscomp$226$$,$n$jscomp$296$$,$prev_index$jscomp$5$$,$node_key$jscomp$16$$,
$tramp$jscomp$25$$){return function($continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$){$continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$=$APP.$cljs$core$__destructure_map$$($continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$);var $new_results_so_far$jscomp$5_parsed_result$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$,$APP.$cljs$cst$828$result$$);$continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$,$APP.$cljs$cst$1801$index$$);$new_results_so_far$jscomp$5_parsed_result$jscomp$5$$=$instaparse$auto_flatten_seq$conj_flat$$($results_so_far$jscomp$5$$,$new_results_so_far$jscomp$5_parsed_result$jscomp$5$$);var $new_n_results_so_far$jscomp$1$$=$n_results_so_far$jscomp$1$$+1;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$,
$APP.$cljs$core$count$$($APP.$cljs$cst$1593$text$$.$cljs$core$IFn$_invoke$arity$1$($tramp$jscomp$25$$)))?$m$jscomp$226$$<=$new_n_results_so_far$jscomp$1$$&&$new_n_results_so_far$jscomp$1$$<=$n$jscomp$296$$?$instaparse$gll$push_result$$($tramp$jscomp$25$$,$node_key$jscomp$16$$,$instaparse$gll$make_success$$($new_results_so_far$jscomp$5_parsed_result$jscomp$5$$,$continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$)):null:$new_n_results_so_far$jscomp$1$$<$n$jscomp$296$$?$instaparse$gll$push_listener$$($tramp$jscomp$25$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$,$parser$jscomp$41$$],null),$instaparse$gll$RepFullListener$$.$cljs$core$IFn$_invoke$arity$8$?$instaparse$gll$RepFullListener$$.$cljs$core$IFn$_invoke$arity$8$($new_results_so_far$jscomp$5_parsed_result$jscomp$5$$,$new_n_results_so_far$jscomp$1$$,$parser$jscomp$41$$,$m$jscomp$226$$,$n$jscomp$296$$,$continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$,
$node_key$jscomp$16$$,$tramp$jscomp$25$$):$instaparse$gll$RepFullListener$$($new_results_so_far$jscomp$5_parsed_result$jscomp$5$$,$new_n_results_so_far$jscomp$1$$,$parser$jscomp$41$$,$m$jscomp$226$$,$n$jscomp$296$$,$continue_index$jscomp$5_map__77253__$1_result$jscomp$362$$,$node_key$jscomp$16$$,$tramp$jscomp$25$$)):null}};var $instaparse$cfg$_STAR_case_insensitive_literals_STAR_$$=$APP.$cljs$cst$205$default$$,$instaparse$cfg$single_quoted_string$$=$APP.$cljs$core$re_pattern$$(/'[^'\\]*(?:\\.[^'\\]*)*'/),$instaparse$cfg$single_quoted_regexp$$=$APP.$cljs$core$re_pattern$$(/#'[^'\\]*(?:\\.[^'\\]*)*'/),$instaparse$cfg$double_quoted_string$$=$APP.$cljs$core$re_pattern$$(/"[^"\\]*(?:\\.[^"\\]*)*"/),$instaparse$cfg$double_quoted_regexp$$=$APP.$cljs$core$re_pattern$$(/#"[^"\\]*(?:\\.[^"\\]*)*"/),$instaparse$cfg$inside_comment$$=
/(?:(?!(?:\(\*|\*\)))[\s\S])*/,$instaparse$cfg$ws$$=$APP.$cljs$core$re_pattern$$("[,\\s]*"),$instaparse$cfg$opt_whitespace$$=$instaparse$combinators_source$hide$$($instaparse$combinators_source$nt$$($cljs$cst$5607$opt_whitespace$$)),$instaparse$cfg$non_terminal$$=$APP.$cljs$core$re_pattern$$("[^, \\r\\t\\n\x3c\x3e(){}\\[\\]+*?:\x3d|'\"#\x26!;./]+"),$instaparse$cfg$non_terminal_namespace_allowed$$=$APP.$cljs$core$re_pattern$$("[^, \\r\\t\\n\x3c\x3e(){}\\[\\]+*?:\x3d|'\"#\x26!;/.][^, \\r\\t\\n\x3c\x3e(){}\\[\\]+*?:\x3d|'\"#\x26!;]*"),
$instaparse$cfg$cfg$$=$instaparse$cfg$make_cfg$$(!1),$instaparse$cfg$cfg_allow_namespaced_nts$$=$instaparse$cfg$make_cfg$$(!0),$read_string_STAR__77513$$=$APP.$cljs$core$deref$$(new $APP.$cljs$core$Var$$(function(){return $cljs$tools$reader$read_string_STAR_$$},$cljs$cst$5617$cljs_DOT_tools_DOT_reader_SLASH_read_string_STAR_$$,$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1483$private$$,$APP.$cljs$cst$176$ns$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$cst$208$file$$,$APP.$cljs$cst$218$end_column$$,
$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$209$line$$,$APP.$cljs$cst$217$end_line$$,$APP.$cljs$cst$1484$arglists$$,$APP.$cljs$cst$1485$doc$$,$APP.$cljs$cst$171$test$$],[!0,$cljs$cst$5618$cljs_DOT_tools_DOT_reader$$,$cljs$cst$5619$read_string_STAR_$$,"cljs/tools/reader.cljs",20,1,306,306,$APP.$cljs$core$list$$(new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$with_meta$$($cljs$cst$5620$reader$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$97$not_native$$],null)),$APP.$cljs$cst$601$_$$,$APP.$cljs$cst$277$opts$$,$cljs$cst$5621$pending_forms$$],null)),null,$APP.$cljs$core$truth_$$($cljs$tools$reader$read_string_STAR_$$)?$cljs$tools$reader$read_string_STAR_$$.$cljs$lang$test$:null]))),$instaparse$cfg$build_rule$$=function $instaparse$cfg$build_rule$$($tree$jscomp$20$$){for(;;){var $G__77322_G__77322__$1_alt_or_ord_vec__77323$$=$APP.$cljs$core$first$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$first$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):
$APP.$cljs$core$first$$($tree$jscomp$20$$);$G__77322_G__77322__$1_alt_or_ord_vec__77323$$=$G__77322_G__77322__$1_alt_or_ord_vec__77323$$ instanceof $APP.$cljs$core$Keyword$$?$G__77322_G__77322__$1_alt_or_ord_vec__77323$$.$fqn$:null;switch($G__77322_G__77322__$1_alt_or_ord_vec__77323$$){case "rule":$G__77322_G__77322__$1_alt_or_ord_vec__77323$$=$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$next$$($tree$jscomp$20$$);
var $nt$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77322_G__77322__$1_alt_or_ord_vec__77323$$,0,null);$G__77322_G__77322__$1_alt_or_ord_vec__77323$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__77322_G__77322__$1_alt_or_ord_vec__77323$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$first$$.$cljs$core$IFn$_invoke$arity$1$($nt$jscomp$2$$):$APP.$cljs$core$first$$($nt$jscomp$2$$),
$cljs$cst$5610$hide_nt$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$(function(){var $G__77326$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($nt$jscomp$2$$):$APP.$cljs$core$fnext$$($nt$jscomp$2$$);return $APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($G__77326$$):
$APP.$cljs$core$fnext$$($G__77326$$)}()),$instaparse$combinators_source$hide_tag$$($instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__77322_G__77322__$1_alt_or_ord_vec__77323$$):$instaparse$cfg$build_rule$$($G__77322_G__77322__$1_alt_or_ord_vec__77323$$))],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($nt$jscomp$2$$):$APP.$cljs$core$fnext$$($nt$jscomp$2$$)),$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__77322_G__77322__$1_alt_or_ord_vec__77323$$):$instaparse$cfg$build_rule$$($G__77322_G__77322__$1_alt_or_ord_vec__77323$$)],null);case "nt":return $instaparse$combinators_source$nt$$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$)));case "alt":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$alt$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$cfg$build_rule$$,$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$next$$($tree$jscomp$20$$)));case "ord":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$ord$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$cfg$build_rule$$,$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$next$$($tree$jscomp$20$$)));case "paren":$tree$jscomp$20$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);continue;case "hide":return $instaparse$combinators_source$hide$$(function(){var $G__77328$$=
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__77328$$):$instaparse$cfg$build_rule$$($G__77328$$)}());case "cat":return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$cat$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$cfg$build_rule$$,
$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$next$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$next$$($tree$jscomp$20$$)));case "string":return $instaparse$cfg$string_PLUS_$$($instaparse$cfg$process_string$$($APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$)),!1);case "regexp":return $instaparse$combinators_source$regexp$$($instaparse$cfg$process_regexp$$($APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$)));case "opt":return $instaparse$combinators_source$opt$$(function(){var $G__77330$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__77330$$):
$instaparse$cfg$build_rule$$($G__77330$$)}());case "star":return $instaparse$combinators_source$star$$(function(){var $G__77331$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__77331$$):$instaparse$cfg$build_rule$$($G__77331$$)}());case "plus":return $instaparse$combinators_source$plus$$(function(){var $G__77333$$=
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__77333$$):$instaparse$cfg$build_rule$$($G__77333$$)}());case "look":return $instaparse$combinators_source$look$$(function(){var $G__77334$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?
$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__77334$$):$instaparse$cfg$build_rule$$($G__77334$$)}());case "neg":return $instaparse$combinators_source$neg$$(function(){var $G__77335$$=$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$?$APP.$cljs$core$fnext$$.$cljs$core$IFn$_invoke$arity$1$($tree$jscomp$20$$):
$APP.$cljs$core$fnext$$($tree$jscomp$20$$);return $instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$cfg$build_rule$$.$cljs$core$IFn$_invoke$arity$1$($G__77335$$):$instaparse$cfg$build_rule$$($G__77335$$)}());case "epsilon":return $instaparse$combinators_source$Epsilon$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77322_G__77322__$1_alt_or_ord_vec__77323$$)].join(""));}break}},$instaparse$cfg$seq_nt$$=function $instaparse$cfg$seq_nt$$($parser$jscomp$61$$){for(;;){var $G__77338_G__77338__$1$$=
$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$);$G__77338_G__77338__$1$$=$G__77338_G__77338__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__77338_G__77338__$1$$.$fqn$:null;switch($G__77338_G__77338__$1$$){case "nt":return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$221$keyword$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$)],null);case "string":case "string-ci":case "char":case "regexp":case "epsilon":return $APP.$cljs$core$PersistentVector$EMPTY$$;
case "opt":case "plus":case "star":case "look":case "neg":case "rep":$parser$jscomp$61$$=$APP.$cljs$cst$646$parser$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$);continue;case "alt":case "cat":return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($instaparse$cfg$seq_nt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5552$parsers$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$)]));case "ord":return $APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($instaparse$cfg$seq_nt$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5550$parser1$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$),$cljs$cst$5551$parser2$$.$cljs$core$IFn$_invoke$arity$1$($parser$jscomp$61$$)],null)]));default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77338_G__77338__$1$$)].join(""));}break}};var $instaparse$transform$enlive_transform$$=function $instaparse$transform$enlive_transform$$($transform_map$$,$parse_tree$$){var $G__77271$jscomp$inline_8804_transform$jscomp$106$$=$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$$);$G__77271$jscomp$inline_8804_transform$jscomp$106$$=$transform_map$$.$cljs$core$IFn$_invoke$arity$1$?$transform_map$$.$cljs$core$IFn$_invoke$arity$1$($G__77271$jscomp$inline_8804_transform$jscomp$106$$):$transform_map$$($G__77271$jscomp$inline_8804_transform$jscomp$106$$);
return $APP.$cljs$core$truth_$$($G__77271$jscomp$inline_8804_transform$jscomp$106$$)?$instaparse$transform$merge_meta$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($G__77271$jscomp$inline_8804_transform$jscomp$106$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$enlive_transform$$,$transform_map$$),$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$$))),$APP.$cljs$core$meta$$($parse_tree$$)):
$APP.$cljs$core$truth_$$($APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$$))?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($parse_tree$$,$APP.$cljs$cst$1642$content$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$enlive_transform$$,$transform_map$$),$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$$))):$parse_tree$$},$instaparse$transform$hiccup_transform$$=
function $instaparse$transform$hiccup_transform$$($transform_map$jscomp$1$$,$parse_tree$jscomp$1$$){if($APP.$cljs$core$sequential_QMARK_$$($parse_tree$jscomp$1$$)&&$APP.$cljs$core$seq$$($parse_tree$jscomp$1$$)){var $G__77274$jscomp$inline_8806_temp__5823__auto__$jscomp$225$$=$APP.$cljs$core$first$$($parse_tree$jscomp$1$$);$G__77274$jscomp$inline_8806_temp__5823__auto__$jscomp$225$$=$transform_map$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$transform_map$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__77274$jscomp$inline_8806_temp__5823__auto__$jscomp$225$$):
$transform_map$jscomp$1$$($G__77274$jscomp$inline_8806_temp__5823__auto__$jscomp$225$$);return $APP.$cljs$core$truth_$$($G__77274$jscomp$inline_8806_temp__5823__auto__$jscomp$225$$)?$instaparse$transform$merge_meta$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($G__77274$jscomp$inline_8806_temp__5823__auto__$jscomp$225$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$hiccup_transform$$,$transform_map$jscomp$1$$),
$APP.$cljs$core$next$$($parse_tree$jscomp$1$$))),$APP.$cljs$core$meta$$($parse_tree$jscomp$1$$)):$APP.$cljs$core$with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$first$$($parse_tree$jscomp$1$$)],null),$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$hiccup_transform$$,$transform_map$jscomp$1$$),
$APP.$cljs$core$next$$($parse_tree$jscomp$1$$))),$APP.$cljs$core$meta$$($parse_tree$jscomp$1$$))}return $parse_tree$jscomp$1$$},$instaparse$transform$transform$$=function $instaparse$transform$transform$$($JSCompiler_temp$jscomp$1742_transform_map$jscomp$2$$,$parse_tree$jscomp$2$$){if(typeof $parse_tree$jscomp$2$$==="string")$JSCompiler_temp$jscomp$1742_transform_map$jscomp$2$$=$parse_tree$jscomp$2$$;else{var $JSCompiler_inline_result$jscomp$1743_and__5023__auto__$jscomp$inline_8808$$=($JSCompiler_inline_result$jscomp$1743_and__5023__auto__$jscomp$inline_8808$$=
$APP.$cljs$core$map_QMARK_$$($parse_tree$jscomp$2$$))?$APP.$cljs$cst$78$tag$$.$cljs$core$IFn$_invoke$arity$1$($parse_tree$jscomp$2$$):$JSCompiler_inline_result$jscomp$1743_and__5023__auto__$jscomp$inline_8808$$;$JSCompiler_temp$jscomp$1742_transform_map$jscomp$2$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1743_and__5023__auto__$jscomp$inline_8808$$)?$instaparse$transform$enlive_transform$$($JSCompiler_temp$jscomp$1742_transform_map$jscomp$2$$,$parse_tree$jscomp$2$$):$APP.$cljs$core$vector_QMARK_$$($parse_tree$jscomp$2$$)&&
$APP.$cljs$core$first$$($parse_tree$jscomp$2$$)instanceof $APP.$cljs$core$Keyword$$?$instaparse$transform$hiccup_transform$$($JSCompiler_temp$jscomp$1742_transform_map$jscomp$2$$,$parse_tree$jscomp$2$$):$APP.$cljs$core$sequential_QMARK_$$($parse_tree$jscomp$2$$)?$APP.$cljs$core$with_meta$$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($instaparse$transform$transform$$,$JSCompiler_temp$jscomp$1742_transform_map$jscomp$2$$),$parse_tree$jscomp$2$$),
$APP.$cljs$core$meta$$($parse_tree$jscomp$2$$)):$parse_tree$jscomp$2$$ instanceof $instaparse$gll$Failure$$?$parse_tree$jscomp$2$$:$instaparse$util$throw_illegal_argument_exception$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["Invalid parse-tree, not recognized as either enlive or hiccup format."]))}return $JSCompiler_temp$jscomp$1742_transform_map$jscomp$2$$};var $instaparse$abnf$abnf_core$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5623$CRLF$$,$cljs$cst$5624$HTAB$$,$cljs$cst$5625$LWSP$$,$cljs$cst$5626$LF$$,$cljs$cst$5627$VCHAR$$,$cljs$cst$5628$DIGIT$$,$cljs$cst$5629$SP$$,$cljs$cst$5630$HEXDIG$$,$cljs$cst$5631$CTL$$,$cljs$cst$5632$DQUOTE$$,$cljs$cst$5633$WSP$$,$cljs$cst$5634$CR$$,$cljs$cst$5635$OCTET$$,$cljs$cst$5636$ALPHA$$,$cljs$cst$5637$CHAR$$,$cljs$cst$5638$BIT$$],[$instaparse$combinators_source$string$$("\r\n"),$instaparse$combinators_source$string$$("\t"),
$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(" "),$instaparse$combinators_source$string$$("\t")])),$instaparse$combinators_source$star$$($instaparse$combinators_source$cat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$("\r\n"),
$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(" "),$instaparse$combinators_source$string$$("\t")]))])))])),$instaparse$combinators_source$string$$("\n"),$instaparse$combinators_source$regexp$$("[\\u0021-\\u007E]"),$instaparse$combinators_source$regexp$$("[0-9]"),$instaparse$combinators_source$string$$(" "),$instaparse$combinators_source$regexp$$("[0-9a-fA-F]"),$instaparse$combinators_source$regexp$$("[\\u0000-\\u001F|\\u007F]"),
$instaparse$combinators_source$string$$('"'),$instaparse$combinators_source$alt$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$string$$(" "),$instaparse$combinators_source$string$$("\t")])),$instaparse$combinators_source$string$$("\r"),$instaparse$combinators_source$regexp$$("[\\u0000-\\u00FF]"),$instaparse$combinators_source$regexp$$("[a-zA-Z]"),$instaparse$combinators_source$regexp$$("[\\u0001-\\u007F]"),$instaparse$combinators_source$regexp$$("[01]")]),
$instaparse$abnf$abnf_parser$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5571$neg$$,$APP.$cljs$cst$1613$group$$,$cljs$cst$5639$hide_tag$$,$cljs$cst$5640$whitespace$$,$cljs$cst$5641$element$$,$cljs$cst$5642$hide_tag_rule$$,$cljs$cst$5570$look$$,$cljs$cst$5643$bin_char$$,$cljs$cst$5609$rule$$,$cljs$cst$5644$rulename_right$$,$cljs$cst$5628$DIGIT$$,$cljs$cst$5645$NUM$$,$cljs$cst$5646$char_val$$,$cljs$cst$5647$num_val$$,$APP.$cljs$cst$2356$hide$$,$cljs$cst$5648$defined_as$$,$cljs$cst$5630$HEXDIG$$,
$cljs$cst$5649$option$$,$cljs$cst$5650$hex_char$$,$cljs$cst$5651$rulename$$,$cljs$cst$5652$bin_val$$,$cljs$cst$5653$dec_val$$,$cljs$cst$5654$concatenation$$,$cljs$cst$5655$alternation$$,$cljs$cst$5553$regexp$$,$cljs$cst$5656$repetition$$,$cljs$cst$5657$rulename_left$$,$cljs$cst$5658$rulelist$$,$cljs$cst$5607$opt_whitespace$$,$APP.$cljs$cst$716$repeat$$,$cljs$cst$5659$hex_val$$,$cljs$cst$5660$dec_char$$,$cljs$cst$5616$rules_or_parser$$],[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"!"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5641$element$$],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5571$neg$$],
null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"("],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5655$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,")"],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,
"\x3c"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5657$rulename_left$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x3e"],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),
null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("\\s+(?:;.*?\\u000D?\\u000A\\s*)*"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,
$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5640$whitespace$$],null)],null)])),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5644$rulename_right$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$1613$group$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$2356$hide$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5649$option$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5646$char_val$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5647$num_val$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5570$look$$],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5571$neg$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5553$regexp$$],null),null,1,null),2,null),3,null),4,null),5,null),6,null),7,null),8,null),9,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,
$APP.$cljs$cst$561$raw$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5639$hide_tag$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,
$cljs$cst$5648$defined_as$$,$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5655$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$,$APP.$cljs$cst$2356$hide$$,!0],null),null,1,null),2,null),3,
null),4,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5642$hide_tag_rule$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x26"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5641$element$$],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5570$look$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"0"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"1"],null),null,1,null),2,null)],null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,
$APP.$cljs$cst$302$key$$,$cljs$cst$5643$bin_char$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5657$rulename_left$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5648$defined_as$$,$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5655$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$,$APP.$cljs$cst$2356$hide$$,!0],
null),null,1,null),2,null),3,null),4,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5609$rule$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5651$rulename$$,$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,
$APP.$cljs$cst$302$key$$,$cljs$cst$5644$rulename_right$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[0-9]"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null)])),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,
$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5628$DIGIT$$],null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5645$NUM$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,'"',$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5565$star$$,$APP.$cljs$cst$646$parser$$,
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[\\u0020-\\u0021\\u0023-\\u007E]"),$APP.$cljs$core$PersistentArrayMap$EMPTY$$]))],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,'"',$APP.$cljs$cst$2356$hide$$,!0],null),null,1,null),2,null),3,null)],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"'",$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5565$star$$,$APP.$cljs$cst$646$parser$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[\\u0020-\\u0026(-~]"),
$APP.$cljs$core$PersistentArrayMap$EMPTY$$]))],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"'",$APP.$cljs$cst$2356$hide$$,!0],null),null,1,null),2,null),3,null)],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5646$char_val$$],null)],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"%",$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5652$bin_val$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5653$dec_val$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5659$hex_val$$],
null),null,1,null),2,null),3,null)],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x3c"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5655$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x3e"],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$2356$hide$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$,$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,
"\x3d"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"\x3d/"],null),null,1,null),2,null)],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$,$APP.$cljs$cst$2356$hide$$,!0],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5648$defined_as$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[0-9a-fA-F]"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null)])),
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"["],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5655$alternation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"]"],null),null,1,null),2,null),$APP.$cljs$cst$2356$hide$$,!0],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5649$option$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5630$HEXDIG$$],null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,
$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5650$hex_char$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("[a-zA-Z][-a-zA-Z0-9]*"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null)])),new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"b",$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5643$bin_char$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,".",$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5643$bin_char$$],null),null,1,null),2,null)],null)],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,
$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"-"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5643$bin_char$$],null),null,1,null),2,null)],null),null,1,null),2,null)],null)],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5652$bin_val$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"d",$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5660$dec_char$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,".",$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5660$dec_char$$],null),null,1,null),2,null)],null)],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"-"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5660$dec_char$$],null),null,1,null),2,null)],null),null,1,null),2,null)],null)],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5653$dec_val$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5656$repetition$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5565$star$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5640$whitespace$$,$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5656$repetition$$],null),null,1,null),2,null)],null)],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,
$APP.$cljs$cst$302$key$$,$cljs$cst$5654$concatenation$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5654$concatenation$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5565$star$$,
$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"/"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$],null),null,1,null),2,null),3,null),$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5654$concatenation$$],null),null,1,null),2,null)],null)],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5655$alternation$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("#'[^'\\\\]*(?:\\\\.[^'\\\\]*)*'"),
$APP.$cljs$core$PersistentArrayMap$EMPTY$$])),new $APP.$cljs$core$List$$(null,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$('#\\"[^\\"\\\\]*(?:\\\\.[^\\"\\\\]*)*\\"'),$APP.$cljs$core$PersistentArrayMap$EMPTY$$])),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,
$cljs$cst$5553$regexp$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$APP.$cljs$cst$716$repeat$$],null)],null),new $APP.$cljs$core$List$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$,$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5641$element$$],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,
$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5656$repetition$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5651$rulename$$,$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5657$rulename_left$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5607$opt_whitespace$$,$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,
$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5609$rule$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5642$hide_tag_rule$$],null),null,1,null),2,null)],null)],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$instaparse$combinators_source$regexp$$("\\s*(?:;.*?(?:\\u000D?\\u000A\\s*|$))*"),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,
$APP.$cljs$cst$302$key$$,$cljs$cst$5607$opt_whitespace$$],null)],null)])),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5645$NUM$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,
$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5645$NUM$$],null)],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,
"*"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5645$NUM$$],null)],null),null,1,null),2,null),3,null)],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,
$APP.$cljs$cst$302$key$$,$APP.$cljs$cst$716$repeat$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"x",$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5650$hex_char$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$993$opt$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,".",$APP.$cljs$cst$2356$hide$$,!0],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5650$hex_char$$],null),null,1,null),2,null)],null)],null),
new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$594$cat$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$198$string$$,$APP.$cljs$cst$198$string$$,"-"],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5650$hex_char$$],
null),null,1,null),2,null)],null),null,1,null),2,null)],null)],null),null,1,null),2,null),3,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5659$hex_val$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5564$plus$$,$APP.$cljs$cst$646$parser$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5628$DIGIT$$],null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5554$reduction_type$$,$cljs$cst$5561$hiccup$$,$APP.$cljs$cst$302$key$$,$cljs$cst$5660$dec_char$$],null)],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$78$tag$$,$APP.$cljs$cst$717$alt$$,$cljs$cst$5552$parsers$$,new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,
$APP.$cljs$cst$221$keyword$$,$cljs$cst$5658$rulelist$$],null),new $APP.$cljs$core$List$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$78$tag$$,$cljs$cst$5569$nt$$,$APP.$cljs$cst$221$keyword$$,$cljs$cst$5655$alternation$$],null),null,1,null),2,null),$APP.$cljs$cst$5555$red$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5554$reduction_type$$,$APP.$cljs$cst$561$raw$$],null)],null)]),$instaparse$abnf$get_char_combinator$$=function $instaparse$abnf$get_char_combinator$$($var_args$jscomp$1439$$){for(var $args__5755__auto__$jscomp$250$$=
[],$len__5749__auto___78033$$=arguments.length,$i__5750__auto___78034$$=0;;)if($i__5750__auto___78034$$<$len__5749__auto___78033$$)$args__5755__auto__$jscomp$250$$.push(arguments[$i__5750__auto___78034$$]),$i__5750__auto___78034$$+=1;else break;return $instaparse$abnf$get_char_combinator$$.$cljs$core$IFn$_invoke$arity$variadic$(0<$args__5755__auto__$jscomp$250$$.length?new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$250$$.slice(0),0,null):null)};
$instaparse$abnf$get_char_combinator$$.$cljs$core$IFn$_invoke$arity$variadic$=function($nums$$){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("-",$APP.$cljs$core$second$$($nums$$))){var $lo$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nums$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nums$$,1,null);var $hi$jscomp$11$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($nums$$,2,null);return $instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$($lo$jscomp$9$$,
$hi$jscomp$11$$)}return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$cat$$,function(){return function $instaparse$abnf$iter__77968$$($s__77969$$){return new $APP.$cljs$core$LazySeq$$(null,function(){for(;;){var $s__77969__$2_temp__5825__auto__$jscomp$354$$=$APP.$cljs$core$seq$$($s__77969$$);if($s__77969__$2_temp__5825__auto__$jscomp$354$$){if($APP.$cljs$core$chunked_seq_QMARK_$$($s__77969__$2_temp__5825__auto__$jscomp$354$$)){var $JSCompiler_inline_result$jscomp$1744_c__5501__auto__$jscomp$45$$=
$APP.$cljs$core$_chunked_first$$($s__77969__$2_temp__5825__auto__$jscomp$354$$),$size__5502__auto__$jscomp$45$$=$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1744_c__5501__auto__$jscomp$45$$),$b__77971_n$jscomp$299$$=$APP.$cljs$core$chunk_buffer$$($size__5502__auto__$jscomp$45$$);a:{for(var $i__77970$jscomp$inline_8810$$=0;;)if($i__77970$jscomp$inline_8810$$<$size__5502__auto__$jscomp$45$$){var $n$jscomp$inline_8811$$=$APP.$cljs$core$_nth$$($JSCompiler_inline_result$jscomp$1744_c__5501__auto__$jscomp$45$$,
$i__77970$jscomp$inline_8810$$);$b__77971_n$jscomp$299$$.add($instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$($n$jscomp$inline_8811$$,$n$jscomp$inline_8811$$));$i__77970$jscomp$inline_8810$$+=1}else{$JSCompiler_inline_result$jscomp$1744_c__5501__auto__$jscomp$45$$=!0;break a}$JSCompiler_inline_result$jscomp$1744_c__5501__auto__$jscomp$45$$=void 0}return $JSCompiler_inline_result$jscomp$1744_c__5501__auto__$jscomp$45$$?$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__77971_n$jscomp$299$$),
$instaparse$abnf$iter__77968$$($APP.$cljs$core$_chunked_rest$$($s__77969__$2_temp__5825__auto__$jscomp$354$$))):$APP.$cljs$core$chunk_cons$$($APP.$cljs$core$chunk$$($b__77971_n$jscomp$299$$),null)}$b__77971_n$jscomp$299$$=$APP.$cljs$core$first$$($s__77969__$2_temp__5825__auto__$jscomp$354$$);return $APP.$cljs$core$cons$$($instaparse$combinators_source$unicode_char$cljs$0core$0IFn$0_invoke$0arity$02$$($b__77971_n$jscomp$299$$,$b__77971_n$jscomp$299$$),$instaparse$abnf$iter__77968$$($APP.$cljs$core$rest$$($s__77969__$2_temp__5825__auto__$jscomp$354$$)))}return null}},
null,null)}($nums$$)}())};$instaparse$abnf$get_char_combinator$$.$cljs$lang$maxFixedArity$=0;$instaparse$abnf$get_char_combinator$$.$cljs$lang$applyTo$=function($seq77964$$){return this.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($seq77964$$))};
var $instaparse$abnf$parse_int$$=parseInt,$instaparse$abnf$abnf_transformer$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5571$neg$$,$cljs$cst$5642$hide_tag_rule$$,$cljs$cst$5570$look$$,$cljs$cst$5643$bin_char$$,$cljs$cst$5609$rule$$,$cljs$cst$5644$rulename_right$$,$cljs$cst$5645$NUM$$,$cljs$cst$5646$char_val$$,$APP.$cljs$cst$2356$hide$$,$cljs$cst$5649$option$$,$cljs$cst$5650$hex_char$$,$cljs$cst$5652$bin_val$$,$cljs$cst$5653$dec_val$$,$cljs$cst$5654$concatenation$$,$cljs$cst$5655$alternation$$,
$cljs$cst$5553$regexp$$,$cljs$cst$5656$repetition$$,$cljs$cst$5657$rulename_left$$,$APP.$cljs$cst$716$repeat$$,$cljs$cst$5659$hex_val$$,$cljs$cst$5660$dec_char$$],[$instaparse$combinators_source$neg$$,function($tag$jscomp$93$$,$rule$jscomp$5$$){return $APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$tag$jscomp$93$$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($rule$jscomp$5$$,$APP.$cljs$cst$5555$red$$,$instaparse$reduction$raw_non_terminal_reduction$$)])},$instaparse$combinators_source$look$$,
function(){function $G__78048$$($var_args$jscomp$1440$$){var $G__78049__i_cs$jscomp$5$$=null;if(arguments.length>0){$G__78049__i_cs$jscomp$5$$=0;for(var $G__78049__a$$=Array(arguments.length-0);$G__78049__i_cs$jscomp$5$$<$G__78049__a$$.length;)$G__78049__a$$[$G__78049__i_cs$jscomp$5$$]=arguments[$G__78049__i_cs$jscomp$5$$+0],++$G__78049__i_cs$jscomp$5$$;$G__78049__i_cs$jscomp$5$$=new $APP.$cljs$core$IndexedSeq$$($G__78049__a$$,0,null)}return $G__78048__delegate$$.call(this,$G__78049__i_cs$jscomp$5$$)}
function $G__78048__delegate$$($G__77983_cs$jscomp$4$$){$G__77983_cs$jscomp$4$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$G__77983_cs$jscomp$4$$);return $instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$2$($G__77983_cs$jscomp$4$$,2):$instaparse$abnf$parse_int$$($G__77983_cs$jscomp$4$$,2)}$G__78048$$.$cljs$lang$maxFixedArity$=0;$G__78048$$.$cljs$lang$applyTo$=function($arglist__78050_cs$jscomp$6$$){$arglist__78050_cs$jscomp$6$$=
$APP.$cljs$core$seq$$($arglist__78050_cs$jscomp$6$$);return $G__78048__delegate$$($arglist__78050_cs$jscomp$6$$)};$G__78048$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__78048__delegate$$;return $G__78048$$}(),$APP.$cljs$core$hash_map$$,function(){function $G__78051$$($var_args$jscomp$1441$$){var $G__78052__i_rest__77981_SHARP_$jscomp$1$$=null;if(arguments.length>0){$G__78052__i_rest__77981_SHARP_$jscomp$1$$=0;for(var $G__78052__a$$=Array(arguments.length-0);$G__78052__i_rest__77981_SHARP_$jscomp$1$$<
$G__78052__a$$.length;)$G__78052__a$$[$G__78052__i_rest__77981_SHARP_$jscomp$1$$]=arguments[$G__78052__i_rest__77981_SHARP_$jscomp$1$$+0],++$G__78052__i_rest__77981_SHARP_$jscomp$1$$;$G__78052__i_rest__77981_SHARP_$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__78052__a$$,0,null)}return $G__78051__delegate$$.call(this,$G__78052__i_rest__77981_SHARP_$jscomp$1$$)}function $G__78051__delegate$$($rest__77981_SHARP_$$){return $APP.$cljs$core$truth_$$(!1)?$instaparse$combinators_source$nt$$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$clojure$string$upper_case$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$rest__77981_SHARP_$$)))):$instaparse$combinators_source$nt$$($APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$rest__77981_SHARP_$$)))}$G__78051$$.$cljs$lang$maxFixedArity$=0;$G__78051$$.$cljs$lang$applyTo$=function($arglist__78053_rest__77981_SHARP_$jscomp$2$$){$arglist__78053_rest__77981_SHARP_$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__78053_rest__77981_SHARP_$jscomp$2$$);return $G__78051__delegate$$($arglist__78053_rest__77981_SHARP_$jscomp$2$$)};
$G__78051$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__78051__delegate$$;return $G__78051$$}(),function(){function $G__78054$$($var_args$jscomp$1442$$){var $G__78055__i_rest__77982_SHARP_$jscomp$1$$=null;if(arguments.length>0){$G__78055__i_rest__77982_SHARP_$jscomp$1$$=0;for(var $G__78055__a$$=Array(arguments.length-0);$G__78055__i_rest__77982_SHARP_$jscomp$1$$<$G__78055__a$$.length;)$G__78055__a$$[$G__78055__i_rest__77982_SHARP_$jscomp$1$$]=arguments[$G__78055__i_rest__77982_SHARP_$jscomp$1$$+0],
++$G__78055__i_rest__77982_SHARP_$jscomp$1$$;$G__78055__i_rest__77982_SHARP_$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__78055__a$$,0,null)}return $G__78054__delegate$$.call(this,$G__78055__i_rest__77982_SHARP_$jscomp$1$$)}function $G__78054__delegate$$($G__77986_rest__77982_SHARP_$$){$G__77986_rest__77982_SHARP_$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$G__77986_rest__77982_SHARP_$$);return $instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$1$($G__77986_rest__77982_SHARP_$$):
$instaparse$abnf$parse_int$$($G__77986_rest__77982_SHARP_$$)}$G__78054$$.$cljs$lang$maxFixedArity$=0;$G__78054$$.$cljs$lang$applyTo$=function($arglist__78056_rest__77982_SHARP_$jscomp$2$$){$arglist__78056_rest__77982_SHARP_$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__78056_rest__77982_SHARP_$jscomp$2$$);return $G__78054__delegate$$($arglist__78056_rest__77982_SHARP_$jscomp$2$$)};$G__78054$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__78054__delegate$$;return $G__78054$$}(),function(){function $G__78058$$($var_args$jscomp$1443$$){var $G__78059__i_cs$jscomp$8$$=
null;if(arguments.length>0){$G__78059__i_cs$jscomp$8$$=0;for(var $G__78059__a$$=Array(arguments.length-0);$G__78059__i_cs$jscomp$8$$<$G__78059__a$$.length;)$G__78059__a$$[$G__78059__i_cs$jscomp$8$$]=arguments[$G__78059__i_cs$jscomp$8$$+0],++$G__78059__i_cs$jscomp$8$$;$G__78059__i_cs$jscomp$8$$=new $APP.$cljs$core$IndexedSeq$$($G__78059__a$$,0,null)}return $G__78058__delegate$$.call(this,$G__78059__i_cs$jscomp$8$$)}function $G__78058__delegate$$($cs$jscomp$7$$){return $instaparse$cfg$string_PLUS_$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$cs$jscomp$7$$),!0)}$G__78058$$.$cljs$lang$maxFixedArity$=0;$G__78058$$.$cljs$lang$applyTo$=function($arglist__78060_cs$jscomp$9$$){$arglist__78060_cs$jscomp$9$$=$APP.$cljs$core$seq$$($arglist__78060_cs$jscomp$9$$);return $G__78058__delegate$$($arglist__78060_cs$jscomp$9$$)};$G__78058$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__78058__delegate$$;return $G__78058$$}(),$instaparse$combinators_source$hide$$,$instaparse$combinators_source$opt$$,function(){function $G__78061$$($var_args$jscomp$1444$$){var $G__78064__i_cs$jscomp$11$$=
null;if(arguments.length>0){$G__78064__i_cs$jscomp$11$$=0;for(var $G__78064__a$$=Array(arguments.length-0);$G__78064__i_cs$jscomp$11$$<$G__78064__a$$.length;)$G__78064__a$$[$G__78064__i_cs$jscomp$11$$]=arguments[$G__78064__i_cs$jscomp$11$$+0],++$G__78064__i_cs$jscomp$11$$;$G__78064__i_cs$jscomp$11$$=new $APP.$cljs$core$IndexedSeq$$($G__78064__a$$,0,null)}return $G__78061__delegate$$.call(this,$G__78064__i_cs$jscomp$11$$)}function $G__78061__delegate$$($G__77987_cs$jscomp$10$$){$G__77987_cs$jscomp$10$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$G__77987_cs$jscomp$10$$);return $instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$2$?$instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$2$($G__77987_cs$jscomp$10$$,16):$instaparse$abnf$parse_int$$($G__77987_cs$jscomp$10$$,16)}$G__78061$$.$cljs$lang$maxFixedArity$=0;$G__78061$$.$cljs$lang$applyTo$=function($arglist__78065_cs$jscomp$12$$){$arglist__78065_cs$jscomp$12$$=$APP.$cljs$core$seq$$($arglist__78065_cs$jscomp$12$$);
return $G__78061__delegate$$($arglist__78065_cs$jscomp$12$$)};$G__78061$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__78061__delegate$$;return $G__78061$$}(),$instaparse$abnf$get_char_combinator$$,$instaparse$abnf$get_char_combinator$$,$instaparse$combinators_source$cat$$,$instaparse$combinators_source$alt$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($instaparse$combinators_source$regexp$$,$instaparse$cfg$process_regexp$$),function(){function $G__78066__2$$($repeat$$,$element$jscomp$79$$){return $APP.$cljs$core$empty_QMARK_$$($repeat$$)?
$instaparse$combinators_source$star$$($element$jscomp$79$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($repeat$$),2)?$instaparse$combinators_source$rep$$($cljs$cst$5661$low$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$),$cljs$cst$5662$high$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$),$element$jscomp$79$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5661$low$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$),1)?$instaparse$combinators_source$plus$$($element$jscomp$79$$):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5662$high$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$),1)?$instaparse$combinators_source$opt$$($element$jscomp$79$$):$instaparse$combinators_source$rep$$(function(){var $or__5025__auto__$jscomp$1113$$=$cljs$cst$5661$low$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1113$$)?$or__5025__auto__$jscomp$1113$$:0}(),function(){var $or__5025__auto__$jscomp$1114$$=$cljs$cst$5662$high$$.$cljs$core$IFn$_invoke$arity$1$($repeat$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1114$$)?$or__5025__auto__$jscomp$1114$$:Infinity}(),$element$jscomp$79$$)}var $G__78066$$=null;$G__78066$$=function($repeat$jscomp$1$$,$element$jscomp$80$$){switch(arguments.length){case 1:return $repeat$jscomp$1$$;case 2:return $G__78066__2$$.call(this,$repeat$jscomp$1$$,$element$jscomp$80$$)}throw Error("Invalid arity: "+arguments.length);};$G__78066$$.$cljs$core$IFn$_invoke$arity$1$=function($element$jscomp$78$$){return $element$jscomp$78$$};
$G__78066$$.$cljs$core$IFn$_invoke$arity$2$=$G__78066__2$$;return $G__78066$$}(),function(){function $G__78068$$($var_args$jscomp$1445$$){var $G__78069__i_rest__77980_SHARP_$jscomp$1$$=null;if(arguments.length>0){$G__78069__i_rest__77980_SHARP_$jscomp$1$$=0;for(var $G__78069__a$$=Array(arguments.length-0);$G__78069__i_rest__77980_SHARP_$jscomp$1$$<$G__78069__a$$.length;)$G__78069__a$$[$G__78069__i_rest__77980_SHARP_$jscomp$1$$]=arguments[$G__78069__i_rest__77980_SHARP_$jscomp$1$$+0],++$G__78069__i_rest__77980_SHARP_$jscomp$1$$;
$G__78069__i_rest__77980_SHARP_$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__78069__a$$,0,null)}return $G__78068__delegate$$.call(this,$G__78069__i_rest__77980_SHARP_$jscomp$1$$)}function $G__78068__delegate$$($rest__77980_SHARP_$$){return $APP.$cljs$core$truth_$$(!1)?$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$clojure$string$upper_case$$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$rest__77980_SHARP_$$))):$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,
$rest__77980_SHARP_$$))}$G__78068$$.$cljs$lang$maxFixedArity$=0;$G__78068$$.$cljs$lang$applyTo$=function($arglist__78070_rest__77980_SHARP_$jscomp$2$$){$arglist__78070_rest__77980_SHARP_$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__78070_rest__77980_SHARP_$jscomp$2$$);return $G__78068__delegate$$($arglist__78070_rest__77980_SHARP_$jscomp$2$$)};$G__78068$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__78068__delegate$$;return $G__78068$$}(),function(){function $G__78071$$($var_args$jscomp$1446$$){var $G__78075__i_items$jscomp$57$$=
null;if(arguments.length>0){$G__78075__i_items$jscomp$57$$=0;for(var $G__78075__a$$=Array(arguments.length-0);$G__78075__i_items$jscomp$57$$<$G__78075__a$$.length;)$G__78075__a$$[$G__78075__i_items$jscomp$57$$]=arguments[$G__78075__i_items$jscomp$57$$+0],++$G__78075__i_items$jscomp$57$$;$G__78075__i_items$jscomp$57$$=new $APP.$cljs$core$IndexedSeq$$($G__78075__a$$,0,null)}return $G__78071__delegate$$.call(this,$G__78075__i_items$jscomp$57$$)}function $G__78071__delegate$$($items$jscomp$56$$){var $G__77989$$=
$APP.$cljs$core$count$$($items$jscomp$56$$);switch($G__77989$$){case 1:return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($items$jscomp$56$$),"*")?$APP.$cljs$core$PersistentArrayMap$EMPTY$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5661$low$$,$APP.$cljs$core$first$$($items$jscomp$56$$),$cljs$cst$5662$high$$,$APP.$cljs$core$first$$($items$jscomp$56$$)],null);case 2:return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($items$jscomp$56$$),
"*")?new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5662$high$$,$APP.$cljs$core$second$$($items$jscomp$56$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5661$low$$,$APP.$cljs$core$first$$($items$jscomp$56$$)],null);case 3:return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5661$low$$,$APP.$cljs$core$first$$($items$jscomp$56$$),$cljs$cst$5662$high$$,$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($items$jscomp$56$$,2)],null);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__77989$$)].join(""));}}$G__78071$$.$cljs$lang$maxFixedArity$=0;$G__78071$$.$cljs$lang$applyTo$=function($arglist__78076_items$jscomp$58$$){$arglist__78076_items$jscomp$58$$=$APP.$cljs$core$seq$$($arglist__78076_items$jscomp$58$$);return $G__78071__delegate$$($arglist__78076_items$jscomp$58$$)};$G__78071$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__78071__delegate$$;return $G__78071$$}(),$instaparse$abnf$get_char_combinator$$,function(){function $G__78077$$($var_args$jscomp$1447$$){var $G__78078__i_cs$jscomp$14$$=
null;if(arguments.length>0){$G__78078__i_cs$jscomp$14$$=0;for(var $G__78078__a$$=Array(arguments.length-0);$G__78078__i_cs$jscomp$14$$<$G__78078__a$$.length;)$G__78078__a$$[$G__78078__i_cs$jscomp$14$$]=arguments[$G__78078__i_cs$jscomp$14$$+0],++$G__78078__i_cs$jscomp$14$$;$G__78078__i_cs$jscomp$14$$=new $APP.$cljs$core$IndexedSeq$$($G__78078__a$$,0,null)}return $G__78077__delegate$$.call(this,$G__78078__i_cs$jscomp$14$$)}function $G__78077__delegate$$($G__77992_cs$jscomp$13$$){$G__77992_cs$jscomp$13$$=
$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$str$$,$G__77992_cs$jscomp$13$$);return $instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$1$?$instaparse$abnf$parse_int$$.$cljs$core$IFn$_invoke$arity$1$($G__77992_cs$jscomp$13$$):$instaparse$abnf$parse_int$$($G__77992_cs$jscomp$13$$)}$G__78077$$.$cljs$lang$maxFixedArity$=0;$G__78077$$.$cljs$lang$applyTo$=function($arglist__78079_cs$jscomp$15$$){$arglist__78079_cs$jscomp$15$$=$APP.$cljs$core$seq$$($arglist__78079_cs$jscomp$15$$);
return $G__78077__delegate$$($arglist__78079_cs$jscomp$15$$)};$G__78077$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__78077__delegate$$;return $G__78077$$}()]);var $instaparse$repeat$failure_signal$$=new $instaparse$gll$Failure$$(null,null,null,null,null),$instaparse$repeat$get_end$$=function $instaparse$repeat$get_end$$($var_args$jscomp$1449$$){switch(arguments.length){case 1:return $instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);case 2:return $instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));
}};$instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$1$=function($parse$jscomp$5$$){var $end$jscomp$102_vec__77276$$=$instaparse$viz$span$$($parse$jscomp$5$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$102_vec__77276$$,0,null);$end$jscomp$102_vec__77276$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$102_vec__77276$$,1,null);return $APP.$cljs$core$truth_$$($end$jscomp$102_vec__77276$$)?$APP.$cljs$core$fix$$($end$jscomp$102_vec__77276$$):$APP.$cljs$core$count$$($parse$jscomp$5$$)};
$instaparse$repeat$get_end$$.$cljs$core$IFn$_invoke$arity$2$=function($parse$jscomp$6$$,$index$jscomp$453$$){var $end$jscomp$103_vec__77279$$=$instaparse$viz$span$$($parse$jscomp$6$$);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$103_vec__77279$$,0,null);$end$jscomp$103_vec__77279$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($end$jscomp$103_vec__77279$$,1,null);return $APP.$cljs$core$truth_$$($end$jscomp$103_vec__77279$$)?$APP.$cljs$core$fix$$($end$jscomp$103_vec__77279$$):
$index$jscomp$453$$+$APP.$cljs$core$count$$($parse$jscomp$6$$)};$instaparse$repeat$get_end$$.$cljs$lang$maxFixedArity$=2;var $instaparse$core$parse$$=function $instaparse$core$parse$$($var_args$jscomp$1455$$){for(var $args__5755__auto__$jscomp$252$$=[],$len__5749__auto___78417$$=arguments.length,$i__5750__auto___78418$$=0;;)if($i__5750__auto___78418$$<$len__5749__auto___78417$$)$args__5755__auto__$jscomp$252$$.push(arguments[$i__5750__auto___78418$$]),$i__5750__auto___78418$$+=1;else break;return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(arguments[0],arguments[1],2<$args__5755__auto__$jscomp$252$$.length?
new $APP.$cljs$core$IndexedSeq$$($args__5755__auto__$jscomp$252$$.slice(2),0,null):null)};
$instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$=function($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,$p__78368_start_production$jscomp$5$$){var $JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$=$APP.$cljs$core$__destructure_map$$($p__78368_start_production$jscomp$5$$);
$p__78368_start_production$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$,$APP.$cljs$cst$1297$start$$,$cljs$cst$5557$start_production$$.$cljs$core$IFn$_invoke$arity$1$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$));var $build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$,
$APP.$cljs$cst$2133$partial$$,!1),$JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$,$cljs$cst$5663$optimize$$,!1),$fail_index$jscomp$inline_14909_unhide$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$,$cljs$cst$5671$unhide$$);$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$,
$APP.$cljs$cst$144$trace$$,!1);$G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$=$instaparse$core$unhide_parser$$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$,$fail_index$jscomp$inline_14909_unhide$jscomp$1$$);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2338$total$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$))?($JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$=
$cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$),$G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$=$cljs$cst$5622$output_format$$.$cljs$core$IFn$_invoke$arity$1$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$),$JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$=$instaparse$reduction$node_builders$$.$cljs$core$IFn$_invoke$arity$1$?
$instaparse$reduction$node_builders$$.$cljs$core$IFn$_invoke$arity$1$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$):$instaparse$reduction$node_builders$$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$),$G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$=$instaparse$gll$parse$$($JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$,
$p__78368_start_production$jscomp$5$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,$build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$),$G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$ instanceof $instaparse$gll$Failure$$?($fail_index$jscomp$inline_14909_unhide$jscomp$1$$=$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$),
$JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$=$instaparse$gll$make_tramp$cljs$0core$0IFn$0_invoke$0arity$05$$($JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,$fail_index$jscomp$inline_14909_unhide$jscomp$1$$,
$JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$),$instaparse$gll$start_parser$$($JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$,$instaparse$combinators_source$nt$$($p__78368_start_production$jscomp$5$$),$build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$),$build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$=$instaparse$gll$run$cljs$0core$0IFn$0_invoke$0arity$02$$($JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$,
null),$APP.$cljs$core$truth_$$($build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$)?$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$=$APP.$cljs$core$first$$($build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$):($build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$=
$instaparse$gll$build_node_with_meta$$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$,$cljs$cst$5602$instaparse_SLASH_failure$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,0,$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$)),$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$=
$instaparse$gll$build_node_with_meta$$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$,$p__78368_start_production$jscomp$5$$,$build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$,0,$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$))),$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$=
$APP.$cljs$core$with_meta$$($JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$,$APP.$cljs$core$meta$$($JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$)])))):
$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$=$G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$)?$APP.$cljs$core$not$$($build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$):
$JSCompiler_temp_const$jscomp$11296_optimize_QMARK__tramp$jscomp$inline_14910$$)?($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$=$instaparse$repeat$try_repeating_parse_strategy$$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,$p__78368_start_production$jscomp$5$$),$APP.$cljs$core$truth_$$($instaparse$core$failure_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?
$instaparse$core$failure_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$):$instaparse$core$failure_QMARK_$$($JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$))?$instaparse$gll$parse$$($cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$),$p__78368_start_production$jscomp$5$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,
$build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$):$JSCompiler_inline_result$jscomp$11297_options$jscomp$603_result$jscomp$368$$):$instaparse$gll$parse$$($cljs$cst$5556$grammar$$.$cljs$core$IFn$_invoke$arity$1$($G__78371$jscomp$inline_13772_parser$jscomp$64_parser__$1$jscomp$1_result$jscomp$inline_14906$$),$p__78368_start_production$jscomp$5$$,$JSCompiler_inline_result$jscomp$inline_14908_JSCompiler_temp$jscomp$inline_14907_JSCompiler_temp$jscomp$inline_14912_text$jscomp$128$$,
$build_failure_node$jscomp$inline_14913_partial_QMARK_$jscomp$7_temp__5823__auto__$jscomp$inline_14911$$)};$instaparse$core$parse$$.$cljs$lang$maxFixedArity$=2;
$instaparse$core$parse$$.$cljs$lang$applyTo$=function($G__78367_seq78365$$){var $G__78366$$=$APP.$cljs$core$first$$($G__78367_seq78365$$),$seq78365__$1_seq78365__$2$$=$APP.$cljs$core$next$$($G__78367_seq78365$$);$G__78367_seq78365$$=$APP.$cljs$core$first$$($seq78365__$1_seq78365__$2$$);$seq78365__$1_seq78365__$2$$=$APP.$cljs$core$next$$($seq78365__$1_seq78365__$2$$);return this.$cljs$core$IFn$_invoke$arity$variadic$($G__78366$$,$G__78367_seq78365$$,$seq78365__$1_seq78365__$2$$)};
$APP.$JSCompiler_prototypeAlias$$=$instaparse$core$Parser$$.prototype;$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$2$=function($this__5323__auto__$jscomp$39$$,$k__5324__auto__$jscomp$39$$){return this.$cljs$core$ILookup$_lookup$arity$3$(null,$k__5324__auto__$jscomp$39$$,null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ILookup$_lookup$arity$3$=function($this__5325__auto__$jscomp$39$$,$k78379$$,$else__5326__auto__$jscomp$39$$){switch($k78379$$ instanceof $APP.$cljs$core$Keyword$$?$k78379$$.$fqn$:null){case "grammar":return this.$grammar$;case "start-production":return this.$start_production$;case "output-format":return this.$output_format$;default:return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k78379$$,$else__5326__auto__$jscomp$39$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IKVReduce$_kv_reduce$arity$3$=function($this__5343__auto__$jscomp$39$$,$f__5344__auto__$jscomp$39$$,$init__5345__auto__$jscomp$39$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($ret__5346__auto__$jscomp$39$$,$p__78385_v__5348__auto__$jscomp$39$$){var $k__5347__auto__$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78385_v__5348__auto__$jscomp$39$$,0,null);$p__78385_v__5348__auto__$jscomp$39$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78385_v__5348__auto__$jscomp$39$$,
1,null);return $f__5344__auto__$jscomp$39$$.$cljs$core$IFn$_invoke$arity$3$?$f__5344__auto__$jscomp$39$$.$cljs$core$IFn$_invoke$arity$3$($ret__5346__auto__$jscomp$39$$,$k__5347__auto__$jscomp$39$$,$p__78385_v__5348__auto__$jscomp$39$$):$f__5344__auto__$jscomp$39$$($ret__5346__auto__$jscomp$39$$,$k__5347__auto__$jscomp$39$$,$p__78385_v__5348__auto__$jscomp$39$$)},$init__5345__auto__$jscomp$39$$,this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($this__5338__auto__$jscomp$39$$,$writer__5339__auto__$jscomp$39$$,$opts__5340__auto__$jscomp$39$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$39$$,function($keyval__5342__auto__$jscomp$39$$){return $APP.$cljs$core$pr_sequential_writer$$($writer__5339__auto__$jscomp$39$$,$APP.$cljs$core$pr_writer$$,""," ","",$opts__5340__auto__$jscomp$39$$,$keyval__5342__auto__$jscomp$39$$)},"#instaparse.core.Parser{",
", ","}",$opts__5340__auto__$jscomp$39$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5556$grammar$$,this.$grammar$],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5557$start_production$$,this.$start_production$],null),new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5622$output_format$$,this.$output_format$],null)],null),this.$__extmap$))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IIterable$_iterator$arity$1$=function(){return new $APP.$cljs$core$RecordIter$$(this,3,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$cljs$cst$5556$grammar$$,$cljs$cst$5557$start_production$$,$cljs$cst$5622$output_format$$],null),$APP.$cljs$core$truth_$$(this.$__extmap$)?$APP.$cljs$core$_iterator$$(this.$__extmap$):$APP.$cljs$core$nil_iter$$())};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMeta$_meta$arity$1$=function(){return this.$__meta$};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICloneable$_clone$arity$1$=function(){return new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,this.$output_format$,this.$__meta$,this.$__extmap$,this.$__hash$)};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICounted$_count$arity$1$=function(){return 3+$APP.$cljs$core$count$$(this.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IHash$_hash$arity$1$=function(){var $h__5134__auto__$jscomp$69_h__5134__auto____$1$jscomp$69$$=this.$__hash$;return $h__5134__auto__$jscomp$69_h__5134__auto____$1$jscomp$69$$!=null?$h__5134__auto__$jscomp$69_h__5134__auto____$1$jscomp$69$$:this.$__hash$=$h__5134__auto__$jscomp$69_h__5134__auto____$1$jscomp$69$$=-360509877^$APP.$cljs$core$hash_unordered_coll$$(this)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IEquiv$_equiv$arity$2$=function($this78380$$,$other78381$$){return $other78381$$!=null&&this.constructor===$other78381$$.constructor&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$grammar$,$other78381$$.$grammar$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$start_production$,$other78381$$.$start_production$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$output_format$,$other78381$$.$output_format$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,
$other78381$$.$__extmap$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IMap$_dissoc$arity$2$=function($this__5333__auto__$jscomp$39$$,$k__5334__auto__$jscomp$39$$){return $APP.$cljs$core$contains_QMARK_$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5557$start_production$$,null,$cljs$cst$5556$grammar$$,null,$cljs$cst$5622$output_format$$,null],null),null),$k__5334__auto__$jscomp$39$$)?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_with_meta$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,this),
this.$__meta$),$k__5334__auto__$jscomp$39$$):new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,this.$output_format$,this.$__meta$,$APP.$cljs$core$not_empty$$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$(this.$__extmap$,$k__5334__auto__$jscomp$39$$)),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_contains_key_QMARK_$arity$2$=function($this__5330__auto__$jscomp$39$$,$k78379$jscomp$1$$){switch($k78379$jscomp$1$$ instanceof $APP.$cljs$core$Keyword$$?$k78379$jscomp$1$$.$fqn$:null){case "grammar":case "start-production":case "output-format":return!0;default:return $APP.$cljs$core$contains_QMARK_$$(this.$__extmap$,$k78379$jscomp$1$$)}};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IAssociative$_assoc$arity$3$=function($this__5331__auto__$jscomp$39$$,$k__5332__auto__$jscomp$39$$,$G__78378$jscomp$1$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5556$grammar$$,$k__5332__auto__$jscomp$39$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5556$grammar$$,$k__5332__auto__$jscomp$39$$))?
new $instaparse$core$Parser$$($G__78378$jscomp$1$$,this.$start_production$,this.$output_format$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5557$start_production$$,$k__5332__auto__$jscomp$39$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5557$start_production$$,$k__5332__auto__$jscomp$39$$))?new $instaparse$core$Parser$$(this.$grammar$,
$G__78378$jscomp$1$$,this.$output_format$,this.$__meta$,this.$__extmap$,null):$APP.$cljs$core$truth_$$($APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$?$APP.$cljs$core$keyword_identical_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5622$output_format$$,$k__5332__auto__$jscomp$39$$):$APP.$cljs$core$keyword_identical_QMARK_$$($cljs$cst$5622$output_format$$,$k__5332__auto__$jscomp$39$$))?new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,$G__78378$jscomp$1$$,
this.$__meta$,this.$__extmap$,null):new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,this.$output_format$,this.$__meta$,$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$(this.$__extmap$,$k__5332__auto__$jscomp$39$$,$G__78378$jscomp$1$$),null)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ISeqable$_seq$arity$1$=function(){return $APP.$cljs$core$seq$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$MapEntry$$($cljs$cst$5556$grammar$$,this.$grammar$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5557$start_production$$,this.$start_production$,null),new $APP.$cljs$core$MapEntry$$($cljs$cst$5622$output_format$$,this.$output_format$,
null)],null),this.$__extmap$))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IWithMeta$_with_meta$arity$2$=function($this__5322__auto__$jscomp$39$$,$G__78378$jscomp$2$$){return new $instaparse$core$Parser$$(this.$grammar$,this.$start_production$,this.$output_format$,$G__78378$jscomp$2$$,this.$__extmap$,this.$__hash$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$ICollection$_conj$arity$2$=function($this__5328__auto__$jscomp$39$$,$entry__5329__auto__$jscomp$39$$){return $APP.$cljs$core$vector_QMARK_$$($entry__5329__auto__$jscomp$39$$)?this.$cljs$core$IAssociative$_assoc$arity$3$(null,$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$39$$,0),$APP.$cljs$core$_nth$$($entry__5329__auto__$jscomp$39$$,1)):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$core$_conj$$,this,$entry__5329__auto__$jscomp$39$$)};
$APP.$JSCompiler_prototypeAlias$$.call=function($unused__14279__auto__$jscomp$32$$){switch(arguments.length-1){case 1:return this.$cljs$core$IFn$_invoke$arity$1$(arguments[1]);case 3:return this.$cljs$core$IFn$_invoke$arity$3$(arguments[1],arguments[2],arguments[3]);case 5:return this.$cljs$core$IFn$_invoke$arity$5$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5]);case 7:return this.$cljs$core$IFn$_invoke$arity$7$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],
arguments[7]);case 9:return this.$cljs$core$IFn$_invoke$arity$9$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9]);case 11:return this.$cljs$core$IFn$_invoke$arity$11$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11]);case 13:return this.$cljs$core$IFn$_invoke$arity$13$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],
arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13]);case 15:return this.$cljs$core$IFn$_invoke$arity$15$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15]);case 17:return this.$cljs$core$IFn$_invoke$arity$17$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],
arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17]);case 19:return this.$cljs$core$IFn$_invoke$arity$19$(arguments[1],arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19]);case 21:return this.$cljs$core$IFn$_invoke$arity$21$(arguments[1],
arguments[2],arguments[3],arguments[4],arguments[5],arguments[6],arguments[7],arguments[8],arguments[9],arguments[10],arguments[11],arguments[12],arguments[13],arguments[14],arguments[15],arguments[16],arguments[17],arguments[18],arguments[19],arguments[20],arguments[21]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length-1)].join(""));}};
$APP.$JSCompiler_prototypeAlias$$.apply=function($self__$jscomp$7485$$,$args78383$$){return this.call.apply(this,[this].concat($APP.$cljs$core$aclone$$($args78383$$)))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$1$=function($text$jscomp$130$$){return $instaparse$core$parse$$(this,$text$jscomp$130$$)};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$3$=function($text$jscomp$131$$,$key1$jscomp$3$$,$val1$jscomp$7$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$131$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$key1$jscomp$3$$,$val1$jscomp$7$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$5$=function($text$jscomp$132$$,$key1$jscomp$4$$,$val1$jscomp$8$$,$key2$jscomp$3$$,$val2$jscomp$7$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$132$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$key1$jscomp$4$$,$val1$jscomp$8$$,$key2$jscomp$3$$,$val2$jscomp$7$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$7$=function($text$jscomp$133$$,$key1$jscomp$5$$,$val1$jscomp$9$$,$key2$jscomp$4$$,$val2$jscomp$8$$,$key3$jscomp$1$$,$val3$jscomp$1$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$133$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$key1$jscomp$5$$,$val1$jscomp$9$$,$key2$jscomp$4$$,$val2$jscomp$8$$,$key3$jscomp$1$$,$val3$jscomp$1$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$9$=function($text$jscomp$134$$,$a$jscomp$420$$,$b$jscomp$343$$,$c$jscomp$308$$,$d$jscomp$238$$,$e$jscomp$348$$,$f$jscomp$862$$,$g$jscomp$144$$,$h$jscomp$170$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$134$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$420$$,$b$jscomp$343$$,$c$jscomp$308$$,$d$jscomp$238$$,$e$jscomp$348$$,$f$jscomp$862$$,$g$jscomp$144$$,$h$jscomp$170$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$11$=function($text$jscomp$135$$,$a$jscomp$421$$,$b$jscomp$344$$,$c$jscomp$309$$,$d$jscomp$239$$,$e$jscomp$349$$,$f$jscomp$863$$,$g$jscomp$145$$,$h$jscomp$171$$,$i$jscomp$522$$,$j$jscomp$115$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$135$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$421$$,$b$jscomp$344$$,$c$jscomp$309$$,$d$jscomp$239$$,$e$jscomp$349$$,$f$jscomp$863$$,
$g$jscomp$145$$,$h$jscomp$171$$,$i$jscomp$522$$,$j$jscomp$115$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$13$=function($text$jscomp$136$$,$a$jscomp$422$$,$b$jscomp$345$$,$c$jscomp$310$$,$d$jscomp$240$$,$e$jscomp$350$$,$f$jscomp$864$$,$g$jscomp$146$$,$h$jscomp$172$$,$i$jscomp$523$$,$j$jscomp$116$$,$k$jscomp$687$$,$l$jscomp$104$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$136$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$422$$,$b$jscomp$345$$,$c$jscomp$310$$,$d$jscomp$240$$,
$e$jscomp$350$$,$f$jscomp$864$$,$g$jscomp$146$$,$h$jscomp$172$$,$i$jscomp$523$$,$j$jscomp$116$$,$k$jscomp$687$$,$l$jscomp$104$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$15$=function($text$jscomp$137$$,$a$jscomp$423$$,$b$jscomp$346$$,$c$jscomp$311$$,$d$jscomp$241$$,$e$jscomp$351$$,$f$jscomp$865$$,$g$jscomp$147$$,$h$jscomp$173$$,$i$jscomp$524$$,$j$jscomp$117$$,$k$jscomp$688$$,$l$jscomp$105$$,$m$jscomp$234$$,$n$jscomp$301$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$137$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$423$$,$b$jscomp$346$$,
$c$jscomp$311$$,$d$jscomp$241$$,$e$jscomp$351$$,$f$jscomp$865$$,$g$jscomp$147$$,$h$jscomp$173$$,$i$jscomp$524$$,$j$jscomp$117$$,$k$jscomp$688$$,$l$jscomp$105$$,$m$jscomp$234$$,$n$jscomp$301$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$17$=function($text$jscomp$138$$,$a$jscomp$424$$,$b$jscomp$347$$,$c$jscomp$312$$,$d$jscomp$242$$,$e$jscomp$352$$,$f$jscomp$866$$,$g$jscomp$148$$,$h$jscomp$174$$,$i$jscomp$525$$,$j$jscomp$118$$,$k$jscomp$689$$,$l$jscomp$106$$,$m$jscomp$235$$,$n$jscomp$302$$,$o$jscomp$273$$,$p$jscomp$249$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$138$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$424$$,
$b$jscomp$347$$,$c$jscomp$312$$,$d$jscomp$242$$,$e$jscomp$352$$,$f$jscomp$866$$,$g$jscomp$148$$,$h$jscomp$174$$,$i$jscomp$525$$,$j$jscomp$118$$,$k$jscomp$689$$,$l$jscomp$106$$,$m$jscomp$235$$,$n$jscomp$302$$,$o$jscomp$273$$,$p$jscomp$249$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$19$=function($text$jscomp$139$$,$a$jscomp$425$$,$b$jscomp$348$$,$c$jscomp$313$$,$d$jscomp$243$$,$e$jscomp$353$$,$f$jscomp$867$$,$g$jscomp$149$$,$h$jscomp$175$$,$i$jscomp$526$$,$j$jscomp$119$$,$k$jscomp$690$$,$l$jscomp$107$$,$m$jscomp$236$$,$n$jscomp$303$$,$o$jscomp$274$$,$p$jscomp$250$$){return $instaparse$core$parse$$.$cljs$core$IFn$_invoke$arity$variadic$(this,$text$jscomp$139$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$a$jscomp$425$$,
$b$jscomp$348$$,$c$jscomp$313$$,$d$jscomp$243$$,$e$jscomp$353$$,$f$jscomp$867$$,$g$jscomp$149$$,$h$jscomp$175$$,$i$jscomp$526$$,$j$jscomp$119$$,$k$jscomp$690$$,$l$jscomp$107$$,$m$jscomp$236$$,$n$jscomp$303$$,$o$jscomp$274$$,$p$jscomp$250$$]))};
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IFn$_invoke$arity$21$=function($text$jscomp$140$$,$a$jscomp$426$$,$b$jscomp$349$$,$c$jscomp$314$$,$d$jscomp$244$$,$e$jscomp$354$$,$f$jscomp$868$$,$g$jscomp$150$$,$h$jscomp$176$$,$i$jscomp$527$$,$j$jscomp$120$$,$k$jscomp$691$$,$l$jscomp$108$$,$m$jscomp$237$$,$n$jscomp$304$$,$o$jscomp$275$$,$p$jscomp$251$$,$q$jscomp$41$$,$r$jscomp$128$$,$s$jscomp$579$$,$more$jscomp$52$$){return $APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$variadic$($instaparse$core$parse$$,
this,$text$jscomp$140$$,$a$jscomp$426$$,$b$jscomp$349$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$c$jscomp$314$$,$d$jscomp$244$$,$e$jscomp$354$$,$f$jscomp$868$$,$g$jscomp$150$$,$h$jscomp$176$$,$i$jscomp$527$$,$j$jscomp$120$$,$k$jscomp$691$$,$l$jscomp$108$$,$m$jscomp$237$$,$n$jscomp$304$$,$o$jscomp$275$$,$p$jscomp$251$$,$q$jscomp$41$$,$r$jscomp$128$$,$s$jscomp$579$$,$more$jscomp$52$$]))};$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$$=$APP.$cljs$core$PROTOCOL_SENTINEL$$;
$APP.$JSCompiler_prototypeAlias$$.$cljs$core$IPrintWithWriter$_pr_writer$arity$3$=function($parser$jscomp$77$$,$writer$jscomp$173$$){return $APP.$cljs$core$_write$$($writer$jscomp$173$$,$instaparse$print$Parser__GT_str$$(this))};var $instaparse$core$standard_whitespace_parsers$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5677$standard$$,$instaparse$core$parser$$("whitespace \x3d #'\\s+'"),$APP.$cljs$cst$5678$comma$$,$instaparse$core$parser$$("whitespace \x3d #'[,\\s]+'")],null);var $app$util$simple_math$parser$$=$instaparse$core$parser$$("opt-expr \x3d '' | expr\n     expr \x3d term (\x3cspaces\x3e ('+'|'-') \x3cspaces\x3e expr)* |\n            ('+'|'-'|'*'|'/') \x3cspaces\x3e factor\n     term \x3d factor (\x3cspaces\x3e ('*'|'/') \x3cspaces\x3e term)*\n     factor \x3d number | ('(' \x3cspaces\x3e expr \x3cspaces\x3e ')')\n     number \x3d #'[0-9]*[.,]?[0-9]+%?'\n     spaces \x3d ' '*"),$app$util$simple_math$interpret$$=function $app$util$simple_math$interpret$$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,
$init_value$$){var $G__78434_token$jscomp$128_value__$1$jscomp$36$$=$APP.$cljs$core$first$$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$),$args$jscomp$262$$=$APP.$cljs$core$rest$$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$);switch($G__78434_token$jscomp$128_value__$1$jscomp$36$$ instanceof $APP.$cljs$core$Keyword$$?$G__78434_token$jscomp$128_value__$1$jscomp$36$$.$fqn$:null){case "opt-expr":if($APP.$cljs$core$empty_QMARK_$$($args$jscomp$262$$))return null;
$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=$APP.$cljs$core$first$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,$init_value$$):$app$util$simple_math$interpret$$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,$init_value$$);
case "expr":if($APP.$cljs$core$truth_$$($APP.$clojure$string$index_of$cljs$0core$0IFn$0_invoke$0arity$02$$("+-*/",$APP.$cljs$core$first$$($args$jscomp$262$$)))){var $G__78444_G__78450_operator$$=$APP.$cljs$core$first$$($args$jscomp$262$$);$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=function(){var $G__78432$$=$APP.$cljs$core$second$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78432$$,
$init_value$$):$app$util$simple_math$interpret$$($G__78432$$,$init_value$$)}();$G__78434_token$jscomp$128_value__$1$jscomp$36$$=$G__78444_G__78450_operator$$;switch($G__78434_token$jscomp$128_value__$1$jscomp$36$$){case "+":return $init_value$$+$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$;case "-":return 0-$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$;case "*":return $init_value$$*$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$;
case "/":return $init_value$$/$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78434_token$jscomp$128_value__$1$jscomp$36$$)].join(""));}}else{$G__78434_token$jscomp$128_value__$1$jscomp$36$$=$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=function(){var $G__78436$$=$APP.$cljs$core$first$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?
$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78436$$,$init_value$$):$app$util$simple_math$interpret$$($G__78436$$,$init_value$$)}();for(var $rest_expr$$=$APP.$cljs$core$rest$$($args$jscomp$262$$);;){if($APP.$cljs$core$empty_QMARK_$$($rest_expr$$))return $G__78434_token$jscomp$128_value__$1$jscomp$36$$;$G__78444_G__78450_operator$$=$APP.$cljs$core$first$$($rest_expr$$);$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=function(){var $G__78442$$=
$APP.$cljs$core$second$$($rest_expr$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78442$$,$init_value$$):$app$util$simple_math$interpret$$($G__78442$$,$init_value$$)}();var $G__78468_G__78470_G__78473_G__78475_rest_expr__$1$$=$APP.$cljs$core$rest$$($APP.$cljs$core$rest$$($rest_expr$$));switch($G__78444_G__78450_operator$$){case "+":$G__78434_token$jscomp$128_value__$1$jscomp$36$$+=$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$;
$rest_expr$$=$G__78468_G__78470_G__78473_G__78475_rest_expr__$1$$;continue;case "-":$G__78434_token$jscomp$128_value__$1$jscomp$36$$-=$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$;$rest_expr$$=$G__78468_G__78470_G__78473_G__78475_rest_expr__$1$$;continue;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78444_G__78450_operator$$)].join(""));}break}}break;case "term":$G__78434_token$jscomp$128_value__$1$jscomp$36$$=
$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=function(){var $G__78445$$=$APP.$cljs$core$first$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78445$$,$init_value$$):$app$util$simple_math$interpret$$($G__78445$$,$init_value$$)}();for($rest_expr$$=$APP.$cljs$core$rest$$($args$jscomp$262$$);;){if($APP.$cljs$core$empty_QMARK_$$($rest_expr$$))return $G__78434_token$jscomp$128_value__$1$jscomp$36$$;
$G__78444_G__78450_operator$$=$APP.$cljs$core$first$$($rest_expr$$);$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=function(){var $G__78448$$=$APP.$cljs$core$second$$($rest_expr$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78448$$,$init_value$$):$app$util$simple_math$interpret$$($G__78448$$,$init_value$$)}();$G__78468_G__78470_G__78473_G__78475_rest_expr__$1$$=
$APP.$cljs$core$rest$$($APP.$cljs$core$rest$$($rest_expr$$));switch($G__78444_G__78450_operator$$){case "*":$G__78434_token$jscomp$128_value__$1$jscomp$36$$*=$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$;$rest_expr$$=$G__78468_G__78470_G__78473_G__78475_rest_expr__$1$$;continue;case "/":$G__78434_token$jscomp$128_value__$1$jscomp$36$$/=$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$;$rest_expr$$=$G__78468_G__78470_G__78473_G__78475_rest_expr__$1$$;
continue;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78444_G__78450_operator$$)].join(""));}break}break;case "factor":if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$first$$($args$jscomp$262$$),"("))return $G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=$APP.$cljs$core$second$$($args$jscomp$262$$),$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,
$init_value$$):$app$util$simple_math$interpret$$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,$init_value$$);$G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=$APP.$cljs$core$first$$($args$jscomp$262$$);return $app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$?$app$util$simple_math$interpret$$.$cljs$core$IFn$_invoke$arity$2$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,
$init_value$$):$app$util$simple_math$interpret$$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,$init_value$$);case "number":return $G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$=$APP.$cuerdas$core$replace$$($APP.$cljs$core$first$$($args$jscomp$262$$),",","."),$APP.$cuerdas$core$ends_with_QMARK_$$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,"%")?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$replace$$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$,
"%",""))/100*$init_value$$:$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($G__78428_G__78451_G__78454_second_value_tree$jscomp$24_value$jscomp$789_value_str$$);default:throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$(["Unknown token",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78434_token$jscomp$128_value__$1$jscomp$36$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$262$$)].join(""),$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$2261$validation$$,$APP.$cljs$cst$275$hint$$,["Unknown token",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__78434_token$jscomp$128_value__$1$jscomp$36$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($args$jscomp$262$$)].join("")],null),null])),null);}};var $app$main$ui$components$numeric_input$numeric_input_STAR_$$=(0,$APP.$rumext$v2$forward_ref$$)(function($props_78489_props__$1$jscomp$70$$,$external_ref$jscomp$1_handle_key_down$jscomp$5$$){var $value_str$jscomp$1$$=$props_78489_props__$1$jscomp$70$$.value,$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$=$props_78489_props__$1$jscomp$70$$.min,$handle_blur$jscomp$1_max_value$jscomp$3$$=$props_78489_props__$1$jscomp$70$$.max,$handle_focus$jscomp$1_step_value$$=$props_78489_props__$1$jscomp$70$$.step,
$wrap_value_QMARK_$$=$props_78489_props__$1$jscomp$70$$["data-wrap"],$on_change$jscomp$36$$=$props_78489_props__$1$jscomp$70$$.onChange,$on_blur$jscomp$8$$=$props_78489_props__$1$jscomp$70$$.onBlur,$on_focus$jscomp$5$$=$props_78489_props__$1$jscomp$70$$.onFocus,$title$jscomp$35$$=$props_78489_props__$1$jscomp$70$$.title,$default$$jscomp$92$$=$props_78489_props__$1$jscomp$70$$["default"],$nillable_QMARK_$$=$props_78489_props__$1$jscomp$70$$.nillable,$class$$jscomp$59$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_78489_props__$1$jscomp$70$$.className,
""),$min_value__$1$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$),$max_value__$1$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($handle_blur$jscomp$1_max_value$jscomp$3$$),$step_value__$1$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($handle_focus$jscomp$1_step_value$$,1),$default$__$1$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($default$$jscomp$92$$,
$APP.$cljs$core$truth_$$($nillable_QMARK_$$)?null:0),$integer_QMARK_$$=$props_78489_props__$1$jscomp$70$$.integer,$select_on_focus_QMARK_$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($props_78489_props__$1$jscomp$70$$.selectOnFocus,!0);$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)();var $ref$jscomp$48$$=$APP.$cljs$core$truth_$$($external_ref$jscomp$1_handle_key_down$jscomp$5$$)?$external_ref$jscomp$1_handle_key_down$jscomp$5$$:$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$,
$value$jscomp$791$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$value_str$jscomp$1$$)?$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$2$($value_str$jscomp$1$$,$default$__$1$$):null,$dirty_ref$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$last_value_STAR_$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$($value$jscomp$791$$),$parse_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($min_value__$1$$),
$APP.$rumext$v2$adapt$$($max_value__$1$$),$APP.$rumext$v2$adapt$$($value$jscomp$791$$),$APP.$rumext$v2$adapt$$($nillable_QMARK_$$),$APP.$rumext$v2$adapt$$($default$__$1$$),$APP.$rumext$v2$adapt$$($integer_QMARK_$$)],function(){var $G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);return $APP.$cljs$core$truth_$$($G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$)?($G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$=
$app$util$simple_math$expr_eval$$($APP.$cuerdas$core$strip_suffix$$($APP.$app$util$dom$get_value$$($G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$),"."),$value$jscomp$791$$),$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$))?($G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$=$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$truth_$$($integer_QMARK_$$)?
$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$):$G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$,-1073741824),1.0737418235E9),$G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$=$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($min_value__$1$$))?$APP.$app$common$data$max$$.$cljs$core$IFn$_invoke$arity$2$($G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$,
$min_value__$1$$):$G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$,$APP.$cljs$core$truth_$$($APP.$app$common$math$finite_QMARK_$$($max_value__$1$$))?$APP.$app$common$data$min$$.$cljs$core$IFn$_invoke$arity$2$($G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$,$max_value__$1$$):$G__78490_G__78492$jscomp$inline_13774_new_value$jscomp$10_temp__5825__auto__$jscomp$356$$):$APP.$cljs$core$truth_$$($nillable_QMARK_$$)?$default$__$1$$:
$value$jscomp$791$$):null}),$update_input$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($new_value$jscomp$11$$){var $temp__5825__auto__$jscomp$357$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$357$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$357$$,$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($new_value$jscomp$11$$)):null}),$apply_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$36$$),
$APP.$rumext$v2$adapt$$($update_input$$),$APP.$rumext$v2$adapt$$($value$jscomp$791$$)],function($event$jscomp$298$$,$new_value$jscomp$12$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$$,!1);$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$12$$,$value$jscomp$791$$)&&$APP.$cljs$core$fn_QMARK_$$($on_change$jscomp$36$$)&&($on_change$jscomp$36$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$36$$.$cljs$core$IFn$_invoke$arity$2$($new_value$jscomp$12$$,$event$jscomp$298$$):
$on_change$jscomp$36$$($new_value$jscomp$12$$,$event$jscomp$298$$));return $update_input$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$12$$):$update_input$$($new_value$jscomp$12$$)}),$set_delta$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($wrap_value_QMARK_$$),$APP.$rumext$v2$adapt$$($min_value__$1$$),$APP.$rumext$v2$adapt$$($max_value__$1$$),$APP.$rumext$v2$adapt$$($parse_value$$),$APP.$rumext$v2$adapt$$($apply_value$$)],
function($event$jscomp$299$$,$up_QMARK_$jscomp$1$$,$down_QMARK_$jscomp$1$$){var $current_value$jscomp$5$$=$parse_value$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$$(),$current_value__$1_new_value__$1_new_value__$2$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$739$$=$APP.$cljs$core$not$$($current_value$jscomp$5$$);return $and__5023__auto__$jscomp$739$$?$APP.$cljs$core$truth_$$($down_QMARK_$jscomp$1$$)?$max_value__$1$$:$down_QMARK_$jscomp$1$$:
$and__5023__auto__$jscomp$739$$}())?$max_value__$1$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$740$$=$APP.$cljs$core$not$$($current_value$jscomp$5$$);return $and__5023__auto__$jscomp$740$$?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$1$$)?$min_value__$1$$:$up_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$740$$}())?$min_value__$1$$:$APP.$cljs$core$not$$($current_value$jscomp$5$$)?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($default$__$1$$,0):$current_value$jscomp$5$$;
if($APP.$cljs$core$truth_$$($current_value__$1_new_value__$1_new_value__$2$$)){var $new_value$jscomp$13$$=$current_value__$1_new_value__$1_new_value__$2$$+($event$jscomp$299$$.shiftKey?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$1$$)?$step_value__$1$$*10:$step_value__$1$$*-10:$event$jscomp$299$$.altKey?$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$1$$)?$step_value__$1$$*.1:$step_value__$1$$*-.1:$APP.$cljs$core$truth_$$($up_QMARK_$jscomp$1$$)?$step_value__$1$$:-$step_value__$1$$);$current_value__$1_new_value__$1_new_value__$2$$=
$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($wrap_value_QMARK_$$)){var $and__5023__auto____$1$jscomp$125_and__5023__auto____$2$jscomp$45$$=$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($max_value__$1$$,$min_value__$1$$);return $and__5023__auto____$1$jscomp$125_and__5023__auto____$2$jscomp$45$$?($and__5023__auto____$1$jscomp$125_and__5023__auto____$2$jscomp$45$$=$new_value$jscomp$13$$>$max_value__$1$$)?$up_QMARK_$jscomp$1$$:$and__5023__auto____$1$jscomp$125_and__5023__auto____$2$jscomp$45$$:
$and__5023__auto____$1$jscomp$125_and__5023__auto____$2$jscomp$45$$}return $wrap_value_QMARK_$$}())?$new_value$jscomp$13$$-$max_value__$1$$+$min_value__$1$$-$step_value__$1$$:$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($wrap_value_QMARK_$$)){var $and__5023__auto____$1$jscomp$126_and__5023__auto____$2$jscomp$46$$=$APP.$app$common$data$num_QMARK_$cljs$0core$0IFn$0_invoke$0arity$02$$($max_value__$1$$,$min_value__$1$$);return $and__5023__auto____$1$jscomp$126_and__5023__auto____$2$jscomp$46$$?
($and__5023__auto____$1$jscomp$126_and__5023__auto____$2$jscomp$46$$=$new_value$jscomp$13$$<$min_value__$1$$)?$down_QMARK_$jscomp$1$$:$and__5023__auto____$1$jscomp$126_and__5023__auto____$2$jscomp$46$$:$and__5023__auto____$1$jscomp$126_and__5023__auto____$2$jscomp$46$$}return $wrap_value_QMARK_$$}())?$new_value$jscomp$13$$-$min_value__$1$$+$max_value__$1$$+$step_value__$1$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$743$$=$APP.$app$common$math$finite_QMARK_$$($min_value__$1$$);
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$743$$)?$new_value$jscomp$13$$<$min_value__$1$$:$and__5023__auto__$jscomp$743$$}())?$min_value__$1$$:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$744$$=$APP.$app$common$math$finite_QMARK_$$($max_value__$1$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$744$$)?$new_value$jscomp$13$$>$max_value__$1$$:$and__5023__auto__$jscomp$744$$}())?$max_value__$1$$:$new_value$jscomp$13$$;$current_value__$1_new_value__$1_new_value__$2$$=
$APP.$cljs$core$truth_$$($integer_QMARK_$$)?$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($current_value__$1_new_value__$1_new_value__$2$$):$current_value__$1_new_value__$1_new_value__$2$$;return $apply_value$$.$cljs$core$IFn$_invoke$arity$2$?$apply_value$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$299$$,$current_value__$1_new_value__$1_new_value__$2$$):$apply_value$$($event$jscomp$299$$,$current_value__$1_new_value__$1_new_value__$2$$)}return null});$external_ref$jscomp$1_handle_key_down$jscomp$5$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set_delta$$),$APP.$rumext$v2$adapt$$($apply_value$$),$APP.$rumext$v2$adapt$$($update_input$$),$APP.$rumext$v2$adapt$$($parse_value$$)],function($event$jscomp$300$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$$,!0);var $up_QMARK_$jscomp$2$$=(0,$APP.$app$util$keyboard$up_arrow_QMARK_$$)($event$jscomp$300$$),$down_QMARK_$jscomp$2$$=(0,$APP.$app$util$keyboard$down_arrow_QMARK_$$)($event$jscomp$300$$),$enter_QMARK_$jscomp$1$$=
(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$300$$),$esc_QMARK_$jscomp$2$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$300$$),$node$jscomp$400$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($up_QMARK_$jscomp$2$$)?$up_QMARK_$jscomp$2$$:$down_QMARK_$jscomp$2$$)&&($set_delta$$.$cljs$core$IFn$_invoke$arity$3$?$set_delta$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$300$$,$up_QMARK_$jscomp$2$$,$down_QMARK_$jscomp$2$$):$set_delta$$($event$jscomp$300$$,
$up_QMARK_$jscomp$2$$,$down_QMARK_$jscomp$2$$));$APP.$cljs$core$reset_BANG_$$($last_value_STAR_$$,$parse_value$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$$());$APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$1$$)&&$APP.$app$util$dom$blur_BANG_$$($node$jscomp$400$$);return $APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$2$$)?($update_input$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$$.$cljs$core$IFn$_invoke$arity$1$($value_str$jscomp$1$$):$update_input$$($value_str$jscomp$1$$),
$APP.$app$util$dom$blur_BANG_$$($node$jscomp$400$$)):null});$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($parse_value$$)],function(){return $APP.$cljs$core$reset_BANG_$$($last_value_STAR_$$,$parse_value$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$$())});var $handle_mouse_wheel$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($set_delta$$)],
function($event$jscomp$301$$){var $G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);if($APP.$cljs$core$truth_$$($G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$)&&$APP.$cljs$core$truth_$$($app$util$dom$active_QMARK_$$($G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$))){$APP.$app$util$dom$prevent_default$$($event$jscomp$301$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$301$$);$G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$=
$app$util$dom$get_delta_position$$($event$jscomp$301$$);$G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$=$APP.$cljs$core$__destructure_map$$($G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$);var $G__78508_y$jscomp$467$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$,$APP.$cljs$cst$1516$y$$);$G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$=$G__78508_y$jscomp$467$$<0;$G__78508_y$jscomp$467$$=
$G__78508_y$jscomp$467$$>0;return $set_delta$$.$cljs$core$IFn$_invoke$arity$3$?$set_delta$$.$cljs$core$IFn$_invoke$arity$3$($event$jscomp$301$$,$G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$,$G__78508_y$jscomp$467$$):$set_delta$$($event$jscomp$301$$,$G__78507_map__78505_map__78505__$1_temp__5825__auto__$jscomp$358$$,$G__78508_y$jscomp$467$$)}return null});$handle_blur$jscomp$1_max_value$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($parse_value$$),
$APP.$rumext$v2$adapt$$($apply_value$$),$APP.$rumext$v2$adapt$$($update_input$$),$APP.$rumext$v2$adapt$$($on_blur$jscomp$8$$)],function($event$jscomp$302$$){if($APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dirty_ref$$))){var $new_value_78530_or__5025__auto__$jscomp$inline_13776$$=$APP.$cljs$core$_deref$$($last_value_STAR_$$);$new_value_78530_or__5025__auto__$jscomp$inline_13776$$=$APP.$cljs$core$truth_$$($new_value_78530_or__5025__auto__$jscomp$inline_13776$$)?$new_value_78530_or__5025__auto__$jscomp$inline_13776$$:
$default$__$1$$;$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($nillable_QMARK_$$)?$nillable_QMARK_$$:$new_value_78530_or__5025__auto__$jscomp$inline_13776$$)?$apply_value$$.$cljs$core$IFn$_invoke$arity$2$?$apply_value$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$302$$,$new_value_78530_or__5025__auto__$jscomp$inline_13776$$):$apply_value$$($event$jscomp$302$$,$new_value_78530_or__5025__auto__$jscomp$inline_13776$$):$update_input$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$$.$cljs$core$IFn$_invoke$arity$1$($new_value_78530_or__5025__auto__$jscomp$inline_13776$$):
$update_input$$($new_value_78530_or__5025__auto__$jscomp$inline_13776$$);return $APP.$cljs$core$fn_QMARK_$$($on_blur$jscomp$8$$)?$on_blur$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$?$on_blur$jscomp$8$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$302$$):$on_blur$jscomp$8$$($event$jscomp$302$$):null}return null});var $handle_unmount$$=$app$main$ui$hooks$use_ref_callback$$($handle_blur$jscomp$1_max_value$jscomp$3$$),$on_click$jscomp$35$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$303_target$jscomp$143$$){$event$jscomp$303_target$jscomp$143$$=
$APP.$app$util$dom$get_target$$($event$jscomp$303_target$jscomp$143$$);var $node$jscomp$402$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);return $node$jscomp$402$$!=null&&$APP.$cljs$core$not$$($APP.$app$util$dom$child_QMARK_$$($node$jscomp$402$$,$event$jscomp$303_target$jscomp$143$$))?$APP.$app$util$dom$blur_BANG_$$($node$jscomp$402$$):null});$handle_focus$jscomp$1_step_value$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_focus$jscomp$5$$),$APP.$rumext$v2$adapt$$($select_on_focus_QMARK_$$)],
function($event$jscomp$304$$){$APP.$cljs$core$reset_BANG_$$($last_value_STAR_$$,$parse_value$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$$());var $target$jscomp$144$$=$APP.$app$util$dom$get_target$$($event$jscomp$304$$);$APP.$cljs$core$truth_$$($on_focus$jscomp$5$$)&&($APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$$,!0),$on_focus$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$?$on_focus$jscomp$5$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$304$$):
$on_focus$jscomp$5$$($event$jscomp$304$$));return $APP.$cljs$core$truth_$$($select_on_focus_QMARK_$$)?($APP.$app$util$dom$select_text_BANG_$$($target$jscomp$144$$),$target$jscomp$144$$.addEventListener("mouseup",$APP.$app$util$dom$prevent_default$$,{once:!0})):null});$props_78489_props__$1$jscomp$70$$=$APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$set_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$unset_BANG_$$($APP.$app$util$object$clone$$($props_78489_props__$1$jscomp$70$$),
"selectOnFocus"),"nillable"),"integer"),"value"),"onChange",$handle_change$jscomp$3_local_ref$jscomp$2_min_value$jscomp$1$$),"className",$class$$jscomp$59$$),"type","text"),"ref",$ref$jscomp$48$$),"defaultValue",$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$791$$)),"title",$title$jscomp$35$$),"onKeyDown",$external_ref$jscomp$1_handle_key_down$jscomp$5$$),"onBlur",$handle_blur$jscomp$1_max_value$jscomp$3$$),"onFocus",$handle_focus$jscomp$1_step_value$$);
$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$791$$)],function(){var $temp__5825__auto__$jscomp$359$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$359$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$359$$,$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$791$$)):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_unmount$$)],
function(){return $handle_unmount$$});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $keys$jscomp$56$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"pointerdown",$on_click$jscomp$35$$),$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"click",$on_click$jscomp$35$$)],null);return function(){return $APP.$cljs$core$run_BANG_$$($APP.$goog$events$unlistenByKey$$,
$keys$jscomp$56$$)}});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_mouse_wheel$$)],function(){var $temp__5825__auto__$jscomp$360$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$48$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$360$$)){var $key$jscomp$411$$=$APP.$goog$events$listen$$($temp__5825__auto__$jscomp$360$$,"wheel",$handle_mouse_wheel$$,{passive:!1});return function(){return $APP.$goog$events$unlistenByKey$$($key$jscomp$411$$)}}return null});
return(0,$APP.$rumext$v2$create_element$$)("input",$props_78489_props__$1$jscomp$70$$)});var $app$main$ui$components$color_input$color_input_STAR_$$=(0,$APP.$rumext$v2$forward_ref$$)(function($class$__$1$jscomp$9_props_77121$$,$external_ref$jscomp$2_handle_key_down$jscomp$6$$){var $aria_label$jscomp$8$$=void 0,$on_change$jscomp$37$$=void 0,$aria_label__$1_select_on_focus$$=void 0,$on_focus$jscomp$6$$=void 0,$value$jscomp$792$$=void 0,$on_blur$jscomp$9$$=void 0,$class$$jscomp$60_handle_focus$jscomp$2_local_ref$jscomp$3$$=void 0,$props$jscomp$301_props__$1$jscomp$71$$=void 0;({value:$value$jscomp$792$$,
onChange:$on_change$jscomp$37$$,onBlur:$on_blur$jscomp$9$$,onFocus:$on_focus$jscomp$6$$,selectOnFocus:$aria_label__$1_select_on_focus$$,className:$class$$jscomp$60_handle_focus$jscomp$2_local_ref$jscomp$3$$,"aria-label":$aria_label$jscomp$8$$,...$props$jscomp$301_props__$1$jscomp$71$$}=$class$__$1$jscomp$9_props_77121$$);var $select_on_focus_QMARK_$jscomp$1$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($aria_label__$1_select_on_focus$$,!0);$class$__$1$jscomp$9_props_77121$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($class$$jscomp$60_handle_focus$jscomp$2_local_ref$jscomp$3$$,
"color-input");$aria_label__$1_select_on_focus$$=function(){var $or__5025__auto__$jscomp$1122$$=$aria_label$jscomp$8$$;return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1122$$)?$or__5025__auto__$jscomp$1122$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("inspect.attributes.color")}();$class$$jscomp$60_handle_focus$jscomp$2_local_ref$jscomp$3$$=(0,$APP.$rumext$v2$use_ref$$)();var $ref$jscomp$50$$=$APP.$cljs$core$truth_$$($external_ref$jscomp$2_handle_key_down$jscomp$6$$)?$external_ref$jscomp$2_handle_key_down$jscomp$6$$:
$class$$jscomp$60_handle_focus$jscomp$2_local_ref$jscomp$3$$,$dirty_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(!1),$parse_value$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $input_node$jscomp$3$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$50$$);try{var $status$jscomp$inline_13782_value__$1$jscomp$37$$=$APP.$app$common$types$color$prepend_hash$$($APP.$app$common$types$color$parse$$($APP.$app$common$types$color$expand_hex$$($APP.$app$util$dom$get_value$$($input_node$jscomp$3$$))));
$input_node$jscomp$3$$!=null&&($input_node$jscomp$3$$.setCustomValidity(""),$input_node$jscomp$3$$.reportValidity());return $status$jscomp$inline_13782_value__$1$jscomp$37$$}catch($e77131$$){return $status$jscomp$inline_13782_value__$1$jscomp$37$$=$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("errors.invalid-color"),$input_node$jscomp$3$$!=null&&($input_node$jscomp$3$$.setCustomValidity($status$jscomp$inline_13782_value__$1$jscomp$37$$),$input_node$jscomp$3$$.reportValidity()),null}}),
$update_input$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($new_value$jscomp$14$$){return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($ref$jscomp$50$$),$app$common$types$color$remove_hash$$($new_value$jscomp$14$$))}),$apply_value$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$37$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$1$$)],function($new_value$jscomp$15$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$1$$,
!1);return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($new_value$jscomp$15$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($app$common$types$color$remove_hash$$($new_value$jscomp$15$$),$value$jscomp$792$$):$new_value$jscomp$15$$)?($APP.$cljs$core$truth_$$($on_change$jscomp$37$$)&&($on_change$jscomp$37$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$37$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$15$$):$on_change$jscomp$37$$($new_value$jscomp$15$$)),$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$15$$):$update_input$jscomp$1$$($new_value$jscomp$15$$)):null});$external_ref$jscomp$2_handle_key_down$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_value$jscomp$1$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$1$$)],function($event$jscomp$305$$){$APP.$rumext$v2$set_ref_val_BANG_$$($dirty_ref$jscomp$1$$,!0);var $input_node$jscomp$5$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$50$$);
if($APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$305$$))){var $value__$1$jscomp$38$$=$parse_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$jscomp$1$$();$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($value__$1$jscomp$38$$):$update_input$jscomp$1$$($value__$1$jscomp$38$$);$APP.$app$util$dom$prevent_default$$($event$jscomp$305$$);
return $APP.$app$util$dom$blur_BANG_$$($input_node$jscomp$5$$)}return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$305$$))?($update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$792$$):$update_input$jscomp$1$$($value$jscomp$792$$),$APP.$app$util$dom$prevent_default$$($event$jscomp$305$$),$APP.$app$util$dom$blur_BANG_$$($input_node$jscomp$5$$)):null});var $on_click$jscomp$36$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$306_target$jscomp$145$$){$event$jscomp$306_target$jscomp$145$$=
$APP.$app$util$dom$get_target$$($event$jscomp$306_target$jscomp$145$$);var $current$jscomp$54$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$50$$);return $current$jscomp$54$$!=null&&$APP.$cljs$core$not$$($current$jscomp$54$$.contains($event$jscomp$306_target$jscomp$145$$))?$APP.$app$util$dom$blur_BANG_$$($current$jscomp$54$$):null}),$on_mouse_up$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$307$$){return $APP.$app$util$dom$prevent_default$$($event$jscomp$307$$)});$class$$jscomp$60_handle_focus$jscomp$2_local_ref$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$308$$){var $target$jscomp$146$$=$APP.$app$util$dom$get_target$$($event$jscomp$308$$);$APP.$cljs$core$truth_$$($on_focus$jscomp$6$$)&&($on_focus$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$?$on_focus$jscomp$6$$.$cljs$core$IFn$_invoke$arity$0$():$on_focus$jscomp$6$$());return $APP.$cljs$core$truth_$$($select_on_focus_QMARK_$jscomp$1$$)?($APP.$app$util$dom$get_target$$($event$jscomp$308$$).select(),$target$jscomp$146$$.addEventListener("mouseup",
$on_mouse_up$$,{once:!0})):null});var $handle_blur$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($parse_value$jscomp$1$$),$APP.$rumext$v2$adapt$$($apply_value$jscomp$1$$),$APP.$rumext$v2$adapt$$($update_input$jscomp$1$$)],function(){var $new_value$jscomp$16$$=$parse_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$parse_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$parse_value$jscomp$1$$();$APP.$cljs$core$truth_$$($new_value$jscomp$16$$)?$apply_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$apply_value$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($new_value$jscomp$16$$):$apply_value$jscomp$1$$($new_value$jscomp$16$$):$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$update_input$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$792$$):$update_input$jscomp$1$$($value$jscomp$792$$);return $APP.$cljs$core$truth_$$($on_blur$jscomp$9$$)?$on_blur$jscomp$9$$.$cljs$core$IFn$_invoke$arity$0$?$on_blur$jscomp$9$$.$cljs$core$IFn$_invoke$arity$0$():$on_blur$jscomp$9$$():null}),$handle_blur__$1$$=
$app$main$ui$hooks$use_ref_callback$$($handle_blur$jscomp$2$$);$props$jscomp$301_props__$1$jscomp$71$$={...$props$jscomp$301_props__$1$jscomp$71$$,className:$class$__$1$jscomp$9_props_77121$$,type:"text",ref:$ref$jscomp$50$$,"aria-label":$aria_label__$1_select_on_focus$$,defaultValue:$value$jscomp$792$$,onKeyDown:$external_ref$jscomp$2_handle_key_down$jscomp$6$$,onBlur:$handle_blur__$1$$,onFocus:$class$$jscomp$60_handle_focus$jscomp$2_local_ref$jscomp$3$$};$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($value$jscomp$792$$)],
function(){var $temp__5825__auto__$jscomp$361$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$50$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$361$$)?$app$util$dom$set_value_BANG_$$($temp__5825__auto__$jscomp$361$$,$value$jscomp$792$$):null});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $APP.$cljs$core$truth_$$($APP.$rumext$v2$ref_val$$($dirty_ref$jscomp$1$$))?$handle_blur__$1$$.$cljs$core$IFn$_invoke$arity$0$?$handle_blur__$1$$.$cljs$core$IFn$_invoke$arity$0$():
$handle_blur__$1$$():null}});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $key1$jscomp$6$$=$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"pointerdown",$on_click$jscomp$36$$),$key2$jscomp$5$$=$APP.$goog$events$listen$$($APP.$app$util$globals$window$$,"click",$on_click$jscomp$36$$);return function(){$APP.$goog$events$unlistenByKey$$($key1$jscomp$6$$);return $APP.$goog$events$unlistenByKey$$($key2$jscomp$5$$)}});return(0,$APP.$rumext$v2$create_element$$)("input",
$props$jscomp$301_props__$1$jscomp$71$$)});var $app$main$ui$workspace$sidebar$assets$common$assets_filters$$=(0,$APP.$rumext$v2$create_context$$)(null),$app$main$ui$workspace$sidebar$assets$common$assets_toggle_ordering$$=(0,$APP.$rumext$v2$create_context$$)(null),$app$main$ui$workspace$sidebar$assets$common$assets_toggle_list_style$$=(0,$APP.$rumext$v2$create_context$$)(null),$app$main$ui$workspace$sidebar$assets$common$initial_context_menu_state$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4601$open_QMARK_$$,!1,$APP.$cljs$cst$1567$top$$,
null,$APP.$cljs$cst$257$left$$,null],null);var $app$main$ui$workspace$sidebar$assets$groups$schema_COLON_group_form$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$202$map$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$939$title$$,"GroupForm"],null),new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$725$name$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$972$app_DOT_common_DOT_schema_SLASH_text$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$339$max$$,250],null)],null)],null)],null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$20$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$20$$,$cljs$cst$5697$name_group_dialog$$,$app$main$ui$workspace$sidebar$assets$groups$name_group_dialog$$)});var $app$main$ui$workspace$colorpicker$libraries$convert_grouped_colors$$=function $app$main$ui$workspace$colorpicker$libraries$convert_grouped_colors$$($groups$jscomp$5$$,$resolved_file_id$$){return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$158$$,$group_key$$,$value$jscomp$801$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($acc$jscomp$158$$,$group_key$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($group_key$$,"")?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__77936_SHARP_$$){return $app$common$types$color$library_color__GT_color$$($p1__77936_SHARP_$$,
$resolved_file_id$$)},$value$jscomp$801$$):$app$main$ui$workspace$colorpicker$libraries$convert_grouped_colors$$.$cljs$core$IFn$_invoke$arity$2$?$app$main$ui$workspace$colorpicker$libraries$convert_grouped_colors$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$801$$,$resolved_file_id$$):$app$main$ui$workspace$colorpicker$libraries$convert_grouped_colors$$($value$jscomp$801$$,$resolved_file_id$$))},$APP.$cljs$core$empty$$($groups$jscomp$5$$),$groups$jscomp$5$$)},$app$main$ui$workspace$colorpicker$libraries$color_row_colorpicker_STAR_$$=
(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($gradient$jscomp$26_props_77937$$){var $color_item$jscomp$2$$=$gradient$jscomp$26_props_77937$$.colorItem,$on_click$jscomp$38$$=$gradient$jscomp$26_props_77937$$.onClick;$gradient$jscomp$26_props_77937$$=$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$);var $image$jscomp$36$$=$APP.$cljs$cst$1617$image$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$),$color$jscomp$143$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$),
$map__77938_map__77938__$1_name$jscomp$444$$=$APP.$cljs$core$meta$$($color_item$jscomp$2$$);$map__77938_map__77938__$1_name$jscomp$444$$=$APP.$cljs$core$__destructure_map$$($map__77938_map__77938__$1_name$jscomp$444$$);$map__77938_map__77938__$1_name$jscomp$444$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__77938_map__77938__$1_name$jscomp$444$$,$APP.$cljs$cst$725$name$$);var $element_id$jscomp$3$$=(0,$APP.$rumext$v2$use_id$$)(),$element_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$handle_click$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_click$jscomp$38$$),$APP.$rumext$v2$adapt$$($color_item$jscomp$2$$)],function(){return $on_click$jscomp$38$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$38$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$):$on_click$jscomp$38$$($color_item$jscomp$2$$)}),$opacity_text$jscomp$1$$=[" (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$)*
100)),"%)"].join(""),$gradient_text$$=[" (",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$color$gradient_type__GT_string$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$26_props_77937$$))),")"].join("");return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$tooltip$tooltip$tooltip_STAR_$$,{content:$APP.$app$main$ui$ds$utilities$swatch$color_title$$($color_item$jscomp$2$$),triggerRef:$element_ref$jscomp$2$$,id:$element_id$jscomp$3$$,children:(0,$APP.$rumext$v2$jsx$$)("li",
{"aria-labelledby":$element_id$jscomp$3$$,ref:$element_ref$jscomp$2$$,children:(0,$APP.$rumext$v2$jsxs$$)("button",{onKeyDown:function($e$jscomp$357$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$357$$.key,"Enter")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$357$$.key," ")?($e$jscomp$357$$.preventDefault(),$handle_click$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$handle_click$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$357$$):$handle_click$jscomp$3$$($e$jscomp$357$$)):
null},onClick:$handle_click$jscomp$3$$,className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color_item$jscomp$2$$,showTooltip:!1,size:"medium"}),$APP.$cljs$core$truth_$$($gradient$jscomp$26_props_77937$$)?$APP.$cljs$core$truth_$$($map__77938_map__77938__$1_name$jscomp$444$$)?(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker-label",
children:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__77938_map__77938__$1_name$jscomp$444$$),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker-gradient-type",children:$gradient_text$$})]}):(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker-label",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.gradient"),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker-gradient-type",
children:$gradient_text$$})]}):$APP.$cljs$core$truth_$$($image$jscomp$36$$)?(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("media.image")}):$APP.$cljs$core$truth_$$($color$jscomp$143$$)?$APP.$cljs$core$truth_$$($map__77938_map__77938__$1_name$jscomp$444$$)?(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker-label",children:[$map__77938_map__77938__$1_name$jscomp$444$$,typeof $APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$)===
"number"&&$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$)<1?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker-opacity",children:$opacity_text$jscomp$1$$}):null]}):(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker-label",children:[$color$jscomp$143$$,typeof $APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$)==="number"&&
$APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($color_item$jscomp$2$$)<1?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-row-colorpicker-opacity",children:$opacity_text$jscomp$1$$}):null]}):(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.other")})]})})})}),$app$main$ui$workspace$colorpicker$libraries$color_group_list_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function $app$main$ui$workspace$colorpicker$libraries$color_group_list_STAR_$$($direct_colors_props_77939$$){var $groups$jscomp$6_subgroups$$=
$direct_colors_props_77939$$.groups,$on_color_click$$=$direct_colors_props_77939$$.onColorClick,$on_toggle_group$$=$direct_colors_props_77939$$.onToggleGroup,$open_groups$$=$direct_colors_props_77939$$.openGroups,$prefix$jscomp$69$$=$direct_colors_props_77939$$.prefix,$resolved_file_id$jscomp$1$$=$direct_colors_props_77939$$.resolvedFileId;$direct_colors_props_77939$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($groups$jscomp$6_subgroups$$,"");$groups$jscomp$6_subgroups$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($groups$jscomp$6_subgroups$$,
"");var $is_root_QMARK_$$=$APP.$cljs$core$empty_QMARK_$$($prefix$jscomp$69$$),$collapsed_QMARK_$jscomp$1$$=!$is_root_QMARK_$$&&$APP.$cljs$core$contains_QMARK_$$($open_groups$$,$prefix$jscomp$69$$),$handle_toggle_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($prefix$jscomp$69$$),$APP.$rumext$v2$adapt$$($on_toggle_group$$)],function(){return $on_toggle_group$$.$cljs$core$IFn$_invoke$arity$1$?$on_toggle_group$$.$cljs$core$IFn$_invoke$arity$1$($prefix$jscomp$69$$):
$on_toggle_group$$($prefix$jscomp$69$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$is_root_QMARK_$$?null:(0,$APP.$rumext$v2$jsxs$$)("div",{role:"button",tabIndex:0,"aria-expanded":!$collapsed_QMARK_$jscomp$1$$,"aria-label":$prefix$jscomp$69$$,onKeyDown:function($e$jscomp$358$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$358$$.key,"Enter")||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$358$$.key," ")?($e$jscomp$358$$.preventDefault(),
$handle_toggle_group$$.$cljs$core$IFn$_invoke$arity$1$?$handle_toggle_group$$.$cljs$core$IFn$_invoke$arity$1$($e$jscomp$358$$):$handle_toggle_group$$($e$jscomp$358$$)):null},onClick:$handle_toggle_group$$,className:"main_ui_workspace_colorpicker_libraries__color-group-header",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:$collapsed_QMARK_$jscomp$1$$?"arrow-right":"arrow-down",size:"s",className:"main_ui_workspace_colorpicker_libraries__color-group-arrow"}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_colorpicker_libraries__color-group-name",children:$prefix$jscomp$69$$})]}),$collapsed_QMARK_$jscomp$1$$?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$122$$,$color$jscomp$144$$){$out_arr__44092__auto__$jscomp$122$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$libraries$color_row_colorpicker_STAR_$$,
{colorItem:$color$jscomp$144$$,onClick:$on_color_click$$},""+($APP.$cljs$cst$1741$ref_id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$144$$)??"")));return $out_arr__44092__auto__$jscomp$122$$},[],$direct_colors_props_77939$$),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$123$$,$p__77940_sub_tree$$){var $group_name$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77940_sub_tree$$,0,null);$p__77940_sub_tree$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__77940_sub_tree$$,
1,null);$out_arr__44092__auto__$jscomp$123$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$colorpicker$libraries$color_group_list_STAR_$$,{groups:$p__77940_sub_tree$$,prefix:$app$common$path_names$merge_path_item_with_dot$$($prefix$jscomp$69$$,$group_name$jscomp$2$$),resolvedFileId:$resolved_file_id$jscomp$1$$,onColorClick:$on_color_click$$,openGroups:$open_groups$$,onToggleGroup:$on_toggle_group$$},$group_name$jscomp$2$$));return $out_arr__44092__auto__$jscomp$123$$},[],$groups$jscomp$6_subgroups$$)]})]})});var $app$main$ui$workspace$colorpicker$shortcuts$shortcuts$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$shortcuts$shortcuts$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5705$delete_stop$$,new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$2957$tooltip$$,$APP.$app$main$data$shortcuts$supr$$(),$APP.$cljs$cst$1818$command$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["del","backspace"],null),$APP.$cljs$cst$4898$subsections$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4996$edit$$],null),$APP.$cljs$cst$2958$overwrite$$,!0,$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_gradient_stop$cljs$0core$0IFn$0_invoke$0arity$01$$(null))}],null)],null)]));var $app$main$ui$workspace$colorpicker$picking_color_QMARK_$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4197$picking_color_QMARK_$$,$APP.$app$main$refs$workspace_global$$),$app$main$ui$workspace$colorpicker$picked_color$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4202$picked_color$$,$APP.$app$main$refs$workspace_global$$),$app$main$ui$workspace$colorpicker$picked_color_select$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4199$picked_color_select$$,
$APP.$app$main$refs$workspace_global$$),$app$main$ui$workspace$colorpicker$viewport$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2211$vport$$,$APP.$app$main$refs$workspace_local$$);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$21$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$21$$,$APP.$cljs$cst$2247$colorpicker$$,$app$main$ui$workspace$colorpicker$colorpicker_modal$$)});var $app$main$ui$workspace$context_menu$menu_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2213$context_menu$$,$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$context_menu$shape_context_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($disable_booleans$jscomp$1_props$jscomp$303_props_78015$$){var $disable_flatten$jscomp$1_map__78018__$1$$=$APP.$cljs$core$__destructure_map$$($disable_booleans$jscomp$1_props$jscomp$303_props_78015$$.mdata);
$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($disable_flatten$jscomp$1_map__78018__$1$$,$cljs$cst$5712$disable_booleans$$);$disable_flatten$jscomp$1_map__78018__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($disable_flatten$jscomp$1_map__78018__$1$$,$cljs$cst$5713$disable_flatten$$);var $objects$jscomp$781$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$),$shape_ids$jscomp$110_shapes$jscomp$203$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$);$shape_ids$jscomp$110_shapes$jscomp$203$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$getf$$($objects$jscomp$781$$),$shape_ids$jscomp$110_shapes$jscomp$203$$);var $is_not_variant_container_QMARK_$$=$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__78014_SHARP_$$){return!$APP.$app$common$types$component$is_variant_container_QMARK_$$($p1__78014_SHARP_$$)},$shape_ids$jscomp$110_shapes$jscomp$203$$);
$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$={shapes:$shape_ids$jscomp$110_shapes$jscomp$203$$,objects:$objects$jscomp$781$$,disableBooleans:$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$,disableFlatten:$disable_flatten$jscomp$1_map__78018__$1$$};return $APP.$cljs$core$empty_QMARK_$$($shape_ids$jscomp$110_shapes$jscomp$203$$)?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_edit_STAR_$$,
$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_layer_position_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),$APP.$cljs$core$truth_$$($is_not_variant_container_QMARK_$$)?(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_flip_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$):null,(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_thumbnail_STAR_$$,
$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_rename_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_group_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_focus_mode_menu_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_path_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_layer_options_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_prototype_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),$APP.$cljs$core$truth_$$($is_not_variant_container_QMARK_$$)?
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_layout_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$):null,(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_component_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_guides_STAR_$$,$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$context_menu$context_menu_delete_STAR_$$,
$disable_booleans$jscomp$1_props$jscomp$303_props_78015$$)]})}),$app$main$ui$workspace$context_menu$guide_color_presets$$=new $APP.$cljs$core$PersistentVector$$(null,8,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,"#ff3277 #4dabf7 #51cf66 #fcc419 #ff922b #cc5de8 #ffffff #868e96".split(" "),null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$22$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$22$$,$cljs$cst$5715$tokens_SLASH_import_from_library$$,$app$main$ui$workspace$tokens$import_from_library$import_modal_library_STAR_$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$23$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$23$$,$APP.$cljs$cst$4038$libraries_dialog$$,$app$main$ui$workspace$libraries$libraries_dialog$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$24$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$24$$,$cljs$cst$5725$v2_info$$,$app$main$ui$workspace$libraries$v2_info_dialog$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$25$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$25$$,$cljs$cst$5726$nudge_option$$,$app$main$ui$workspace$nudge$nudge_modal$$)});var $app$main$ui$workspace$color_palette$palette_item_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78495_size$jscomp$151$$){var $selected$jscomp$147$$=$props_78495_size$jscomp$151$$.selected,$color$jscomp$158$$=$props_78495_size$jscomp$151$$.color;$props_78495_size$jscomp$151$$=$props_78495_size$jscomp$151$$.size;var $select_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($color$jscomp$158$$),$APP.$rumext$v2$adapt$$($selected$jscomp$147$$)],
function($event$jscomp$347$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$colors$add_recent_color$$($color$jscomp$158$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$colors$apply_color_from_palette$$($color$jscomp$158$$,$event$jscomp$347$$.altKey),$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$147$$,$cljs$cst$5702$recent$$)?$APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"use-library-color",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"color-palette",$APP.$cljs$cst$4001$external_library$$,$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$147$$,$APP.$cljs$cst$208$file$$)],null)):null]))}),$title$jscomp$38$$=$app$util$color$get_color_name$$($color$jscomp$158$$);return(0,$APP.$rumext$v2$jsxs$$)("button",{title:$title$jscomp$38$$,"aria-label":$title$jscomp$38$$,
type:"button",onClick:$select_color$$,className:"main_ui_workspace_color_palette__color-cell "+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$158$$)==null?"main_ui_workspace_color_palette__is-not-library-color":"")+" "+($props_78495_size$jscomp$151$$<=64?"main_ui_workspace_color_palette__no-text":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color$jscomp$158$$,size:"medium"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$color_bullet$color_name_STAR_$$,
{color:$color$jscomp$158$$,size:$props_78495_size$jscomp$151$$,origin:$APP.$cljs$cst$4867$palette$$})]})}),$app$main$ui$workspace$color_palette$palette_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78503_search_open_QMARK_$$){var $selected$jscomp$148$$=$props_78503_search_open_QMARK_$$.selected,$width$jscomp$191_width__$1$jscomp$8$$=$props_78503_search_open_QMARK_$$.width,$colors$jscomp$15$$=$props_78503_search_open_QMARK_$$.colors,$size$jscomp$152$$=$props_78503_search_open_QMARK_$$.size,
$state$jscomp$1192$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5727$show_menu$$,!1],null)}),$search_term_STAR_$jscomp$1$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$search_term$jscomp$4$$=$APP.$cljs$core$_deref$$($search_term_STAR_$jscomp$1$$),$search_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$props_78503_search_open_QMARK_$$=$APP.$cljs$core$_deref$$($search_open_STAR_$$);
var $has_colors_QMARK_$$=$APP.$cljs$core$seq$$($colors$jscomp$15$$),$filtered_colors$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($colors$jscomp$15$$),$APP.$rumext$v2$adapt$$($search_term$jscomp$4$$)],function(){return $APP.$cljs$core$empty_QMARK_$$($search_term$jscomp$4$$)?$colors$jscomp$15$$:$APP.$cljs$core$filterv$$(function($or__5025__auto__$jscomp$inline_8961_p1__78496_SHARP_$$){$or__5025__auto__$jscomp$inline_8961_p1__78496_SHARP_$$=$app$util$color$get_color_name$$($or__5025__auto__$jscomp$inline_8961_p1__78496_SHARP_$$);
return $app$util$strings$matches_search$$($APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8961_p1__78496_SHARP_$$)?$or__5025__auto__$jscomp$inline_8961_p1__78496_SHARP_$$:"",$search_term$jscomp$4$$)},$colors$jscomp$15$$)}),$on_search_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__78497_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$1$$,$p1__78497_SHARP_$$)}),$on_toggle_search$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($search_open_STAR_$$))&&
$APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$1$$,"");return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($search_open_STAR_$$,$APP.$cljs$core$not$$)}),$on_search_clear$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$1$$,"");return $APP.$cljs$core$reset_BANG_$$($search_open_STAR_$$,!1)}),$offset_step$$=$size$jscomp$152$$<=64?40:72,$search_width_show_arrows_QMARK_$$=$APP.$cljs$core$not$$($has_colors_QMARK_$$)?
0:$APP.$cljs$core$truth_$$($props_78503_search_open_QMARK_$$)?192:32;$width$jscomp$191_width__$1$jscomp$8$$-=$size$jscomp$152$$<=64?164+$search_width_show_arrows_QMARK_$$:132+$search_width_show_arrows_QMARK_$$;var $offset$jscomp$209_visible$jscomp$1$$=$width$jscomp$191_width__$1$jscomp$8$$/$offset_step$$|0,$on_scroll_visible__$1$$=($search_width_show_arrows_QMARK_$$=$APP.$cljs$core$count$$($filtered_colors$$)>$offset$jscomp$209_visible$jscomp$1$$)?($width$jscomp$191_width__$1$jscomp$8$$-48)/$offset_step$$|
0:$offset$jscomp$209_visible$jscomp$1$$;$offset$jscomp$209_visible$jscomp$1$$=$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($state$jscomp$1192$$),0);var $max_offset$jscomp$2$$=$APP.$cljs$core$count$$($filtered_colors$$)-$on_scroll_visible__$1$$,$container$jscomp$83$$=(0,$APP.$rumext$v2$use_ref$$)(null),$bullet_size$$=$size$jscomp$152$$<=64?"32":$size$jscomp$152$$<=72?"28":"32",$color_cell_width$$=$size$jscomp$152$$<=64?32:64,$on_left_arrow_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$2$$),
$APP.$rumext$v2$adapt$$($on_scroll_visible__$1$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1192$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$195$offset$$,function($offset__$1$jscomp$23_x__5110__auto__$jscomp$137$$){return $offset__$1$jscomp$23_x__5110__auto__$jscomp$137$$>0?(--$offset__$1$jscomp$23_x__5110__auto__$jscomp$137$$,$offset__$1$jscomp$23_x__5110__auto__$jscomp$137$$>0?$offset__$1$jscomp$23_x__5110__auto__$jscomp$137$$:0):$offset__$1$jscomp$23_x__5110__auto__$jscomp$137$$})}),
$on_right_arrow_click$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_scroll_visible__$1$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1192$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$195$offset$$,function($offset__$1$jscomp$24_y__5114__auto__$jscomp$76$$){return $offset__$1$jscomp$24_y__5114__auto__$jscomp$76$$<$max_offset$jscomp$2$$?($offset__$1$jscomp$24_y__5114__auto__$jscomp$76$$+=
1,$max_offset$jscomp$2$$<$offset__$1$jscomp$24_y__5114__auto__$jscomp$76$$?$max_offset$jscomp$2$$:$offset__$1$jscomp$24_y__5114__auto__$jscomp$76$$):$offset__$1$jscomp$24_y__5114__auto__$jscomp$76$$})});$on_scroll_visible__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($max_offset$jscomp$2$$)],function($event$jscomp$348_event__$1$jscomp$4$$){$event$jscomp$348_event__$1$jscomp$4$$=$event$jscomp$348_event__$1$jscomp$4$$.nativeEvent;return $event$jscomp$348_event__$1$jscomp$4$$.deltaY+
$event$jscomp$348_event__$1$jscomp$4$$.deltaX>0?$on_right_arrow_click$$.$cljs$core$IFn$_invoke$arity$1$?$on_right_arrow_click$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$348_event__$1$jscomp$4$$):$on_right_arrow_click$$($event$jscomp$348_event__$1$jscomp$4$$):$on_left_arrow_click$$.$cljs$core$IFn$_invoke$arity$1$?$on_left_arrow_click$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$348_event__$1$jscomp$4$$):$on_left_arrow_click$$($event$jscomp$348_event__$1$jscomp$4$$)});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],
function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1192$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$290$width$$,$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($container$jscomp$83$$),"clientWidth"))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($width$jscomp$191_width__$1$jscomp$8$$),$APP.$rumext$v2$adapt$$($filtered_colors$$)],function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,
$APP.$cljs$cst$195$offset$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1192$$)))?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state$jscomp$1192$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$195$offset$$,0):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($has_colors_QMARK_$$)],function(){if($has_colors_QMARK_$$)return null;$APP.$cljs$core$reset_BANG_$$($search_open_STAR_$$,!1);return $APP.$cljs$core$reset_BANG_$$($search_term_STAR_$jscomp$1$$,
"")});return(0,$APP.$rumext$v2$jsxs$$)("div",{style:{"--bullet-size":""+($bullet_size$$??"")+"px","--color-cell-width":""+($color_cell_width$$??"")+"px"},className:"main_ui_workspace_color_palette__color-palette "+($size$jscomp$152$$<64?"main_ui_workspace_color_palette__no-text":""),children:[$has_colors_QMARK_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:($APP.$cljs$core$truth_$$($props_78503_search_open_QMARK_$$)?"main_ui_workspace_color_palette__palette-search":"")+" "+($APP.$cljs$core$not$$($props_78503_search_open_QMARK_$$)?
"main_ui_workspace_color_palette__palette-search-collapsed":""),children:[$APP.$cljs$core$truth_$$($props_78503_search_open_QMARK_$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_search_change$jscomp$1$$,onClear:$on_search_clear$$,value:$search_term$jscomp$4$$,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.search"),autoFocus:!0}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost",icon:"search",onClick:$on_toggle_search$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.search")})]}):null,$search_width_show_arrows_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$209_visible$jscomp$1$$,0),onClick:$on_left_arrow_click$$,className:"main_ui_workspace_color_palette__left-arrow",children:$APP.$app$main$ui$icons$arrow$$}):null,(0,$APP.$rumext$v2$jsx$$)("div",
{ref:$container$jscomp$83$$,onWheel:$on_scroll_visible__$1$$,className:"main_ui_workspace_color_palette__color-palette-content",children:$APP.$cljs$core$empty_QMARK_$$($filtered_colors$$)?(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"absolute",left:"50%",top:"50%",transform:"translate(-50%, -50%)"},className:"main_ui_workspace_color_palette__color-palette-empty",children:$APP.$cljs$core$empty_QMARK_$$($search_term$jscomp$4$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.colors.empty-palette"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.not-found")}):(0,$APP.$rumext$v2$jsx$$)("div",{style:{position:"relative",maxWidth:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$191_width__$1$jscomp$8$$),"px"].join(""),right:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($offset_step$$*$offset$jscomp$209_visible$jscomp$1$$),"px"].join("")},className:"main_ui_workspace_color_palette__color-palette-inside",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$134$$,
$item$jscomp$128_p__78516$$){var $idx$jscomp$115$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$128_p__78516$$,0,null);$item$jscomp$128_p__78516$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($item$jscomp$128_p__78516$$,1,null);$out_arr__44092__auto__$jscomp$134$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$color_palette$palette_item_STAR_$$,{color:$item$jscomp$128_p__78516$$,size:$size$jscomp$152$$,selected:$selected$jscomp$148$$},$idx$jscomp$115$$));
return $out_arr__44092__auto__$jscomp$134$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$filtered_colors$$))})}),$search_width_show_arrows_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($offset$jscomp$209_visible$jscomp$1$$,$max_offset$jscomp$2$$),onClick:$on_right_arrow_click$$,className:"main_ui_workspace_color_palette__right-arrow",children:$APP.$app$main$ui$icons$arrow$$}):null]})}),
$app$main$ui$workspace$color_palette$color_palette_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78540_props__$1$jscomp$74$$){var $selected$jscomp$149$$=$props_78540_props__$1$jscomp$74$$.selected,$file_id$jscomp$381$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$149$$,$cljs$cst$5702$recent$$))return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$color_palette$recent_colors_palette_STAR_$$,
$props_78540_props__$1$jscomp$74$$);$props_78540_props__$1$jscomp$74$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($selected$jscomp$149$$,$APP.$cljs$cst$208$file$$)?{...$props_78540_props__$1$jscomp$74$$,fileId:$file_id$jscomp$381$$}:{...$props_78540_props__$1$jscomp$74$$,fileId:$selected$jscomp$149$$};return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$color_palette$file_color_palette_STAR_$$,$props_78540_props__$1$jscomp$74$$)});var $app$main$ui$workspace$color_palette_ctx_menu$xf_COLON_sample_colors$$=$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$val$$),$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$1$(7));var $app$main$ui$workspace$text_palette$text_palette_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78570_size$jscomp$155$$){var $selected$jscomp$152$$=$props_78570_size$jscomp$155$$.selected,$width$jscomp$193$$=$props_78570_size$jscomp$155$$.width;$props_78570_size$jscomp$155$$=$props_78570_size$jscomp$155$$.size;var $selected_ids$jscomp$9$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_shapes$$),$file_typographies$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),
$libraries$jscomp$146$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$),$current_file_id$jscomp$18$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$text_palette$palette_STAR_$$,{currentFileId:$current_file_id$jscomp$18$$,selectedIds:$selected_ids$jscomp$9$$,fileTypographies:$file_typographies$jscomp$1$$,libraries:$libraries$jscomp$146$$,width:$width$jscomp$193$$,selected:$selected$jscomp$152$$,size:$props_78570_size$jscomp$155$$})});var $app$main$ui$workspace$palette$ref_COLON_viewport$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2211$vport$$,$APP.$app$main$refs$workspace_local$$);var $app$main$ui$workspace$main_menu$help_info_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($plugins_QMARK__props_78655$$){var $on_close$jscomp$19$$=$plugins_QMARK__props_78655$$.onClose,$layout$jscomp$20$$=$plugins_QMARK__props_78655$$.layout,$nav_to_helpc_center$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-help-center-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://help.penpot.app")}),$nav_to_community$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-community-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://community.penpot.app")}),$nav_to_youtube$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-tutorials-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://www.youtube.com/c/Penpot")}),$nav_to_templates$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-libraries-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/libraries-templates")}),$nav_to_github$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-github-repository-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://github.com/penpot/penpot")}),$nav_to_terms$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"explore-terms-service-click",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"],null)));return $APP.$app$util$dom$open_new_window$cljs$0core$0IFn$0_invoke$0arity$01$$("https://penpot.app/terms")}),$nav_to_feedback$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$common$go_to_feedback$$())});
$plugins_QMARK__props_78655$$=$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime");var $mcp_enabled_QMARK_$jscomp$1$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1237$mcp$$),$show_shortcuts$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout$jscomp$20$$)],function(){$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$20$$,$cljs$cst$5729$collapse_left_sidebar$$)&&
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($cljs$cst$5729$collapse_left_sidebar$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$2961$shortcuts$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu"))}),$show_release_notes$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$353$$){var $version$jscomp$26$$=$APP.$cljs$cst$1285$main$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$config$version$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"show-release-notes",$APP.$cljs$cst$1726$version$$,$version$jscomp$26$$],null)));$APP.$cljs$core$println$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$version$jscomp$26$$]));
return $event$jscomp$353$$.altKey&&$APP.$app$util$keyboard$mod_QMARK_$$($event$jscomp$353$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1223$onboarding$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$5476$release_notes$$,$APP.$cljs$cst$1726$version$$,$version$jscomp$26$$],null)))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,onClose:$on_close$jscomp$19$$,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu "+($plugins_QMARK__props_78655$$||$mcp_enabled_QMARK_$jscomp$1$$?"":"main_ui_workspace_main_menu__pos-final-5")+" "+($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($plugins_QMARK__props_78655$$,
$mcp_enabled_QMARK_$jscomp$1$$)?"main_ui_workspace_main_menu__pos-final-6":"")+" "+($plugins_QMARK__props_78655$$&&$mcp_enabled_QMARK_$jscomp$1$$?"main_ui_workspace_main_menu__pos-final-7":""),children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_helpc_center$$,onKeyDown:function($event$jscomp$354$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$354$$))?
$nav_to_helpc_center$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_helpc_center$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$354$$):$nav_to_helpc_center$$($event$jscomp$354$$):null},id:"file-menu-help-center",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onClick:$nav_to_community$$,onKeyDown:function($event$jscomp$355$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$355$$))?$nav_to_community$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_community$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$355$$):$nav_to_community$$($event$jscomp$355$$):null},id:"file-menu-community",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.community")})}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_youtube$$,onKeyDown:function($event$jscomp$356$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$356$$))?$nav_to_youtube$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_youtube$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$356$$):$nav_to_youtube$$($event$jscomp$356$$):
null},id:"file-menu-youtube",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.tutorials")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$show_release_notes$jscomp$1$$,onKeyDown:function($event$jscomp$357$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$357$$))?
$show_release_notes$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$show_release_notes$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$357$$):$show_release_notes$jscomp$1$$($event$jscomp$357$$):null},id:"file-menu-release-notes",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.release-notes")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_templates$$,onKeyDown:function($event$jscomp$358$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$358$$))?$nav_to_templates$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_templates$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$358$$):$nav_to_templates$$($event$jscomp$358$$):null},id:"file-menu-templates",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.libraries-and-templates")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_github$$,onKeyDown:function($event$jscomp$359$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$359$$))?
$nav_to_github$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_github$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$359$$):$nav_to_github$$($event$jscomp$359$$):null},id:"file-menu-github",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.github-repo")})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onClick:$nav_to_terms$$,onKeyDown:function($event$jscomp$360$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$360$$))?$nav_to_terms$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_terms$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$360$$):$nav_to_terms$$($event$jscomp$360$$):null},id:"file-menu-terms",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("auth.terms-of-service")})}),
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$show_shortcuts$$,onKeyDown:function($event$jscomp$361$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$361$$))?$show_shortcuts$$.$cljs$core$IFn$_invoke$arity$1$?$show_shortcuts$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$361$$):$show_shortcuts$$($event$jscomp$361$$):
null},id:"file-menu-shortcuts",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("label.shortcuts")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4979$show_shortcuts$$})]}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1228$user_feedback$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$nav_to_feedback$$,onKeyDown:function($event$jscomp$362$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$362$$))?$nav_to_feedback$$.$cljs$core$IFn$_invoke$arity$1$?$nav_to_feedback$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$362$$):$nav_to_feedback$$($event$jscomp$362$$):null},id:"file-menu-feedback",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__feedback main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.give-feedback")})}):null]})}),$app$main$ui$workspace$main_menu$preferences_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78672_renderer$jscomp$1$$){var $toggle_theme$$=$props_78672_renderer$jscomp$1$$.toggleTheme,$profile$jscomp$77$$=$props_78672_renderer$jscomp$1$$.profile,$toggle_render$$=$props_78672_renderer$jscomp$1$$.toggleRender,$on_close$jscomp$20$$=$props_78672_renderer$jscomp$1$$.onClose,
$layout$jscomp$21$$=$props_78672_renderer$jscomp$1$$.layout,$toggle_flag$$=$props_78672_renderer$jscomp$1$$.toggleFlag;$props_78672_renderer$jscomp$1$$=function(){var $or__5025__auto__$jscomp$1157$$=$APP.$cljs$cst$3129$renderer$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$575$props$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$77$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1157$$)?$or__5025__auto__$jscomp$1157$$:$APP.$cljs$cst$1543$svg$$}();var $show_nudge_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$139$type$$,$cljs$cst$5726$nudge_option$$],null))});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-4",onClose:$on_close$jscomp$20$$,children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$toggle_flag$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onKeyDown:function($event$jscomp$363$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$363$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$363$$):$toggle_flag$$($event$jscomp$363$$):null},"data-testid":"scale-text",id:"file-menu-scale-text",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$21$$,
$APP.$cljs$cst$3765$scale_text$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-scale-content"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-scale-content")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$1910$scale$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$toggle_flag$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",
onKeyDown:function($event$jscomp$364$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$364$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$364$$):$toggle_flag$$($event$jscomp$364$$):null},"data-testid":"snap-ruler-guides",id:"file-menu-snap-ruler-guides",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$21$$,
$APP.$cljs$cst$3773$snap_ruler_guides$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-snap-ruler-guides"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-snap-ruler-guides")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4924$toggle_snap_ruler_guide$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$toggle_flag$$,
className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$365$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$365$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$365$$):$toggle_flag$$($event$jscomp$365$$):null},"data-testid":"snap-guides",id:"file-menu-snap-guides",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$21$$,$APP.$cljs$cst$3769$snap_guides$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-snap-guides"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-snap-guides")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4959$toggle_snap_guides$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$toggle_flag$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$366$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$366$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$366$$):$toggle_flag$$($event$jscomp$366$$):null},"data-testid":"dynamic-alignment",id:"file-menu-dynamic-alignment",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$21$$,$APP.$cljs$cst$3774$dynamic_alignment$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-dynamic-alignment"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-dynamic-alignment")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4972$toggle_alignment$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$toggle_flag$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$367$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$367$$))?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$367$$):$toggle_flag$$($event$jscomp$367$$):null},"data-testid":"snap-pixel-grid",id:"file-menu-pixel-grid",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$21$$,$APP.$cljs$cst$2218$snap_pixel_grid$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-snap-pixel-grid"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-snap-pixel-grid")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$2218$snap_pixel_grid$$})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$show_nudge_options$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$368$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$368$$))?$show_nudge_options$$.$cljs$core$IFn$_invoke$arity$1$?$show_nudge_options$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$368$$):$show_nudge_options$$($event$jscomp$368$$):null},"data-testid":"snap-pixel-grid",id:"file-menu-nudge",children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("modals.nudge-title")})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$toggle_theme$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$369$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$369$$))?$toggle_theme$$.$cljs$core$IFn$_invoke$arity$1$?
$toggle_theme$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$369$$):$toggle_theme$$($event$jscomp$369$$):null},"data-testid":"toggle-theme",id:"file-menu-toggle-theme",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:function(){switch($APP.$cljs$cst$3208$theme$$.$cljs$core$IFn$_invoke$arity$1$($profile$jscomp$77$$)){case "dark":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.toggle-light-theme");case "light":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.toggle-system-theme");
case "system":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.toggle-dark-theme");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.toggle-light-theme")}}()}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4986$toggle_theme$$})]}),$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1198$render_switch$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{onClick:$toggle_render$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$370$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$370$$))?$toggle_render$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_render$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$370$$):$toggle_render$$($event$jscomp$370$$):null},children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($props_78672_renderer$jscomp$1$$,$APP.$cljs$cst$3128$wasm$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.disable-webgl"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.enable-webgl")})}):null]})}),$app$main$ui$workspace$main_menu$view_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78676_read_only_QMARK_$jscomp$11$$){var $on_close$jscomp$21$$=
$props_78676_read_only_QMARK_$jscomp$11$$.onClose,$layout$jscomp$22$$=$props_78676_read_only_QMARK_$jscomp$11$$.layout,$toggle_flag$jscomp$1$$=$props_78676_read_only_QMARK_$jscomp$11$$.toggleFlag;$props_78676_read_only_QMARK_$jscomp$11$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);var $toggle_color_palette$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1568$bottom$$;
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3790$textpalette$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3764$colorpalette$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu")]))}),$toggle_text_palette$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$ui$hooks$resize$last_resize_type$$=$APP.$cljs$cst$1568$bottom$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$3764$colorpalette$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($APP.$cljs$cst$3790$textpalette$$),
$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu")]))}),$toggle_comments_visibility$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_close$jscomp$21$$)],function($event$jscomp$371$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$371$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$comments$toggle_comments_visibility$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1792$origin$$,"workspace:menu"],null)])));return $on_close$jscomp$21$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$21$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$21$$()});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-3",onClose:$on_close$jscomp$21$$,children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$372$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$372$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$372$$):$toggle_flag$jscomp$1$$($event$jscomp$372$$):null},"data-testid":"rulers",id:"file-menu-rulers",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$22$$,$APP.$cljs$cst$2219$rulers$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-rules"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-rules")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4983$toggle_rulers$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$373$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$373$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$373$$):$toggle_flag$jscomp$1$$($event$jscomp$373$$):null},"data-testid":"display-guides",id:"file-menu-guides",
children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$22$$,$APP.$cljs$cst$3775$display_guides$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-guides"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-guides")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4937$toggle_guides$$})]}),
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$374$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$374$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$374$$):$toggle_flag$jscomp$1$$($event$jscomp$374$$):
null},"data-testid":"lock-guides",id:"file-menu-lock-guides",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$22$$,$APP.$cljs$cst$3770$lock_guides$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.unlock-guides"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.lock-guides")})}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_comments_visibility$$,onKeyDown:function($event$jscomp$375$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$375$$))?$toggle_comments_visibility$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_comments_visibility$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$375$$):$toggle_comments_visibility$$($event$jscomp$375$$):null},"data-testid":"display-comments",
id:"file-menu-comments",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$22$$,$APP.$cljs$cst$3771$display_comments$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-comments"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-comments")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4963$toggle_comments_visibility$$})]}),
$props_78676_read_only_QMARK_$jscomp$11$$?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_color_palette$$,onKeyDown:function($event$jscomp$376$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$376$$))?$toggle_color_palette$$.$cljs$core$IFn$_invoke$arity$1$?
$toggle_color_palette$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$376$$):$toggle_color_palette$$($event$jscomp$376$$):null},id:"file-menu-color-palette",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$22$$,$APP.$cljs$cst$3764$colorpalette$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-palette"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-palette")}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4920$toggle_colorpalette$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_text_palette$$,onKeyDown:function($event$jscomp$377$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$377$$))?$toggle_text_palette$$.$cljs$core$IFn$_invoke$arity$1$?
$toggle_text_palette$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$377$$):$toggle_text_palette$$($event$jscomp$377$$):null},id:"file-menu-text-palette",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$22$$,$APP.$cljs$cst$3790$textpalette$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-textpalette"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-textpalette")}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4965$toggle_textpalette$$})]})]}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$378$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$378$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?
$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$378$$):$toggle_flag$jscomp$1$$($event$jscomp$378$$):null},"data-testid":"display-artboard-names",id:"file-menu-artboards",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$22$$,$APP.$cljs$cst$3772$display_artboard_names$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-artboard-names"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-artboard-names")})}),
$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$379$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$379$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$379$$):$toggle_flag$jscomp$1$$($event$jscomp$379$$):
null},"data-testid":"show-pixel-grid",id:"file-menu-pixel-grid",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$22$$,$APP.$cljs$cst$3766$show_pixel_grid$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.hide-pixel-grid"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.show-pixel-grid")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,
{id:$APP.$cljs$cst$3766$show_pixel_grid$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$toggle_flag$jscomp$1$$,onKeyDown:function($event$jscomp$380$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$380$$))?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$toggle_flag$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$380$$):
$toggle_flag$jscomp$1$$($event$jscomp$380$$):null},"data-testid":"hide-ui",id:"file-menu-hide-ui",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.hide-ui")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$3046$hide_ui$$})]})]})}),$app$main$ui$workspace$main_menu$edit_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($can_edit$jscomp$3_perms$jscomp$1_props_78679$$){var $on_close$jscomp$22$$=
$can_edit$jscomp$3_perms$jscomp$1_props_78679$$.onClose;$can_edit$jscomp$3_perms$jscomp$1_props_78679$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$permissions$$);$can_edit$jscomp$3_perms$jscomp$1_props_78679$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($can_edit$jscomp$3_perms$jscomp$1_props_78679$$);var $select_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_all$$())}),
$find$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$on_close$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$22$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4905$find$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3784$force_QMARK_$$,!0],null)))}),
$find_and_replace$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$on_close$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$22$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$22$$();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$open_layers_search$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4602$find_and_replace$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3784$force_QMARK_$$,
!0],null)))}),$undo$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$undo$$)}),$redo$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$redo$$)});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-2",onClose:$on_close$jscomp$22$$,children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$select_all$$,onKeyDown:function($event$jscomp$381$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$381$$))?
$select_all$$.$cljs$core$IFn$_invoke$arity$1$?$select_all$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$381$$):$select_all$$($event$jscomp$381$$):null},id:"file-menu-select-all",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.select-all")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4954$select_all$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$find$jscomp$4$$,onKeyDown:function($event$jscomp$382$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$382$$))?$find$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$?$find$jscomp$4$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$382$$):$find$jscomp$4$$($event$jscomp$382$$):null},id:"file-menu-find",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.find")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4905$find$$})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$find_and_replace$$,onKeyDown:function($event$jscomp$383$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$383$$))?
$find_and_replace$$.$cljs$core$IFn$_invoke$arity$1$?$find_and_replace$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$383$$):$find_and_replace$$($event$jscomp$383$$):null},id:"file-menu-find-and-replace",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.find-and-replace")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4602$find_and_replace$$})]}),
$APP.$cljs$core$truth_$$($can_edit$jscomp$3_perms$jscomp$1_props_78679$$)?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$undo$jscomp$6$$,onKeyDown:function($event$jscomp$384$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$384$$))?$undo$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$?$undo$jscomp$6$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$384$$):
$undo$jscomp$6$$($event$jscomp$384$$):null},id:"file-menu-undo",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.undo")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4961$undo$$})]}):null,$APP.$cljs$core$truth_$$($can_edit$jscomp$3_perms$jscomp$1_props_78679$$)?$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,
{className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onClick:$redo$jscomp$1$$,onKeyDown:function($event$jscomp$385$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$385$$))?$redo$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$redo$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$385$$):$redo$jscomp$1$$($event$jscomp$385$$):null},id:"file-menu-redo",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.menu.redo")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$4934$redo$$})]}):null]})}),$app$main$ui$workspace$main_menu$plugins_menu_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_close$jscomp$24_props_78683$$){var $open_plugins$$=$on_close$jscomp$24_props_78683$$.openPlugins;$on_close$jscomp$24_props_78683$$=$on_close$jscomp$24_props_78683$$.onClose;
if($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")){var $plugins$jscomp$1$$=$APP.$app$plugins$register$plugins_list$$(),$user_can_edit_QMARK_$jscomp$3$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$permissions$$)),$permissions_peek$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$plugins_permissions_peek$$);return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_STAR_$$,
{show:!0,className:"main_ui_workspace_main_menu__base-menu main_ui_workspace_main_menu__sub-menu main_ui_workspace_main_menu__pos-5 main_ui_workspace_main_menu__plugins",onClose:$on_close$jscomp$24_props_78683$$,children:[$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$open_plugins$$,className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item",onKeyDown:function($event$jscomp$394$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$394$$))?
$open_plugins$$.$cljs$core$IFn$_invoke$arity$1$?$open_plugins$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$394$$):$open_plugins$$($event$jscomp$394$$):null},"data-testid":"open-plugins",id:"file-menu-open-plugins",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.menu.plugins-manager")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$main_menu$shortcuts_STAR_$$,{id:$APP.$cljs$cst$3222$plugins$$})]}),
$APP.$app$common$data$not_empty_QMARK_$$($plugins$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_main_menu__separator"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$141$$,$map__78688_p__78684$$){var $idx$jscomp$118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__78688_p__78684$$,0,null);$map__78688_p__78684$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__78688_p__78684$$,1,null);
var $map__78688__$1$$=$APP.$cljs$core$__destructure_map$$($map__78688_p__78684$$),$plugin_id$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78688__$1$$,$APP.$cljs$cst$1725$plugin_id$$),$name$jscomp$449$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78688__$1$$,$APP.$cljs$cst$725$name$$),$host$jscomp$15$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78688__$1$$,$APP.$cljs$cst$744$host$$),$permissions$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78688__$1$$,
$APP.$cljs$cst$1728$permissions$$);$out_arr__44092__auto__$jscomp$141$$.push(function(){var $is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$40_permissions__$1$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1158$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($permissions_peek$$,$plugin_id$jscomp$14$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1158$$)?$or__5025__auto__$jscomp$1158$$:$permissions$jscomp$33$$}();$is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$40_permissions__$1$jscomp$2$$=
$APP.$cljs$core$contains_QMARK_$$($is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$40_permissions__$1$jscomp$2$$,"content:write")||$APP.$cljs$core$contains_QMARK_$$($is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$40_permissions__$1$jscomp$2$$,"library:write");var $can_open_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($user_can_edit_QMARK_$jscomp$3$$)?$user_can_edit_QMARK_$jscomp$3$$:!$is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$40_permissions__$1$jscomp$2$$;$is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$40_permissions__$1$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_open_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($name$jscomp$449$$),$APP.$rumext$v2$adapt$$($host$jscomp$15$$),$APP.$rumext$v2$adapt$$($map__78688__$1$$),$APP.$rumext$v2$adapt$$($user_can_edit_QMARK_$jscomp$3$$)],function($event$jscomp$395$$){return $APP.$cljs$core$truth_$$($can_open_QMARK_$jscomp$1$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"start-plugin",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu",$APP.$cljs$cst$725$name$$,$name$jscomp$449$$,$APP.$cljs$cst$744$host$$,$host$jscomp$15$$],null))),$APP.$app$main$data$plugins$open_plugin_BANG_$$($map__78688__$1$$,$user_can_edit_QMARK_$jscomp$3$$)):$APP.$app$util$dom$stop_propagation$$($event$jscomp$395$$)});var $on_key_down$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_open_QMARK_$jscomp$1$$),
$APP.$rumext$v2$adapt$$($name$jscomp$449$$),$APP.$rumext$v2$adapt$$($host$jscomp$15$$),$APP.$rumext$v2$adapt$$($map__78688__$1$$),$APP.$rumext$v2$adapt$$($user_can_edit_QMARK_$jscomp$3$$)],function($event$jscomp$396$$){return $APP.$cljs$core$truth_$$($can_open_QMARK_$jscomp$1$$)&&$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$396$$))?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"start-plugin",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:menu",$APP.$cljs$cst$725$name$$,$name$jscomp$449$$,$APP.$cljs$cst$744$host$$,$host$jscomp$15$$],null))),$APP.$app$main$data$plugins$open_plugin_BANG_$$($map__78688__$1$$,$user_can_edit_QMARK_$jscomp$3$$)):null});return $APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$dropdown_menu$dropdown_menu_item_STAR_$$,{onClick:$is_edition_plugin_QMARK_$jscomp$2_on_click$jscomp$40_permissions__$1$jscomp$2$$,
className:"main_ui_workspace_main_menu__base-menu-item main_ui_workspace_main_menu__submenu-item "+($APP.$cljs$core$not$$($can_open_QMARK_$jscomp$1$$)?"main_ui_workspace_main_menu__disabled":""),onKeyDown:$on_key_down$jscomp$13$$,children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_main_menu__item-name",children:$name$jscomp$449$$}),$APP.$cljs$core$truth_$$($can_open_QMARK_$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)("span",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.plugins.error.need-editor"),
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"help",className:"main_ui_workspace_main_menu__item-icon"})})]},"plugins-menu-"+($idx$jscomp$118$$??""))}());return $out_arr__44092__auto__$jscomp$141$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($plugins$jscomp$1$$))]})}return null});var $app$main$data$workspace$history$initialize_history_78648$$;var $app$main$ui$workspace$presence$session_widget_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($profile__$1$jscomp$5_props_78659$$){var $index$jscomp$476$$=$profile__$1$jscomp$5_props_78659$$.index,$color$jscomp$164$$=$profile__$1$jscomp$5_props_78659$$.color;$profile__$1$jscomp$5_props_78659$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($profile__$1$jscomp$5_props_78659$$.profile,$APP.$cljs$cst$1303$color$$,$color$jscomp$164$$);var $full_name$$=$APP.$cljs$cst$1365$fullname$$.$cljs$core$IFn$_invoke$arity$1$($profile__$1$jscomp$5_props_78659$$);
return(0,$APP.$rumext$v2$jsx$$)("li",{style:{zIndex:""+(2+-1*$index$jscomp$476$$),backgroundColor:$color$jscomp$164$$},title:$full_name$$,className:"main_ui_workspace_presence__session-icon",children:(0,$APP.$rumext$v2$jsx$$)("img",{alt:$full_name$$,style:{backgroundColor:$color$jscomp$164$$},src:$APP.$app$config$resolve_profile_photo_url$$($profile__$1$jscomp$5_props_78659$$)})})}),$app$main$ui$workspace$presence$active_sessions_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function(){var $profiles$jscomp$3$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$profiles$$),$presence$jscomp$4_sessions$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_presence$$);$presence$jscomp$4_sessions$$=$APP.$cljs$core$vals$$($presence$jscomp$4_sessions$$);var $num_sessions$$=$APP.$cljs$core$count$$($presence$jscomp$4_sessions$$),$avatar_count$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_sessions$$,3)?3:2,$open_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$open_QMARK_$jscomp$9$$=
$APP.$cljs$core$_deref$$($open_STAR_$jscomp$2$$)&&$num_sessions$$>3,$on_open$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$2$$,!0);return $APP.$app$util$timers$schedule_on_idle$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$dom$focus_BANG_$$($APP.$goog$dom$getElement$$("users-close"))})}),$on_close$jscomp$26$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$2$$,
!1)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$open_QMARK_$jscomp$9$$?(0,$APP.$rumext$v2$jsx$$)("button",{id:"users-close",onClick:$on_close$jscomp$26$$,onBlur:$on_close$jscomp$26$$,className:"main_ui_workspace_presence__active-users-opened",children:(0,$APP.$rumext$v2$jsx$$)("ul",{"data-testid":"active-users-list",className:"main_ui_workspace_presence__active-users-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$142$$,
$session$jscomp$3$$){$out_arr__44092__auto__$jscomp$142$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$presence$session_widget_STAR_$$,{color:$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$3$$),index:0,profile:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profiles$jscomp$3$$,$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$3$$))},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($session$jscomp$3$$)??"")));return $out_arr__44092__auto__$jscomp$142$$},
[],$presence$jscomp$4_sessions$$)})}):null,(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_open$jscomp$1$$,className:"main_ui_workspace_presence__active-users",children:(0,$APP.$rumext$v2$jsxs$$)("ul",{"data-testid":"active-users-list",className:"main_ui_workspace_presence__active-users-list",children:[$num_sessions$$>3?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_presence__users-num",children:"+"+(1+($num_sessions$$-3))}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$143$$,
$p__78665_session$jscomp$4$$){var $index$jscomp$477$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78665_session$jscomp$4$$,0,null);$p__78665_session$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__78665_session$jscomp$4$$,1,null);$out_arr__44092__auto__$jscomp$143$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$presence$session_widget_STAR_$$,{color:$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($p__78665_session$jscomp$4$$),index:$index$jscomp$477$$,
profile:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profiles$jscomp$3$$,$APP.$cljs$cst$2321$profile_id$$.$cljs$core$IFn$_invoke$arity$1$($p__78665_session$jscomp$4$$))},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p__78665_session$jscomp$4$$)??"")));return $out_arr__44092__auto__$jscomp$143$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$($avatar_count$$,$presence$jscomp$4_sessions$$)))]})})]})});var $app$main$ui$workspace$right_header$zoom_widget_workspace$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($open_QMARK_$jscomp$10_props_78701$$){var $on_zoom_reset$jscomp$1$$=$open_QMARK_$jscomp$10_props_78701$$["on-zoom-reset"],$zoom$jscomp$68_zoom__$1$$=$open_QMARK_$jscomp$10_props_78701$$.zoom,$on_zoom_fit$jscomp$1$$=$open_QMARK_$jscomp$10_props_78701$$["on-zoom-fit"],$on_zoom_selected$$=$open_QMARK_$jscomp$10_props_78701$$["on-zoom-selected"],$on_decrease$jscomp$1$$=$open_QMARK_$jscomp$10_props_78701$$["on-decrease"],
$on_increase$jscomp$1$$=$open_QMARK_$jscomp$10_props_78701$$["on-increase"],$open_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$open_QMARK_$jscomp$10_props_78701$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$3$$);var $open_dropdown$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$417$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$417$$);return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$3$$,!0)}),$close_dropdown$jscomp$3$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$418$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$418$$);return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$3$$,!1)}),$on_increase__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_increase$jscomp$1$$)],function($event$jscomp$419$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$419$$);return $on_increase$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?
$on_increase$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_increase$jscomp$1$$()}),$on_decrease__$1$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_decrease$jscomp$1$$)],function($event$jscomp$420$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$420$$);return $on_decrease$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$on_decrease$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$on_decrease$jscomp$1$$()});$zoom$jscomp$68_zoom__$1$$=$APP.$app$main$ui$formats$format_percent$cljs$0core$0IFn$0_invoke$0arity$02$$($zoom$jscomp$68_zoom__$1$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$267$precision$$,0],null));return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("div",{onClick:$open_dropdown$jscomp$3$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom"),className:"main_ui_workspace_right_header__zoom-widget "+($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$10_props_78701$$)?"main_ui_workspace_right_header__selected":""),children:(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_right_header__label",children:$zoom$jscomp$68_zoom__$1$$})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$open_QMARK_$jscomp$10_props_78701$$,"on-close":$close_dropdown$jscomp$3$$,children:(0,$APP.$rumext$v2$jsxs$$)("ul",{className:"main_ui_workspace_right_header__dropdown",children:[(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_right_header__basic-zoom-bar",children:[(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_right_header__zoom-btns",
children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.decrease-zoom"),onClick:$on_decrease__$1$jscomp$1$$,icon:"remove"}),(0,$APP.$rumext$v2$jsx$$)("p",{className:"main_ui_workspace_right_header__zoom-text",children:$zoom$jscomp$68_zoom__$1$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("shortcuts.increase-zoom"),
onClick:$on_increase__$1$jscomp$1$$,icon:"add"})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_zoom_reset$jscomp$1$$,className:"main_ui_workspace_right_header__reset-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.reset-zoom")})]}),(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$on_zoom_fit$jscomp$1$$,className:"main_ui_workspace_right_header__zoom-option",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom-fit-all"),(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_right_header__shortcuts",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$144$$,$sc$jscomp$11$$){$out_arr__44092__auto__$jscomp$144$$.push((0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_right_header__shortcut-key",children:$sc$jscomp$11$$},["zoom-fit-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sc$jscomp$11$$)].join("")));return $out_arr__44092__auto__$jscomp$144$$},[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4918$fit_all$$)))})]}),
(0,$APP.$rumext$v2$jsxs$$)("li",{onClick:$on_zoom_selected$$,className:"main_ui_workspace_right_header__zoom-option",children:[$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.header.zoom-selected"),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_right_header__shortcuts",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$145$$,$sc$jscomp$12$$){$out_arr__44092__auto__$jscomp$145$$.push((0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_right_header__shortcut-key",children:$sc$jscomp$12$$},["zoom-selected-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sc$jscomp$12$$)].join("")));return $out_arr__44092__auto__$jscomp$145$$},[],$APP.$app$main$data$shortcuts$split_sc$$($app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4968$zoom_selected$$)))})]})]})})]})});var $app$main$ui$workspace$sidebar$assets$colors$colors_group$$=function $app$main$ui$workspace$sidebar$assets$colors$colors_group$$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$){$group_open_QMARK__map__78712_map__78712__$1_props_78711$$=$APP.$rumext$v2$util$wrap_props$$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$);$group_open_QMARK__map__78712_map__78712__$1_props_78711$$=$APP.$cljs$core$__destructure_map$$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$);
var $groups$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$APP.$cljs$cst$4449$groups$$),$on_asset_click$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5734$on_asset_click$$),$on_rename_group$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5735$on_rename_group$$),
$selected_full$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5736$selected_full$$),$on_assets_delete$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5737$on_assets_delete$$),$force_open_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5738$force_open_QMARK_$$),
$selected$jscomp$157$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$APP.$cljs$cst$1938$selected$$),$file_id$jscomp$389$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$APP.$cljs$cst$1649$file_id$$),$multi_assets_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5739$multi_assets_QMARK_$$),
$on_ungroup$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5740$on_ungroup$$),$local_QMARK_$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$APP.$cljs$cst$3743$local_QMARK_$$),$colors$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$APP.$cljs$cst$2220$colors$$),
$open_groups$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5741$open_groups$$),$prefix$jscomp$70$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$APP.$cljs$cst$971$prefix$$),$on_clear_selection$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5694$on_clear_selection$$),
$on_group$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5742$on_group$$),$multi_colors_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5743$multi_colors_QMARK_$$),$on_delete_group$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($group_open_QMARK__map__78712_map__78712__$1_props_78711$$,$cljs$cst$5744$on_delete_group$$);
$group_open_QMARK__map__78712_map__78712__$1_props_78711$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($open_groups$jscomp$2$$,$prefix$jscomp$70$$)===!1?!1:$force_open_QMARK_$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_groups$jscomp$2$$,$prefix$jscomp$70$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prefix$jscomp$70$$,"")?!0:!1);var $dragging_STAR_$jscomp$6$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$6$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$6$$),
$selected_paths$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_full$jscomp$3$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$1$("")),$selected_full$jscomp$3$$)}),$move_color$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$389$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$libraries$rename_color$$,$file_id$jscomp$389$$)),$on_drag_enter$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$6$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$70$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$5$$)],function($event$jscomp$431$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$($event$jscomp$431$$,
$dragging_STAR_$jscomp$6$$,$prefix$jscomp$70$$,$selected_paths$jscomp$5$$)}),$on_drag_leave$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$6$$)],function($event$jscomp$432$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$432$$,$dragging_STAR_$jscomp$6$$)}),$on_drop$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$6$$),
$APP.$rumext$v2$adapt$$($prefix$jscomp$70$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$5$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$3$$),$APP.$rumext$v2$adapt$$($move_color$jscomp$1$$)],function($event$jscomp$433$$){return $app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$($event$jscomp$433$$,$dragging_STAR_$jscomp$6$$,$prefix$jscomp$70$$,$selected_paths$jscomp$5$$,$selected_full$jscomp$3$$,$move_color$jscomp$1$$)});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$3$$,
onDragLeave:$on_drag_leave$jscomp$3$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$6$$,className:"main_ui_workspace_sidebar_assets_colors__colors-group",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$,{fileId:$file_id$jscomp$389$$,section:$APP.$cljs$cst$2220$colors$$,path:$prefix$jscomp$70$$,isGroupOpen:$group_open_QMARK__map__78712_map__78712__$1_props_78711$$,onRename:$on_rename_group$$,onUngroup:$on_ungroup$jscomp$1$$,
onDeleteGroup:$on_delete_group$jscomp$1$$}),$group_open_QMARK__map__78712_map__78712__$1_props_78711$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[function(){var $colors__$1$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$8$$,"",$APP.$cljs$core$PersistentVector$EMPTY$$);return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$3$$,onDragLeave:$on_drag_leave$jscomp$3$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$6$$,
className:"main_ui_workspace_sidebar_assets_colors__asset-list",children:[$dragging_QMARK_$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_colors__grid-placeholder",children:" "}):null,$APP.$cljs$core$empty_QMARK_$$($colors__$1$jscomp$5$$)&&$groups$jscomp$8$$!=null?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_colors__drop-space"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$146$$,
$color$jscomp$166$$){$out_arr__44092__auto__$jscomp$146$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$colors$color_item_STAR_$$,{isLocal:$local_QMARK_$jscomp$5$$,selected:$selected$jscomp$157$$,onGroup:$on_group$jscomp$1$$,onAssetClick:$on_asset_click$jscomp$1$$,onAssetsDelete:$on_assets_delete$jscomp$1$$,isMultiAssets:$multi_assets_QMARK_$$,moveColor:$move_color$jscomp$1$$,onClearSelection:$on_clear_selection$jscomp$2$$,isMultiColors:$multi_colors_QMARK_$$,colors:$colors__$1$jscomp$5$$,
fileId:$file_id$jscomp$389$$,color:$color$jscomp$166$$,selectedFull:$selected_full$jscomp$3$$,selectedPaths:$selected_paths$jscomp$5$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($color$jscomp$166$$)??"")));return $out_arr__44092__auto__$jscomp$146$$},[],$colors__$1$jscomp$5$$)]})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$147$$,$content$jscomp$246_p__78714$$){var $path_item$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$246_p__78714$$,
0,null);$content$jscomp$246_p__78714$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$246_p__78714$$,1,null);$out_arr__44092__auto__$jscomp$147$$.push($APP.$cljs$core$empty_QMARK_$$($path_item$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$colors$colors_group$$,{"selected-full":$selected_full$jscomp$3$$,"on-assets-delete":$on_assets_delete$jscomp$1$$,"force-open?":$force_open_QMARK_$$,selected:$selected$jscomp$157$$,"file-id":$file_id$jscomp$389$$,
"multi-assets?":$multi_assets_QMARK_$$,"on-ungroup":$on_ungroup$jscomp$1$$,"local?":$local_QMARK_$jscomp$5$$,colors:$colors$jscomp$21$$,"open-groups":$open_groups$jscomp$2$$,prefix:$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$70$$,$path_item$$),"on-group":$on_group$jscomp$1$$,"on-clear-selection":$on_clear_selection$jscomp$2$$,"multi-colors?":$multi_colors_QMARK_$$,"on-delete-group":$on_delete_group$jscomp$1$$,groups:$content$jscomp$246_p__78714$$,"on-asset-click":$on_asset_click$jscomp$1$$,
"on-rename-group":$on_rename_group$$},"group-"+($path_item$$??"")));return $out_arr__44092__auto__$jscomp$147$$},[],$groups$jscomp$8$$)]}):null]})};var $app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2585$is_local$$,!1],null)),$app$main$ui$workspace$sidebar$assets$components$count_leaves$$=function $app$main$ui$workspace$sidebar$assets$components$count_leaves$$($m$jscomp$239$$){return $APP.$cljs$core$reduce_kv$$(function($acc$jscomp$159$$,$_$jscomp$3039$$,$v$jscomp$669$$){return $APP.$cljs$core$map_QMARK_$$($v$jscomp$669$$)?
$acc$jscomp$159$$+($app$main$ui$workspace$sidebar$assets$components$count_leaves$$.$cljs$core$IFn$_invoke$arity$1$?$app$main$ui$workspace$sidebar$assets$components$count_leaves$$.$cljs$core$IFn$_invoke$arity$1$($v$jscomp$669$$):$app$main$ui$workspace$sidebar$assets$components$count_leaves$$($v$jscomp$669$$)):$APP.$cljs$core$vector_QMARK_$$($v$jscomp$669$$)?$acc$jscomp$159$$+$APP.$cljs$core$count$$($v$jscomp$669$$):$acc$jscomp$159$$},0,$m$jscomp$239$$)},$app$main$ui$workspace$sidebar$assets$components$components_group_STAR_$$=
function $app$main$ui$workspace$sidebar$assets$components$components_group_STAR_$$($group_open_QMARK_$jscomp$1_props_78733$$){var $on_group_combine_variants$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78733$$.onGroupCombineVariants,$groups$jscomp$10$$=$group_open_QMARK_$jscomp$1_props_78733$$.groups,$on_asset_click$jscomp$4$$=$group_open_QMARK_$jscomp$1_props_78733$$.onAssetClick,$on_rename_group$jscomp$2$$=$group_open_QMARK_$jscomp$1_props_78733$$.onRenameGroup,$selected_full$jscomp$6$$=$group_open_QMARK_$jscomp$1_props_78733$$.selectedFull,
$selected$jscomp$160$$=$group_open_QMARK_$jscomp$1_props_78733$$.selected,$file_id$jscomp$393$$=$group_open_QMARK_$jscomp$1_props_78733$$.fileId,$cancel_rename$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78733$$.cancelRename,$is_listing_thumbs$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78733$$.isListingThumbs,$count_variants$$=$group_open_QMARK_$jscomp$1_props_78733$$.countVariants,$is_force_open$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78733$$.isForceOpen,$on_ungroup$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78733$$.onUngroup,
$on_context_menu$jscomp$5$$=$group_open_QMARK_$jscomp$1_props_78733$$.onContextMenu,$renaming$jscomp$1$$=$group_open_QMARK_$jscomp$1_props_78733$$.renaming,$open_groups$jscomp$4$$=$group_open_QMARK_$jscomp$1_props_78733$$.openGroups,$prefix$jscomp$71$$=$group_open_QMARK_$jscomp$1_props_78733$$.prefix,$do_rename$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78733$$.doRename,$is_local$jscomp$4$$=$group_open_QMARK_$jscomp$1_props_78733$$.isLocal,$on_group$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78733$$.onGroup,
$on_drag_start$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78733$$.onDragStart,$on_delete_group$jscomp$3$$=$group_open_QMARK_$jscomp$1_props_78733$$.onDeleteGroup;$group_open_QMARK_$jscomp$1_props_78733$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($open_groups$jscomp$4$$,$prefix$jscomp$71$$)===!1?!1:$is_force_open$jscomp$1$$||$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_groups$jscomp$4$$,$prefix$jscomp$71$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prefix$jscomp$71$$,
"")?!0:!1);var $dragging_STAR_$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$8$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$8$$),$selected_paths$jscomp$7$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_full$jscomp$6$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$),
$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$1$("")),$selected_full$jscomp$6$$)}),$components$jscomp$13$$=$APP.$cljs$core$not_empty$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$10$$,"",$APP.$cljs$core$PersistentVector$EMPTY$$)),$can_combine_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_local$jscomp$4$$),$APP.$rumext$v2$adapt$$($groups$jscomp$10$$),$APP.$rumext$v2$adapt$$($components$jscomp$13$$)],function(){if($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)){var $and__5023__auto____$1$jscomp$136_and__5023__auto____$2$jscomp$49$$=
$app$main$ui$workspace$sidebar$assets$components$count_leaves$$($groups$jscomp$10$$)>1;return $and__5023__auto____$1$jscomp$136_and__5023__auto____$2$jscomp$49$$?($and__5023__auto____$1$jscomp$136_and__5023__auto____$2$jscomp$49$$=$APP.$cljs$core$not_any_QMARK_$$($APP.$app$common$types$component$is_variant_QMARK_$$,$components$jscomp$13$$))?$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_EQ_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2071$main_instance_page$$,
$components$jscomp$13$$)):$and__5023__auto____$1$jscomp$136_and__5023__auto____$2$jscomp$49$$:$and__5023__auto____$1$jscomp$136_and__5023__auto____$2$jscomp$49$$}return $is_local$jscomp$4$$}),$on_drag_enter$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$8$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$71$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$7$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$4$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],
function($event$jscomp$444$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)?$APP.$cljs$cst$2585$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$4$$)?$app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$($event$jscomp$444$$,$dragging_STAR_$jscomp$8$$,$prefix$jscomp$71$$,$selected_paths$jscomp$7$$):null}),$on_drag_leave$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$8$$),
$APP.$rumext$v2$adapt$$($is_local$jscomp$4$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$445$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)?$APP.$cljs$cst$2585$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$4$$)?$app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$445$$,
$dragging_STAR_$jscomp$8$$):null}),$on_drop$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$8$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$71$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$7$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$6$$),$APP.$rumext$v2$adapt$$($is_local$jscomp$4$$),$APP.$rumext$v2$adapt$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)],function($event$jscomp$446$$){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_local$jscomp$4$$)?
$APP.$cljs$cst$2585$is_local$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$components$drag_data_STAR_$$)):$is_local$jscomp$4$$)?$app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$($event$jscomp$446$$,$dragging_STAR_$jscomp$8$$,$prefix$jscomp$71$$,$selected_paths$jscomp$7$$,$selected_full$jscomp$6$$,$APP.$app$main$data$workspace$variants$rename_comp_or_variant_and_main$$):null});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$5$$,
onDragLeave:$on_drag_leave$jscomp$5$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$8$$,className:"main_ui_workspace_sidebar_assets_components__component-group",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$,{path:$prefix$jscomp$71$$,section:$APP.$cljs$cst$1643$components$$,onUngroup:$on_ungroup$jscomp$3$$,onGroupCombineVariants:$on_group_combine_variants$jscomp$1$$,isCanCombine:$can_combine_QMARK_$$,onDeleteGroup:$on_delete_group$jscomp$3$$,
onRename:$on_rename_group$jscomp$2$$,isGroupOpen:$group_open_QMARK_$jscomp$1_props_78733$$,fileId:$file_id$jscomp$393$$}),$group_open_QMARK_$jscomp$1_props_78733$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$5$$,onDragLeave:$on_drag_leave$jscomp$5$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$8$$,className:($APP.$cljs$core$truth_$$($is_listing_thumbs$jscomp$1$$)?"main_ui_workspace_sidebar_assets_components__component-group-grid":
"")+" "+($APP.$cljs$core$not$$($is_listing_thumbs$jscomp$1$$)?"main_ui_workspace_sidebar_assets_components__component-group-list":""),children:[$dragging_QMARK_$jscomp$8$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_components__component-group-placeholder",children:" "}):null,$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$793_and__5023__auto____$1$jscomp$137$$=$APP.$cljs$core$empty_QMARK_$$($components$jscomp$13$$);return $and__5023__auto__$jscomp$793_and__5023__auto____$1$jscomp$137$$?
($and__5023__auto__$jscomp$793_and__5023__auto____$1$jscomp$137$$=$groups$jscomp$10$$!=null)?$is_local$jscomp$4$$:$and__5023__auto__$jscomp$793_and__5023__auto____$1$jscomp$137$$:$and__5023__auto__$jscomp$793_and__5023__auto____$1$jscomp$137$$}())?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_components__component-group-drop-space "+($APP.$cljs$core$not$$($dragging_QMARK_$jscomp$8$$)?"main_ui_workspace_sidebar_assets_components__component-group-drop-space-small":"")}):
null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$148$$,$component$jscomp$126$$){var $JSCompiler_temp_const$jscomp$1783$$=$out_arr__44092__auto__$jscomp$148$$.push;var $G__78737$jscomp$inline_8965_JSCompiler_inline_result$jscomp$1785$$=$APP.$cljs$cst$2016$variant_id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$126$$);$G__78737$jscomp$inline_8965_JSCompiler_inline_result$jscomp$1785$$=$count_variants$$.$cljs$core$IFn$_invoke$arity$1$?$count_variants$$.$cljs$core$IFn$_invoke$arity$1$($G__78737$jscomp$inline_8965_JSCompiler_inline_result$jscomp$1785$$):
$count_variants$$($G__78737$jscomp$inline_8965_JSCompiler_inline_result$jscomp$1785$$);$JSCompiler_temp_const$jscomp$1783$$.call($out_arr__44092__auto__$jscomp$148$$,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$components$components_item_STAR_$$,{isLocal:$is_local$jscomp$4$$,selected:$selected$jscomp$160$$,onGroup:$on_group$jscomp$3$$,onAssetClick:$on_asset_click$jscomp$4$$,doRename:$do_rename$jscomp$3$$,component:$component$jscomp$126$$,cancelRename:$cancel_rename$jscomp$1$$,numVariants:$G__78737$jscomp$inline_8965_JSCompiler_inline_result$jscomp$1785$$,
onContextMenu:$on_context_menu$jscomp$5$$,isListingThumbs:$is_listing_thumbs$jscomp$1$$,renaming:$renaming$jscomp$1$$,onDragStart:$on_drag_start$jscomp$3$$,fileId:$file_id$jscomp$393$$,selectedFull:$selected_full$jscomp$6$$,selectedPaths:$selected_paths$jscomp$7$$},"component-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($component$jscomp$126$$)??"")));return $out_arr__44092__auto__$jscomp$148$$},[],$components$jscomp$13$$)]}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$149$$,
$content$jscomp$247_p__78738$$){var $path_item$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$247_p__78738$$,0,null);$content$jscomp$247_p__78738$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$247_p__78738$$,1,null);$out_arr__44092__auto__$jscomp$149$$.push($APP.$cljs$core$empty_QMARK_$$($path_item$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$components$components_group_STAR_$$,{isLocal:$is_local$jscomp$4$$,
selected:$selected$jscomp$160$$,onRenameGroup:$on_rename_group$jscomp$2$$,onAssetClick:$on_asset_click$jscomp$4$$,prefix:$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$71$$,$path_item$jscomp$1$$),isForceOpen:$is_force_open$jscomp$1$$,doRename:$do_rename$jscomp$3$$,countVariants:$count_variants$$,cancelRename:$cancel_rename$jscomp$1$$,onContextMenu:$on_context_menu$jscomp$5$$,isListingThumbs:$is_listing_thumbs$jscomp$1$$,onUngroup:$on_ungroup$jscomp$3$$,onGroupCombineVariants:$on_group_combine_variants$jscomp$1$$,
openGroups:$open_groups$jscomp$4$$,onDeleteGroup:$on_delete_group$jscomp$3$$,renaming:$renaming$jscomp$1$$,onDragStart:$on_drag_start$jscomp$3$$,fileId:$file_id$jscomp$393$$,groups:$content$jscomp$247_p__78738$$,selectedFull:$selected_full$jscomp$6$$},$path_item$jscomp$1$$));return $out_arr__44092__auto__$jscomp$149$$},[],$groups$jscomp$10$$)]}):null]})};var $shadow$js$shim$module$0react_virtualized$$=shadow$bridge("react-virtualized");var $app$main$ui$workspace$sidebar$options$menus$typography$font_item_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78786_style$jscomp$72$$){var $is_current$$=$props_78786_style$jscomp$72$$.isCurrent,$on_click$jscomp$42$$=$props_78786_style$jscomp$72$$.onClick,$font$jscomp$44$$=$props_78786_style$jscomp$72$$.font;$props_78786_style$jscomp$72$$=$props_78786_style$jscomp$72$$.style;var $item_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(),$on_click__$1$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($font$jscomp$44$$)],function(){return $on_click$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$?$on_click$jscomp$42$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$44$$):$on_click$jscomp$42$$($font$jscomp$44$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_current$$)],function(){if($APP.$cljs$core$truth_$$($is_current$$)){var $element$jscomp$81$$=$APP.$rumext$v2$ref_val$$($item_ref$jscomp$5$$);
return $APP.$cljs$core$truth_$$($app$util$dom$is_in_viewport_QMARK_$$($element$jscomp$81$$))?null:$element$jscomp$81$$!=null?$element$jscomp$81$$.scrollIntoView(!1):null}return null});return(0,$APP.$rumext$v2$jsx$$)("div",{style:$props_78786_style$jscomp$72$$,ref:$item_ref$jscomp$5$$,onClick:$on_click__$1$jscomp$2$$,className:"main_ui_workspace_sidebar_options_menus_typography__font-wrapper",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-item "+
($APP.$cljs$core$truth_$$($is_current$$)?"main_ui_workspace_sidebar_options_menus_typography__selected":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__font-item-label",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font$jscomp$44$$)}),$APP.$cljs$core$truth_$$($is_current$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"tick",size:"s"}):null]})})}),$app$main$ui$workspace$sidebar$options$menus$typography$typography_advanced_options_STAR_$$=
$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($font_data$jscomp$12_props_78822$$){var $name_input_ref$$=$font_data$jscomp$12_props_78822$$.nameInputRef,$on_key_down$jscomp$15$$=$font_data$jscomp$12_props_78822$$.onKeyDown,$on_change$jscomp$52$$=$font_data$jscomp$12_props_78822$$.onChange,$is_asset_QMARK__show_actions_QMARK_$$=$font_data$jscomp$12_props_78822$$.isAsset,$navigate_to_library$$=$font_data$jscomp$12_props_78822$$.navigateToLibrary,$on_name_blur$$=$font_data$jscomp$12_props_78822$$.onNameBlur,
$is_editable$$=$font_data$jscomp$12_props_78822$$.isEditable,$file_id$jscomp$395$$=$font_data$jscomp$12_props_78822$$.fileId,$on_close$jscomp$28$$=$font_data$jscomp$12_props_78822$$.onClose,$is_local$jscomp$6$$=$font_data$jscomp$12_props_78822$$.isLocal,$typography$jscomp$32$$=$font_data$jscomp$12_props_78822$$.typography,$is_visible$$=$font_data$jscomp$12_props_78822$$.isVisible,$ref$jscomp$51$$=(0,$APP.$rumext$v2$use_ref$$)(null);$font_data$jscomp$12_props_78822$$=$APP.$app$main$fonts$get_font_data$$($APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$));
var $typography_id$jscomp$8$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$);$is_asset_QMARK__show_actions_QMARK_$$=$APP.$cljs$core$truth_$$($is_asset_QMARK__show_actions_QMARK_$$)?$is_editable$$:$is_asset_QMARK__show_actions_QMARK_$$;var $on_delete$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography_id$jscomp$8$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$395$$),$APP.$rumext$v2$adapt$$($on_close$jscomp$28$$)],
function(){$on_close$jscomp$28$$.$cljs$core$IFn$_invoke$arity$0$?$on_close$jscomp$28$$.$cljs$core$IFn$_invoke$arity$0$():$on_close$jscomp$28$$();var $undo_id$jscomp$101$$=Symbol();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($undo_id$jscomp$101$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$libraries$delete_typography$$($typography_id$jscomp$8$$),$APP.$app$main$data$workspace$libraries$sync_file$cljs$0core$0IFn$0_invoke$0arity$04$$($file_id$jscomp$395$$,
$file_id$jscomp$395$$,$APP.$cljs$cst$2223$typographies$$,$typography_id$jscomp$8$$),$APP.$app$main$data$workspace$undo$commit_undo_transaction$$($undo_id$jscomp$101$$)]))}),$on_duplicate$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$395$$),$APP.$rumext$v2$adapt$$($typography_id$jscomp$8$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$libraries$duplicate_typography$$($file_id$jscomp$395$$,
$typography_id$jscomp$8$$))});$APP.$app$main$fonts$ensure_loaded_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_visible$$)],function(){var $temp__5825__auto__$jscomp$371$$=$APP.$rumext$v2$ref_val$$($ref$jscomp$51$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$371$$)?$APP.$cljs$core$truth_$$($is_visible$$)?$APP.$app$util$dom$scroll_into_view_if_needed_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($temp__5825__auto__$jscomp$371$$,
!1):null:null});return $APP.$cljs$core$truth_$$($is_visible$$)?(0,$APP.$rumext$v2$jsx$$)("div",{ref:$ref$jscomp$51$$,className:"main_ui_workspace_sidebar_options_menus_typography__advanced-options-wrapper",children:$is_editable$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__font-name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$),
fontWeight:$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$),fontStyle:$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$)},className:"main_ui_workspace_sidebar_options_menus_typography__typography-sample-input",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",ref:$name_input_ref$$,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$),
maxLength:255,onKeyDown:$on_key_down$jscomp$15$$,onBlur:$on_name_blur$$,className:"main_ui_workspace_sidebar_options_menus_typography__adv-typography-name"}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__action-btns",children:[$APP.$cljs$core$truth_$$($is_asset_QMARK__show_actions_QMARK_$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.duplicate"),onClick:$on_duplicate$jscomp$2$$,icon:"clipboard"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.delete"),onClick:$on_delete$jscomp$10$$,icon:"delete"})]}):null,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"action",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$on_close$jscomp$28$$,icon:"tick"})]})]}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$text_options_STAR_$$,{values:$typography$jscomp$32$$,onChange:$on_change$jscomp$52$$,showRecent:!1})]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__typography-info-wrapper",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__typography-name-wrapper",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{style:{fontFamily:$APP.$cljs$cst$1764$font_family$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$),fontWeight:$APP.$cljs$cst$1767$font_weight$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$),fontStyle:$APP.$cljs$cst$1768$font_style$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$)},className:"main_ui_workspace_sidebar_options_menus_typography__typography-sample",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.sample")}),
(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$),className:"main_ui_workspace_sidebar_options_menus_typography__typography-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$)}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__typography-font",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($font_data$jscomp$12_props_78822$$)}),
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$on_close$jscomp$28$$,icon:"menu"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.font-style")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1765$font_variant_id$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.font-size")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1766$font_size$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.line-height")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1771$line_height$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.letter-spacing")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1772$letter_spacing$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_typography__info-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.text-transform")}),
(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_typography__info-content",children:$APP.$cljs$cst$1775$text_transform$$.$cljs$core$IFn$_invoke$arity$1$($typography$jscomp$32$$)})]}),$APP.$cljs$core$truth_$$($is_local$jscomp$6$$)?null:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$buttons$button$button_STAR_$$,{variant:"secondary",onClick:$navigate_to_library$$,children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography.go-to-edit")})]})}):
null});var $app$main$ui$workspace$sidebar$assets$typographies$lens_COLON_typography_section_state$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($gstate$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5749$rename_typography$$,$cljs$cst$5749$rename_typography$$.$cljs$core$IFn$_invoke$arity$1$($gstate$$),$APP.$cljs$cst$3983$edit_typography$$,$APP.$cljs$cst$3983$edit_typography$$.$cljs$core$IFn$_invoke$arity$1$($gstate$$)],null)},$APP.$app$main$refs$workspace_global$$,
$APP.$cljs$core$_EQ_$$),$app$main$ui$workspace$sidebar$assets$typographies$typographies_group$$=function $app$main$ui$workspace$sidebar$assets$typographies$typographies_group$$($group_open_QMARK_$jscomp$2_props_78833$$){var $groups$jscomp$12$$=$group_open_QMARK_$jscomp$2_props_78833$$.groups,$on_asset_click$jscomp$7$$=$group_open_QMARK_$jscomp$2_props_78833$$["on-asset-click"],$on_rename_group$jscomp$4$$=$group_open_QMARK_$jscomp$2_props_78833$$["on-rename-group"],$selected_full$jscomp$9$$=$group_open_QMARK_$jscomp$2_props_78833$$["selected-full"],
$force_open_QMARK_$jscomp$1$$=$group_open_QMARK_$jscomp$2_props_78833$$["force-open?"],$handle_change$jscomp$7$$=$group_open_QMARK_$jscomp$2_props_78833$$["handle-change"],$selected$jscomp$165$$=$group_open_QMARK_$jscomp$2_props_78833$$.selected,$file_id$jscomp$398$$=$group_open_QMARK_$jscomp$2_props_78833$$["file-id"],$is_read_only$jscomp$2$$=$group_open_QMARK_$jscomp$2_props_78833$$["is-read-only"],$file$jscomp$165$$=$group_open_QMARK_$jscomp$2_props_78833$$.file,$on_ungroup$jscomp$5$$=$group_open_QMARK_$jscomp$2_props_78833$$["on-ungroup"],
$local_QMARK_$jscomp$7$$=$group_open_QMARK_$jscomp$2_props_78833$$["local?"],$on_context_menu$jscomp$9$$=$group_open_QMARK_$jscomp$2_props_78833$$["on-context-menu"],$local_data$$=$group_open_QMARK_$jscomp$2_props_78833$$["local-data"],$open_groups$jscomp$6$$=$group_open_QMARK_$jscomp$2_props_78833$$["open-groups"],$prefix$jscomp$72$$=$group_open_QMARK_$jscomp$2_props_78833$$.prefix,$editing_id$jscomp$2$$=$group_open_QMARK_$jscomp$2_props_78833$$["editing-id"],$renaming_id$jscomp$1$$=$group_open_QMARK_$jscomp$2_props_78833$$["renaming-id"],
$on_delete_group$jscomp$5$$=$group_open_QMARK_$jscomp$2_props_78833$$["on-delete-group"];$group_open_QMARK_$jscomp$2_props_78833$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($open_groups$jscomp$6$$,$prefix$jscomp$72$$)===!1?!1:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_groups$jscomp$6$$,$prefix$jscomp$72$$,!0);var $dragging_STAR_$jscomp$10$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$dragging_QMARK_$jscomp$10$$=$APP.$cljs$core$_deref$$($dragging_STAR_$jscomp$10$$),
$selected_paths$jscomp$9$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_full$jscomp$9$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$),$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$1$("")),$selected_full$jscomp$9$$)}),$move_typography$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$398$$)],$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$data$workspace$libraries$rename_typography$$,$file_id$jscomp$398$$)),$on_drag_enter$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$10$$),$APP.$rumext$v2$adapt$$($prefix$jscomp$72$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$9$$)],function($event$jscomp$468$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_enter_asset_group$$($event$jscomp$468$$,
$dragging_STAR_$jscomp$10$$,$prefix$jscomp$72$$,$selected_paths$jscomp$9$$)}),$on_drag_leave$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$10$$)],function($event$jscomp$469$$){return $app$main$ui$workspace$sidebar$assets$common$on_drag_leave_asset$$($event$jscomp$469$$,$dragging_STAR_$jscomp$10$$)}),$on_drop$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($dragging_STAR_$jscomp$10$$),
$APP.$rumext$v2$adapt$$($prefix$jscomp$72$$),$APP.$rumext$v2$adapt$$($selected_paths$jscomp$9$$),$APP.$rumext$v2$adapt$$($selected_full$jscomp$9$$),$APP.$rumext$v2$adapt$$($move_typography$jscomp$1$$)],function($event$jscomp$470$$){return $app$main$ui$workspace$sidebar$assets$common$on_drop_asset_group$$($event$jscomp$470$$,$dragging_STAR_$jscomp$10$$,$prefix$jscomp$72$$,$selected_paths$jscomp$9$$,$selected_full$jscomp$9$$,$move_typography$jscomp$1$$)}),$add_typography_to_group$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$398$$),
$APP.$rumext$v2$adapt$$($prefix$jscomp$72$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$set_assets_section_open$$($file_id$jscomp$398$$,$APP.$cljs$cst$2223$typographies$$,!0),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$texts$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($file_id$jscomp$398$$,$prefix$jscomp$72$$)]))});return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$7$$,
onDragLeave:$on_drag_leave$jscomp$7$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$10$$,className:"main_ui_workspace_sidebar_assets_typographies__typographies-group",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$groups$asset_group_title_STAR_$$,{fileId:$file_id$jscomp$398$$,section:$APP.$cljs$cst$2223$typographies$$,path:$prefix$jscomp$72$$,isGroupOpen:$group_open_QMARK_$jscomp$2_props_78833$$,onRename:$on_rename_group$jscomp$4$$,onUngroup:$on_ungroup$jscomp$5$$,
onDeleteGroup:$on_delete_group$jscomp$5$$,onAdd:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($local_QMARK_$jscomp$7$$)?$APP.$cljs$core$not$$($is_read_only$jscomp$2$$):$local_QMARK_$jscomp$7$$)?$add_typography_to_group$$:null}),$APP.$cljs$core$truth_$$($group_open_QMARK_$jscomp$2_props_78833$$)?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[function(){var $typographies$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($groups$jscomp$12$$,"",$APP.$cljs$core$PersistentVector$EMPTY$$);
return(0,$APP.$rumext$v2$jsxs$$)("div",{onDragEnter:$on_drag_enter$jscomp$7$$,onDragLeave:$on_drag_leave$jscomp$7$$,onDragOver:$APP.$app$util$dom$prevent_default$$,onDrop:$on_drop$jscomp$10$$,className:"main_ui_workspace_sidebar_assets_typographies__assets-list",children:[$dragging_QMARK_$jscomp$10$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_typographies__grid-placeholder",children:" "}):null,$APP.$cljs$core$empty_QMARK_$$($typographies$jscomp$7$$)&&$groups$jscomp$12$$!=
null?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_assets_typographies__drop-space"}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$152$$,$map__78837__$1_p__78836$$){$map__78837__$1_p__78836$$=$APP.$cljs$core$__destructure_map$$($map__78837__$1_p__78836$$);var $id$jscomp$947$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__78837__$1_p__78836$$,$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$152$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$typographies$typography_item$$,
{"selected-full":$selected_full$jscomp$9$$,"handle-change":$handle_change$jscomp$7$$,selected:$selected$jscomp$165$$,"rename?":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5749$rename_typography$$.$cljs$core$IFn$_invoke$arity$1$($local_data$$),$id$jscomp$947$$),"file-id":$file_id$jscomp$398$$,"local?":$local_QMARK_$jscomp$7$$,"on-context-menu":$on_context_menu$jscomp$9$$,"editing-id":$editing_id$jscomp$2$$,typography:$map__78837__$1_p__78836$$,"renaming-id":$renaming_id$jscomp$1$$,
"selected-paths":$selected_paths$jscomp$9$$,"move-typography":$move_typography$jscomp$1$$,"on-asset-click":$on_asset_click$jscomp$7$$},"typography-"+($id$jscomp$947$$??"")));return $out_arr__44092__auto__$jscomp$152$$},[],$typographies$jscomp$7$$)]})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$153$$,$content$jscomp$248_p__78838$$){var $path_item$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$248_p__78838$$,
0,null);$content$jscomp$248_p__78838$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($content$jscomp$248_p__78838$$,1,null);$out_arr__44092__auto__$jscomp$153$$.push($APP.$cljs$core$empty_QMARK_$$($path_item$jscomp$2$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$typographies$typographies_group$$,{"selected-full":$selected_full$jscomp$9$$,"force-open?":$force_open_QMARK_$jscomp$1$$,"handle-change":$handle_change$jscomp$7$$,selected:$selected$jscomp$165$$,"file-id":$file_id$jscomp$398$$,
"is-read-only":$is_read_only$jscomp$2$$,"on-ungroup":$on_ungroup$jscomp$5$$,file:$file$jscomp$165$$,"local?":$local_QMARK_$jscomp$7$$,"on-context-menu":$on_context_menu$jscomp$9$$,"local-data":$local_data$$,"open-groups":$open_groups$jscomp$6$$,prefix:$APP.$app$common$path_names$merge_path_item$$($prefix$jscomp$72$$,$path_item$jscomp$2$$),"editing-id":$editing_id$jscomp$2$$,"renaming-id":$renaming_id$jscomp$1$$,"on-delete-group":$on_delete_group$jscomp$5$$,groups:$content$jscomp$248_p__78838$$,"on-asset-click":$on_asset_click$jscomp$7$$,
"on-rename-group":$on_rename_group$jscomp$4$$},"group-"+($path_item$jscomp$2$$??"")));return $out_arr__44092__auto__$jscomp$153$$},[],$groups$jscomp$12$$)]}):null]})};var $app$main$ui$workspace$sidebar$assets$file_library$ref_COLON_open_status$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$4564$open_status$$],null)),$APP.$app$main$store$state$$),$app$main$ui$workspace$sidebar$assets$file_library$ref_COLON_selected$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$in$0$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$4563$workspace_assets$$,$APP.$cljs$cst$1938$selected$$],null)),$APP.$app$main$store$state$$);var $app$main$ui$workspace$sidebar$assets$assets_libraries_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($libraries$jscomp$148_props_78921$$){var $filters$jscomp$9$$=$libraries$jscomp$148_props_78921$$.filters,$file_id$jscomp$406$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$files$jscomp$28$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$files$$);$libraries$jscomp$148_props_78921$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($files$jscomp$28$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$406$$)],function(){return $APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78920_SHARP_$$){return $APP.$cuerdas$core$lower$$($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($p1__78920_SHARP_$$))},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($file$jscomp$169$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($file$jscomp$169$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1635$pages_index$$)},
$APP.$cljs$core$remove$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__78915_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($file_id$jscomp$406$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($p1__78915_SHARP_$$))},$APP.$cljs$core$vals$$($APP.$app$main$refs$select_libraries$$($files$jscomp$28$$,$file_id$jscomp$406$$)))))});return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$154$$,$file$jscomp$170$$){$out_arr__44092__auto__$jscomp$154$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$file_library$file_library_STAR_$$,
{file:$file$jscomp$170$$,isLocal:!1,isDefaultOpen:!1,filters:$filters$jscomp$9$$},""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$170$$)??"")));return $out_arr__44092__auto__$jscomp$154$$},[],$libraries$jscomp$148_props_78921$$)}),$app$main$ui$workspace$sidebar$assets$ref_COLON_local_library$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($file$jscomp$171$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($file$jscomp$171$$,$APP.$cljs$cst$142$data$$,
$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1635$pages_index$$)},$APP.$app$main$refs$file$$),$app$main$ui$workspace$sidebar$assets$session_filters_STAR_$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$app$main$ui$workspace$sidebar$assets$assets_toolbox_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78933_size$jscomp$157$$){var $file_id$jscomp$407$$=$props_78933_size$jscomp$157$$.fileId;$props_78933_size$jscomp$157$$=
$props_78933_size$jscomp$157$$.size;var $read_only_QMARK_$jscomp$20$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$filters_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $JSCompiler_temp_const$jscomp$1790$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$,$JSCompiler_temp_const$jscomp$11298_or__5025__auto__$jscomp$inline_8981$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$_deref$$($app$main$ui$workspace$sidebar$assets$session_filters_STAR_$$),
$file_id$jscomp$407$$);$JSCompiler_temp_const$jscomp$11298_or__5025__auto__$jscomp$inline_8981$$=$APP.$cljs$core$truth_$$($JSCompiler_temp_const$jscomp$11298_or__5025__auto__$jscomp$inline_8981$$)?$JSCompiler_temp_const$jscomp$11298_or__5025__auto__$jscomp$inline_8981$$:new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2524$term$$,"",$APP.$cljs$cst$1371$section$$,"all"],null);var $JSCompiler_inline_result$jscomp$11299_or__5025__auto__$jscomp$inline_13800$$=$cljs$cst$5731$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_ordering$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$user$$);
$JSCompiler_inline_result$jscomp$11299_or__5025__auto__$jscomp$inline_13800$$=$APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$11299_or__5025__auto__$jscomp$inline_13800$$)?$JSCompiler_inline_result$jscomp$11299_or__5025__auto__$jscomp$inline_13800$$:$APP.$cljs$cst$5263$asc$$;var $or__5025__auto__$jscomp$inline_13802$$=$cljs$cst$5732$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_list_style$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$storage$user$$);return $JSCompiler_temp_const$jscomp$1790$$.call($APP.$cljs$core$assoc$$,
$JSCompiler_temp_const$jscomp$11298_or__5025__auto__$jscomp$inline_8981$$,$cljs$cst$5692$ordering$$,$JSCompiler_inline_result$jscomp$11299_or__5025__auto__$jscomp$inline_13800$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$5751$list_style$$,$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_13802$$)?$or__5025__auto__$jscomp$inline_13802$$:$cljs$cst$5733$thumbs$$,$cljs$cst$5752$open_menu$$,!1]))}),$filters$jscomp$11$$=$APP.$cljs$core$_deref$$($filters_STAR_$$),
$term$jscomp$9$$=$APP.$cljs$cst$2524$term$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),$list_style$jscomp$3$$=$APP.$cljs$cst$5751$list_style$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),$menu_open_QMARK_$$=$cljs$cst$5752$open_menu$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),$section$jscomp$30$$=$APP.$cljs$cst$1371$section$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),$ordering$jscomp$3$$=$cljs$cst$5692$ordering$$.$cljs$core$IFn$_invoke$arity$1$($filters$jscomp$11$$),
$reverse_sort_QMARK_$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2709$desc$$,$ordering$jscomp$3$$),$libs$jscomp$1_shared_QMARK_$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$libraries$$),$num_libs$$=$APP.$cljs$core$count$$($libs$jscomp$1_shared_QMARK_$jscomp$7$$),$file$jscomp$173$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($libs$jscomp$1_shared_QMARK_$jscomp$7$$,$file_id$jscomp$407$$);$libs$jscomp$1_shared_QMARK_$jscomp$7$$=$APP.$cljs$cst$2190$is_shared$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$173$$);
var $components$jscomp$16$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file$jscomp$173$$)],function(){return $APP.$app$common$types$components_list$components$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$142$data$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$173$$))}),$toggle_ordering$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ordering$jscomp$3$$)],function(){var $new_value$jscomp$21$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($ordering$jscomp$3$$,
$APP.$cljs$cst$5263$asc$$)?$APP.$cljs$cst$2709$desc$$:$APP.$cljs$cst$5263$asc$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$5692$ordering$$,$new_value$jscomp$21$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$cljs$cst$5731$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_ordering$$,$new_value$jscomp$21$$)}),$toggle_list_style$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($list_style$jscomp$3$$)],
function(){var $new_value$jscomp$22$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($list_style$jscomp$3$$,$cljs$cst$5733$thumbs$$)?$APP.$cljs$cst$201$list$$:$cljs$cst$5733$thumbs$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$5751$list_style$$,$new_value$jscomp$22$$);return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($APP.$app$util$storage$user$$,$APP.$cljs$core$assoc$$,$cljs$cst$5732$app_DOT_main_DOT_data_DOT_workspace_DOT_assets_SLASH_list_style$$,
$new_value$jscomp$22$$)}),$on_search_term_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$475$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clear_assets_section_open$$());return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$2524$term$$,$event$jscomp$475$$)}),$on_section_filter_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$476_value$jscomp$813$$){var $or__5025__auto__$jscomp$inline_8991$$=
$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$476_value$jscomp$813$$));$event$jscomp$476_value$jscomp$813$$=$APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_8991$$)?$or__5025__auto__$jscomp$inline_8991$$:$APP.$app$util$dom$get_attribute$$($APP.$app$util$dom$get_current_target$$($event$jscomp$476_value$jscomp$813$$),"data-testid");$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$clear_assets_section_open$$());return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($filters_STAR_$$,
$APP.$cljs$core$assoc$$,$APP.$cljs$cst$1371$section$$,$event$jscomp$476_value$jscomp$813$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5752$open_menu$$,!1]))}),$show_libraries_dialog$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$407$$)],function(){return $APP.$app$main$data$modal$show_BANG_$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4038$libraries_dialog$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$407$$],null))}),$on_open_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$update$$,$cljs$cst$5752$open_menu$$,$APP.$cljs$core$not$$)}),$on_menu_close$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($filters_STAR_$$,$APP.$cljs$core$assoc$$,
$cljs$cst$5752$open_menu$$,!1)}),$options$jscomp$612$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_section_filter_change$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.box-filter-all"),$APP.$cljs$cst$266$id$$,"all",$APP.$cljs$cst$2413$handler$$,
$on_section_filter_change$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.components"),$APP.$cljs$cst$266$id$$,"components",$APP.$cljs$cst$2413$handler$$,$on_section_filter_change$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.colors"),$APP.$cljs$cst$266$id$$,"colors",$APP.$cljs$cst$2413$handler$$,
$on_section_filter_change$$],null),new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$725$name$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.typography"),$APP.$cljs$cst$266$id$$,"typographies",$APP.$cljs$cst$2413$handler$$,$on_section_filter_change$$],null)],null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$407$$),$APP.$rumext$v2$adapt$$($term$jscomp$9$$),$APP.$rumext$v2$adapt$$($section$jscomp$30$$)],
function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($app$main$ui$workspace$sidebar$assets$session_filters_STAR_$$,$APP.$cljs$core$assoc$$,$file_id$jscomp$407$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2524$term$$,$term$jscomp$9$$,$APP.$cljs$cst$1371$section$$,$section$jscomp$30$$],null))});return(0,$APP.$rumext$v2$jsxs$$)("article",{className:"main_ui_workspace_sidebar_assets__assets-bar",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets__assets-header",
children:[$read_only_QMARK_$jscomp$20$$?null:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($num_libs$$,1)&&$APP.$cljs$core$empty_QMARK_$$($components$jscomp$16$$)&&$APP.$cljs$core$not$$($libs$jscomp$1_shared_QMARK_$jscomp$7$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$show_libraries_dialog$jscomp$1$$,"data-testid":"libraries",className:"main_ui_workspace_sidebar_assets__add-library-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.add-library")}):
(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$show_libraries_dialog$jscomp$1$$,"data-testid":"libraries",className:"main_ui_workspace_sidebar_assets__libraries-button",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.manage-library")}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_assets__search-wrapper",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_search_term_change$$,value:$term$jscomp$9$$,
placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.search"),children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$on_open_menu$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.filter"),className:"main_ui_workspace_sidebar_assets__section-button "+($APP.$cljs$core$truth_$$($menu_open_QMARK_$$)?"main_ui_workspace_sidebar_assets__opened":""),children:$APP.$app$main$ui$icons$filter_icon$$})}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$context_menu_a11y$context_menu_STAR_$$,
{selected:$section$jscomp$30$$,width:$props_78933_size$jscomp$157$$,top:158,onClose:$on_menu_close$jscomp$1$$,fixed:!0,minWidth:!0,show:$menu_open_QMARK_$$,selectable:!0,options:$options$jscomp$612$$,left:18}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.assets.sort"),onClick:$toggle_ordering$$,icon:$reverse_sort_QMARK_$jscomp$3$$?"asc-sort":"desc-sort"})]})]}),
(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$workspace$sidebar$assets$common$assets_filters$$),{value:$filters$jscomp$11$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$workspace$sidebar$assets$common$assets_toggle_ordering$$),{value:$toggle_ordering$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($app$main$ui$workspace$sidebar$assets$common$assets_toggle_list_style$$),{value:$toggle_list_style$jscomp$2$$,children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,
{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$assets_local_library_STAR_$$,{filters:$filters$jscomp$11$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$assets_libraries_STAR_$$,{filters:$filters$jscomp$11$$})]})})})})]})});var $app$main$ui$workspace$sidebar$debug_shape_info$display_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1624$parent_id$$,$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$1619$shapes$$,$APP.$cljs$cst$1632$component_id$$,$APP.$cljs$cst$1648$component_file$$,$APP.$cljs$cst$2052$component_root$$,$APP.$cljs$cst$2053$main_instance$$,$APP.$cljs$cst$2055$shape_ref$$,$APP.$cljs$cst$1515$x$$,
$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1610$selrect$$,$APP.$cljs$cst$1609$points$$,$APP.$cljs$cst$1294$transform$$,$APP.$cljs$cst$1793$transform_inverse$$],null),$app$main$ui$workspace$sidebar$debug_shape_info$remove_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2054$remote_synced$$,null,$APP.$cljs$cst$725$name$$,null],null),null),$app$main$ui$workspace$sidebar$debug_shape_info$custom_renderer$$=
$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1294$transform$$,$APP.$cljs$cst$1701$layout_grid_cells$$,$APP.$cljs$cst$1609$points$$,$APP.$cljs$cst$2055$shape_ref$$,$APP.$cljs$cst$1793$transform_inverse$$,$APP.$cljs$cst$1624$parent_id$$,$APP.$cljs$cst$1612$frame_id$$,$APP.$cljs$cst$1610$selrect$$,$APP.$cljs$cst$1619$shapes$$],[$cljs$cst$5754$matrix_render$$,$cljs$cst$5755$cells_render$$,$cljs$cst$5756$points_render$$,$cljs$cst$5757$shape_link$$,$cljs$cst$5754$matrix_render$$,$cljs$cst$5757$shape_link$$,
$cljs$cst$5757$shape_link$$,$cljs$cst$5758$rect_render$$,$cljs$cst$5759$shape_list$$]);var $app$main$ui$workspace$sidebar$history$workspace_undo$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$3616$workspace_undo$$,$APP.$app$main$store$state$$);var $app$main$ui$workspace$sidebar$layers$ref_COLON_highlighted_shapes$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($local$jscomp$31$$){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($local$jscomp$31$$,$APP.$cljs$cst$4366$highlighted$$))},$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$sidebar$layers$ref_COLON_shape_for_rename$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$4490$shape_for_rename$$),
$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$sidebar$layers$layers_tree_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78914_root$jscomp$66_shapes__$1$jscomp$32$$){var $is_filtered$jscomp$2$$=$props_78914_root$jscomp$66_shapes__$1$jscomp$32$$.isFiltered,$objects$jscomp$792$$=$props_78914_root$jscomp$66_shapes__$1$jscomp$32$$.objects,$parent_size$jscomp$3$$=$props_78914_root$jscomp$66_shapes__$1$jscomp$32$$.parentSize,$selected$jscomp$172$$=$app$main$ui$workspace$sidebar$layers$use_selected_shapes$$(),
$highlighted$jscomp$3$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$layers$ref_COLON_highlighted_shapes$$);$props_78914_root$jscomp$66_shapes__$1$jscomp$32$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$792$$,$APP.$app$common$uuid$zero$$);var $rename_id$jscomp$3$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$layers$ref_COLON_shape_for_rename$$),$shapes$jscomp$204$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_78914_root$jscomp$66_shapes__$1$jscomp$32$$,
$APP.$cljs$cst$1619$shapes$$);$props_78914_root$jscomp$66_shapes__$1$jscomp$32$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$204$$),$APP.$rumext$v2$adapt$$($objects$jscomp$792$$)],function(){for(var $G__78966_G__78969_counter$jscomp$5$$=0,$G__78967_G__78970_shapes__$1$jscomp$33$$=$APP.$cljs$core$seq$$($shapes$jscomp$204$$),$G__78968_G__78971_result$jscomp$372$$=$APP.$cljs$core$List$EMPTY$$;;){var $obj$jscomp$220_temp__5823__auto__$jscomp$230_temp__5823__auto____$1$jscomp$16$$=
$APP.$cljs$core$first$$($G__78967_G__78970_shapes__$1$jscomp$33$$);if($APP.$cljs$core$truth_$$($obj$jscomp$220_temp__5823__auto__$jscomp$230_temp__5823__auto____$1$jscomp$16$$))$obj$jscomp$220_temp__5823__auto__$jscomp$230_temp__5823__auto____$1$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$792$$,$obj$jscomp$220_temp__5823__auto__$jscomp$230_temp__5823__auto____$1$jscomp$16$$),$APP.$cljs$core$truth_$$($obj$jscomp$220_temp__5823__auto__$jscomp$230_temp__5823__auto____$1$jscomp$16$$)?
($obj$jscomp$220_temp__5823__auto__$jscomp$230_temp__5823__auto____$1$jscomp$16$$.__$__counter=$G__78966_G__78969_counter$jscomp$5$$,$G__78966_G__78969_counter$jscomp$5$$+=1,$G__78967_G__78970_shapes__$1$jscomp$33$$=$APP.$cljs$core$rest$$($G__78967_G__78970_shapes__$1$jscomp$33$$),$G__78968_G__78971_result$jscomp$372$$=$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($G__78968_G__78971_result$jscomp$372$$,$obj$jscomp$220_temp__5823__auto__$jscomp$230_temp__5823__auto____$1$jscomp$16$$)):($G__78966_G__78969_counter$jscomp$5$$+=
1,$G__78967_G__78970_shapes__$1$jscomp$33$$=$APP.$cljs$core$rest$$($G__78967_G__78970_shapes__$1$jscomp$33$$));else return $G__78968_G__78971_result$jscomp$372$$}});return(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"layer-item",className:"main_ui_workspace_sidebar_layers__element-list",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$163$$,$obj$jscomp$221$$){$out_arr__44092__auto__$jscomp$163$$.push($APP.$app$common$files$helpers$frame_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($obj$jscomp$221$$)?
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$frame_wrapper_STAR_$$,{selected:$selected$jscomp$172$$,index:$obj$jscomp$221$$.__$__counter,isSortable:!0,parentSize:$parent_size$jscomp$3$$,highlighted:$highlighted$jscomp$3$$,objects:$objects$jscomp$792$$,isFiltered:$is_filtered$jscomp$2$$,item:$obj$jscomp$221$$,depth:-1,renameId:$rename_id$jscomp$3$$},""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$221$$,$APP.$cljs$cst$266$id$$)??"")):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$,
{selected:$selected$jscomp$172$$,index:$obj$jscomp$221$$.__$__counter,isSortable:!0,parentSize:$parent_size$jscomp$3$$,highlighted:$highlighted$jscomp$3$$,objects:$objects$jscomp$792$$,isFiltered:$is_filtered$jscomp$2$$,item:$obj$jscomp$221$$,depth:-1,renameId:$rename_id$jscomp$3$$},""+($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($obj$jscomp$221$$,$APP.$cljs$cst$266$id$$)??"")));return $out_arr__44092__auto__$jscomp$163$$},[],$props_78914_root$jscomp$66_shapes__$1$jscomp$32$$)})})}),$app$main$ui$workspace$sidebar$layers$filters_tree_STAR_$$,
$p1__78925_SHARP_$jscomp$inline_9014$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78926_root$jscomp$67$$){var $objects$jscomp$794$$=$props_78926_root$jscomp$67$$.objects,$parent_size$jscomp$4$$=$props_78926_root$jscomp$67$$.parentSize,$selected$jscomp$173$$=$app$main$ui$workspace$sidebar$layers$use_selected_shapes$$(),$highlighted$jscomp$4$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$layers$ref_COLON_highlighted_shapes$$);$props_78926_root$jscomp$67$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$794$$,
$APP.$app$common$uuid$zero$$);return(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_layers__element-list",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$164$$,$JSCompiler_temp_const$jscomp$1815_p__78927$$){var $JSCompiler_inline_result$jscomp$1817_index$jscomp$485$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1815_p__78927$$,0,null),$id$jscomp$958$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1815_p__78927$$,
1,null);$JSCompiler_temp_const$jscomp$1815_p__78927$$=$out_arr__44092__auto__$jscomp$164$$.push;var $temp__5825__auto__$jscomp$inline_9012$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$794$$,$id$jscomp$958$$);$JSCompiler_inline_result$jscomp$1817_index$jscomp$485$$=$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$inline_9012$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$workspace$sidebar$layer_item$layer_item_STAR_$$,{selected:$selected$jscomp$173$$,index:$JSCompiler_inline_result$jscomp$1817_index$jscomp$485$$,
isSortable:!1,parentSize:$parent_size$jscomp$4$$,highlighted:$highlighted$jscomp$4$$,objects:$objects$jscomp$794$$,isFiltered:!0,item:$temp__5825__auto__$jscomp$inline_9012$$,depth:-1},$id$jscomp$958$$):null;$JSCompiler_temp_const$jscomp$1815_p__78927$$.call($out_arr__44092__auto__$jscomp$164$$,$JSCompiler_inline_result$jscomp$1817_index$jscomp$485$$);return $out_arr__44092__auto__$jscomp$164$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($props_78926_root$jscomp$67$$)))})});
$app$main$ui$workspace$sidebar$layers$filters_tree_STAR_$$=$rumext$v2$throttle$$($p1__78925_SHARP_$jscomp$inline_9014$$,50);
var $app$main$ui$workspace$sidebar$layers$ref_COLON_layers_search$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$4605$layers_search$$),$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$sidebar$layers$layers_toolbox_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_78961_size_parent$$){function $on_render_container$$($element$jscomp$82_observer$jscomp$6$$){var $temp__5825__auto__$jscomp$378$$=$APP.$rumext$v2$ref_val$$($lazy_load_ref$$);
if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$378$$)){if($element$jscomp$82_observer$jscomp$6$$!=null&&$APP.$cljs$core$_deref$$($observer_var$$)==null)return $element$jscomp$82_observer$jscomp$6$$=new IntersectionObserver($intersection_callback$$,{root:$element$jscomp$82_observer$jscomp$6$$}),$element$jscomp$82_observer$jscomp$6$$.observe($temp__5825__auto__$jscomp$378$$),$APP.$cljs$core$reset_BANG_$$($observer_var$$,$element$jscomp$82_observer$jscomp$6$$);if($element$jscomp$82_observer$jscomp$6$$==
null&&$APP.$cljs$core$_deref$$($observer_var$$)!=null)return $APP.$cljs$core$_deref$$($observer_var$$).disconnect(),$APP.$cljs$core$reset_BANG_$$($observer_var$$,null)}return null}function $intersection_callback$$($and__5023__auto__$jscomp$inline_9020_entries$jscomp$41$$){$and__5023__auto__$jscomp$inline_9020_entries$jscomp$41$$=$APP.$cljs$core$first$$($and__5023__auto__$jscomp$inline_9020_entries$jscomp$41$$).isIntersecting;return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9020_entries$jscomp$41$$)?
$show_more$$!=null:$and__5023__auto__$jscomp$inline_9020_entries$jscomp$41$$)?$show_more$$.$cljs$core$IFn$_invoke$arity$0$?$show_more$$.$cljs$core$IFn$_invoke$arity$0$():$show_more$$():null}$props_78961_size_parent$$=$props_78961_size_parent$$.sizeParent;var $filtered_objects$jscomp$1_page$jscomp$167$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page$$),$page_id$jscomp$430$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($filtered_objects$jscomp$1_page$jscomp$167$$,$APP.$cljs$cst$266$id$$),
$focus$jscomp$17$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),$objects$jscomp$797$$=$app$main$ui$hooks$with_focus_objects$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1636$objects$$.$cljs$core$IFn$_invoke$arity$1$($filtered_objects$jscomp$1_page$jscomp$167$$),$focus$jscomp$17$$),$title$jscomp$39$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($focus$jscomp$17$$))?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$797$$,
$APP.$cljs$core$first$$($focus$jscomp$17$$)),$APP.$cljs$cst$725$name$$):null,$observer_var$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$lazy_load_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$filter_component_vec__78962$$=$app$main$ui$workspace$sidebar$layers$use_search$$($filtered_objects$jscomp$1_page$jscomp$167$$,$objects$jscomp$797$$);$filtered_objects$jscomp$1_page$jscomp$167$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_component_vec__78962$$,0,null);
var $show_more$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_component_vec__78962$$,1,null);$filter_component_vec__78962$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($filter_component_vec__78962$$,2,null);var $toogle_focus_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$toggle_focus_mode$$())});return(0,$APP.$rumext$v2$jsxs$$)("div",
{id:"layers","data-testid":"layer-tree",className:"main_ui_workspace_sidebar_layers__layers",children:[$APP.$app$common$data$not_empty_QMARK_$$($focus$jscomp$17$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__tool-window-bar",children:(0,$APP.$rumext$v2$jsxs$$)("button",{onClick:$toogle_focus_mode$$,className:"main_ui_workspace_sidebar_layers__focus-title",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_layers__focus-back-button",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,
{iconId:"arrow-left"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__focus-name",children:$APP.$cljs$core$truth_$$($title$jscomp$39$$)?$title$jscomp$39$$:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_layers__focus-mode-tag-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$notifications$badge$badge_notification$$,{content:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.focus.focus-mode"),
size:$APP.$cljs$cst$3945$small$$,"is-focus":!0})})]})}):$filter_component_vec__78962$$.$cljs$core$IFn$_invoke$arity$0$?$filter_component_vec__78962$$.$cljs$core$IFn$_invoke$arity$0$():$filter_component_vec__78962$$(),$filtered_objects$jscomp$1_page$jscomp$167$$!=null?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{"data-scroll-container":!0,ref:$on_render_container$$,className:"main_ui_workspace_sidebar_layers__tool-window-content",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$filters_tree_STAR_$$,
{objects:$filtered_objects$jscomp$1_page$jscomp$167$$,parentSize:$props_78961_size_parent$$},""+($page_id$jscomp$430$$??"")),(0,$APP.$rumext$v2$jsx$$)("div",{ref:$lazy_load_ref$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{onScroll:$app$main$ui$workspace$sidebar$layers$on_scroll$$,"data-scroll-container":!0,style:{display:$filtered_objects$jscomp$1_page$jscomp$167$$!=null?"none":null},className:"main_ui_workspace_sidebar_layers__tool-window-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$layers_tree_wrapper_STAR_$$,
{objects:$filtered_objects$jscomp$1_page$jscomp$167$$,isFiltered:!0,parentSize:$props_78961_size_parent$$},""+($page_id$jscomp$430$$??""))})]}):(0,$APP.$rumext$v2$jsx$$)("div",{onScroll:$app$main$ui$workspace$sidebar$layers$on_scroll$$,"data-scroll-container":!0,style:{display:$filtered_objects$jscomp$1_page$jscomp$167$$!=null?"none":null},className:"main_ui_workspace_sidebar_layers__tool-window-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$layers_tree_wrapper_STAR_$$,
{objects:$objects$jscomp$797$$,isFiltered:!1,parentSize:$props_78961_size_parent$$},""+($page_id$jscomp$430$$??""))})]})});var $app$main$ui$workspace$sidebar$options$menus$border_radius$border_radius_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($applied_tokens$jscomp$6_props_79025$$){function $on_radius_r4_change$$($p1__79018_SHARP_$$){return $on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__79018_SHARP_$$,$APP.$cljs$cst$1654$r4$$):$on_single_radius_change$$($p1__79018_SHARP_$$,$APP.$cljs$cst$1654$r4$$)}function $on_radius_r3_change$$($p1__79017_SHARP_$$){return $on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$?
$on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__79017_SHARP_$$,$APP.$cljs$cst$1653$r3$$):$on_single_radius_change$$($p1__79017_SHARP_$$,$APP.$cljs$cst$1653$r3$$)}function $on_radius_r2_change$$($p1__79016_SHARP_$$){return $on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__79016_SHARP_$$,$APP.$cljs$cst$1652$r2$$):$on_single_radius_change$$($p1__79016_SHARP_$$,$APP.$cljs$cst$1652$r2$$)}function $on_radius_r1_change$$($p1__79015_SHARP_$$){return $on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$?
$on_single_radius_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__79015_SHARP_$$,$APP.$cljs$cst$1651$r1$$):$on_single_radius_change$$($p1__79015_SHARP_$$,$APP.$cljs$cst$1651$r1$$)}var $ids$jscomp$285$$=$applied_tokens$jscomp$6_props_79025$$.ids,$class$$jscomp$72$$=$applied_tokens$jscomp$6_props_79025$$.className,$values$jscomp$80$$=$applied_tokens$jscomp$6_props_79025$$.values;$applied_tokens$jscomp$6_props_79025$$=$applied_tokens$jscomp$6_props_79025$$.appliedTokens;var $token_numeric_inputs$$=$APP.$app$main$features$use_feature$$("tokens/numeric-input"),
$all_values_equal_QMARK_$$=$app$main$ui$workspace$sidebar$options$menus$border_radius$all_equal_QMARK_$$($values$jscomp$80$$),$all_token_equal_QMARK_$$=$APP.$cljs$core$seq$$($applied_tokens$jscomp$6_props_79025$$)&&$app$main$ui$workspace$sidebar$options$menus$border_radius$all_equal_QMARK_$$($applied_tokens$jscomp$6_props_79025$$),$radius_expanded_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$radius_expanded$$=$APP.$cljs$core$_deref$$($radius_expanded_STAR_$$),$on_detach_token$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$285$$)],function($token_name$jscomp$20$$,$attr$jscomp$68$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$20$$,$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$68$$]),
$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$285$$],null)))}),$on_detach_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],function($token$jscomp$133$$){return $APP.$cljs$core$run_BANG_$$(function($p1__79012_SHARP_$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$133$$,$p1__79012_SHARP_$$):$on_detach_token$jscomp$2$$($token$jscomp$133$$,
$p1__79012_SHARP_$$)},new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1654$r4$$],null))}),$on_detach_r1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],function($token$jscomp$134$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$134$$,
$APP.$cljs$cst$1651$r1$$):$on_detach_token$jscomp$2$$($token$jscomp$134$$,$APP.$cljs$cst$1651$r1$$)}),$on_detach_r2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],function($token$jscomp$135$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$135$$,$APP.$cljs$cst$1652$r2$$):$on_detach_token$jscomp$2$$($token$jscomp$135$$,$APP.$cljs$cst$1652$r2$$)}),
$on_detach_r3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],function($token$jscomp$136$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$136$$,$APP.$cljs$cst$1653$r3$$):$on_detach_token$jscomp$2$$($token$jscomp$136$$,$APP.$cljs$cst$1653$r3$$)}),$on_detach_r4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_detach_token$jscomp$2$$)],
function($token$jscomp$137$$){return $on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach_token$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($token$jscomp$137$$,$APP.$cljs$cst$1654$r4$$):$on_detach_token$jscomp$2$$($token$jscomp$137$$,$APP.$cljs$cst$1654$r4$$)}),$change_radius$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$285$$)],function($update_fn$jscomp$50$$){return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$285$$,
function($shape$jscomp$998$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$998$$)),$APP.$cljs$cst$1651$r1$$)?$update_fn$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$?$update_fn$jscomp$50$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$998$$):$update_fn$jscomp$50$$($shape$jscomp$998$$):$shape$jscomp$998$$},new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3688$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1654$r4$$],null)],null))}),$change_one_radius$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$285$$)],function($update_fn$jscomp$51$$,$attr$jscomp$69$$){return $APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$285$$,
function($shape$jscomp$999$$){return $APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$999$$)),$APP.$cljs$cst$1651$r1$$)?$update_fn$jscomp$51$$.$cljs$core$IFn$_invoke$arity$1$?$update_fn$jscomp$51$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$999$$):$update_fn$jscomp$51$$($shape$jscomp$999$$):$shape$jscomp$999$$},new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$3688$reg_objects_QMARK_$$,!0,$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$attr$jscomp$69$$],null)],null))}),$toggle_radius_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($radius_expanded$$)],function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($radius_expanded_STAR_$$,$APP.$cljs$core$not$$)}),$on_all_radius_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_radius$$),
$APP.$rumext$v2$adapt$$($ids$jscomp$285$$)],function($value$jscomp$823$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value$jscomp$823$$,function($p1__79013_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){function $G__79032$$($shape$jscomp$1000$$){return $APP.$app$common$types$shape$radius$set_radius_to_all_corners$$($shape$jscomp$1000$$,$p1__79013_SHARP_$$)}return $change_radius$$.$cljs$core$IFn$_invoke$arity$1$?$change_radius$$.$cljs$core$IFn$_invoke$arity$1$($G__79032$$):
$change_radius$$($G__79032$$)}())},$ids$jscomp$285$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1652$r2$$,null,$APP.$cljs$cst$1653$r3$$,null,$APP.$cljs$cst$1651$r1$$,null,$APP.$cljs$cst$1654$r4$$,null],null),null))}),$on_single_radius_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_one_radius$$),$APP.$rumext$v2$adapt$$($ids$jscomp$285$$)],function($value$jscomp$824$$,$attr$jscomp$70$$){return $app$main$ui$workspace$sidebar$options$common$emit_value_or_token$$($value$jscomp$824$$,
function($p1__79014_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$(function(){function $G__79037$$($shape$jscomp$1001$$){return $APP.$app$common$types$shape$radius$set_radius_to_single_corner$$($shape$jscomp$1001$$,$attr$jscomp$70$$,$p1__79014_SHARP_$$)}return $change_one_radius$$.$cljs$core$IFn$_invoke$arity$2$?$change_one_radius$$.$cljs$core$IFn$_invoke$arity$2$($G__79037$$,$attr$jscomp$70$$):$change_one_radius$$($G__79037$$,$attr$jscomp$70$$)}())},$ids$jscomp$285$$,
$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$70$$]))}),$expand_stream$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($cljs$cst$5782$expand_border_radius$$),$APP.$app$main$store$stream$$)});$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($expand_stream$$,function(){return $APP.$cljs$core$reset_BANG_$$($radius_expanded_STAR_$$,
!0)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$285$$)],function(){return $APP.$cljs$core$reset_BANG_$$($radius_expanded_STAR_$$,!1)});return $token_numeric_inputs$$?(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.radius-section"),className:""+($class$$jscomp$72$$??"")+" main_ui_workspace_sidebar_options_menus_border_radius__radius-token",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-first-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_all_radius_change$$,placeholder:$all_values_equal_QMARK_$$&&$all_token_equal_QMARK_$$?"--":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),attr:$APP.$cljs$cst$1998$border_radius$$,appliedToken:$APP.$cljs$core$not$$($APP.$cljs$core$seq$$($applied_tokens$jscomp$6_props_79025$$))?
null:$all_values_equal_QMARK_$$&&$all_token_equal_QMARK_$$?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,$APP.$cljs$cst$1651$r1$$):$APP.$cljs$cst$1621$multiple$$,value:$all_values_equal_QMARK_$$?$APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)==null?0:$APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$):null,onDetach:$on_detach_all$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius"),
nillable:!0,icon:"corner-radius"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:$APP.$cljs$core$truth_$$($radius_expanded$$)?"main_ui_workspace_sidebar_options_menus_border_radius__selected":"",variant:"ghost",tooltipPlacement:"top-left",onClick:$toggle_radius_mode$$,"aria-label":$APP.$cljs$core$truth_$$($radius_expanded$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.hide-all-corners"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.show-single-corners"),
icon:"corner-radius"})]}),$APP.$cljs$core$truth_$$($radius_expanded$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-4-token",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_radius_r1_change$$,className:"main_ui_workspace_sidebar_options_menus_border_radius__dropdown-offset",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,$APP.$cljs$cst$1651$r1$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$80$$,$APP.$cljs$cst$1651$r1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",innerClass:"main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input",attr:$APP.$cljs$cst$1998$border_radius$$,
appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,$APP.$cljs$cst$1651$r1$$),value:$APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$),onDetach:$on_detach_r1$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-top-left")}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,
onChange:$on_radius_r2_change$$,tooltipPlacement:"top-left",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,$APP.$cljs$cst$1652$r2$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$80$$,$APP.$cljs$cst$1652$r2$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",innerClass:"main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input",attr:$APP.$cljs$cst$1998$border_radius$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,$APP.$cljs$cst$1652$r2$$),value:$APP.$cljs$cst$1652$r2$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$),onDetach:$on_detach_r2$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-top-right"),nillable:!0}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,
{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_radius_r4_change$$,className:"main_ui_workspace_sidebar_options_menus_border_radius__dropdown-offset",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,$APP.$cljs$cst$1654$r4$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$80$$,
$APP.$cljs$cst$1654$r4$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",innerClass:"main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input",attr:$APP.$cljs$cst$1998$border_radius$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,$APP.$cljs$cst$1654$r4$$),value:$APP.$cljs$cst$1654$r4$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$),onDetach:$on_detach_r4$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-bottom-left"),
nillable:!0}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_radius_r3_change$$,tooltipPlacement:"top-left",className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-wrapper",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,
$APP.$cljs$cst$1653$r3$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$80$$,$APP.$cljs$cst$1653$r3$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",innerClass:"main_ui_workspace_sidebar_options_menus_border_radius__no-icon-input",attr:$APP.$cljs$cst$1998$border_radius$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$6_props_79025$$,
$APP.$cljs$cst$1653$r3$$),value:$APP.$cljs$cst$1653$r3$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$),onDetach:$on_detach_r3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-bottom-right"),nillable:!0})]}):null]}):(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.radius-section"),className:""+($class$$jscomp$72$$??"")+" main_ui_workspace_sidebar_options_menus_border_radius__radius",
children:[$APP.$cljs$core$not$$($radius_expanded$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius"),className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-1",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"corner-radius",size:"s",className:"main_ui_workspace_sidebar_options_menus_border_radius__icon"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{placeholder:$all_values_equal_QMARK_$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"),min:0,nillable:!0,onChange:$on_all_radius_change$$,value:$all_values_equal_QMARK_$$?$APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)==
null?0:$APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$):null})]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__radius-4",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__small-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-top-left"),
min:0,onChange:$on_radius_r1_change$$,value:$APP.$cljs$cst$1651$r1$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__small-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-top-right"),min:0,onChange:$on_radius_r2_change$$,value:$APP.$cljs$cst$1652$r2$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__small-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-bottom-left"),min:0,onChange:$on_radius_r4_change$$,value:$APP.$cljs$cst$1654$r4$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_border_radius__small-input",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius-bottom-right"),min:0,onChange:$on_radius_r3_change$$,value:$APP.$cljs$cst$1653$r3$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$80$$)})})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{className:$APP.$cljs$core$truth_$$($radius_expanded$$)?"main_ui_workspace_sidebar_options_menus_border_radius__selected":
"",variant:"ghost",onClick:$toggle_radius_mode$$,"aria-label":$APP.$cljs$core$truth_$$($radius_expanded$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.hide-all-corners"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.radius.show-single-corners"),icon:"corner-radius"})]})},function($old_props$jscomp$2$$,$new_props$jscomp$3$$){var $old_values$$=$old_props$jscomp$2$$.values,$new_values$$=$new_props$jscomp$3$$.values,$old_applied_tokens$jscomp$1$$=
$old_props$jscomp$2$$.appliedTokens,$new_applied_tokens$jscomp$1$$=$new_props$jscomp$3$$.appliedTokens;return $old_props$jscomp$2$$["class"]===$new_props$jscomp$3$$["class"]&&$old_props$jscomp$2$$.ids===$new_props$jscomp$3$$.ids&&$old_props$jscomp$2$$.shapes===$new_props$jscomp$3$$.shapes&&$old_applied_tokens$jscomp$1$$===$new_applied_tokens$jscomp$1$$&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$$,$APP.$cljs$cst$1651$r1$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$$,
$APP.$cljs$cst$1651$r1$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$$,$APP.$cljs$cst$1652$r2$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$$,$APP.$cljs$cst$1652$r2$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$$,$APP.$cljs$cst$1653$r3$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$$,$APP.$cljs$cst$1653$r3$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$$,$APP.$cljs$cst$1654$r4$$)===
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$$,$APP.$cljs$cst$1654$r4$$)});var $app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,18,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1814$proportion_lock$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$3465$ox$$,$APP.$cljs$cst$3466$oy$$,$APP.$cljs$cst$1794$rotation$$,$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1610$selrect$$,
$APP.$cljs$cst$1609$points$$,$APP.$cljs$cst$1884$show_content$$,$APP.$cljs$cst$1883$hide_in_viewer$$,$APP.$cljs$cst$1713$layout_item_h_sizing$$,$APP.$cljs$cst$1714$layout_item_v_sizing$$],null),$app$main$ui$workspace$sidebar$options$menus$measures$generic_options$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1794$rotation$$,null,$APP.$cljs$cst$874$size$$,null,$APP.$cljs$cst$1681$position$$,null],null),null),$app$main$ui$workspace$sidebar$options$menus$measures$rect_options$$=
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1794$rotation$$,null,$APP.$cljs$cst$2831$radius$$,null,$APP.$cljs$cst$874$size$$,null,$APP.$cljs$cst$1681$position$$,null],null),null),$app$main$ui$workspace$sidebar$options$menus$measures$frame_options$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,7,[$cljs$cst$5783$show_in_viewer$$,null,$APP.$cljs$cst$1794$rotation$$,null,$cljs$cst$5784$clip_content$$,
null,$APP.$cljs$cst$2831$radius$$,null,$APP.$cljs$cst$874$size$$,null,$cljs$cst$5785$presets$$,null,$APP.$cljs$cst$1681$position$$,null],null),null),$app$main$ui$workspace$sidebar$options$menus$measures$xf_COLON_map_type$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$139$type$$),$app$main$ui$workspace$sidebar$options$menus$measures$xf_COLON_mapcat_type_to_options$$=$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$options$menus$measures$type__GT_options$$),
$app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($applied_tokens$jscomp$7_props_79059$$){var $shapes$jscomp$205$$=$applied_tokens$jscomp$7_props_79059$$.shapes,$ids$jscomp$286$$=$applied_tokens$jscomp$7_props_79059$$.ids,$type$jscomp$627$$=$applied_tokens$jscomp$7_props_79059$$.type,$values$jscomp$81$$=$applied_tokens$jscomp$7_props_79059$$.values;$applied_tokens$jscomp$7_props_79059$$=$applied_tokens$jscomp$7_props_79059$$.appliedTokens;
var $token_numeric_inputs$jscomp$1$$=$APP.$app$main$features$use_feature$$("tokens/numeric-input"),$all_types$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$627$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$205$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$627$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$main$ui$workspace$sidebar$options$menus$measures$xf_COLON_map_type$$,
$shapes$jscomp$205$$):null}),$options$jscomp$621$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$627$$),$APP.$rumext$v2$adapt$$($all_types$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$627$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$app$main$ui$workspace$sidebar$options$menus$measures$xf_COLON_mapcat_type_to_options$$,
$all_types$$):$app$main$ui$workspace$sidebar$options$menus$measures$type__GT_options$$($type$jscomp$627$$)}),$frames$jscomp$28$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$205$$)],function(){var $objects$jscomp$798$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1612$frame_id$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$798$$))),$shapes$jscomp$205$$)}),$disabled_position_QMARK__selection_parents_selection_parents_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$286$$)});$disabled_position_QMARK__selection_parents_selection_parents_ref$$=$APP.$rumext$v2$deref$$($disabled_position_QMARK__selection_parents_selection_parents_ref$$);
var $disabled_width_sizing_QMARK__shape$jscomp$1003$$=$APP.$cljs$core$first$$($shapes$jscomp$205$$),$flex_child_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$,$disabled_position_QMARK__selection_parents_selection_parents_ref$$),$absolute_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_width_sizing_QMARK__shape$jscomp$1003$$),$flex_container_QMARK_$$=$APP.$app$common$types$shape$layout$flex_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($disabled_width_sizing_QMARK__shape$jscomp$1003$$),
$flex_auto_width_QMARK_$$=$APP.$app$common$types$shape$layout$auto_width_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_width_sizing_QMARK__shape$jscomp$1003$$),$flex_fill_width_QMARK_$$=$APP.$app$common$types$shape$layout$fill_width_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($disabled_width_sizing_QMARK__shape$jscomp$1003$$),$flex_auto_height_QMARK_$$=$APP.$app$common$types$shape$layout$auto_height_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($disabled_width_sizing_QMARK__shape$jscomp$1003$$),
$flex_fill_height_QMARK_$$=$APP.$app$common$types$shape$layout$fill_height_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($disabled_width_sizing_QMARK__shape$jscomp$1003$$);$disabled_position_QMARK__selection_parents_selection_parents_ref$$=$APP.$cljs$core$truth_$$($flex_child_QMARK_$$)?!$absolute_QMARK_$jscomp$1$$:$flex_child_QMARK_$$;$disabled_width_sizing_QMARK__shape$jscomp$1003$$=function(){var $and__5023__auto__$jscomp$830$$=$APP.$cljs$core$truth_$$($flex_child_QMARK_$$)?$flex_child_QMARK_$$:$flex_container_QMARK_$$;
return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$830$$)?($flex_auto_width_QMARK_$$||$flex_fill_width_QMARK_$$)&&!$absolute_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$830$$}();var $disabled_height_sizing_QMARK_$$=function(){var $and__5023__auto__$jscomp$831$$=$APP.$cljs$core$truth_$$($flex_child_QMARK_$$)?$flex_child_QMARK_$$:$flex_container_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$831$$)?($flex_auto_height_QMARK_$$||$flex_fill_height_QMARK_$$)&&!$absolute_QMARK_$jscomp$1$$:
$and__5023__auto__$jscomp$831$$}(),$on_proportion_lock_change_shapes__$1$jscomp$34$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$205$$),$APP.$rumext$v2$adapt$$($frames$jscomp$28$$)],function(){return $APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$shapes$translate_to_frame$$,$shapes$jscomp$205$$,$frames$jscomp$28$$)}),$shape__$1$jscomp$106$$=$APP.$cljs$core$first$$($on_proportion_lock_change_shapes__$1$jscomp$34$$),
$values__$1$jscomp$4$$=function(){var $G__79060__$2_rect$jscomp$46$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$106$$,$APP.$cljs$cst$1609$points$$)),$G__79060__$3_val_x$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$81$$,$APP.$cljs$cst$1515$x$$),$val_y$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$81$$,$APP.$cljs$cst$1516$y$$),$G__79060__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__79060__$3_val_x$$,
$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($values$jscomp$81$$,$APP.$cljs$cst$1515$x$$,$G__79060__$2_rect$jscomp$46$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__79060__$2_rect$jscomp$46$$,$APP.$cljs$cst$1515$x$$)):$values$jscomp$81$$;$G__79060__$2_rect$jscomp$46$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val_y$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79060__$1$$,$APP.$cljs$cst$1516$y$$,
$G__79060__$2_rect$jscomp$46$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__79060__$2_rect$jscomp$46$$,$APP.$cljs$cst$1516$y$$)):$G__79060__$1$$;$G__79060__$3_val_x$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__79060__$3_val_x$$,$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$cst$3465$ox$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$81$$)!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79060__$2_rect$jscomp$46$$,$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$3465$ox$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$81$$)):
$G__79060__$2_rect$jscomp$46$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($val_y$$,$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$cst$3466$oy$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$81$$)!=null?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79060__$3_val_x$$,$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$3466$oy$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$81$$)):$G__79060__$3_val_x$$}(),$values__$2$jscomp$1$$=function(){var $G__79061__$2_selrect$jscomp$83$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$106$$,
$APP.$cljs$cst$1610$selrect$$),$rotation$jscomp$23$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($shape__$1$jscomp$106$$,$APP.$cljs$cst$1794$rotation$$,0),$G__79061__$1$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$4$$),$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($values__$1$jscomp$4$$,$APP.$cljs$cst$290$width$$,$G__79061__$2_selrect$jscomp$83$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__79061__$2_selrect$jscomp$83$$,$APP.$cljs$cst$290$width$$)):$values__$1$jscomp$4$$;$G__79061__$2_selrect$jscomp$83$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$4$$),$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79061__$1$$,$APP.$cljs$cst$1527$height$$,$G__79061__$2_selrect$jscomp$83$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($G__79061__$2_selrect$jscomp$83$$,
$APP.$cljs$cst$1527$height$$)):$G__79061__$1$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$4$$),$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79061__$2_selrect$jscomp$83$$,$APP.$cljs$cst$1794$rotation$$,$rotation$jscomp$23$$):$G__79061__$2_selrect$jscomp$83$$}(),$proportion_lock$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,
$APP.$cljs$cst$1814$proportion_lock$$),$clip_content_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$show_in_viewer_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$preset_state_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$show_presets_dropdown_QMARK_$$=$APP.$cljs$core$_deref$$($preset_state_STAR_$$),$preset_search_term_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(""),$preset_search_term$$=$APP.$cljs$core$_deref$$($preset_search_term_STAR_$$),$preset_container_ref$$=
(0,$APP.$rumext$v2$use_ref$$)(null),$toggle_presets$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($preset_state_STAR_$$,$APP.$cljs$core$not$$);return $APP.$cljs$core$reset_BANG_$$($preset_search_term_STAR_$$,"")}),$close_presets$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($show_presets_dropdown_QMARK_$$)],function(){$APP.$cljs$core$reset_BANG_$$($preset_state_STAR_$$,
!1);return $APP.$cljs$core$reset_BANG_$$($preset_search_term_STAR_$$,"")}),$on_preset_search_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($value$jscomp$827$$){return $APP.$cljs$core$reset_BANG_$$($preset_search_term_STAR_$$,$value$jscomp$827$$)}),$filtered_size_presets$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($preset_search_term$$)],function(){return $app$main$ui$workspace$sidebar$options$menus$measures$filter_size_presets$$($preset_search_term$$)}),
$on_preset_selected$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($event$jscomp$503_height$jscomp$168$$){var $width$jscomp$197$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$503_height$jscomp$168$$),"width"));$event$jscomp$503_height$jscomp$168$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$503_height$jscomp$168$$),
"height"));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$($ids$jscomp$286$$,$APP.$cljs$cst$290$width$$,$width$jscomp$197$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$($ids$jscomp$286$$,$APP.$cljs$cst$1527$height$$,$event$jscomp$503_height$jscomp$168$$)]));$APP.$cljs$core$reset_BANG_$$($preset_state_STAR_$$,
!1);return $APP.$cljs$core$reset_BANG_$$($preset_search_term_STAR_$$,"")}),$orientation$jscomp$7$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$627$$,$APP.$cljs$cst$1611$frame$$)?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)>$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)?$APP.$cljs$cst$1815$horiz$$:$cljs$cst$5786$vert$$:null,$on_orientation_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],
function($JSCompiler_inline_result$jscomp$1685_orientation__$1_param72329$jscomp$inline_9025$$){var $JSCompiler_temp_const$jscomp$1683$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;$JSCompiler_inline_result$jscomp$1685_orientation__$1_param72329$jscomp$inline_9025$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1685_orientation__$1_param72329$jscomp$inline_9025$$);$JSCompiler_inline_result$jscomp$1685_orientation__$1_param72329$jscomp$inline_9025$$=
$app$main$data$workspace$transforms$change_orientation$$($ids$jscomp$286$$,$JSCompiler_inline_result$jscomp$1685_orientation__$1_param72329$jscomp$inline_9025$$);return $JSCompiler_temp_const$jscomp$1683$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1685_orientation__$1_param72329$jscomp$inline_9025$$)}),$on_size_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$),$APP.$rumext$v2$adapt$$($on_proportion_lock_change_shapes__$1$jscomp$34$$)],
function($value$jscomp$828$$,$attr$jscomp$71$$){return typeof $value$jscomp$828$$==="string"||typeof $value$jscomp$828$$==="number"?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$286$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$update_dimensions$$.$cljs$core$IFn$_invoke$arity$3$($ids$jscomp$286$$,$attr$jscomp$71$$,$value$jscomp$828$$)])):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$286$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$828$$),$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$71$$]),
$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$286$$],null))]))});$on_proportion_lock_change_shapes__$1$jscomp$34$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$),$APP.$rumext$v2$adapt$$($proportion_lock$jscomp$1$$)],function(){var $new_lock$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($proportion_lock$jscomp$1$$,$APP.$cljs$cst$1621$multiple$$)?!0:$APP.$cljs$core$not$$($proportion_lock$jscomp$1$$);return $APP.$cljs$core$run_BANG_$$(function($p1__79053_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_shape_proportion_lock$$($p1__79053_SHARP_$$,
$new_lock$$))},$ids$jscomp$286$$)});var $on_position_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($value$jscomp$829$$,$attr$jscomp$72$$){return typeof $value$jscomp$829$$==="string"||typeof $value$jscomp$829$$==="number"?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$286$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$update_positions$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$286$$,
$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$attr$jscomp$72$$,$value$jscomp$829$$])))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$286$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$829$$),
$APP.$cljs$cst$2656$attrs$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$72$$]),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$286$$],null))]))}),$on_rotation_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($value$jscomp$830_value__$1$jscomp$48$$){return typeof $value$jscomp$830_value__$1$jscomp$48$$==="string"||typeof $value$jscomp$830_value__$1$jscomp$48$$==="number"?($value$jscomp$830_value__$1$jscomp$48$$=
$app$main$ui$workspace$sidebar$options$menus$measures$fixed_decimal_value$cljs$0core$0IFn$0_invoke$0arity$02$$($value$jscomp$830_value__$1$jscomp$48$$,2),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$286$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_rotation$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$286$$,$value$jscomp$830_value__$1$jscomp$48$$))):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$286$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$830_value__$1$jscomp$48$$),$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1794$rotation$$,null],null),null),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$286$$],null))]))}),$on_width_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$$)],function($p1__79054_SHARP_$$){return $on_size_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__79054_SHARP_$$,$APP.$cljs$cst$290$width$$):$on_size_change$$($p1__79054_SHARP_$$,
$APP.$cljs$cst$290$width$$)}),$on_height_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_size_change$$)],function($p1__79055_SHARP_$$){return $on_size_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_size_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__79055_SHARP_$$,$APP.$cljs$cst$1527$height$$):$on_size_change$$($p1__79055_SHARP_$$,$APP.$cljs$cst$1527$height$$)}),$on_pos_x_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_position_change$$)],
function($p1__79056_SHARP_$$){return $on_position_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_position_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__79056_SHARP_$$,$APP.$cljs$cst$1515$x$$):$on_position_change$$($p1__79056_SHARP_$$,$APP.$cljs$cst$1515$x$$)}),$on_pos_y_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_position_change$$)],function($p1__79057_SHARP_$$){return $on_position_change$$.$cljs$core$IFn$_invoke$arity$2$?$on_position_change$$.$cljs$core$IFn$_invoke$arity$2$($p1__79057_SHARP_$$,
$APP.$cljs$cst$1516$y$$):$on_position_change$$($p1__79057_SHARP_$$,$APP.$cljs$cst$1516$y$$)}),$on_detach_token$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($token_name$jscomp$21$$,$attr$jscomp$73$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$21$$,
$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$73$$]),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$286$$],null)))}),$on_change_clip_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($event$jscomp$504$$){var $value$jscomp$831$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$504$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,
function($shape__$2$jscomp$10$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$2$jscomp$10$$,$APP.$cljs$cst$1884$show_content$$,$APP.$cljs$core$not$$($value$jscomp$831$$))}))}),$on_change_show_in_viewer$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$286$$)],function($event$jscomp$505_undo_id$jscomp$107$$){var $value$jscomp$832$$=$APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$505_undo_id$jscomp$107$$));
$event$jscomp$505_undo_id$jscomp$107$$=Symbol();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($event$jscomp$505_undo_id$jscomp$107$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$286$$,function($shape__$2$jscomp$11$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape__$2$jscomp$11$$,
$APP.$cljs$cst$1883$hide_in_viewer$$,$APP.$cljs$core$not$$($value$jscomp$832$$))})]));$APP.$cljs$core$truth_$$($value$jscomp$832$$)||$APP.$cljs$core$run_BANG_$$($APP.$app$main$store$emit_BANG_$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79058_SHARP_$$){return $app$main$data$workspace$interactions$remove_all_interactions_nav_to$$($p1__79058_SHARP_$$)},$ids$jscomp$286$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($event$jscomp$505_undo_id$jscomp$107$$))}),
$handle_fit_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$transforms$selected_fit_content$$())});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"shape-measures-section",className:"main_ui_workspace_sidebar_options_menus_measures__element-set",children:[$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$832$$=$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?
$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5785$presets$$):$options$jscomp$621$$($cljs$cst$5785$presets$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$832$$)?$all_types$$==null||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($all_types$$),1):$and__5023__auto__$jscomp$832$$}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__presets",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{ref:$preset_container_ref$$,
onClick:$toggle_presets$$,className:"main_ui_workspace_sidebar_options_menus_measures__presets-wrapper "+($APP.$cljs$core$truth_$$($show_presets_dropdown_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_measures__opened":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__select-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size-presets")}),(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__collapsed-icon",
children:$APP.$app$main$ui$icons$arrow$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$show_presets_dropdown_QMARK_$$,"on-close":$close_presets$$,container:$preset_container_ref$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{onClick:$APP.$app$util$dom$stop_propagation$$,className:"main_ui_workspace_sidebar_options_menus_measures__custom-select-dropdown",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-search",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$search_bar$search_bar_STAR_$$,{onChange:$on_preset_search_change$$,value:$preset_search_term$$,autoFocus:!0,placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.search-size-preset")})}),(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-list",children:$APP.$cljs$core$empty_QMARK_$$($filtered_size_presets$$)?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_sidebar_options_menus_measures__dropdown-element main_ui_workspace_sidebar_options_menus_measures__disabled",
children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-name",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.no-size-preset-results")})}):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$166$$,$JSCompiler_temp$jscomp$1824_size_preset$$){var $JSCompiler_temp_const$jscomp$1822$$=$out_arr__44092__auto__$jscomp$166$$.push;if($APP.$cljs$core$not$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$)))$JSCompiler_temp$jscomp$1824_size_preset$$=
(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_sidebar_options_menus_measures__dropdown-element main_ui_workspace_sidebar_options_menus_measures__disabled",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$)})},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$));
else{var $preset_match$jscomp$inline_9027$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$),$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$),0))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$),
$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$),0));$JSCompiler_temp$jscomp$1824_size_preset$$=(0,$APP.$rumext$v2$jsxs$$)("li",{"data-width":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$)),"data-height":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$)),
onClick:$on_preset_selected$$,className:"main_ui_workspace_sidebar_options_menus_measures__dropdown-element "+($preset_match$jscomp$inline_9027$$?"main_ui_workspace_sidebar_options_menus_measures__match":""),children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__name-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-name",children:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$)}),
(0,$APP.$rumext$v2$jsxs$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__preset-size",children:[$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$)," x ",$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$)]})]}),$preset_match$jscomp$inline_9027$$?(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__check-icon",children:$APP.$app$main$ui$icons$tick$$}):
null]},$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1824_size_preset$$))}$JSCompiler_temp_const$jscomp$1822$$.call($out_arr__44092__auto__$jscomp$166$$,$JSCompiler_temp$jscomp$1824_size_preset$$);return $out_arr__44092__auto__$jscomp$166$$},[],$filtered_size_presets$$)})]})})]}),$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:function(){var $or__5025__auto__$jscomp$1224$$=$APP.$app$common$data$name$$($orientation$jscomp$7$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1224$$)?$or__5025__auto__$jscomp$1224$$:""}(),"on-change":$on_orientation_change$$,name:"frame-orientation",wide:!0,"class":"main_ui_workspace_sidebar_options_menus_measures__radio-buttons",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"size-vertical",value:"vert",id:"size-vertical"}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{icon:"size-horizontal",value:"horiz",
id:"size-horizontal"})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fit-content"),onPointerDown:$handle_fit_content$$,icon:"fit-content"})]}):null,$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$874$size$$):$options$jscomp$621$$($APP.$cljs$cst$874$size$$))?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__size",children:[$token_numeric_inputs$jscomp$1$$?(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:.01,onChange:$on_width_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,
$APP.$cljs$cst$290$width$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$290$width$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$290$width$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,$APP.$cljs$cst$290$width$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,
$APP.$cljs$cst$290$width$$),onDetach:$on_detach_token$jscomp$3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.width"),disabled:$disabled_width_sizing_QMARK__shape$jscomp$1003$$,icon:"character-w"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:.01,align:$APP.$cljs$cst$258$right$$,onChange:$on_height_change$$,attr:$APP.$cljs$cst$1527$height$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,
$APP.$cljs$cst$1527$height$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1527$height$$),onDetach:$on_detach_token$jscomp$3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.height"),disabled:$disabled_height_sizing_QMARK_$$,icon:"character-h"})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.width"),
className:"main_ui_workspace_sidebar_options_menus_measures__width "+($APP.$cljs$core$truth_$$($disabled_width_sizing_QMARK__shape$jscomp$1003$$)?"main_ui_workspace_sidebar_options_menus_measures__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon-text",children:"W"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,noValidate:!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",onChange:$on_width_change$$,disabled:$disabled_width_sizing_QMARK__shape$jscomp$1003$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.height"),
className:"main_ui_workspace_sidebar_options_menus_measures__height "+($APP.$cljs$core$truth_$$($disabled_height_sizing_QMARK_$$)?"main_ui_workspace_sidebar_options_menus_measures__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon-text",children:"H"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,noValidate:!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",onChange:$on_height_change$$,disabled:$disabled_height_sizing_QMARK_$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost",tooltipPlacement:"top-left",icon:$APP.$cljs$core$truth_$$($proportion_lock$jscomp$1$$)?"lock":"unlock",className:$proportion_lock$jscomp$1$$===!0?"main_ui_workspace_sidebar_options_menus_measures__selected":"",disabled:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($proportion_lock$jscomp$1$$,$APP.$cljs$cst$1621$multiple$$),"aria-label":$APP.$cljs$core$truth_$$($proportion_lock$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size.unlock"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size.lock"),onClick:$on_proportion_lock_change_shapes__$1$jscomp$34$$})]}):null,$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1681$position$$):$options$jscomp$621$$($APP.$cljs$cst$1681$position$$))?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__position",children:$token_numeric_inputs$jscomp$1$$?
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{onChange:$on_pos_x_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,$APP.$cljs$cst$1515$x$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1515$x$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$1515$x$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,$APP.$cljs$cst$1515$x$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1515$x$$),onDetach:$on_detach_token$jscomp$3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.x"),
disabled:$disabled_position_QMARK__selection_parents_selection_parents_ref$$,icon:"character-x"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{align:$APP.$cljs$cst$258$right$$,onChange:$on_pos_y_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,$APP.$cljs$cst$1516$y$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1516$y$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",attr:$APP.$cljs$cst$1516$y$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,$APP.$cljs$cst$1516$y$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1516$y$$),onDetach:$on_detach_token$jscomp$3$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.y"),
disabled:$disabled_position_QMARK__selection_parents_selection_parents_ref$$,icon:"character-y"})]}):(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.x"),className:"main_ui_workspace_sidebar_options_menus_measures__x-position "+($APP.$cljs$core$truth_$$($disabled_position_QMARK__selection_parents_selection_parents_ref$$)?"main_ui_workspace_sidebar_options_menus_measures__disabled":
""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon-text",children:"X"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",onChange:$on_pos_x_change$$,
disabled:$disabled_position_QMARK__selection_parents_selection_parents_ref$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.y"),className:"main_ui_workspace_sidebar_options_menus_measures__y-position "+($APP.$cljs$core$truth_$$($disabled_position_QMARK__selection_parents_selection_parents_ref$$)?
"main_ui_workspace_sidebar_options_menus_measures__disabled":""),children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon-text",children:"Y"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{noValidate:!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",disabled:$disabled_position_QMARK__selection_parents_selection_parents_ref$$,onChange:$on_pos_y_change$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]})]})}):null,$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1225$$=$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1794$rotation$$):$options$jscomp$621$$($APP.$cljs$cst$1794$rotation$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1225$$)?$or__5025__auto__$jscomp$1225$$:$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2831$radius$$):$options$jscomp$621$$($APP.$cljs$cst$2831$radius$$)}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__rotation-radius",children:[$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1794$rotation$$):
$options$jscomp$621$$($APP.$cljs$cst$1794$rotation$$))?$token_numeric_inputs$jscomp$1$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:-359,onChange:$on_rotation_change$$,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,$APP.$cljs$cst$1794$rotation$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1794$rotation$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",max:359,attr:$APP.$cljs$cst$1794$rotation$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$7_props_79059$$,$APP.$cljs$cst$1794$rotation$$),value:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$1$$,$APP.$cljs$cst$1794$rotation$$),onDetach:$on_detach_token$jscomp$3$$,
property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.rotation"),icon:"rotation"}):(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.rotation"),className:"main_ui_workspace_sidebar_options_menus_measures__rotation",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_measures__icon",children:$APP.$app$main$ui$icons$rotation$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,
{noValidate:!0,min:-359,max:359,"data-wrap":!0,placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):"--",onChange:$on_rotation_change$$,className:"main_ui_workspace_sidebar_options_menus_measures__numeric-input",value:$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)})]}):
null,$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2831$radius$$):$options$jscomp$621$$($APP.$cljs$cst$2831$radius$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$border_radius$border_radius_menu_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_measures__border-radius",ids:$ids$jscomp$286$$,values:$values__$2$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$7_props_79059$$}):
null]}):null,$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1226$$=$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5784$clip_content$$):$options$jscomp$621$$($cljs$cst$5784$clip_content$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1226$$)?$or__5025__auto__$jscomp$1226$$:$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5783$show_in_viewer$$):
$options$jscomp$621$$($cljs$cst$5783$show_in_viewer$$)}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__clip-show",children:[$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5784$clip_content$$):$options$jscomp$621$$($cljs$cst$5784$clip_content$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__clip-content",
children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"clip-content",ref:$clip_content_ref$$,checked:$APP.$cljs$core$not$$($APP.$cljs$cst$1884$show_content$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)),onChange:$on_change_clip_content$$,className:"main_ui_workspace_sidebar_options_menus_measures__clip-content-input"}),(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"clip-content",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.clip-content"),className:"main_ui_workspace_sidebar_options_menus_measures__clip-content-label "+
($APP.$cljs$core$not$$($APP.$cljs$cst$1884$show_content$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?"main_ui_workspace_sidebar_options_menus_measures__selected":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"clip-content"})})]}):null,$APP.$cljs$core$truth_$$($options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$?$options$jscomp$621$$.$cljs$core$IFn$_invoke$arity$1$($cljs$cst$5783$show_in_viewer$$):$options$jscomp$621$$($cljs$cst$5783$show_in_viewer$$))?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_measures__show-in-viewer",children:[(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"show-in-viewer",ref:$show_in_viewer_ref$$,checked:$APP.$cljs$core$not$$($APP.$cljs$cst$1883$hide_in_viewer$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$)),onChange:$on_change_show_in_viewer$$,className:"main_ui_workspace_sidebar_options_menus_measures__clip-content-input"}),(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"show-in-viewer",
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.show-in-viewer"),className:"main_ui_workspace_sidebar_options_menus_measures__clip-content-label "+($APP.$cljs$core$not$$($APP.$cljs$cst$1883$hide_in_viewer$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$1$$))?"main_ui_workspace_sidebar_options_menus_measures__selected":""),children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"play"})})]}):null]}):null]})},function($old_props$jscomp$3$$,
$new_props$jscomp$4$$){var $o_values$$=$old_props$jscomp$3$$.values,$n_values$$=$new_props$jscomp$4$$.values;return $old_props$jscomp$3$$.ids===$new_props$jscomp$4$$.ids&&$old_props$jscomp$3$$.type===$new_props$jscomp$4$$.type&&$old_props$jscomp$3$$.appliedTokens===$new_props$jscomp$4$$.appliedTokens&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1515$x$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1515$x$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,
$APP.$cljs$cst$1516$y$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1516$y$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1794$rotation$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1794$rotation$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1883$hide_in_viewer$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1883$hide_in_viewer$$)&&
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$290$width$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$290$width$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1527$height$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1527$height$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1713$layout_item_h_sizing$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,
$APP.$cljs$cst$1713$layout_item_h_sizing$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1714$layout_item_v_sizing$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1714$layout_item_v_sizing$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1609$points$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1609$points$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,
$APP.$cljs$cst$1610$selrect$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1610$selrect$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1651$r1$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1651$r1$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1652$r2$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1652$r2$$)&&
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1653$r3$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1653$r3$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1654$r4$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,$APP.$cljs$cst$1654$r4$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$$,$APP.$cljs$cst$1814$proportion_lock$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$$,
$APP.$cljs$cst$1814$proportion_lock$$)});var $app$main$ui$workspace$sidebar$options$drawing$drawing_options_STAR_$$=$rumext$v2$throttle$$(function($drawing_state$jscomp$2_props_79073$$){$drawing_state$jscomp$2_props_79073$$=$drawing_state$jscomp$2_props_79073$$.drawingState;var $G__79074$$=$APP.$cljs$cst$2205$tool$$.$cljs$core$IFn$_invoke$arity$1$($drawing_state$jscomp$2_props_79073$$);switch($G__79074$$ instanceof $APP.$cljs$core$Keyword$$?$G__79074$$.$fqn$:null){case "frame":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$drawing$frame$options_STAR_$$,
{drawingState:$drawing_state$jscomp$2_props_79073$$});default:return null}},60);var $app$main$ui$workspace$sidebar$options$menus$bool$flatten_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_sidebar_options_menus_bool__flatten-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boolean-flatten"})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$26$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$26$$,$cljs$cst$5787$variants_help_modal$$,$app$main$ui$workspace$sidebar$options$menus$variants_help_modal$variants_help_modal$$)});var $app$main$ui$workspace$sidebar$options$menus$component$ref_COLON_annotations_state$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4594$workspace_annotations$$,$APP.$app$main$store$state$$);var $app$main$ui$workspace$sidebar$options$menus$grid_cell$cell_props$$=new $APP.$cljs$core$PersistentVector$$(null,9,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1681$position$$,$APP.$cljs$cst$1661$row$$,$APP.$cljs$cst$1662$row_span$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$1663$column_span$$,$APP.$cljs$cst$1682$align_self$$,$APP.$cljs$cst$1683$justify_self$$,$APP.$cljs$cst$1680$area_name$$],null),$app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$=
(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($open_QMARK_$jscomp$17_props_79110$$){var $area_name$jscomp$2_cell_ids$jscomp$2_cells$jscomp$31$$=$open_QMARK_$jscomp$17_props_79110$$.cells,$cell$jscomp$46_column_end_map__79115__$1$$=$open_QMARK_$jscomp$17_props_79110$$.cell,$shape_id$jscomp$162$$=$open_QMARK_$jscomp$17_props_79110$$.shapeId,$state_STAR_$jscomp$15$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$3487$open$$,
!0],null));$open_QMARK_$jscomp$17_props_79110$$=$APP.$cljs$cst$3487$open$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state_STAR_$jscomp$15$$));var $cells__$1$jscomp$8$$=$APP.$app$main$ui$hooks$use_equal_memo$$($area_name$jscomp$2_cell_ids$jscomp$2_cells$jscomp$31$$),$cell__$1$jscomp$4$$=$APP.$cljs$core$truth_$$($cell$jscomp$46_column_end_map__79115__$1$$)?$cell$jscomp$46_column_end_map__79115__$1$$:$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$($cells__$1$jscomp$8$$,
$app$main$ui$workspace$sidebar$options$menus$grid_cell$cell_props$$),$multiple_QMARK_$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$));$area_name$jscomp$2_cell_ids$jscomp$2_cells$jscomp$31$$=$multiple_QMARK_$jscomp$6$$?$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$cells__$1$jscomp$8$$):new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$)],null);var $cell_ids__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($area_name$jscomp$2_cell_ids$jscomp$2_cells$jscomp$31$$);$cell$jscomp$46_column_end_map__79115__$1$$=$APP.$cljs$core$__destructure_map$$($cell__$1$jscomp$4$$);var $cell_mode_cell_mode__$1_position$jscomp$199$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$46_column_end_map__79115__$1$$,$APP.$cljs$cst$1681$position$$);$area_name$jscomp$2_cell_ids$jscomp$2_cells$jscomp$31$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$46_column_end_map__79115__$1$$,$APP.$cljs$cst$1680$area_name$$);var $align_self$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$46_column_end_map__79115__$1$$,$APP.$cljs$cst$1682$align_self$$),$justify_self$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$46_column_end_map__79115__$1$$,$APP.$cljs$cst$1683$justify_self$$),$column$jscomp$42$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$46_column_end_map__79115__$1$$,
$APP.$cljs$cst$216$column$$),$column_span$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$46_column_end_map__79115__$1$$,$APP.$cljs$cst$1663$column_span$$),$row$jscomp$33$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$46_column_end_map__79115__$1$$,$APP.$cljs$cst$1661$row$$),$row_span$jscomp$12$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($cell$jscomp$46_column_end_map__79115__$1$$,$APP.$cljs$cst$1662$row_span$$);$cell$jscomp$46_column_end_map__79115__$1$$=
$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$840$$=$APP.$app$common$math$finite_QMARK_$$($column$jscomp$42$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$840$$)?$APP.$app$common$math$finite_QMARK_$$($column_span$jscomp$12$$):$and__5023__auto__$jscomp$840$$}())?$column$jscomp$42$$+$column_span$jscomp$12$$:null;var $row_end$$=$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$841$$=$APP.$app$common$math$finite_QMARK_$$($row$jscomp$33$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$841$$)?
$APP.$app$common$math$finite_QMARK_$$($row_span$jscomp$12$$):$and__5023__auto__$jscomp$841$$}())?$row$jscomp$33$$+$row_span$jscomp$12$$:null;$cell_mode_cell_mode__$1_position$jscomp$199$$=$APP.$cljs$core$truth_$$($cell_mode_cell_mode__$1_position$jscomp$199$$)?$cell_mode_cell_mode__$1_position$jscomp$199$$:$APP.$cljs$cst$1677$auto$$;$cell_mode_cell_mode__$1_position$jscomp$199$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1677$auto$$,$cell_mode_cell_mode__$1_position$jscomp$199$$)&&
($APP.$cljs$cst$1663$column_span$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$)>1||$APP.$cljs$cst$1662$row_span$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$)>1)?$APP.$cljs$cst$1678$manual$$:$cell_mode_cell_mode__$1_position$jscomp$199$$;var $valid_area_cells_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($cells__$1$jscomp$8$$)],function(){return $app$common$types$shape$layout$valid_area_cells_QMARK_$$($cells__$1$jscomp$8$$)}),$set_alignment$jscomp$1$$=
$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($align_self$jscomp$5$$),$APP.$rumext$v2$adapt$$($shape_id$jscomp$162$$),$APP.$rumext$v2$adapt$$($cell_ids__$1$$)],function($value$jscomp$842$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align_self$jscomp$5$$,$value$jscomp$842$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($shape_id$jscomp$162$$,$cell_ids__$1$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1682$align_self$$,null],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($shape_id$jscomp$162$$,$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1682$align_self$$,$value$jscomp$842$$],null)))}),$set_justify_self$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($justify_self$jscomp$4$$),
$APP.$rumext$v2$adapt$$($shape_id$jscomp$162$$),$APP.$rumext$v2$adapt$$($cell_ids__$1$$)],function($value$jscomp$843$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($justify_self$jscomp$4$$,$value$jscomp$843$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($shape_id$jscomp$162$$,$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1683$justify_self$$,null],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($shape_id$jscomp$162$$,
$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1683$justify_self$$,$value$jscomp$843$$],null)))}),$on_grid_coordinates$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($column$jscomp$42$$),$APP.$rumext$v2$adapt$$($row$jscomp$33$$),$APP.$rumext$v2$adapt$$($shape_id$jscomp$162$$),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$))],function($field$jscomp$7_property$jscomp$85$$,
$type$jscomp$629_value__$2$jscomp$8_vec__79119$$,$value$jscomp$844$$){if($multiple_QMARK_$jscomp$6$$)return null;var $value__$1$jscomp$50$$=$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$844$$),$column__$1$jscomp$3$$=$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($column$jscomp$42$$),$row__$1$jscomp$4$$=$APP.$app$common$math$round$$.$cljs$core$IFn$_invoke$arity$1$($row$jscomp$33$$);$type$jscomp$629_value__$2$jscomp$8_vec__79119$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$629_value__$2$jscomp$8_vec__79119$$,
$APP.$cljs$cst$216$column$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$85$$,$APP.$cljs$cst$2132$all$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$85$$,$APP.$cljs$cst$1297$start$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$216$column$$,$value__$1$jscomp$50$$],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$629_value__$2$jscomp$8_vec__79119$$,
$APP.$cljs$cst$216$column$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$85$$,$APP.$cljs$cst$1298$end$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1663$column_span$$,function(){var $y__5111__auto__$jscomp$140$$=$value__$1$jscomp$50$$-$column__$1$jscomp$3$$;return 1>$y__5111__auto__$jscomp$140$$?1:$y__5111__auto__$jscomp$140$$}()],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$629_value__$2$jscomp$8_vec__79119$$,
$APP.$cljs$cst$1661$row$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$85$$,$APP.$cljs$cst$2132$all$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$85$$,$APP.$cljs$cst$1297$start$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1661$row$$,$value__$1$jscomp$50$$],null):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$629_value__$2$jscomp$8_vec__79119$$,
$APP.$cljs$cst$1661$row$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($field$jscomp$7_property$jscomp$85$$,$APP.$cljs$cst$1298$end$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1662$row_span$$,function(){var $y__5111__auto__$jscomp$141$$=$value__$1$jscomp$50$$-$row__$1$jscomp$4$$;return 1>$y__5111__auto__$jscomp$141$$?1:$y__5111__auto__$jscomp$141$$}()],null):null;$field$jscomp$7_property$jscomp$85$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$629_value__$2$jscomp$8_vec__79119$$,
0,null);$type$jscomp$629_value__$2$jscomp$8_vec__79119$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($type$jscomp$629_value__$2$jscomp$8_vec__79119$$,1,null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cell_position$$($shape_id$jscomp$162$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$),$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$field$jscomp$7_property$jscomp$85$$,
$type$jscomp$629_value__$2$jscomp$8_vec__79119$$])))}),$on_area_name_change$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$162$$),$APP.$rumext$v2$adapt$$($cell_ids__$1$$)],function($event$jscomp$523_value$jscomp$845$$){$event$jscomp$523_value$jscomp$845$$=$APP.$app$util$dom$get_value$$($APP.$app$util$dom$get_target$$($event$jscomp$523_value$jscomp$845$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$523_value$jscomp$845$$,
"")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($shape_id$jscomp$162$$,$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$area_name$$,null],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_grid_cells$$($shape_id$jscomp$162$$,$cell_ids__$1$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1680$area_name$$,
$event$jscomp$523_value$jscomp$845$$],null)))}),$set_cell_mode$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$162$$),$APP.$rumext$v2$adapt$$($cell_ids__$1$$)],function($mode$jscomp$50_mode__$1$jscomp$2$$){$mode$jscomp$50_mode__$1$jscomp$2$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($mode$jscomp$50_mode__$1$jscomp$2$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_cells_mode$$($shape_id$jscomp$162$$,
$cell_ids__$1$$,$mode$jscomp$50_mode__$1$jscomp$2$$))}),$toggle_edit_mode$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$162$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$edition$start_edition_mode$$($shape_id$jscomp$162$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$grid_layout$editor$clear_selection$$($shape_id$jscomp$162$$)]))});
return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$17_props_79110$$),onCollapsed:function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$15$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$3487$open$$,$APP.$cljs$core$not$$)},title:"Grid cell"})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$17_props_79110$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-cell-menu-container",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__cell-mode main_ui_workspace_sidebar_options_menus_grid_cell__row",children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,
{selected:$APP.$app$common$data$name$$($cell_mode_cell_mode__$1_position$jscomp$199$$),"on-change":$set_cell_mode$$,name:"cell-mode",wide:!0,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"auto",id:$APP.$cljs$cst$1677$auto$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"manual",id:$APP.$cljs$cst$1678$manual$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"area",
id:$APP.$cljs$cst$1679$area$$,disabled:$APP.$cljs$core$not$$($valid_area_cells_QMARK_$$)})]})}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1679$area$$,$cell_mode_cell_mode__$1_position$jscomp$199$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:(0,$APP.$rumext$v2$jsx$$)("input",{autoComplete:"off",placeholder:"Area name",defaultValue:$area_name$jscomp$2_cell_ids$jscomp$2_cells$jscomp$31$$,type:"text",id:"grid-area-name",
className:"main_ui_workspace_sidebar_options_menus_grid_cell__area-input","aria-label":"grid-area-name",onChange:$on_area_name_change$$},"name-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell__$1$jscomp$4$$)??""))}):null,!$multiple_QMARK_$jscomp$6$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1677$auto$$,$cell_mode_cell_mode__$1_position$jscomp$199$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__icon",children:$APP.$app$main$ui$icons$flex_vertical$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:"Column",onClick:function($p1__79104_SHARP_$$){return $app$util$dom$select_target$$($p1__79104_SHARP_$$)},
onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$2132$all$$,$APP.$cljs$cst$216$column$$),integer:!0,value:$column$jscomp$42$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__icon",children:$APP.$app$main$ui$icons$flex_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",title:"Row",onClick:function($p1__79105_SHARP_$$){return $app$util$dom$select_target$$($p1__79105_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$2132$all$$,$APP.$cljs$cst$1661$row$$),integer:!0,value:$row$jscomp$33$$})})]})]}):null,$multiple_QMARK_$jscomp$6$$||
!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1678$manual$$,$cell_mode_cell_mode__$1_position$jscomp$199$$)&&!$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1679$area$$,$cell_mode_cell_mode__$1_position$jscomp$199$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_menus_grid_cell__icon",children:$APP.$app$main$ui$icons$flex_vertical$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",onPointerDown:function($p1__79106_SHARP_$$){return $app$util$dom$select_target$$($p1__79106_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,
$APP.$cljs$cst$1297$start$$,$APP.$cljs$cst$216$column$$),integer:!0,value:$column$jscomp$42$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",onPointerDown:function($p1__79107_SHARP_$$){return $app$util$dom$select_target$$($p1__79107_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,
$APP.$cljs$cst$1298$end$$,$APP.$cljs$cst$216$column$$),integer:!0,value:$cell$jscomp$46_column_end_map__79115__$1$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__grid-coord-group",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__icon",children:$APP.$app$main$ui$icons$flex_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input main_ui_workspace_sidebar_options_menus_grid_cell__double",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",onPointerDown:function($p1__79108_SHARP_$$){return $app$util$dom$select_target$$($p1__79108_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$1297$start$$,$APP.$cljs$cst$1661$row$$),integer:!0,value:$row$jscomp$33$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__coord-input",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"--",onPointerDown:function($p1__79109_SHARP_$$){return $app$util$dom$select_target$$($p1__79109_SHARP_$$)},onChange:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($on_grid_coordinates$$,$APP.$cljs$cst$1298$end$$,$APP.$cljs$cst$1661$row$$),integer:!0,value:$row_end$$})})]})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$set_self_alignment$$,{"is-col?":!1,alignment:$align_self$jscomp$5$$,"set-alignment":$set_alignment$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$set_self_alignment$$,{"is-col?":!0,alignment:$justify_self$jscomp$4$$,"set-alignment":$set_justify_self$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_grid_cell__row",children:(0,$APP.$rumext$v2$jsx$$)("button",
{alt:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.options.edit-grid"),onClick:$toggle_edit_mode$$,className:"main_ui_workspace_sidebar_options_menus_grid_cell__edit-grid-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.options.edit-grid")})})]}):null]})},function($old_props$jscomp$4$$,$new_props$jscomp$5$$){return $old_props$jscomp$4$$.shapeId===$new_props$jscomp$5$$.shapeId&&$old_props$jscomp$4$$.cell===
$new_props$jscomp$5$$.cell&&$old_props$jscomp$4$$.cells===$new_props$jscomp$5$$.cells});var $app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,14,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1620$layout$$,$APP.$cljs$cst$1684$layout_flex_dir$$,$APP.$cljs$cst$1688$layout_gap_type$$,$APP.$cljs$cst$1685$layout_gap$$,$APP.$cljs$cst$1697$layout_align_items$$,$APP.$cljs$cst$1694$layout_justify_content$$,$APP.$cljs$cst$1696$layout_align_content$$,$APP.$cljs$cst$1689$layout_wrap_type$$,$APP.$cljs$cst$1690$layout_padding_type$$,
$APP.$cljs$cst$1691$layout_padding$$,$APP.$cljs$cst$1698$layout_grid_dir$$,$APP.$cljs$cst$1695$layout_justify_items$$,$APP.$cljs$cst$1700$layout_grid_columns$$,$APP.$cljs$cst$1699$layout_grid_rows$$],null),$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$=function $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$($var_args$jscomp$1461$$){switch(arguments.length){case 1:return $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$1$(arguments[0]);
case 4:return $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$(arguments[0],arguments[1],arguments[2],arguments[3]);default:throw Error(["Invalid arity: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};
$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$1$=function($p$jscomp$253$$){return $app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$253$$,$APP.$cljs$cst$1093$p1$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$253$$,$APP.$cljs$cst$1091$p2$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$253$$,
$APP.$cljs$cst$1692$p3$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p$jscomp$253$$,$APP.$cljs$cst$1693$p4$$))};
$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$core$IFn$_invoke$arity$4$=function($p1_QMARK_$$,$p2_QMARK_$$,$p3_QMARK_$$,$p4_QMARK_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_paddings_selected$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1093$p1$$,$p1_QMARK_$$,$APP.$cljs$cst$1091$p2$$,$p2_QMARK_$$,$APP.$cljs$cst$1692$p3$$,$p3_QMARK_$$,$APP.$cljs$cst$1693$p4$$,$p4_QMARK_$$],null)))};
$app$main$ui$workspace$sidebar$options$menus$layout_container$select_padding$$.$cljs$lang$maxFixedArity$=4;
var $app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($has_layout_QMARK_$jscomp$4_props_79337$$){var $ids$jscomp$292$$=$has_layout_QMARK_$jscomp$4_props_79337$$.ids,$multiple$jscomp$1$$=$has_layout_QMARK_$jscomp$4_props_79337$$.multiple,$values$jscomp$83$$=$has_layout_QMARK_$jscomp$4_props_79337$$.values,$applied_tokens$jscomp$11$$=$has_layout_QMARK_$jscomp$4_props_79337$$.appliedTokens,$layout_type$$=$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$);
$has_layout_QMARK_$jscomp$4_props_79337$$=$layout_type$$!=null;var $show_dropdown_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$add_layout_dropdown_show_dropdown_QMARK_$jscomp$5$$=$APP.$cljs$core$_deref$$($show_dropdown_STAR_$$),$open_STAR_$jscomp$7$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$truth_$$($layout_type$$)?!0:!1}),$open_QMARK_$jscomp$18$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$7$$),$on_toggle_visibility$jscomp$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$7$$,$APP.$cljs$core$not$$)}),$on_add_layout$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$547_type$jscomp$639$$){$event$jscomp$547_type$jscomp$639$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$547_type$jscomp$639$$),
"type"));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$with_meta$$($APP.$app$main$data$workspace$shape_layout$create_layout$$($event$jscomp$547_type$jscomp$639$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:sidebar"],null)));return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$7$$,!0)}),$on_remove_layout$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],
function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout$$($ids$jscomp$292$$));return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$7$$,!1)}),$saved_dir$$=$APP.$cljs$cst$1684$layout_flex_dir$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$is_column$jscomp$8$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$saved_dir$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1667$column_reverse$$,
$saved_dir$$),$wrap_type$jscomp$4$$=$APP.$cljs$cst$1689$layout_wrap_type$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$toggle_wrap$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($wrap_type$jscomp$4$$),$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function(){var $type$jscomp$640$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($wrap_type$jscomp$4$$,$APP.$cljs$cst$896$wrap$$)?$APP.$cljs$cst$1669$nowrap$$:$APP.$cljs$cst$896$wrap$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1689$layout_wrap_type$$,$type$jscomp$640$$],null)))}),$align_items$jscomp$3$$=$APP.$cljs$cst$1697$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$set_align_items$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($value$jscomp$876$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1697$layout_align_items$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$876$$)],null)))}),$justify_content$jscomp$4$$=$APP.$cljs$cst$1694$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$set_justify_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($value$jscomp$877$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1694$layout_justify_content$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$877$$)],null)))}),$align_content$jscomp$3$$=$APP.$cljs$cst$1696$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$on_align_content_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$),$APP.$rumext$v2$adapt$$($align_content$jscomp$3$$)],function($value$jscomp$878$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align_content$jscomp$3$$,
$value$jscomp$878$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1696$layout_align_content$$,$APP.$cljs$cst$1674$stretch$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1696$layout_align_content$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$878$$)],null)))}),$on_gap_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($multiple_QMARK_$jscomp$7$$,$type$jscomp$641$$,$val$jscomp$216_val__$1$jscomp$17$$){$val$jscomp$216_val__$1$jscomp$17$$=$APP.$app$common$math$finite$$($val$jscomp$216_val__$1$jscomp$17$$,0);
return $multiple_QMARK_$jscomp$7$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1686$row_gap$$,$val$jscomp$216_val__$1$jscomp$17$$,$APP.$cljs$cst$1687$column_gap$$,$val$jscomp$216_val__$1$jscomp$17$$],null)],null))):$type$jscomp$641$$!=
null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_gap$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$type$jscomp$641$$,$val$jscomp$216_val__$1$jscomp$17$$])],null))):null}),$on_padding_type_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],
function($type$jscomp$642$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1690$layout_padding_type$$,$type$jscomp$642$$],null)))}),$on_padding_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($type$jscomp$643$$,$prop$jscomp$35$$,
$val$jscomp$217_val__$1$jscomp$18$$){$val$jscomp$217_val__$1$jscomp$18$$=$APP.$app$common$math$finite$$($val$jscomp$217_val__$1$jscomp$18$$,0);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$643$$,$APP.$cljs$cst$1668$simple$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$35$$,$APP.$cljs$cst$1093$p1$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$35$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1692$p3$$,null,$APP.$cljs$cst$1093$p1$$,null],null),null)))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$val$jscomp$217_val__$1$jscomp$18$$,$APP.$cljs$cst$1692$p3$$,$val$jscomp$217_val__$1$jscomp$18$$],
null)],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$643$$,$APP.$cljs$cst$1668$simple$$)&&($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$35$$,$APP.$cljs$cst$1091$p2$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$35$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,null,$APP.$cljs$cst$1693$p4$$,null],null),null)))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,$val$jscomp$217_val__$1$jscomp$18$$,$APP.$cljs$cst$1693$p4$$,$val$jscomp$217_val__$1$jscomp$18$$],null)],null))):$prop$jscomp$35$$!=null?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1691$layout_padding$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$prop$jscomp$35$$,$val$jscomp$217_val__$1$jscomp$18$$])],null))):null}),$saved_grid_dir$$=$APP.$cljs$cst$1698$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$on_direction_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout_type$$),$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($dir$jscomp$7$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1665$flex$$,
$layout_type$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1684$layout_flex_dir$$,$dir$jscomp$7$$],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1698$layout_grid_dir$$,$dir$jscomp$7$$],null)))}),$align_items_row$$=$APP.$cljs$cst$1697$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$align_items_column$$=$APP.$cljs$cst$1695$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$on_column_align_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($value$jscomp$879$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1695$layout_justify_items$$,$value$jscomp$879$$],null)))}),$on_row_align_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($value$jscomp$880$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1697$layout_align_items$$,$value$jscomp$880$$],null)))}),$grid_justify_content_row$$=$APP.$cljs$cst$1694$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$grid_justify_content_column$$=$APP.$cljs$cst$1696$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),$on_column_justify_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($value$jscomp$881$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1696$layout_align_content$$,$value$jscomp$881$$],null)))}),$on_row_justify_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$292$$)],function($value$jscomp$882$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$292$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1694$layout_justify_content$$,$value$jscomp$882$$],null)))}),$on_toggle_dropdown_visibility$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_dropdown_STAR_$$,$APP.$cljs$core$not$$)}),$on_hide_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($show_dropdown_STAR_$$,!1)});$add_layout_dropdown_show_dropdown_QMARK_$jscomp$5$$=
$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$dropdown$dropdown$$,{show:$add_layout_dropdown_show_dropdown_QMARK_$jscomp$5$$,"on-close":$on_hide_dropdown$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-options",children:[(0,$APP.$rumext$v2$jsx$$)("button",{"data-type":"flex",onClick:$on_add_layout$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.flex-layout")}),
(0,$APP.$rumext$v2$jsx$$)("button",{"data-type":"grid",onClick:$on_add_layout$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_layout_container__layout-option",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.grid-layout")})]})});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"Layout container section","data-testid":"inspect-layout",className:"main_ui_workspace_sidebar_options_menus_layout_container__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_container__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_layout_QMARK_$jscomp$4_props_79337$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$18$$),onCollapsed:$on_toggle_visibility$jscomp$1$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.layout"),className:$has_layout_QMARK_$jscomp$4_props_79337$$?"":"main_ui_workspace_sidebar_options_menus_layout_container__title-spacing-layout",
children:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$844$$=$APP.$cljs$core$not$$($multiple$jscomp$1$$);return $and__5023__auto__$jscomp$844$$?$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$):$and__5023__auto__$jscomp$844$$}())?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__title-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-layout"),onClick:$on_toggle_dropdown_visibility$$,icon:"menu"}),$add_layout_dropdown_show_dropdown_QMARK_$jscomp$5$$,$has_layout_QMARK_$jscomp$4_props_79337$$?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.remove-layout"),onClick:$on_remove_layout$jscomp$1$$,
icon:"remove"}):null]}):(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__title-actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.add-layout"),onClick:$on_toggle_dropdown_visibility$$,icon:"add"}),$add_layout_dropdown_show_dropdown_QMARK_$jscomp$5$$,$has_layout_QMARK_$jscomp$4_props_79337$$?
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.delete"),onClick:$on_remove_layout$jscomp$1$$,icon:"remove"}):null]})})}),$open_QMARK_$jscomp$18$$&&$has_layout_QMARK_$jscomp$4_props_79337$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$layout_type$$)?function(){switch($layout_type$$ instanceof $APP.$cljs$core$Keyword$$?
$layout_type$$.$fqn$:null){case "flex":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__flex-layout-menu",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__first-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_row$$,{"is-column":$is_column$jscomp$8$$,value:$align_items$jscomp$3$$,"on-change":$set_align_items$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_flex$$,
{"on-change":$on_direction_change$$,value:$saved_dir$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$wrap_row$$,{"wrap-type":$wrap_type$jscomp$4$$,"on-click":$toggle_wrap$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__second-row main_ui_workspace_sidebar_options_menus_layout_container__help-button-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_content_row$$,
{"is-column":$is_column$jscomp$8$$,"justify-content":$justify_content$jscomp$4$$,"on-change":$set_justify_content$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center"),onClick:$app$main$ui$workspace$sidebar$options$menus$layout_container$open_flex_help$$,icon:"help"})]}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$896$wrap$$,$wrap_type$jscomp$4$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__third-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_content_row$$,{"is-column":$is_column$jscomp$8$$,value:$align_content$jscomp$3$$,"on-change":$on_align_content_change$$})}):null,(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__forth-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$,
{isColumn:$is_column$jscomp$8$$,wrapType:$wrap_type$jscomp$4$$,onChange:$on_gap_change$$,ids:$ids$jscomp$292$$,appliedTokens:$applied_tokens$jscomp$11$$,value:$APP.$cljs$cst$1685$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$)}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$,{value:$APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),type:$APP.$cljs$cst$1690$layout_padding_type$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),
onTypeChange:$on_padding_type_change$$,ids:$ids$jscomp$292$$,appliedTokens:$applied_tokens$jscomp$11$$,onChange:$on_padding_change$$})]})]});case "grid":return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-menu",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($ids$jscomp$292$$))?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__edit-grid-wrapper",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_edit_mode$$,{id:$APP.$cljs$core$first$$($ids$jscomp$292$$)}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center"),onClick:$app$main$ui$workspace$sidebar$options$menus$layout_container$open_grid_help$$,icon:"help"})]}):null,(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_container__first-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__direction-edit",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__direction",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_grid$$,{value:$saved_grid_dir$$,"on-change":$on_direction_change$$})})}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,{"is-column":!1,value:$align_items_row$$,"on-change":$on_row_align_change$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,{"is-column":!0,value:$align_items_column$$,"on-change":$on_column_align_change$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__row main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-align",
children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,{"is-column":!0,value:$grid_justify_content_column$$,"on-change":$on_column_justify_change$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,{"is-column":!1,value:$grid_justify_content_row$$,"on-change":$on_row_justify_change$$})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__gap-row",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$,{onChange:$on_gap_change$$,ids:$ids$jscomp$292$$,appliedTokens:$applied_tokens$jscomp$11$$,value:$APP.$cljs$cst$1685$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$,
{value:$APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),type:$APP.$cljs$cst$1690$layout_padding_type$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$83$$),ids:$ids$jscomp$292$$,appliedTokens:$applied_tokens$jscomp$11$$,onTypeChange:$on_padding_type_change$$,onChange:$on_padding_change$$})})]});default:return null}}():null]})},function($old_props$jscomp$5$$,$new_props$jscomp$6$$){var $o_values$jscomp$1$$=$old_props$jscomp$5$$.values,$n_values$jscomp$1$$=$new_props$jscomp$6$$.values;
return $old_props$jscomp$5$$.ids===$new_props$jscomp$6$$.ids&&$old_props$jscomp$5$$.appliedTokens===$new_props$jscomp$6$$.appliedTokens&&$old_props$jscomp$5$$.multiple===$new_props$jscomp$6$$.multiple&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1685$layout_gap$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1685$layout_gap$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1688$layout_gap_type$$)===
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1688$layout_gap_type$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1691$layout_padding$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1691$layout_padding$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1690$layout_padding_type$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,
$APP.$cljs$cst$1690$layout_padding_type$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1689$layout_wrap_type$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1689$layout_wrap_type$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1697$layout_align_items$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1697$layout_align_items$$)&&
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1684$layout_flex_dir$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1684$layout_flex_dir$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1694$layout_justify_content$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1694$layout_justify_content$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,
$APP.$cljs$cst$1696$layout_align_content$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1696$layout_align_content$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$1$$,$APP.$cljs$cst$1620$layout$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$1$$,$APP.$cljs$cst$1620$layout$$)}),$app$main$ui$workspace$sidebar$options$menus$layout_container$grid_layout_edition$$=function($component__44608__auto__$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($component__44608__auto__$$,
function($new_props_79371$$,$old_props_79372$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79371$$.ids,$old_props_79372$$.ids)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79371$$.values,$old_props_79372$$.values)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79371$$["applied-tokens"],$old_props_79372$$["applied-tokens"])})}(function($map__79377_props_79370_values$jscomp$84$$){$map__79377_props_79370_values$jscomp$84$$=$APP.$rumext$v2$util$wrap_props$$($map__79377_props_79370_values$jscomp$84$$);
var $applied_tokens$jscomp$12_map__79377__$1$$=$APP.$cljs$core$__destructure_map$$($map__79377_props_79370_values$jscomp$84$$),$ids$jscomp$293$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$12_map__79377__$1$$,$APP.$cljs$cst$1729$ids$$);$map__79377_props_79370_values$jscomp$84$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$12_map__79377__$1$$,$APP.$cljs$cst$301$values$$);$applied_tokens$jscomp$12_map__79377__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$12_map__79377__$1$$,
$APP.$cljs$cst$1881$applied_tokens$$);var $saved_grid_dir$jscomp$1$$=$APP.$cljs$cst$1698$layout_grid_dir$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),$on_direction_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($dir$jscomp$8$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1698$layout_grid_dir$$,$dir$jscomp$8$$],null)))}),$on_gap_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($multiple_QMARK_$jscomp$8$$,$type$jscomp$644$$,$val$jscomp$218_val__$1$jscomp$19$$){$val$jscomp$218_val__$1$jscomp$19$$=$APP.$app$common$math$finite$$($val$jscomp$218_val__$1$jscomp$19$$,0);return $APP.$cljs$core$truth_$$($multiple_QMARK_$jscomp$8$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_gap$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1686$row_gap$$,$val$jscomp$218_val__$1$jscomp$19$$,$APP.$cljs$cst$1687$column_gap$$,$val$jscomp$218_val__$1$jscomp$19$$],null)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1685$layout_gap$$,$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$type$jscomp$644$$,$val$jscomp$218_val__$1$jscomp$19$$])],null)))}),$on_padding_type_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($type$jscomp$645$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1690$layout_padding_type$$,$type$jscomp$645$$],null)))}),$align_items_row$jscomp$1$$=$APP.$cljs$cst$1697$layout_align_items$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),$align_items_column$jscomp$1$$=$APP.$cljs$cst$1695$layout_justify_items$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),$on_column_align_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],
function($value$jscomp$883$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1695$layout_justify_items$$,$value$jscomp$883$$],null)))}),$on_row_align_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($value$jscomp$884$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1697$layout_align_items$$,$value$jscomp$884$$],null)))}),$grid_justify_content_row$jscomp$1$$=$APP.$cljs$cst$1694$layout_justify_content$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),$grid_justify_content_column$jscomp$1$$=$APP.$cljs$cst$1696$layout_align_content$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),$on_column_justify_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],
function($value$jscomp$885$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1696$layout_align_content$$,$value$jscomp$885$$],null)))}),$on_row_justify_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($value$jscomp$886$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1694$layout_justify_content$$,$value$jscomp$886$$],null)))}),$columns_open_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$rows_open_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$column_values$jscomp$1$$=$APP.$cljs$cst$1700$layout_grid_columns$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),$rows_values$$=$APP.$cljs$cst$1699$layout_grid_rows$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),
$toggle_columns_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($columns_open_QMARK_$$,$APP.$cljs$core$not$$)}),$toggle_rows_open$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($rows_open_QMARK_$$,$APP.$cljs$core$not$$)}),$add_new_element$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],
function($type$jscomp$647$$,$value$jscomp$887$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$293$$,$type$jscomp$647$$,$value$jscomp$887$$))}),$remove_element$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($event$jscomp$548_index$jscomp$492$$){var $type$jscomp$648$$=$APP.$app$common$data$read_string$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$548_index$jscomp$492$$),
"type"));$event$jscomp$548_index$jscomp$492$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$548_index$jscomp$492$$),"index"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$remove_layout_track$$($ids$jscomp$293$$,$type$jscomp$648$$,$event$jscomp$548_index$jscomp$492$$))}),$reorder_track$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],
function($type$jscomp$649$$,$from_index$jscomp$12$$,$to_index$jscomp$19$$,$move_content_QMARK_$jscomp$5$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$reorder_layout_track$$($ids$jscomp$293$$,$type$jscomp$649$$,$from_index$jscomp$12$$,$to_index$jscomp$19$$,$move_content_QMARK_$jscomp$5$$))}),$hover_track$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($type$jscomp$650$$,
$index$jscomp$493$$,$hover_QMARK_$jscomp$7$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$hover_layout_track$$($ids$jscomp$293$$,$type$jscomp$650$$,$index$jscomp$493$$,$hover_QMARK_$jscomp$7$$))}),$handle_select_track$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($type$jscomp$651$$,$index$jscomp$494$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$select_track_cells$$($APP.$cljs$core$first$$($ids$jscomp$293$$),
$type$jscomp$651$$,$index$jscomp$494$$))}),$set_column_value$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($type$jscomp$652$$,$index$jscomp$495$$,$value$jscomp$888$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($ids$jscomp$293$$,$type$jscomp$652$$,$index$jscomp$495$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$260$value$$,
$value$jscomp$888$$],null)))}),$set_column_type$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],function($type$jscomp$653$$,$index$jscomp$496$$,$track_type$$){var $value$jscomp$889$$=function(){var $G__79388__$1$$=$track_type$$ instanceof $APP.$cljs$core$Keyword$$?$track_type$$.$fqn$:null;switch($G__79388__$1$$){case "auto":return null;case "flex":return 1;case "percent":return 20;case "fixed":return 100;default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79388__$1$$)].join(""));}}();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$($ids$jscomp$293$$,$type$jscomp$653$$,$index$jscomp$496$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$value$jscomp$889$$,$APP.$cljs$cst$139$type$$,$track_type$$],null)))}),$handle_locate_grid$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$293$$)],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$locate_board$$($APP.$cljs$core$first$$($ids$jscomp$293$$)))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-menu",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-first-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-menu-title",
children:"GRID LAYOUT"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_workspace_sidebar_options_menus_layout_container__help-button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.help-center"),onClick:$app$main$ui$workspace$sidebar$options$menus$layout_container$open_grid_help$$,icon:"help"}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$edition$clear_edition_mode$$())},
className:"main_ui_workspace_sidebar_options_menus_layout_container__exit-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.options.exit")})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__row main_ui_workspace_sidebar_options_menus_layout_container__first-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__direction-edit",children:(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_container__direction",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$direction_row_grid$$,{value:$saved_grid_dir$jscomp$1$$,"on-change":$on_direction_change$jscomp$1$$})})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,{"is-column":!1,value:$align_items_row$jscomp$1$$,"on-change":$on_row_align_change$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$align_grid_row$$,
{"is-column":!0,value:$align_items_column$jscomp$1$$,"on-change":$on_column_align_change$jscomp$1$$})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__row main_ui_workspace_sidebar_options_menus_layout_container__grid-layout-align",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,{"is-column":!0,value:$grid_justify_content_column$jscomp$1$$,"on-change":$on_column_justify_change$jscomp$1$$}),
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$justify_grid_row$$,{"is-column":!1,value:$grid_justify_content_row$jscomp$1$$,"on-change":$on_row_justify_change$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",className:"main_ui_workspace_sidebar_options_menus_layout_container__locate-button","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.layout-grid.editor.top-bar.locate.tooltip"),
onClick:$handle_locate_grid$$,icon:"locate"})]}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__gap-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$gap_section_STAR_$$,{onChange:$on_gap_change$jscomp$1$$,ids:$ids$jscomp$293$$,appliedTokens:$applied_tokens$jscomp$12_map__79377__$1$$,value:$APP.$cljs$cst$1685$layout_gap$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$)})}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__padding-row main_ui_workspace_sidebar_options_menus_layout_container__padding-section",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$padding_section_STAR_$$,{value:$APP.$cljs$cst$1691$layout_padding$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),type:$APP.$cljs$cst$1690$layout_padding_type$$.$cljs$core$IFn$_invoke$arity$1$($map__79377_props_79370_values$jscomp$84$$),
onTypeChange:$on_padding_type_change$jscomp$1$$,onChange:function($type$jscomp$646$$,$prop$jscomp$36$$,$val$jscomp$219_val__$1$jscomp$20$$){$val$jscomp$219_val__$1$jscomp$20$$=$APP.$app$common$math$finite$$($val$jscomp$219_val__$1$jscomp$20$$,0);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$646$$,$APP.$cljs$cst$1668$simple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$36$$,$APP.$cljs$cst$1093$p1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1093$p1$$,$val$jscomp$219_val__$1$jscomp$20$$,$APP.$cljs$cst$1692$p3$$,$val$jscomp$219_val__$1$jscomp$20$$],null)],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$646$$,$APP.$cljs$cst$1668$simple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$36$$,$APP.$cljs$cst$1091$p2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1091$p2$$,$val$jscomp$219_val__$1$jscomp$20$$,$APP.$cljs$cst$1693$p4$$,$val$jscomp$219_val__$1$jscomp$20$$],null)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$293$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1691$layout_padding$$,
$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$prop$jscomp$36$$,$val$jscomp$219_val__$1$jscomp$20$$])],null)))}})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_container__grid-tracks-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_columns_row$$,{"is-column":!0,"hover-track":$hover_track$jscomp$2$$,"expanded?":$APP.$cljs$core$_deref$$($columns_open_QMARK_$$),"set-column-value":$set_column_value$jscomp$2$$,
toggle:$toggle_columns_open$$,"add-new-element":$add_new_element$jscomp$1$$,"reorder-track":$reorder_track$jscomp$2$$,"remove-element":$remove_element$jscomp$2$$,"set-column-type":$set_column_type$jscomp$2$$,"on-select-track":$handle_select_track$jscomp$1$$,"column-values":$column_values$jscomp$1$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$grid_columns_row$$,{"is-column":!1,"hover-track":$hover_track$jscomp$2$$,"expanded?":$APP.$cljs$core$_deref$$($rows_open_QMARK_$$),
"set-column-value":$set_column_value$jscomp$2$$,toggle:$toggle_rows_open$$,"add-new-element":$add_new_element$jscomp$1$$,"reorder-track":$reorder_track$jscomp$2$$,"remove-element":$remove_element$jscomp$2$$,"set-column-type":$set_column_type$jscomp$2$$,"on-select-track":$handle_select_track$jscomp$1$$,"column-values":$rows_values$$})]})]})});var $app$main$ui$workspace$sidebar$options$page$ref_COLON_background_color$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2066$background$$),$APP.$app$main$refs$workspace_page$$),$app$main$ui$workspace$sidebar$options$page$ref_COLON_pixel_grid_color$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2067$pixel_grid_color$$),$APP.$app$main$refs$workspace_page$$),$app$main$ui$workspace$sidebar$options$page$ref_COLON_pixel_grid_opacity$$=
$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$2068$pixel_grid_opacity$$),$APP.$app$main$refs$workspace_page$$),$app$main$ui$workspace$sidebar$options$page$options_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $background$jscomp$12$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$page$ref_COLON_background_color$$),$grid_color$jscomp$2$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$page$ref_COLON_pixel_grid_color$$),
$grid_alpha$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$page$ref_COLON_pixel_grid_opacity$$),$on_change$jscomp$69$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79196_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$change_canvas_color$cljs$0core$0IFn$0_invoke$0arity$02$$(null,$p1__79196_SHARP_$$))}),$on_open$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$start_undo_transaction$$($APP.$cljs$cst$873$options$$))}),
$on_close$jscomp$32$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$commit_undo_transaction$$($APP.$cljs$cst$873$options$$))}),$on_grid_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79197_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$change_pixel_grid_color$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__79197_SHARP_$$))}),
$color$jscomp$167$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($background$jscomp$12$$)],function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($background$jscomp$12$$,"#E8E9EA"),$APP.$cljs$cst$1740$opacity$$,1],null)}),$grid_color__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid_color$jscomp$2$$),$APP.$rumext$v2$adapt$$($grid_alpha$$)],
function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1303$color$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($grid_color$jscomp$2$$,"#0070E4"),$APP.$cljs$cst$1740$opacity$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($grid_alpha$$,.2)],null)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_page__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.canvas-background"),className:"main_ui_workspace_sidebar_options_page__title-spacing-page"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,
{origin:$APP.$cljs$cst$3103$canvas$$,onClose:$on_close$jscomp$32$$,onChange:$on_change$jscomp$69$$,disableOpacity:!0,disableGradient:!0,disableImage:!0,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.canvas-background"),color:$color$jscomp$167$$,onOpen:$on_open$jscomp$3$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-title",
children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!1,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.pixel grid-color"),className:"main_ui_workspace_sidebar_options_page__title-spacing-page"})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_page__element-content",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{disableGradient:!0,
disableImage:!0,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.pixel grid-color"),color:$grid_color__$1$$,onChange:$on_grid_change$$,origin:$APP.$cljs$cst$3091$pixel_grid$$,onOpen:$on_open$jscomp$3$$,onClose:$on_close$jscomp$32$$})})]})]})});var $app$main$ui$workspace$sidebar$options$menus$blur$blur_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1197$background_blur$$],null),$app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$){var $ids$jscomp$294$$=$open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$.ids,$type$jscomp$656$$=
$open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$.type,$values$jscomp$86$$=$open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$.values,$bg_blur_QMARK_$jscomp$3$$=$APP.$app$main$features$use_feature$$("render-wasm/v1")&&$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1197$background_blur$$),$blur_values$jscomp$1$$=$app$main$ui$workspace$sidebar$options$menus$blur$get_blurs$$($values$jscomp$86$$),$mixed_state$$=($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1613$group$$,
$type$jscomp$656$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$type$jscomp$656$$))&&$APP.$cljs$core$boolean$0$$($APP.$cljs$core$some$$(function($p1__79290_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($p1__79290_SHARP_$$))},$blur_values$jscomp$1$$)),$state_STAR_$jscomp$16$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1884$show_content$$,!0],null));$open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$16$$);$open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$=$APP.$cljs$cst$1884$show_content$$.$cljs$core$IFn$_invoke$arity$1$($open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$);var $toggle_content$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$16$$,
$APP.$cljs$core$update$$,$APP.$cljs$cst$1884$show_content$$,$APP.$cljs$core$not$$)}),$change_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$294$$)],function($update_fn$jscomp$53$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$294$$,$update_fn$jscomp$53$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$294$$)]))}),
$handle_delete_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_BANG_$$)],function(){function $G__79298$$($p1__79291_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__79291_SHARP_$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1197$background_blur$$]))}return $change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__79298$$):
$change_BANG_$$($G__79298$$)}),$handle_add$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($change_BANG_$$),$APP.$rumext$v2$adapt$$($blur_values$jscomp$1$$)],function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($blur_values$jscomp$1$$))){var $G__79299_79333_G__79300_79334_existing_key_79328$$=$APP.$cljs$cst$302$key$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($blur_values$jscomp$1$$)),$new_key_79329$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($G__79299_79333_G__79300_79334_existing_key_79328$$,
$APP.$cljs$cst$1658$blur$$)?$APP.$cljs$cst$1197$background_blur$$:$APP.$cljs$cst$1658$blur$$;$G__79299_79333_G__79300_79334_existing_key_79328$$=function($p1__79292_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79292_SHARP_$$,$new_key_79329$$,$app$main$ui$workspace$sidebar$options$menus$blur$create_blur$$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1658$blur$$,$new_key_79329$$)?$APP.$cljs$cst$1925$layer_blur$$:$APP.$cljs$cst$1197$background_blur$$))};
$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__79299_79333_G__79300_79334_existing_key_79328$$):$change_BANG_$$($G__79299_79333_G__79300_79334_existing_key_79328$$)}else $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$count$$($blur_values$jscomp$1$$))&&($G__79299_79333_G__79300_79334_existing_key_79328$$=function($p1__79294_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79294_SHARP_$$,$APP.$cljs$cst$1658$blur$$,
$app$main$ui$workspace$sidebar$options$menus$blur$create_blur$$($APP.$cljs$cst$1925$layer_blur$$))},$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$change_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($G__79299_79333_G__79300_79334_existing_key_79328$$):$change_BANG_$$($G__79299_79333_G__79300_79334_existing_key_79328$$));return $blur_values$jscomp$1$$});return(0,$APP.$rumext$v2$jsxs$$)("section",{hidden:$APP.$cljs$core$not$$($open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$),"aria-label":$bg_blur_QMARK_$jscomp$3$$?
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.blur-effects"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.blur"),className:"main_ui_workspace_sidebar_options_menus_blur__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$APP.$cljs$core$seq$$($blur_values$jscomp$1$$),collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$),
onCollapsed:$toggle_content$jscomp$5$$,"aria-expanded":$open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$,"aria-controls":"blur-content",title:$bg_blur_QMARK_$jscomp$3$$?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$656$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-effects-options.title.multiple"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$656$$,$APP.$cljs$cst$1613$group$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-effects-options.title.group"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.blur-effects"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$656$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.title.multiple"):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$656$$,$APP.$cljs$cst$1613$group$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.title.group"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.blur"),
className:($APP.$cljs$core$not$$($APP.$cljs$core$seq$$($blur_values$jscomp$1$$))?"main_ui_workspace_sidebar_options_menus_blur__title-spacing-blur":"")+" main_ui_workspace_sidebar_options_menus_blur__long-title",children:function(){var $and__5023__auto__$jscomp$845$$=!$mixed_state$$;return $and__5023__auto__$jscomp$845$$?$bg_blur_QMARK_$jscomp$3$$?$APP.$cljs$core$count$$($blur_values$jscomp$1$$)<2:$APP.$cljs$cst$1658$blur$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$86$$)==null:$and__5023__auto__$jscomp$845$$}()?
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.add-blur"),onClick:$handle_add$$,icon:"add",tooltipPlacement:"top-left","data-testid":"add-blur"}):null})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$)?$APP.$cljs$core$seq$$($blur_values$jscomp$1$$):$open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$)?
(0,$APP.$rumext$v2$jsx$$)("div",{hidden:$APP.$cljs$core$not$$($open_QMARK_$jscomp$19_props_79295_state$jscomp$1207$$),id:"blur-content",className:"main_ui_workspace_sidebar_options_menus_blur__element-set-content",children:$mixed_state$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_blur__first-row",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_blur__mixed-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.mixed-values")}),
(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.blur-options.remove-blur"),onClick:$handle_delete_all$$,tooltipPlacement:"top-left",icon:"remove"})]}):$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$177$$,$key$jscomp$419_p__79309$$){var $map__79310__$1_value$jscomp$891$$=$APP.$cljs$core$__destructure_map$$($key$jscomp$419_p__79309$$);
$key$jscomp$419_p__79309$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79310__$1_value$jscomp$891$$,$APP.$cljs$cst$302$key$$);$map__79310__$1_value$jscomp$891$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79310__$1_value$jscomp$891$$,$APP.$cljs$cst$260$value$$);$out_arr__44092__auto__$jscomp$177$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_content_STAR_$$,{blurKey:$key$jscomp$419_p__79309$$,value:$map__79310__$1_value$jscomp$891$$,
blurValues:$blur_values$jscomp$1$$,changeFn:$change_BANG_$$},$key$jscomp$419_p__79309$$));return $out_arr__44092__auto__$jscomp$177$$},[],$blur_values$jscomp$1$$)}):null]})},function($old_props$jscomp$6$$,$new_props$jscomp$7$$){var $old_values$jscomp$1$$=$old_props$jscomp$6$$.values,$new_values$jscomp$1$$=$new_props$jscomp$7$$.values;return $old_props$jscomp$6$$.ids===$new_props$jscomp$7$$.ids&&$old_props$jscomp$6$$.type===$new_props$jscomp$7$$.type&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$1$$,
$APP.$cljs$cst$1658$blur$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$1$$,$APP.$cljs$cst$1658$blur$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$1$$,$APP.$cljs$cst$1197$background_blur$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$1$$,$APP.$cljs$cst$1197$background_blur$$)});var $app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1650$fixed_scroll$$,$APP.$cljs$cst$1624$parent_id$$,$APP.$cljs$cst$1612$frame_id$$],null),$app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($open_QMARK_$jscomp$20_props_79345$$){var $ids$jscomp$295$$=
$open_QMARK_$jscomp$20_props_79345$$.ids,$values$jscomp$87$$=$open_QMARK_$jscomp$20_props_79345$$.values,$state_STAR_$jscomp$17$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$open_QMARK_$jscomp$20_props_79345$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$17$$);var $toggle_content$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$17$$,$APP.$cljs$core$not$$)}),
$in_frame_QMARK__old_shapes$jscomp$2$$=$APP.$cljs$core$_deref$$($app$main$refs$objects_by_id$$($ids$jscomp$295$$)),$first_level_QMARK__frames$jscomp$31$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79339_SHARP_$$){return $APP.$cljs$core$deref$$($app$main$refs$object_by_id$$($APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__79339_SHARP_$$)))},$in_frame_QMARK__old_shapes$jscomp$2$$),$shapes$jscomp$214$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$geom$shapes$translate_to_frame$$,
$in_frame_QMARK__old_shapes$jscomp$2$$,$first_level_QMARK__frames$jscomp$31$$),$values__$1$jscomp$5$$=function(){var $G__79347__$1_map__79346_x$jscomp$1254$$=$APP.$app$common$geom$rect$points__GT_rect$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$214$$))),$map__79346__$1_y$jscomp$475$$=$APP.$cljs$core$__destructure_map$$($G__79347__$1_map__79346_x$jscomp$1254$$);$G__79347__$1_map__79346_x$jscomp$1254$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79346__$1_y$jscomp$475$$,
$APP.$cljs$cst$1515$x$$);$map__79346__$1_y$jscomp$475$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79346__$1_y$jscomp$475$$,$APP.$cljs$cst$1516$y$$);$G__79347__$1_map__79346_x$jscomp$1254$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$87$$),$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($values$jscomp$87$$,$APP.$cljs$cst$1515$x$$,$G__79347__$1_map__79346_x$jscomp$1254$$):
$values$jscomp$87$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$87$$),$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79347__$1_map__79346_x$jscomp$1254$$,$APP.$cljs$cst$1516$y$$,$map__79346__$1_y$jscomp$475$$):$G__79347__$1_map__79346_x$jscomp$1254$$}(),$values__$2$jscomp$2$$=function(){var $G__79349__$1_map__79348_width$jscomp$199$$=$APP.$cljs$cst$1610$selrect$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes$jscomp$214$$)),
$height$jscomp$170_map__79348__$1$$=$APP.$cljs$core$__destructure_map$$($G__79349__$1_map__79348_width$jscomp$199$$);$G__79349__$1_map__79348_width$jscomp$199$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$170_map__79348__$1$$,$APP.$cljs$cst$290$width$$);$height$jscomp$170_map__79348__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$170_map__79348__$1$$,$APP.$cljs$cst$1527$height$$);$G__79349__$1_map__79348_width$jscomp$199$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$5$$),
$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($values__$1$jscomp$5$$,$APP.$cljs$cst$290$width$$,$G__79349__$1_map__79348_width$jscomp$199$$):$values__$1$jscomp$5$$;return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($values__$1$jscomp$5$$),$APP.$cljs$cst$1621$multiple$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79349__$1_map__79348_width$jscomp$199$$,$APP.$cljs$cst$1527$height$$,
$height$jscomp$170_map__79348__$1$$):$G__79349__$1_map__79348_width$jscomp$199$$}();$first_level_QMARK__frames$jscomp$31$$=($in_frame_QMARK__old_shapes$jscomp$2$$=$ids$jscomp$295$$!=null&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$),$APP.$app$common$uuid$zero$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$),
$APP.$cljs$cst$1612$frame_id$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$));var $constraints_h$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1250$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$2$$,$APP.$cljs$cst$1879$constraints_h$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1250$$)?$or__5025__auto__$jscomp$1250$$:$APP.$app$common$geom$shapes$constraints$default_constraints_h$$($values__$2$jscomp$2$$)}(),$constraints_v$jscomp$2$$=function(){var $or__5025__auto__$jscomp$1251$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values__$2$jscomp$2$$,$APP.$cljs$cst$1878$constraints_v$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1251$$)?$or__5025__auto__$jscomp$1251$$:$APP.$app$common$geom$shapes$constraints$default_constraints_v$$($values__$2$jscomp$2$$)}(),$on_constraint_button_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$295$$),$APP.$rumext$v2$adapt$$($values__$2$jscomp$2$$)],function($event$jscomp$549_vec__79350$$){var $button$jscomp$2$$=
$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$549_vec__79350$$),"value")),$constraints_h__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($values__$2$jscomp$2$$,$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$1910$scale$$),$constraints_v__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($values__$2$jscomp$2$$,$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1910$scale$$);$event$jscomp$549_vec__79350$$=
function(){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1567$top$$,$button$jscomp$2$$))switch($constraints_v__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_v__$1$$.$fqn$:null){case "top":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1910$scale$$],null);case "topbottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1568$bottom$$],null);case "bottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1909$topbottom$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1567$top$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1568$bottom$$,
$button$jscomp$2$$))switch($constraints_v__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_v__$1$$.$fqn$:null){case "bottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1910$scale$$],null);case "topbottom":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1567$top$$],null);case "top":return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1909$topbottom$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1568$bottom$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$257$left$$,$button$jscomp$2$$))switch($constraints_h__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_h__$1$$.$fqn$:
null){case "left":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$1910$scale$$],null);case "leftright":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$258$right$$],null);case "right":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,
$APP.$cljs$cst$1908$leftright$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$257$left$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$258$right$$,$button$jscomp$2$$))switch($constraints_h__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_h__$1$$.$fqn$:null){case "right":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$1910$scale$$],null);case "leftright":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$257$left$$],null);case "left":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$1908$leftright$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$258$right$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5800$centerv$$,$button$jscomp$2$$))switch($constraints_v__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_v__$1$$.$fqn$:null){case "center":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1910$scale$$],
null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$cst$1672$center$$],null)}else if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($cljs$cst$5801$centerh$$,$button$jscomp$2$$))switch($constraints_h__$1$$ instanceof $APP.$cljs$core$Keyword$$?$constraints_h__$1$$.$fqn$:null){case "center":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$1910$scale$$],null);default:return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$cst$1672$center$$],null)}else{if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(null,$button$jscomp$2$$))return $APP.$cljs$core$List$EMPTY$$;throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($button$jscomp$2$$)].join(""));}}();
var $constraint$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$549_vec__79350$$,0,null),$new_value$jscomp$25$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($event$jscomp$549_vec__79350$$,1,null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$295$$,function($p1__79340_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79340_SHARP_$$,
$constraint$jscomp$3$$,$new_value$jscomp$25$$)}))}),$on_constraint_h_select_changed$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$295$$)],function($value$jscomp$892$$){return $APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$892$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$295$$,function($p1__79341_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79341_SHARP_$$,
$APP.$cljs$cst$1879$constraints_h$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$892$$))}))}),$on_constraint_v_select_changed$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$295$$)],function($value$jscomp$893$$){return $APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$893$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$295$$,
function($p1__79342_SHARP_$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79342_SHARP_$$,$APP.$cljs$cst$1878$constraints_v$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$893$$))}))}),$on_fixed_scroll_clicked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$295$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$295$$,
function($p1__79343_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($p1__79343_SHARP_$$,$APP.$cljs$cst$1650$fixed_scroll$$,$APP.$cljs$core$not$$)}))}),$options_h$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($constraints_h$jscomp$2$$)],function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$1621$multiple$$)?
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,"left",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.left")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"right",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.right")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"leftright",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.leftright")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"center",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.center")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"scale",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.scale")],null)],null)]))}),$options_v$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($constraints_v$jscomp$2$$)],
function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1621$multiple$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")],null)],null):null,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"top",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.top")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"bottom",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.bottom")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"topbottom",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.topbottom")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"center",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.center")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
"scale",$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.scale")],null)],null)]))});return $in_frame_QMARK__old_shapes$jscomp$2$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,
{collapsable:!0,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$20_props_79345$$),onCollapsed:$toggle_content$jscomp$6$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints")})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$20_props_79345$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__element-set-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-widget",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-top",children:(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"top",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1567$top$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1909$topbottom$$)?
"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-left",children:(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"left",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$257$left$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$1908$leftright$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-center",
children:[(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"centerv",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1672$center$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})}),(0,$APP.$rumext$v2$jsx$$)("button",
{"data-value":"centerh",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-special main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$1672$center$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})]}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-right",children:(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"right",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn main_ui_workspace_sidebar_options_menus_constraints__constraint-btn-rotated "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$258$right$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,
$APP.$cljs$cst$1908$leftright$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-bottom",children:(0,$APP.$rumext$v2$jsx$$)("button",{"data-value":"bottom",onClick:$on_constraint_button_clicked$$,className:"main_ui_workspace_sidebar_options_menus_constraints__constraint-btn "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1568$bottom$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1909$topbottom$$)?"main_ui_workspace_sidebar_options_menus_constraints__active":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_constraints__resalted-area"})})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__constraints-selects",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"constraint-h-select",className:"main_ui_workspace_sidebar_options_menus_constraints__horizontal-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_h$jscomp$2$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$($constraints_h$jscomp$2$$),"scale"):"",options:$options_h$$,
"on-change":$on_constraint_h_select_changed$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{"data-testid":"constraint-v-select",className:"main_ui_workspace_sidebar_options_menus_constraints__vertical-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($constraints_v$jscomp$2$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$data$name$$($constraints_v$jscomp$2$$),
"scale"):"",options:$options_v$$,"on-change":$on_constraint_v_select_changed$$})}),$first_level_QMARK__frames$jscomp$31$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_constraints__checkbox",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"fixed-on-scroll",className:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1650$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$))?"main_ui_workspace_sidebar_options_menus_constraints__checked":"",children:[(0,$APP.$rumext$v2$jsx$$)("span",
{className:"main_ui_workspace_sidebar_options_menus_constraints__check-mark "+($APP.$cljs$core$truth_$$($APP.$cljs$cst$1650$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$))?"main_ui_workspace_sidebar_options_menus_constraints__checked":""),children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$1650$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$))?$APP.$app$main$ui$icons$status_tick$$:null}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.constraints.fix-when-scrolling"),
(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"fixed-on-scroll",checked:$APP.$cljs$cst$1650$fixed_scroll$$.$cljs$core$IFn$_invoke$arity$1$($values__$2$jscomp$2$$),onChange:$on_fixed_scroll_clicked$$})]})}):null]})]}):null]}):null},function($old_props$jscomp$7$$,$new_props$jscomp$8$$){var $old_values$jscomp$2$$=$old_props$jscomp$7$$.values,$new_values$jscomp$2$$=$new_props$jscomp$8$$.values;return $old_props$jscomp$7$$.ids===$new_props$jscomp$8$$.ids&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,
$APP.$cljs$cst$1879$constraints_h$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,$APP.$cljs$cst$1879$constraints_h$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,$APP.$cljs$cst$1878$constraints_v$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,$APP.$cljs$cst$1878$constraints_v$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,$APP.$cljs$cst$1650$fixed_scroll$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,
$APP.$cljs$cst$1650$fixed_scroll$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,$APP.$cljs$cst$1624$parent_id$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,$APP.$cljs$cst$1624$parent_id$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,$APP.$cljs$cst$1612$frame_id$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,$APP.$cljs$cst$1612$frame_id$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,
$APP.$cljs$cst$1515$x$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,$APP.$cljs$cst$1515$x$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,$APP.$cljs$cst$1516$y$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,$APP.$cljs$cst$1516$y$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,$APP.$cljs$cst$290$width$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,
$APP.$cljs$cst$290$width$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$2$$,$APP.$cljs$cst$1527$height$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$2$$,$APP.$cljs$cst$1527$height$$)});var $app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1877$exports$$],null),$app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($open_QMARK_$jscomp$21_props_79363$$){var $shapes$jscomp$215$$=$open_QMARK_$jscomp$21_props_79363$$.shapes,$file_id$jscomp$410$$=$open_QMARK_$jscomp$21_props_79363$$.fileId,
$ids$jscomp$296$$=$open_QMARK_$jscomp$21_props_79363$$.ids,$type$jscomp$657$$=$open_QMARK_$jscomp$21_props_79363$$.type,$page_id$jscomp$431$$=$open_QMARK_$jscomp$21_props_79363$$.pageId,$exports__$1$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($open_QMARK_$jscomp$21_props_79363$$.values,$APP.$cljs$cst$1877$exports$$,$APP.$cljs$core$PersistentVector$EMPTY$$),$open_STAR_$jscomp$8$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$open_QMARK_$jscomp$21_props_79363$$=
$APP.$cljs$core$_deref$$($open_STAR_$jscomp$8$$);var $in_progress_QMARK_$jscomp$2_state$jscomp$1208$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$export$0$$);$in_progress_QMARK_$jscomp$2_state$jscomp$1208$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($in_progress_QMARK_$jscomp$2_state$jscomp$1208$$,$APP.$cljs$cst$4652$in_progress$$);var $has_exports_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$exports__$1$jscomp$13$$)||$APP.$cljs$core$seq$$($exports__$1$jscomp$13$$)!=
null,$toggle_content$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$8$$,$APP.$cljs$core$not$$)}),$shapes_with_exports$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$215$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$seq$$,
$APP.$cljs$cst$1877$exports$$),$shapes$jscomp$215$$)}),$sname$jscomp$3$$=$APP.$cljs$core$seqable_QMARK_$$($exports__$1$jscomp$13$$)?function(){var $sname$jscomp$4$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes_with_exports$$)),$suffix$jscomp$31$$=$APP.$cljs$cst$1376$suffix$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($exports__$1$jscomp$13$$));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($exports__$1$jscomp$13$$))&&
$suffix$jscomp$31$$!=null?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($sname$jscomp$4$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($suffix$jscomp$31$$)].join(""):$sname$jscomp$4$$}():null,$scale_enabled_QMARK_$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__79366_export$$jscomp$11$$){$G__79366_export$$jscomp$11$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($G__79366_export$$jscomp$11$$);var $fexpr__79365$$=new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1539$png$$,null,$APP.$cljs$cst$1541$webp$$,null,$APP.$cljs$cst$1540$jpeg$$,null],null),null);return $fexpr__79365$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__79365$$.$cljs$core$IFn$_invoke$arity$1$($G__79366_export$$jscomp$11$$):$fexpr__79365$$($G__79366_export$$jscomp$11$$)}),$on_download$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$431$$),
$APP.$rumext$v2$adapt$$($file_id$jscomp$410$$),$APP.$rumext$v2$adapt$$($exports__$1$jscomp$13$$)],function($event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$);if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$type$jscomp$657$$)){if($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($shapes_with_exports$$))&&
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($APP.$cljs$cst$1877$exports$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes_with_exports$$))))){var $shape$jscomp$1015$$=$APP.$cljs$core$first$$($shapes_with_exports$$);$event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$=$APP.$cljs$core$first$$($APP.$cljs$cst$1877$exports$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1015$$));var $suffix$jscomp$32$$=$APP.$cljs$cst$1376$suffix$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$),
$sname__$1$$=function(){var $G__79369$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1015$$);return $suffix$jscomp$32$$!=null?[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__79369$$),$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($suffix$jscomp$32$$)].join(""):$G__79369$$}(),$defaults$jscomp$5$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$431$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$410$$,$APP.$cljs$cst$725$name$$,
$sname__$1$$,$APP.$cljs$cst$2281$object_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($shapes_with_exports$$))],null);$event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$,$defaults$jscomp$5$$]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$exports$assets$request_simple_export$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$2185$export$$,$event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$],null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$exports$assets$export_shapes_event$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$],null),"workspace:sidebar")]))}return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$exports$assets$show_workspace_export_dialog$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1938$selected$$,$APP.$cljs$core$reverse$$($ids$jscomp$296$$),$APP.$cljs$cst$1792$origin$$,"workspace:sidebar"],null)))}$defaults$jscomp$5$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$2051$page_id$$,$page_id$jscomp$431$$,$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$410$$,$APP.$cljs$cst$725$name$$,$sname$jscomp$3$$,$APP.$cljs$cst$2281$object_id$$,$APP.$cljs$core$first$$($ids$jscomp$296$$)],null);$event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$=
$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79361_SHARP_$$){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$p1__79361_SHARP_$$,$defaults$jscomp$5$$]))},$exports__$1$jscomp$13$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$exports$assets$request_export$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1877$exports$$,$event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$exports$assets$export_shapes_event$$($event$jscomp$550_export$$jscomp$12_exports__$2$jscomp$2_full_export$$,"workspace:sidebar")]))}),$add_export$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$)],function(){var $xspec$jscomp$1$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$1539$png$$,$APP.$cljs$cst$1376$suffix$$,
"",$APP.$cljs$cst$1910$scale$$,1],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$296$$,function($shape$jscomp$1016$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1016$$,$APP.$cljs$cst$1877$exports$$,$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$xspec$jscomp$1$$],null),$APP.$cljs$cst$1877$exports$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1016$$)))}))}),$delete_export$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$)],function($event$jscomp$551$$){function $remove_fill_by_index$jscomp$2$$($values__$1$jscomp$6$$,$index$jscomp$497$$){return $APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$second$$,$APP.$cljs$core$filterv$$(function($p__79373$$){var $idx$jscomp$124$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79373$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79373$$,1,null);return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($idx$jscomp$124$$,$index$jscomp$497$$)},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($values__$1$jscomp$6$$)))}var $value$jscomp$894$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$551$$),
"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$296$$,function($shape$jscomp$1017$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1017$$,$APP.$cljs$cst$1877$exports$$,$remove_fill_by_index$jscomp$2$$,$value$jscomp$894$$)}))}),$on_scale_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$)],
function($index$jscomp$498$$,$event$jscomp$552$$){var $scale$jscomp$44$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$552$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$296$$,function($shape$jscomp$1018$$){return $APP.$cljs$core$assoc_in$$($shape$jscomp$1018$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1877$exports$$,$index$jscomp$498$$,$APP.$cljs$cst$1910$scale$$],null),$scale$jscomp$44$$)}))}),$on_suffix_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$)],function($event$jscomp$553$$){var $value$jscomp$895$$=(0,$APP.$app$util$dom$get_target_val$$)($event$jscomp$553$$),$index$jscomp$499$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$553$$),
"value"));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$296$$,function($shape$jscomp$1019$$){return $APP.$cljs$core$assoc_in$$($shape$jscomp$1019$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1877$exports$$,$index$jscomp$499$$,$APP.$cljs$cst$1376$suffix$$],null),$value$jscomp$895$$)}))}),$on_type_change$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$)],function($index$jscomp$500$$,$event$jscomp$554$$){var $type__$1$jscomp$16$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$554$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$296$$,function($shape$jscomp$1020$$){return $APP.$cljs$core$assoc_in$$($shape$jscomp$1020$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1877$exports$$,$index$jscomp$500$$,$APP.$cljs$cst$139$type$$],null),$type__$1$jscomp$16$$)}))}),$on_remove_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$296$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$296$$,
function($shape$jscomp$1021$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1021$$,$APP.$cljs$cst$1877$exports$$,$APP.$cljs$core$PersistentVector$EMPTY$$)}))}),$manage_key_down$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$555$$){var $esc_QMARK_$jscomp$7$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$555$$);return $APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$7$$)?$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$555$$)):
null}),$size_options$jscomp$2$$=new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"0.5",$APP.$cljs$cst$2296$label$$,"0.5x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"0.75",$APP.$cljs$cst$2296$label$$,"0.75x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"1",$APP.$cljs$cst$2296$label$$,"1x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,"1.5",$APP.$cljs$cst$2296$label$$,"1.5x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"2",$APP.$cljs$cst$2296$label$$,"2x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"4",$APP.$cljs$cst$2296$label$$,"4x"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"6",$APP.$cljs$cst$2296$label$$,"6x"],null)],null),$format_options$jscomp$1$$=new $APP.$cljs$core$PersistentVector$$(null,
5,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"png",$APP.$cljs$cst$2296$label$$,"PNG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"jpeg",$APP.$cljs$cst$2296$label$$,"JPG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"webp",$APP.$cljs$cst$2296$label$$,"WEBP"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"svg",
$APP.$cljs$cst$2296$label$$,"SVG"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,"pdf",$APP.$cljs$cst$2296$label$$,"PDF"],null)],null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_exports_QMARK_$$,
collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$21_props_79363$$),onCollapsed:$toggle_content$jscomp$7$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$count$$($ids$jscomp$296$$)>1?"workspace.options.export-multiple":"workspace.options.export"),className:$has_exports_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_exports__title-spacing-export",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost",
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.add-export"),onClick:$add_export$jscomp$1$$,icon:"add"})})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$21_props_79363$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__element-set-content",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$exports__$1$jscomp$13$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__multiple-exports",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__actions",children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.remove-export"),
onClick:$on_remove_all$$,icon:"remove"})})]}):$APP.$cljs$core$seq$$($exports__$1$jscomp$13$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$178$$,$export$$jscomp$13_p__79383$$){var $index$jscomp$501$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$13_p__79383$$,0,null);$export$$jscomp$13_p__79383$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($export$$jscomp$13_p__79383$$,
1,null);$out_arr__44092__auto__$jscomp$178$$.push((0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__element-group",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__input-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_exports__format-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$app$common$data$name$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$13_p__79383$$)),
options:$format_options$jscomp$1$$,"dropdown-class":"main_ui_workspace_sidebar_options_menus_exports__dropdown-upwards","on-change":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_type_change$jscomp$2$$,$index$jscomp$501$$)})}),$APP.$cljs$core$truth_$$($scale_enabled_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$scale_enabled_QMARK_$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$13_p__79383$$):$scale_enabled_QMARK_$jscomp$1$$($export$$jscomp$13_p__79383$$))?(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_exports__size-select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1910$scale$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$13_p__79383$$)),options:$size_options$jscomp$2$$,"dropdown-class":"main_ui_workspace_sidebar_options_menus_exports__dropdown-upwards","on-change":$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($on_scale_change$jscomp$1$$,
$index$jscomp$501$$)})}):null,(0,$APP.$rumext$v2$jsx$$)("label",{htmlFor:"suffix-export-input",className:"main_ui_workspace_sidebar_options_menus_exports__suffix-input",children:(0,$APP.$rumext$v2$jsx$$)("input",{id:"suffix-export-input",type:"text",value:$APP.$cljs$cst$1376$suffix$$.$cljs$core$IFn$_invoke$arity$1$($export$$jscomp$13_p__79383$$),placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.suffix"),"data-value":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$501$$),
onChange:$on_suffix_change$jscomp$1$$,onKeyDown:$manage_key_down$jscomp$2$$,className:"main_ui_workspace_sidebar_options_menus_exports__type-input"})})]}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.export.remove-export"),onClick:$delete_export$jscomp$1$$,"data-value":$index$jscomp$501$$,icon:"remove"})]},$index$jscomp$501$$));return $out_arr__44092__auto__$jscomp$178$$},
[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($exports__$1$jscomp$13$$))}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$exports__$1$jscomp$13$$)||$APP.$cljs$core$seq$$($exports__$1$jscomp$13$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$2_state$jscomp$1208$$)?null:$on_download$jscomp$2$$,disabled:$in_progress_QMARK_$jscomp$2_state$jscomp$1208$$,className:"main_ui_workspace_sidebar_options_menus_exports__export-btn "+
($APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$2_state$jscomp$1208$$)?"main_ui_workspace_sidebar_options_menus_exports__btn-disabled":""),children:$APP.$cljs$core$truth_$$($in_progress_QMARK_$jscomp$2_state$jscomp$1208$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.exporting-object"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.options.export-object",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$util$i18n$c$$($APP.$cljs$core$count$$($shapes_with_exports$$))]))}):
null]}):null]})},function($old_props$jscomp$8$$,$new_props$jscomp$9$$){return $old_props$jscomp$8$$.ids===$new_props$jscomp$9$$.ids&&$old_props$jscomp$8$$.type===$new_props$jscomp$9$$.type&&$old_props$jscomp$8$$.pageId===$new_props$jscomp$9$$.pageId&&$old_props$jscomp$8$$.fileId===$new_props$jscomp$9$$.fileId&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($old_props$jscomp$8$$.values,$new_props$jscomp$9$$.values)});var $app$main$ui$workspace$sidebar$options$menus$fill$fill_attrs$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1882$hide_fill_on_export$$,null,$APP.$cljs$cst$1639$fills$$,null],null),null),$app$main$ui$workspace$sidebar$options$menus$fill$xf_COLON_process_fills$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$502$$,$item$jscomp$136$$){var $color$jscomp$168$$=$APP.$app$common$types$fills$fill__GT_color$$($item$jscomp$136$$);
return $APP.$cljs$core$with_meta$$($item$jscomp$136$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1801$index$$,$index$jscomp$502$$,$APP.$cljs$cst$1303$color$$,$color$jscomp$168$$],null))}),$app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$){var $ids$jscomp$297$$=$applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$.ids,$type$jscomp$658$$=$applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$.type,
$fills__$1$jscomp$7_values$jscomp$89$$=$applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$.values;$applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$=$applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$.appliedTokens;var $fills$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($fills__$1$jscomp$7_values$jscomp$89$$,$APP.$cljs$cst$1639$fills$$),$hide_on_export$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($fills__$1$jscomp$7_values$jscomp$89$$,$APP.$cljs$cst$1882$hide_fill_on_export$$,
!1),$fill_token_applied$$=$APP.$cljs$cst$1408$fill$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$),$label$jscomp$48_render_wasm_QMARK_$jscomp$6$$=$APP.$app$main$features$use_feature$$("render-wasm/v1"),$multiple_QMARK_$jscomp$9$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$fills$jscomp$31$$);$fills__$1$jscomp$7_values$jscomp$89$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fills$jscomp$31$$)],
function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$fills$jscomp$31$$)?$fills$jscomp$31$$:$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$workspace$sidebar$options$menus$fill$xf_COLON_process_fills$$,$fills$jscomp$31$$))});$applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$=$multiple_QMARK_$jscomp$9$$||$fills__$1$jscomp$7_values$jscomp$89$$!=null;var $empty_fills_QMARK_$$=
!$multiple_QMARK_$jscomp$9$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$APP.$cljs$core$count$$($fills__$1$jscomp$7_values$jscomp$89$$)),$open_STAR_$jscomp$9$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$),$open_QMARK_$jscomp$22$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$9$$),$toggle_content$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$9$$,
$APP.$cljs$core$not$$)}),$open_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$9$$,!0)}),$close_content$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($open_STAR_$jscomp$9$$,!1)}),$checkbox_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$can_add_fills_QMARK_$$=$label$jscomp$48_render_wasm_QMARK_$jscomp$6$$?!$multiple_QMARK_$jscomp$9$$&&$APP.$cljs$core$count$$($fills__$1$jscomp$7_values$jscomp$89$$)<
8:!$multiple_QMARK_$jscomp$9$$;$label$jscomp$48_render_wasm_QMARK_$jscomp$6$$=function(){switch($type$jscomp$658$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$658$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.selection-fill");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.group-fill");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill")}}();
var $on_add$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$),$APP.$rumext$v2$adapt$$($multiple_QMARK_$jscomp$9$$),$APP.$rumext$v2$adapt$$($empty_fills_QMARK_$$)],function(){if($can_add_fills_QMARK_$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$297$$));var $JSCompiler_temp_const$jscomp$1679$$=$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;
var $JSCompiler_inline_result$jscomp$1681$$=$app$main$data$workspace$colors$add_fill$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$297$$);$JSCompiler_temp_const$jscomp$1679$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$1681$$);return $multiple_QMARK_$jscomp$9$$||$empty_fills_QMARK_$$?$open_content$$.$cljs$core$IFn$_invoke$arity$0$?$open_content$$.$cljs$core$IFn$_invoke$arity$0$():$open_content$$():null}return null}),$on_change$jscomp$70$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],
function($color$jscomp$169_color__$1$jscomp$33$$,$index$jscomp$503$$){$color$jscomp$169_color__$1$jscomp$33$$=$APP.$cljs$core$select_keys$$($color$jscomp$169_color__$1$jscomp$33$$,$APP.$app$common$types$color$color_attrs$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_fill$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$297$$,$color$jscomp$169_color__$1$jscomp$33$$,$index$jscomp$503$$))}),$on_reorder$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],
function($from_pos$jscomp$15$$,$to_space_between_pos$jscomp$15$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$reorder_fills$$($ids$jscomp$297$$,$from_pos$jscomp$15$$,$to_space_between_pos$jscomp$15$$))}),$on_remove$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$),$APP.$rumext$v2$adapt$$($multiple_QMARK_$jscomp$9$$),$APP.$rumext$v2$adapt$$($empty_fills_QMARK_$$)],function($index$jscomp$504$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_fill$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$297$$,
$index$jscomp$504$$));return $multiple_QMARK_$jscomp$9$$||$empty_fills_QMARK_$$?$close_content$$.$cljs$core$IFn$_invoke$arity$0$?$close_content$$.$cljs$core$IFn$_invoke$arity$0$():$close_content$$():null}),$on_remove_all$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$remove_all_fills$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$297$$,
null))}),$on_detach$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function($index$jscomp$505$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$detach_fill$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$297$$,$index$jscomp$505$$))}),$on_change_show_on_export$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function($event$jscomp$556$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_hide_fill_on_export$$($ids$jscomp$297$$,
$APP.$cljs$core$not$$($APP.$app$util$dom$checked_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$556$$)))))}),$disable_drag_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$disable_drag_QMARK_$$=$APP.$cljs$core$_deref$$($disable_drag_STAR_$$),$on_focus$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($disable_drag_STAR_$$,!0)}),$on_blur$jscomp$21$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($disable_drag_STAR_$$,
!1)}),$on_token_change$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function($_$jscomp$3060$$,$token$jscomp$140$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1136$token$$,$token$jscomp$140$$,$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1408$fill$$,null],null),null),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$297$$,$APP.$cljs$cst$4735$expand_with_children$$,!0],null)))}),$on_detach_token$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$297$$)],function($token_name$jscomp$23$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$23$$,$APP.$cljs$cst$2009$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1408$fill$$,null],null),null),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$297$$],null)))});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hide_on_export$$)],function(){var $temp__5825__auto__$jscomp$389$$=$APP.$rumext$v2$ref_val$$($checkbox_ref$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$389$$)?
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($hide_on_export$$,$APP.$cljs$cst$1621$multiple$$)?$APP.$app$util$dom$set_attribute_BANG_$$($temp__5825__auto__$jscomp$389$$,"indeterminate",!0):$APP.$app$util$dom$remove_attribute_BANG_$$($temp__5825__auto__$jscomp$389$$,"indeterminate"):null});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill.section"),className:"main_ui_workspace_sidebar_options_menus_fill__fill-section",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$22$$),onCollapsed:$toggle_content$jscomp$8$$,title:$label$jscomp$48_render_wasm_QMARK_$jscomp$6$$,className:$applied_tokens$jscomp$13_has_fills_QMARK__props_79421$$?"":"main_ui_workspace_sidebar_options_menus_fill__fill-title-bar",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$fills__$1$jscomp$7_values$jscomp$89$$)?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill.add-fill"),onClick:$on_add$jscomp$1$$,"data-testid":"add-fill",disabled:!$can_add_fills_QMARK_$$,icon:"add"})})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$22$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-content",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$fills__$1$jscomp$7_values$jscomp$89$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$fill_token_applied$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-multiple-label",
children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill.remove-fill"),onClick:$on_remove_all$jscomp$1$$,icon:"remove"})]}):$fills__$1$jscomp$7_values$jscomp$89$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$179$$,
$JSCompiler_inline_result$jscomp$1841_index$jscomp$inline_9060_value$jscomp$897$$){var $JSCompiler_temp_const$jscomp$1839$$=$out_arr__44092__auto__$jscomp$179$$.push,$color$jscomp$inline_9061_mdata$jscomp$inline_9059$$=$APP.$cljs$core$meta$$($JSCompiler_inline_result$jscomp$1841_index$jscomp$inline_9060_value$jscomp$897$$);$JSCompiler_inline_result$jscomp$1841_index$jscomp$inline_9060_value$jscomp$897$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$inline_9061_mdata$jscomp$inline_9059$$,
$APP.$cljs$cst$1801$index$$);$color$jscomp$inline_9061_mdata$jscomp$inline_9059$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$inline_9061_mdata$jscomp$inline_9059$$,$APP.$cljs$cst$1303$color$$);$JSCompiler_inline_result$jscomp$1841_index$jscomp$inline_9060_value$jscomp$897$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{onRemove:$on_remove$jscomp$2$$,origin:$APP.$cljs$cst$1408$fill$$,index:$JSCompiler_inline_result$jscomp$1841_index$jscomp$inline_9060_value$jscomp$897$$,
onChange:$on_change$jscomp$70$$,selectOnFocus:$APP.$cljs$core$not$$($disable_drag_QMARK_$$),onReorder:$on_reorder$jscomp$3$$,onTokenChange:$on_token_change$jscomp$5$$,disableDrag:$disable_drag_QMARK_$$,onDetachToken:$on_detach_token$jscomp$7$$,appliedToken:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1841_index$jscomp$inline_9060_value$jscomp$897$$,0)?$fill_token_applied$$:null,onFocus:$on_focus$jscomp$14$$,onDetach:$on_detach$jscomp$4$$,onBlur:$on_blur$jscomp$21$$,
title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.fill"),color:$color$jscomp$inline_9061_mdata$jscomp$inline_9059$$},$JSCompiler_inline_result$jscomp$1841_index$jscomp$inline_9060_value$jscomp$897$$);$JSCompiler_temp_const$jscomp$1839$$.call($out_arr__44092__auto__$jscomp$179$$,$JSCompiler_inline_result$jscomp$1841_index$jscomp$inline_9060_value$jscomp$897$$);return $out_arr__44092__auto__$jscomp$179$$},[],$fills__$1$jscomp$7_values$jscomp$89$$)}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$658$$,
$APP.$cljs$cst$1611$frame$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$658$$,$APP.$cljs$cst$1621$multiple$$)&&$hide_on_export$$!=null?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_fill__fill-checkbox",children:(0,$APP.$rumext$v2$jsxs$$)("label",{htmlFor:"show-fill-on-export",className:$APP.$cljs$core$not$$($hide_on_export$$)?"checked":"",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_fill__check-mark "+
($APP.$cljs$core$not$$($hide_on_export$$)?"main_ui_workspace_sidebar_options_menus_fill__checked":""),children:$APP.$cljs$core$not$$($hide_on_export$$)?$APP.$app$main$ui$icons$status_tick$$:null}),$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.show-fill-on-export"),(0,$APP.$rumext$v2$jsx$$)("input",{type:"checkbox",id:"show-fill-on-export",ref:$checkbox_ref$$,checked:$APP.$cljs$core$not$$($hide_on_export$$),onChange:$on_change_show_on_export$$})]})}):null]}):null]})},
function($n_props_o_fills$$,$n_fills_o_props$$){var $and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$=$n_props_o_fills$$.ids===$n_fills_o_props$$.ids;if($and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$){if($and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$=$n_props_o_fills$$.appliedTokens===$n_fills_o_props$$.appliedTokens){$and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$=$n_fills_o_props$$.values;
var $n_hide_n_vals$$=$n_props_o_fills$$.values;$n_props_o_fills$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$,$APP.$cljs$cst$1639$fills$$);$n_fills_o_props$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_hide_n_vals$$,$APP.$cljs$cst$1639$fills$$);$and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$,
$APP.$cljs$cst$1882$hide_fill_on_export$$);$n_hide_n_vals$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_hide_n_vals$$,$APP.$cljs$cst$1882$hide_fill_on_export$$);return $and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$===$n_hide_n_vals$$&&$n_props_o_fills$$===$n_fills_o_props$$}return $and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$}return $and__5023__auto__$jscomp$847_and__5023__auto____$1$jscomp$143_o_hide_o_vals$$});var $app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1740$opacity$$,$APP.$cljs$cst$1874$blend_mode$$,$APP.$cljs$cst$1628$blocked$$,$APP.$cljs$cst$1625$hidden$$],null),$app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($applied_tokens$jscomp$14_props_79415$$){var $ids$jscomp$299$$=$applied_tokens$jscomp$14_props_79415$$.ids,
$values$jscomp$90$$=$applied_tokens$jscomp$14_props_79415$$.values;$applied_tokens$jscomp$14_props_79415$$=$applied_tokens$jscomp$14_props_79415$$.appliedTokens;var $token_numeric_inputs$jscomp$5$$=$APP.$app$main$features$use_feature$$("tokens/numeric-input"),$hidden_QMARK_$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$90$$,$APP.$cljs$cst$1625$hidden$$),$blocked_QMARK_$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$90$$,$APP.$cljs$cst$1628$blocked$$),
$opacity$jscomp$52$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$90$$,$APP.$cljs$cst$1740$opacity$$),$on_detach_token$jscomp$8$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],function($token_name$jscomp$24$$,$attr$jscomp$82$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,
$token_name$jscomp$24$$,$APP.$cljs$cst$2009$attributes$$,$APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$attr$jscomp$82$$]),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$299$$],null)))}),$current_blend_mode$$=function(){var $or__5025__auto__$jscomp$1252$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$90$$,$APP.$cljs$cst$1874$blend_mode$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1252$$)?$or__5025__auto__$jscomp$1252$$:$APP.$cljs$cst$2033$normal$$}(),$current_opacity$$=
$app$main$ui$workspace$sidebar$options$menus$layer$opacity__GT_string$$($APP.$cljs$cst$1740$opacity$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$90$$)),$state_STAR_$jscomp$18$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5802$selected_blend_mode$$,$current_blend_mode$$,$cljs$cst$5803$option_highlighted_QMARK_$$,!1,$cljs$cst$5804$preview_complete_QMARK_$$,!0],null)}),$handle_change_blend_mode_state$jscomp$1209$$=
$APP.$cljs$core$_deref$$($state_STAR_$jscomp$18$$),$selected_blend_mode$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_change_blend_mode_state$jscomp$1209$$,$cljs$cst$5802$selected_blend_mode$$),$option_highlighted_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_change_blend_mode_state$jscomp$1209$$,$cljs$cst$5803$option_highlighted_QMARK_$$),$preview_complete_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_change_blend_mode_state$jscomp$1209$$,
$cljs$cst$5804$preview_complete_QMARK_$$),$wasm_renderer_enabled_QMARK_$$=$APP.$app$main$features$use_feature$$("render-wasm/v1");$handle_change_blend_mode_state$jscomp$1209$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],function($value$jscomp$899$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$18$$,$APP.$cljs$core$assoc$$,$cljs$cst$5802$selected_blend_mode$$,$value$jscomp$899$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5803$option_highlighted_QMARK_$$,
!1,$cljs$cst$5804$preview_complete_QMARK_$$,!0]));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$unset_preview_blend_mode$$($ids$jscomp$299$$));return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$299$$,$APP.$cljs$cst$1874$blend_mode$$,$value$jscomp$899$$)});var $handle_blend_mode_enter$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$),$APP.$rumext$v2$adapt$$($current_blend_mode$$)],
function($value$jscomp$900$$){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($state_STAR_$jscomp$18$$,$APP.$cljs$core$assoc$$,$cljs$cst$5804$preview_complete_QMARK_$$,!1,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$cljs$cst$5803$option_highlighted_QMARK_$$,!0]));if($wasm_renderer_enabled_QMARK_$$)for(var $c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$=$APP.$cljs$core$seq$$($ids$jscomp$299$$),$G__79453_chunk__79423_79440_seq__79422_79450__$1$$=
null,$G__79454_count__79424_79441$$=0,$G__79452_i__79425_79442$$=0;;)if($G__79452_i__79425_79442$$<$G__79454_count__79424_79441$$){var $id_79444$$=$G__79453_chunk__79423_79440_seq__79422_79450__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__79452_i__79425_79442$$);$APP.$app$render_wasm$api$use_shape$$($id_79444$$);$APP.$app$render_wasm$api$set_shape_blend_mode$$($value$jscomp$900$$);$APP.$app$render_wasm$api$request_render$$("preview-blend-mode");$G__79452_i__79425_79442$$+=1}else if($c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$=
$APP.$cljs$core$seq$$($c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$))$G__79453_chunk__79423_79440_seq__79422_79450__$1$$=$c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__79453_chunk__79423_79440_seq__79422_79450__$1$$)?($c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$=$APP.$cljs$core$_chunked_first$$($G__79453_chunk__79423_79440_seq__79422_79450__$1$$),$G__79452_i__79425_79442$$=
$APP.$cljs$core$_chunked_rest$$($G__79453_chunk__79423_79440_seq__79422_79450__$1$$),$G__79453_chunk__79423_79440_seq__79422_79450__$1$$=$c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$,$G__79454_count__79424_79441$$=$APP.$cljs$core$count$$($c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$),$c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$=$G__79452_i__79425_79442$$):($c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$=
$APP.$cljs$core$first$$($G__79453_chunk__79423_79440_seq__79422_79450__$1$$),$APP.$app$render_wasm$api$use_shape$$($c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$),$APP.$app$render_wasm$api$set_shape_blend_mode$$($value$jscomp$900$$),$APP.$app$render_wasm$api$request_render$$("preview-blend-mode"),$c__5548__auto___79451_id_79456_seq__79422_79439_temp__5825__auto___79449$$=$APP.$cljs$core$next$$($G__79453_chunk__79423_79440_seq__79422_79450__$1$$),$G__79453_chunk__79423_79440_seq__79422_79450__$1$$=
null,$G__79454_count__79424_79441$$=0),$G__79452_i__79425_79442$$=0;else break;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$299$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$set_preview_blend_mode$$($ids$jscomp$299$$,$value$jscomp$900$$))}),$handle_blend_mode_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$),
$APP.$rumext$v2$adapt$$($current_blend_mode$$),$APP.$rumext$v2$adapt$$($wasm_renderer_enabled_QMARK_$$)],function(){$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$18$$,$APP.$cljs$core$assoc$$,$cljs$cst$5804$preview_complete_QMARK_$$,!0);if($wasm_renderer_enabled_QMARK_$$)for(var $c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$=$APP.$cljs$core$seq$$($ids$jscomp$299$$),$G__79475_chunk__79428_79463_seq__79427_79472__$1$$=null,$G__79476_count__79429_79464$$=
0,$G__79474_i__79430_79465$$=0;;)if($G__79474_i__79430_79465$$<$G__79476_count__79429_79464$$){var $id_79466$$=$G__79475_chunk__79428_79463_seq__79427_79472__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$G__79474_i__79430_79465$$);$APP.$app$render_wasm$api$use_shape$$($id_79466$$);$APP.$app$render_wasm$api$set_shape_blend_mode$$($current_blend_mode$$);$APP.$app$render_wasm$api$request_render$$("preview-blend-mode");$G__79474_i__79430_79465$$+=1}else if($c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$=
$APP.$cljs$core$seq$$($c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$))$G__79475_chunk__79428_79463_seq__79427_79472__$1$$=$c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__79475_chunk__79428_79463_seq__79427_79472__$1$$)?($c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$=$APP.$cljs$core$_chunked_first$$($G__79475_chunk__79428_79463_seq__79427_79472__$1$$),$G__79474_i__79430_79465$$=
$APP.$cljs$core$_chunked_rest$$($G__79475_chunk__79428_79463_seq__79427_79472__$1$$),$G__79475_chunk__79428_79463_seq__79427_79472__$1$$=$c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$,$G__79476_count__79429_79464$$=$APP.$cljs$core$count$$($c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$),$c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$=$G__79474_i__79430_79465$$):($c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$=
$APP.$cljs$core$first$$($G__79475_chunk__79428_79463_seq__79427_79472__$1$$),$APP.$app$render_wasm$api$use_shape$$($c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$),$APP.$app$render_wasm$api$set_shape_blend_mode$$($current_blend_mode$$),$APP.$app$render_wasm$api$request_render$$("preview-blend-mode"),$c__5548__auto___79473_id_79478_seq__79427_79462_temp__5825__auto___79471$$=$APP.$cljs$core$next$$($G__79475_chunk__79428_79463_seq__79427_79472__$1$$),$G__79475_chunk__79428_79463_seq__79427_79472__$1$$=
null,$G__79476_count__79429_79464$$=0),$G__79474_i__79430_79465$$=0;else break;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$unset_preview_blend_mode$$($ids$jscomp$299$$))}),$handle_opacity_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],function($value$jscomp$901$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$299$$));
return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$299$$,$APP.$cljs$cst$1740$opacity$$,$value$jscomp$901$$/100)}),$on_opacity_change$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($handle_opacity_change$$)],function($value$jscomp$902$$){return typeof $value$jscomp$902$$==="string"||typeof $value$jscomp$902$$==="number"?$handle_opacity_change$$.$cljs$core$IFn$_invoke$arity$1$?$handle_opacity_change$$.$cljs$core$IFn$_invoke$arity$1$($value$jscomp$902$$):
$handle_opacity_change$$($value$jscomp$902$$):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$apply_token_from_input$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1136$token$$,$APP.$cljs$core$first$$($value$jscomp$902$$),$APP.$cljs$cst$2656$attrs$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1740$opacity$$,null],null),null),$APP.$cljs$cst$4722$shape_ids$$,
$ids$jscomp$299$$],null)))}),$handle_set_hidden$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$299$$));return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$299$$,$APP.$cljs$cst$1625$hidden$$,!0)}),$handle_set_visible$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],
function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$299$$));return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$299$$,$APP.$cljs$cst$1625$hidden$$,!1)}),$handle_set_blocked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$299$$));
return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$299$$,$APP.$cljs$cst$1628$blocked$$,!0)}),$handle_set_unblocked$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$299$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$299$$));return $app$main$ui$workspace$sidebar$options$menus$layer$on_change$$($ids$jscomp$299$$,
$APP.$cljs$cst$1628$blocked$$,!1)}),$options$jscomp$624$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_blend_mode$$)],function(){return $APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$current_blend_mode$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$2296$label$$,"--"],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,16,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2033$normal$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.normal")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2030$darken$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.darken")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2039$multiply$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.multiply")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2042$color_burn$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.color-burn")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2032$lighten$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.lighten")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2029$screen$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.screen")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2041$color_dodge$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.color-dodge")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2034$overlay$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.overlay")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2040$soft_light$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.soft-light")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2038$hard_light$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.hard-light")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2035$difference$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.difference")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2037$exclusion$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.exclusion")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2028$hue$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.hue")],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2031$saturation$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.saturation")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.color")],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$2036$luminosity$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.blend-mode.luminosity")],null)],null)]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($current_blend_mode$$),$APP.$rumext$v2$adapt$$($option_highlighted_QMARK_$$),$APP.$rumext$v2$adapt$$($preview_complete_QMARK_$$)],function(){var $or__5025__auto__$jscomp$inline_9063$$=
$APP.$cljs$core$not$$($option_highlighted_QMARK_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$inline_9063$$?$or__5025__auto__$jscomp$inline_9063$$:$APP.$cljs$core$truth_$$($option_highlighted_QMARK_$$)?$preview_complete_QMARK_$$:$option_highlighted_QMARK_$$)?$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$18$$,$APP.$cljs$core$assoc$$,$cljs$cst$5802$selected_blend_mode$$,$current_blend_mode$$):null});return $token_numeric_inputs$jscomp$5$$?(0,$APP.$rumext$v2$jsxs$$)("section",
{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.layer-section"),className:"main_ui_workspace_sidebar_options_menus_layer__element-set-content-token",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$selected_blend_mode$$,options:$options$jscomp$624$$,"on-change":$handle_change_blend_mode_state$jscomp$1209$$,"is-open?":$option_highlighted_QMARK_$$,"class":$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$5$$)?
"main_ui_workspace_sidebar_options_menus_layer__hidden-select":"","on-pointer-enter-option":$handle_blend_mode_enter$$,"on-pointer-leave-option":$handle_blend_mode_leave$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$input_wrapper_tokens$numeric_input_wrapper_STAR_$$,{min:0,align:$APP.$cljs$cst$258$right$$,onChange:$on_opacity_change$jscomp$2$$,className:"main_ui_workspace_sidebar_options_menus_layer__numeric-input-wrapper",placeholder:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$14_props_79415$$,$APP.$cljs$cst$1740$opacity$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,function(){var $or__5025__auto____$1$jscomp$137$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$90$$,$APP.$cljs$cst$1740$opacity$$);return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$137$$)?$or__5025__auto____$1$jscomp$137$$:1}())?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple"):
"--",max:100,attr:$APP.$cljs$cst$1740$opacity$$,appliedToken:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$14_props_79415$$,$APP.$cljs$cst$1740$opacity$$),value:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$opacity$jscomp$52$$)?$opacity$jscomp$52$$:100*$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($opacity$jscomp$52$$,1),onDetach:$on_detach_token$jscomp$8$$,property:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.opacity"),
disabled:$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1254$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$hidden_QMARK_$jscomp$5$$);return $or__5025__auto__$jscomp$1254$$?$or__5025__auto__$jscomp$1254$$:$hidden_QMARK_$jscomp$5$$}())?!0:!1,icon:"percentage"}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$hidden_QMARK_$jscomp$5$$)||$APP.$cljs$core$not$$($hidden_QMARK_$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.toggle-layer"),onClick:$handle_set_hidden$$,tooltipPlacement:"top-left",icon:"shown"}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.toggle-layer"),onClick:$handle_set_visible$$,tooltipPlacement:"top-left",icon:"hide"}),
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$blocked_QMARK_$jscomp$3$$)||$APP.$cljs$core$not$$($blocked_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.lock"),onClick:$handle_set_blocked$$,tooltipPlacement:"top-left",icon:"unlock"}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unlock"),onClick:$handle_set_unblocked$$,tooltipPlacement:"top-left",icon:"lock"})]}):(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.layer-section"),className:"main_ui_workspace_sidebar_options_menus_layer__element-set-content "+($APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$5$$)?"main_ui_workspace_sidebar_options_menus_layer__hidden":
""),children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layer__select",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"default-value":$selected_blend_mode$$,options:$options$jscomp$624$$,"on-change":$handle_change_blend_mode_state$jscomp$1209$$,"is-open?":$option_highlighted_QMARK_$$,"class":$APP.$cljs$core$truth_$$($hidden_QMARK_$jscomp$5$$)?"main_ui_workspace_sidebar_options_menus_layer__hidden-select":"","on-pointer-enter-option":$handle_blend_mode_enter$$,
"on-pointer-leave-option":$handle_blend_mode_leave$$})}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.opacity"),className:"main_ui_workspace_sidebar_options_menus_layer__input",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layer__icon",children:"%"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{value:$current_opacity$$,placeholder:"--",onChange:$handle_opacity_change$$,
min:0,max:100,className:"main_ui_workspace_sidebar_options_menus_layer__numeric-input"})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layer__actions",children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$hidden_QMARK_$jscomp$5$$)||$APP.$cljs$core$not$$($hidden_QMARK_$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.toggle-layer"),
onClick:$handle_set_hidden$$,icon:"shown"}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.layer-options.toggle-layer"),onClick:$handle_set_visible$$,icon:"hide"}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$blocked_QMARK_$jscomp$3$$)||$APP.$cljs$core$not$$($blocked_QMARK_$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.lock"),onClick:$handle_set_blocked$$,icon:"unlock"}):(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.shape.menu.unlock"),onClick:$handle_set_unblocked$$,icon:"lock"})]})]})},function($old_props$jscomp$9$$,$new_props$jscomp$10$$){var $old_values$jscomp$3$$=
$old_props$jscomp$9$$.values,$new_values$jscomp$3$$=$new_props$jscomp$10$$.values,$old_applied_tokens$jscomp$2$$=$old_props$jscomp$9$$.appliedTokens,$new_applied_tokens$jscomp$2$$=$new_props$jscomp$10$$.appliedTokens;return $old_props$jscomp$9$$["class"]===$new_props$jscomp$10$$["class"]&&$old_props$jscomp$9$$.ids===$new_props$jscomp$10$$.ids&&$old_applied_tokens$jscomp$2$$===$new_applied_tokens$jscomp$2$$&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$3$$,$APP.$cljs$cst$1740$opacity$$)===
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$3$$,$APP.$cljs$cst$1740$opacity$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$3$$,$APP.$cljs$cst$1874$blend_mode$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$3$$,$APP.$cljs$cst$1874$blend_mode$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$3$$,$APP.$cljs$cst$1628$blocked$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$3$$,
$APP.$cljs$cst$1628$blocked$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$3$$,$APP.$cljs$cst$1625$hidden$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$3$$,$APP.$cljs$cst$1625$hidden$$)});var $app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,11,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1704$layout_item_margin$$,$APP.$cljs$cst$1703$layout_item_margin_type$$,$APP.$cljs$cst$1713$layout_item_h_sizing$$,$APP.$cljs$cst$1714$layout_item_v_sizing$$,$APP.$cljs$cst$1709$layout_item_max_h$$,$APP.$cljs$cst$1710$layout_item_min_h$$,$APP.$cljs$cst$1711$layout_item_max_w$$,$APP.$cljs$cst$1712$layout_item_min_w$$,
$APP.$cljs$cst$1715$layout_item_align_self$$,$APP.$cljs$cst$1716$layout_item_absolute$$,$APP.$cljs$cst$1717$layout_item_z_index$$],null),$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($is_absolute_QMARK__props_79515_selection_parents_STAR_$$){var $is_layout_container$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.isLayoutContainer,$is_layout_child_is_layout_child_QMARK_$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.isLayoutChild,
$is_grid_layout_title$jscomp$43$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.isGridLayout,$is_flex_layout_on_align_self_change$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.isFlexLayout,$ids$jscomp$303$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.ids,$is_flex_parent$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.isFlexParent,$values$jscomp$92$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.values,$applied_tokens$jscomp$18$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.appliedTokens,
$is_grid_parent_on_margin_type_change$$=$is_absolute_QMARK__props_79515_selection_parents_STAR_$$.isGridParent;$is_absolute_QMARK__props_79515_selection_parents_STAR_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$303$$)});var $is_col_QMARK_$jscomp$1_selection_parents$jscomp$1$$=$APP.$rumext$v2$deref$$($is_absolute_QMARK__props_79515_selection_parents_STAR_$$);$is_absolute_QMARK__props_79515_selection_parents_STAR_$$=
$APP.$cljs$cst$1716$layout_item_absolute$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$);$is_col_QMARK_$jscomp$1_selection_parents$jscomp$1$$=$APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$col_QMARK_$$,$is_col_QMARK_$jscomp$1_selection_parents$jscomp$1$$);$is_layout_child_is_layout_child_QMARK_$$=$is_layout_child_is_layout_child_QMARK_$$&&!$is_absolute_QMARK__props_79515_selection_parents_STAR_$$;var $state_STAR_$jscomp$19$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),
$open_QMARK_$jscomp$23$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$19$$),$toggle_content$jscomp$9$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$19$$,$APP.$cljs$core$not$$)}),$has_content_QMARK_$$=$is_layout_child_is_layout_child_QMARK_$$||$is_flex_parent$$||$is_grid_parent_on_margin_type_change$$||$is_layout_container$$,$align_self$jscomp$6$$=$APP.$cljs$cst$1715$layout_item_align_self$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$),
$h_sizing$jscomp$2$$=$APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$),$v_sizing$jscomp$3$$=$APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$);$is_grid_layout_title$jscomp$43$$=$is_layout_container$$&&$is_flex_layout_on_align_self_change$$&&!$is_layout_child_is_layout_child_QMARK_$$?"Flex board":$is_layout_container$$&&$is_grid_layout_title$jscomp$43$$&&!$is_layout_child_is_layout_child_QMARK_$$?"Grid board":
$is_layout_container$$&&!$is_layout_child_is_layout_child_QMARK_$$?"Layout board":$is_flex_parent$$?"Flex element":$is_grid_parent_on_margin_type_change$$?"Grid element":"Layout element";$is_flex_layout_on_align_self_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$),$APP.$rumext$v2$adapt$$($align_self$jscomp$6$$)],function($value$jscomp$909$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($align_self$jscomp$6$$,$value$jscomp$909$$)?
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1715$layout_item_align_self$$,null],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1715$layout_item_align_self$$,$value$jscomp$909$$],null)))});$is_grid_parent_on_margin_type_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],function($type$jscomp$660$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1703$layout_item_margin_type$$,
$type$jscomp$660$$],null)))});var $on_margin_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],function($type$jscomp$661$$,$prop$jscomp$39$$,$val$jscomp$220$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$661$$,$APP.$cljs$cst$1668$simple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$39$$,$APP.$cljs$cst$1705$m1$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1705$m1$$,$val$jscomp$220$$,$APP.$cljs$cst$1707$m3$$,$val$jscomp$220$$],null)],null))):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$661$$,$APP.$cljs$cst$1668$simple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($prop$jscomp$39$$,$APP.$cljs$cst$1706$m2$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1706$m2$$,$val$jscomp$220$$,$APP.$cljs$cst$1708$m4$$,$val$jscomp$220$$],null)],null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1704$layout_item_margin$$,
$APP.$cljs$core$PersistentArrayMap$createAsIfByAssoc$$([$prop$jscomp$39$$,$val$jscomp$220$$])],null)))}),$on_behaviour_h_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],function($value$jscomp$910$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1713$layout_item_h_sizing$$,$value$jscomp$910$$],null)))}),$on_behaviour_v_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],function($value$jscomp$911$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1714$layout_item_v_sizing$$,
$value$jscomp$911$$],null)))}),$on_change_position$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],function($value$jscomp$912$$){$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$912$$,$cljs$cst$5805$static$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1717$layout_item_z_index$$,null],null)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1716$layout_item_absolute$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($value$jscomp$912$$,$APP.$cljs$cst$4144$absolute$$)],null)))}),$on_change_z_index$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$303$$)],
function($value$jscomp$913$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$update_layout_child$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$303$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1717$layout_item_z_index$$,$value$jscomp$913$$],null)))});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"Layout item section",className:"main_ui_workspace_sidebar_options_menus_layout_item__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_layout_item__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_content_QMARK_$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$23$$),onCollapsed:$toggle_content$jscomp$9$$,title:$is_grid_layout_title$jscomp$43$$,className:"main_ui_workspace_sidebar_options_menus_layout_item__title-spacing-layout-element "+($has_content_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_layout_item__title-spacing-empty")})}),
$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$23$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__flex-element-menu",children:[$is_layout_child_is_layout_child_QMARK_$$||$is_absolute_QMARK__props_79515_selection_parents_STAR_$$?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__position-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__position-options",
children:$APP.$rumext$v2$jsxs$$($APP.$app$main$ui$components$radio_buttons$radio_buttons$$,{selected:$is_absolute_QMARK__props_79515_selection_parents_STAR_$$?"absolute":"static","decode-fn":$APP.$cljs$core$keyword$$,"on-change":$on_change_position$$,name:"layout-style",wide:!0,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,{value:"static",id:$cljs$cst$5806$static_position$$}),$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$radio_buttons$radio_button$$,
{value:"absolute",id:$cljs$cst$5807$absolute_position$$})]})}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:"z-index",className:"main_ui_workspace_sidebar_options_menus_layout_item__z-index-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_layout_item__icon-text",children:"Z"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_layout_item__numeric-input",placeholder:"--",
onFocus:function($p1__79513_SHARP_$$){return $app$util$dom$select_target$$($p1__79513_SHARP_$$)},onChange:function($p1__79514_SHARP_$$){return $on_change_z_index$$.$cljs$core$IFn$_invoke$arity$1$?$on_change_z_index$$.$cljs$core$IFn$_invoke$arity$1$($p1__79514_SHARP_$$):$on_change_z_index$$($p1__79514_SHARP_$$)},nillable:!0,value:$APP.$cljs$cst$1717$layout_item_z_index$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$)})]})]}):null,(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__behavior-row",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__behaviour-menu "+($is_layout_child_is_layout_child_QMARK_$$&&$is_layout_container$$?"main_ui_workspace_sidebar_options_menus_layout_item__wrap":""),children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_horizontal$$,{"is-auto":$is_layout_container$$,"has-fill":$is_layout_child_is_layout_child_QMARK_$$,value:$APP.$cljs$cst$1713$layout_item_h_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$),
"on-change":$on_behaviour_h_change$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$element_behaviour_vertical$$,{"is-auto":$is_layout_container$$,"has-fill":$is_layout_child_is_layout_child_QMARK_$$,value:$APP.$cljs$cst$1714$layout_item_v_sizing$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$),"on-change":$on_behaviour_v_change$$})]})}),$is_layout_child_is_layout_child_QMARK_$$&&$is_flex_parent$$?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_layout_item__align-row",
children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$align_self_row$$,{"is-col":$is_col_QMARK_$jscomp$1_selection_parents$jscomp$1$$,value:$align_self$jscomp$6$$,"on-change":$is_flex_layout_on_align_self_change$$})}):null,$is_layout_child_is_layout_child_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$margin_section_STAR_$$,{value:$APP.$cljs$cst$1704$layout_item_margin$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$),
type:$APP.$cljs$cst$1703$layout_item_margin_type$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$92$$),onTypeChange:$is_grid_parent_on_margin_type_change$$,appliedTokens:$applied_tokens$jscomp$18$$,ids:$ids$jscomp$303$$,onChange:$on_margin_change$$}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($h_sizing$jscomp$2$$,$APP.$cljs$cst$1408$fill$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($v_sizing$jscomp$3$$,$APP.$cljs$cst$1408$fill$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_size_constraints_STAR_$$,
{ids:$ids$jscomp$303$$,values:$values$jscomp$92$$,appliedTokens:$applied_tokens$jscomp$18$$}):null]}):null]})},function($old_props$jscomp$10$$,$new_props$jscomp$11$$){var $old_values$jscomp$4$$=$old_props$jscomp$10$$.values,$new_values$jscomp$4$$=$new_props$jscomp$11$$.values;return $old_props$jscomp$10$$.ids===$new_props$jscomp$11$$.ids&&$old_props$jscomp$10$$.type===$new_props$jscomp$11$$.type&&$old_props$jscomp$10$$.isLayoutChild===$new_props$jscomp$11$$.isLayoutChild&&$old_props$jscomp$10$$.isLayoutContainer===
$new_props$jscomp$11$$.isLayoutContainer&&$old_props$jscomp$10$$.isGridParent===$new_props$jscomp$11$$.isGridParent&&$old_props$jscomp$10$$.isFlexParent===$new_props$jscomp$11$$.isFlexParent&&$old_props$jscomp$10$$.isGridLayout===$new_props$jscomp$11$$.isGridLayout&&$old_props$jscomp$10$$.isFlexLayout===$new_props$jscomp$11$$.isFlexLayout&&$old_props$jscomp$10$$.appliedTokens===$new_props$jscomp$11$$.appliedTokens&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1704$layout_item_margin$$)===
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1704$layout_item_margin$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1703$layout_item_margin_type$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1703$layout_item_margin_type$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1713$layout_item_h_sizing$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,
$APP.$cljs$cst$1713$layout_item_h_sizing$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1714$layout_item_v_sizing$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1714$layout_item_v_sizing$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1709$layout_item_max_h$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1709$layout_item_max_h$$)&&
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1710$layout_item_min_h$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1710$layout_item_min_h$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1711$layout_item_max_w$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1711$layout_item_max_w$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,
$APP.$cljs$cst$1712$layout_item_min_w$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1712$layout_item_min_w$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1715$layout_item_align_self$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1715$layout_item_align_self$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1716$layout_item_absolute$$)===
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1716$layout_item_absolute$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$4$$,$APP.$cljs$cst$1717$layout_item_z_index$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$4$$,$APP.$cljs$cst$1717$layout_item_z_index$$)});var $app$main$ui$workspace$sidebar$options$menus$shadow$shadow_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1659$shadow$$],null),$app$main$ui$workspace$sidebar$options$menus$shadow$xf_COLON_add_index$$=$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$509$$,$shadow__$1$jscomp$18$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shadow__$1$jscomp$18$$,$cljs$cst$5809$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_menus_DOT_shadow_SLASH_index$$,
$index$jscomp$509$$)}),$app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_79508_shadows$jscomp$4$$){var $ids$jscomp$304$$=$props_79508_shadows$jscomp$4$$.ids,$type$jscomp$662$$=$props_79508_shadows$jscomp$4$$.type,$values$jscomp$94$$=$props_79508_shadows$jscomp$4$$.values;$props_79508_shadows$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($values$jscomp$94$$)],function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$values$jscomp$94$$)?$values$jscomp$94$$:$APP.$cljs$core$not_empty$$($APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$app$main$ui$workspace$sidebar$options$menus$shadow$xf_COLON_add_index$$,$values$jscomp$94$$))});var $ids_ref$$=$app$main$ui$hooks$use_update_ref$$($ids$jscomp$304$$),$open_state_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$),$open_state$$=$APP.$cljs$core$_deref$$($open_state_STAR_$$),
$has_shadows_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$props_79508_shadows$jscomp$4$$)||$APP.$cljs$core$seq$$($props_79508_shadows$jscomp$4$$)!=null,$show_content_STAR_$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),$show_content_QMARK_$jscomp$4$$=$APP.$cljs$core$_deref$$($show_content_STAR_$jscomp$3$$),$toggle_content$jscomp$10$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($show_content_STAR_$jscomp$3$$,
$APP.$cljs$core$not$$)}),$on_toggle_open$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79503_SHARP_$$){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($open_state_STAR_$$,$APP.$cljs$core$update$$,$p1__79503_SHARP_$$,$APP.$cljs$core$not$$)}),$on_remove_all$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $ids__$1$jscomp$23$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$23$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$23$$,function($p1__79504_SHARP_$$){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($p1__79504_SHARP_$$,$APP.$cljs$cst$1659$shadow$$)}))}),$handle_reorder$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($from_pos$jscomp$17$$,$to_space_between_pos$jscomp$17$$){var $ids__$1$jscomp$24$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$24$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$reorder_shadows$$($ids__$1$jscomp$24$$,$from_pos$jscomp$17$$,$to_space_between_pos$jscomp$17$$))}),$on_add_shadow$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $ids__$1$jscomp$25$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$25$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$add_shadow$$($ids__$1$jscomp$25$$))}),$on_detach_color$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$510$$){var $ids__$1$jscomp$26$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$26$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$26$$,function($p1__79505_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$variadic$($p1__79505_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1659$shadow$$,$index$jscomp$510$$,$APP.$cljs$cst$1303$color$$],null),$APP.$cljs$core$dissoc$$,
$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1649$file_id$$,$APP.$cljs$cst$1741$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1742$ref_file$$]))}))}),$on_toggle_visibility$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$511$$){var $ids__$1$jscomp$27$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$27$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$27$$,function($p1__79506_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($p1__79506_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1659$shadow$$,$index$jscomp$511$$,$APP.$cljs$cst$1625$hidden$$],null),$APP.$cljs$core$not$$)}))}),
$on_remove$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$304$$)],function($index$jscomp$512$$){var $ids__$1$jscomp$28$$=$APP.$rumext$v2$ref_val$$($ids_ref$$);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids__$1$jscomp$28$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids__$1$jscomp$28$$,
function($p1__79507_SHARP_$$){return $APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($p1__79507_SHARP_$$,$APP.$cljs$cst$1659$shadow$$,$app$main$ui$workspace$sidebar$options$menus$shadow$remove_shadow_by_index$$,$index$jscomp$512$$)}))}),$on_update$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($index$jscomp$513$$,$attr$jscomp$91$$,$value$jscomp$919$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$rumext$v2$ref_val$$($ids_ref$$),
function($shape$jscomp$1022$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($shape$jscomp$1022$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1659$shadow$$,$index$jscomp$513$$],null),function($shadow__$1$jscomp$19$$){return(0,$APP.$app$common$types$shape$shadow$check_shadow$$)($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($shadow__$1$jscomp$19$$,$attr$jscomp$91$$,$value$jscomp$919$$))})}))});return(0,$APP.$rumext$v2$jsxs$$)("div",
{"data-testid":"shadow-section",className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-section",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_shadows_QMARK_$$,collapsed:$APP.$cljs$core$not$$($show_content_QMARK_$jscomp$4$$),onCollapsed:$toggle_content$jscomp$10$$,title:function(){switch($type$jscomp$662$$ instanceof
$APP.$cljs$core$Keyword$$?$type$jscomp$662$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.title.multiple");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.title.group");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.title")}}(),className:$has_shadows_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_shadow__shadow-title-bar",
children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$props_79508_shadows$jscomp$4$$)?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.add-shadow"),onClick:$on_add_shadow$$,icon:"add","data-testid":"add-shadow"})})}),$APP.$cljs$core$truth_$$($show_content_QMARK_$jscomp$4$$)?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$props_79508_shadows$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-content",children:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-multiple-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.shadow-options.remove-shadow"),onClick:$on_remove_all$jscomp$2$$,icon:"remove"})]})}):$props_79508_shadows$jscomp$4$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_shadow__shadow-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$180$$,
$map__79512__$1_p__79511$$){$map__79512__$1_p__79511$$=$APP.$cljs$core$__destructure_map$$($map__79512__$1_p__79511$$);var $index$jscomp$514$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79512__$1_p__79511$$,$cljs$cst$5809$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_menus_DOT_shadow_SLASH_index$$),$id$jscomp$973$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79512__$1_p__79511$$,$APP.$cljs$cst$266$id$$);$out_arr__44092__auto__$jscomp$180$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$shadow_row$shadow_row_STAR_$$,
{onRemove:$on_remove$jscomp$4$$,onToggleVisibility:$on_toggle_visibility$jscomp$3$$,index:$index$jscomp$514$$,onUpdate:$on_update$jscomp$1$$,onReorder:$handle_reorder$$,shadow:$map__79512__$1_p__79511$$,onDetachColor:$on_detach_color$jscomp$1$$,onToggleOpen:$on_toggle_open$jscomp$1$$,isOpen:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($open_state$$,$id$jscomp$973$$)},""+($index$jscomp$514$$??"")));return $out_arr__44092__auto__$jscomp$180$$},[],$props_79508_shadows$jscomp$4$$)})}):null:null]})},
function($old_props$jscomp$11$$,$new_props$jscomp$12$$){return $old_props$jscomp$11$$.ids===$new_props$jscomp$12$$.ids&&$old_props$jscomp$11$$.type===$new_props$jscomp$12$$.type&&$old_props$jscomp$11$$.values===$new_props$jscomp$12$$.values});var $app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$=new $APP.$cljs$core$PersistentVector$$(null,13,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$strokes$$,$APP.$cljs$cst$1873$stroke_style$$,$APP.$cljs$cst$1875$stroke_alignment$$,$APP.$cljs$cst$1660$stroke_width$$,$APP.$cljs$cst$1880$stroke_dash$$,$APP.$cljs$cst$1871$stroke_gap$$,$APP.$cljs$cst$1745$stroke_color$$,$APP.$cljs$cst$1748$stroke_color_ref_id$$,$APP.$cljs$cst$1646$stroke_color_ref_file$$,$APP.$cljs$cst$1746$stroke_opacity$$,
$APP.$cljs$cst$1747$stroke_color_gradient$$,$APP.$cljs$cst$1872$stroke_cap_start$$,$APP.$cljs$cst$1876$stroke_cap_end$$],null),$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($label$jscomp$49_props_79539$$){function $on_blur$jscomp$26$$(){return $APP.$cljs$core$reset_BANG_$$($disable_drag$jscomp$3$$,!1)}function $on_focus$jscomp$18$$(){return $APP.$cljs$core$reset_BANG_$$($disable_drag$jscomp$3$$,!0)}function $on_add_stroke$$(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$add_stroke$$($ids$jscomp$306$$,$APP.$app$common$types$stroke$default_stroke$$));return $APP.$cljs$core$seq$$($strokes$jscomp$11$$)==null?$open_content$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$open_content$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$open_content$jscomp$1$$():null}function $on_stroke_cap_switch$jscomp$1$$($index$jscomp$526$$){var $stroke_cap_start$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$95$$,
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$strokes$$,$index$jscomp$526$$,$APP.$cljs$cst$1872$stroke_cap_start$$],null)),$stroke_cap_end$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$95$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$strokes$$,$index$jscomp$526$$,$APP.$cljs$cst$1876$stroke_cap_end$$],null));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($stroke_cap_start$$,
$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($stroke_cap_end$$,$APP.$cljs$cst$1621$multiple$$)?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$306$$,new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1872$stroke_cap_start$$,$stroke_cap_end$$,$APP.$cljs$cst$1876$stroke_cap_end$$,$stroke_cap_start$$],null),$index$jscomp$526$$))):null}function $on_stroke_cap_end_change$jscomp$1$$($index$jscomp$525$$,$value$jscomp$927$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$306$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1876$stroke_cap_end$$,$value$jscomp$927$$],null),$index$jscomp$525$$))}function $on_stroke_cap_start_change$jscomp$1$$($index$jscomp$524$$,$value$jscomp$926$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$306$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1872$stroke_cap_start$$,$value$jscomp$926$$],null),$index$jscomp$524$$))}function $on_stroke_gap_change$jscomp$1$$($index$jscomp$523$$,$value$jscomp$925$$){if($APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$925$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$306$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1871$stroke_gap$$,$value$jscomp$925$$],null),$index$jscomp$523$$))}function $on_stroke_dash_change$jscomp$1$$($index$jscomp$522$$,$value$jscomp$924$$){if($APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$924$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$306$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1880$stroke_dash$$,$value$jscomp$924$$],null),$index$jscomp$522$$))}function $on_stroke_width_change$jscomp$1$$($index$jscomp$521$$,$value$jscomp$923$$){if($APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$923$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$306$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1660$stroke_width$$,$value$jscomp$923$$],null),$index$jscomp$521$$))}function $on_stroke_alignment_change$jscomp$1$$($index$jscomp$520$$,$value$jscomp$922$$){if($APP.$cuerdas$core$empty_QMARK_$$($value$jscomp$922$$))return null;$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$306$$,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1875$stroke_alignment$$,$value$jscomp$922$$],null),$index$jscomp$520$$))}var $disable_stroke_style$jscomp$1$$=$label$jscomp$49_props_79539$$.disableStrokeStyle,$ids$jscomp$306$$=$label$jscomp$49_props_79539$$.ids,$type$jscomp$663$$=$label$jscomp$49_props_79539$$.type,$show_caps$jscomp$1$$=$label$jscomp$49_props_79539$$.showCaps,$values$jscomp$95$$=$label$jscomp$49_props_79539$$.values,$applied_tokens$jscomp$20$$=$label$jscomp$49_props_79539$$.appliedTokens;
$label$jscomp$49_props_79539$$=function(){switch($type$jscomp$663$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$663$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.selection-stroke");case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.group-stroke");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.stroke")}}();var $state_STAR_$jscomp$20$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0),
$open_QMARK_$jscomp$24$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$20$$),$toggle_content$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$20$$,$APP.$cljs$core$not$$)}),$open_content$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($state_STAR_$jscomp$20$$,!0)}),$strokes$jscomp$11$$=$APP.$cljs$cst$1641$strokes$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$95$$),
$has_strokes_QMARK_$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$strokes$jscomp$11$$)||$APP.$cljs$core$seq$$($strokes$jscomp$11$$)!=null,$on_color_change$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$)],function($index$jscomp$516$$,$color$jscomp$174$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_stroke_color$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$306$$,$color$jscomp$174$$,$index$jscomp$516$$))}),$on_remove$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$)],function($index$jscomp$517$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_stroke$$($ids$jscomp$306$$,$index$jscomp$517$$))}),$handle_remove_all$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$remove_all_strokes$$($ids$jscomp$306$$))}),
$on_color_detach$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$)],function($index$jscomp$518$$,$color$jscomp$175_color__$1$jscomp$34$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));$color$jscomp$175_color__$1$jscomp$34$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$175_color__$1$jscomp$34$$,
$APP.$cljs$cst$1741$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1742$ref_file$$]));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_stroke_color$cljs$0core$0IFn$0_invoke$0arity$04$$($ids$jscomp$306$$,$color$jscomp$175_color__$1$jscomp$34$$,$index$jscomp$518$$))}),$handle_reorder$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$)],
function($from_pos$jscomp$19$$,$to_space_between_pos$jscomp$19$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$reorder_strokes$$($ids$jscomp$306$$,$from_pos$jscomp$19$$,$to_space_between_pos$jscomp$19$$))}),$on_stroke_style_change$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$)],
function($index$jscomp$519$$,$value$jscomp$921$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$colors$change_stroke_attrs$cljs$0core$0IFn$0_invoke$0arity$03$$($ids$jscomp$306$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1873$stroke_style$$,$value$jscomp$921$$],null),$index$jscomp$519$$))}),
$on_toggle_visibility$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$)],function($index$jscomp$527$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$transforms$trigger_bounding_box_cloaking$$($ids$jscomp$306$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$306$$,
function($p1__79538_SHARP_$$){return $APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$3$($p1__79538_SHARP_$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1641$strokes$$,$index$jscomp$527$$,$APP.$cljs$cst$1625$hidden$$],null),$APP.$cljs$core$not$$)})]))}),$disable_drag$jscomp$3$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$on_detach_token$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$306$$)],
function($token_name$jscomp$28$$,$attrs$jscomp$177$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$28$$,$APP.$cljs$cst$2009$attributes$$,$attrs$jscomp$177$$,$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$306$$],null)))});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":"Stroke section",className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-section",
children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_strokes_QMARK_$jscomp$1$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$24$$),onCollapsed:$toggle_content$jscomp$11$$,title:$label$jscomp$49_props_79539$$,className:$has_strokes_QMARK_$jscomp$1$$?"":"main_ui_workspace_sidebar_options_menus_stroke__stroke-title-bar",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$strokes$jscomp$11$$)?null:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.add-stroke"),onClick:$on_add_stroke$$,icon:"add","data-testid":"add-stroke"})})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$24$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-content "+($has_strokes_QMARK_$jscomp$1$$?
"":"main_ui_workspace_sidebar_options_menus_stroke__stroke-content-empty"),children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1745$stroke_color$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$20$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$APP.$cljs$cst$1660$stroke_width$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$20$$))||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$strokes$jscomp$11$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-multiple",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_stroke__stroke-multiple-label",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("settings.multiple")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke.remove-stroke"),
onClick:$handle_remove_all$$,icon:"remove"})]}):$APP.$cljs$core$seq$$($strokes$jscomp$11$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$hooks$sortable_container_STAR_$$,{children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$181$$,$p__79541_value$jscomp$928$$){var $index$jscomp$528$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79541_value$jscomp$928$$,0,null);$p__79541_value$jscomp$928$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79541_value$jscomp$928$$,
1,null);$out_arr__44092__auto__$jscomp$181$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$stroke_row$stroke_row_STAR_$$,{onStrokeStyleChange:$on_stroke_style_change$jscomp$1$$,onRemove:$on_remove$jscomp$6$$,onToggleVisibility:$on_toggle_visibility$jscomp$5$$,index:$index$jscomp$528$$,appliedTokens:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(0,$index$jscomp$528$$)?$applied_tokens$jscomp$20$$:null,showCaps:$show_caps$jscomp$1$$,onStrokeWidthChange:$on_stroke_width_change$jscomp$1$$,
onStrokeDashChange:$on_stroke_dash_change$jscomp$1$$,onStrokeCapEndChange:$on_stroke_cap_end_change$jscomp$1$$,selectOnFocus:$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($disable_drag$jscomp$3$$)),disableStrokeStyle:$disable_stroke_style$jscomp$1$$,onStrokeCapSwitch:$on_stroke_cap_switch$jscomp$1$$,onReorder:$handle_reorder$jscomp$1$$,disableDrag:$disable_drag$jscomp$3$$,onStrokeGapChange:$on_stroke_gap_change$jscomp$1$$,ids:$ids$jscomp$306$$,onDetachToken:$on_detach_token$jscomp$13$$,stroke:$p__79541_value$jscomp$928$$,
onStrokeAlignmentChange:$on_stroke_alignment_change$jscomp$1$$,onColorDetach:$on_color_detach$jscomp$1$$,onFocus:$on_focus$jscomp$18$$,onColorChange:$on_color_change$jscomp$2$$,onBlur:$on_blur$jscomp$26$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.stroke-color"),onStrokeCapStartChange:$on_stroke_cap_start_change$jscomp$1$$},"stroke-"+($index$jscomp$528$$??"")+"-"+($APP.$cljs$core$hash$$($applied_tokens$jscomp$20$$)??"")));return $out_arr__44092__auto__$jscomp$181$$},
[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1641$strokes$$.$cljs$core$IFn$_invoke$arity$2$($values$jscomp$95$$,$APP.$cljs$core$PersistentVector$EMPTY$$)))}):null}):null]})},function($n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$,$o_props$jscomp$1_o_strokes$$){var $and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$=$n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$.ids===
$o_props$jscomp$1_o_strokes$$.ids;return $and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$?($and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$=$n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$.type===$o_props$jscomp$1_o_strokes$$.type)?($and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$=
$n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$.appliedTokens===$o_props$jscomp$1_o_strokes$$.appliedTokens)?($and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$=$n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$.showCaps===$o_props$jscomp$1_o_strokes$$.showCaps)?($and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$=
$n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$.disableStrokeStyle===$o_props$jscomp$1_o_strokes$$.disableStrokeStyle)?($n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$=$n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$.values,$o_props$jscomp$1_o_strokes$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_props$jscomp$1_o_strokes$$.values,$APP.$cljs$cst$1641$strokes$$),$n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$,
$APP.$cljs$cst$1641$strokes$$),$o_props$jscomp$1_o_strokes$$===$n_props$jscomp$1_n_strokes_n_vals$jscomp$1$$):$and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$:$and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$:$and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$:
$and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$:$and__5023__auto__$jscomp$849_and__5023__auto____$1$jscomp$144_and__5023__auto____$2$jscomp$52_and__5023__auto____$3$jscomp$9_and__5023__auto____$4$jscomp$4$$});var $app$main$ui$workspace$sidebar$options$menus$svg_attrs$attribute_value_STAR_$$=function $app$main$ui$workspace$sidebar$options$menus$svg_attrs$attribute_value_STAR_$$($handle_change$jscomp$10_props_79547$$){var $on_change$jscomp$76$$=$handle_change$jscomp$10_props_79547$$.onChange,$attr$jscomp$92$$=$handle_change$jscomp$10_props_79547$$.attr,$value$jscomp$929$$=$handle_change$jscomp$10_props_79547$$.value,$on_delete$jscomp$11$$=$handle_change$jscomp$10_props_79547$$.onDelete,$last_value$jscomp$1$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($value$jscomp$929$$),$handle_change_STAR_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$util$functions$debounce$cljs$0core$0IFn$0_invoke$0arity$02$$(function($val$jscomp$221$$){return $on_change$jscomp$76$$.$cljs$core$IFn$_invoke$arity$2$?$on_change$jscomp$76$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$92$$,$val$jscomp$221$$):$on_change$jscomp$76$$($attr$jscomp$92$$,$val$jscomp$221$$)},300));$handle_change$jscomp$10_props_79547$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($attr$jscomp$92$$),$APP.$rumext$v2$adapt$$($on_change$jscomp$76$$),$APP.$rumext$v2$adapt$$($handle_change_STAR_$$)],function($G__79548_event$jscomp$559$$){$APP.$cljs$core$reset_BANG_$$($last_value$jscomp$1$$,(0,$APP.$app$util$dom$get_target_val$$)($G__79548_event$jscomp$559$$));$G__79548_event$jscomp$559$$=(0,$APP.$app$util$dom$get_target_val$$)($G__79548_event$jscomp$559$$);return $handle_change_STAR_$$.$cljs$core$IFn$_invoke$arity$1$?
$handle_change_STAR_$$.$cljs$core$IFn$_invoke$arity$1$($G__79548_event$jscomp$559$$):$handle_change_STAR_$$($G__79548_event$jscomp$559$$)});var $handle_delete$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($attr$jscomp$92$$),$APP.$rumext$v2$adapt$$($on_delete$jscomp$11$$)],function(){return $on_delete$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$?$on_delete$jscomp$11$$.$cljs$core$IFn$_invoke$arity$1$($attr$jscomp$92$$):$on_delete$jscomp$11$$($attr$jscomp$92$$)}),
$label$jscomp$50$$=$APP.$app$common$data$name$$($APP.$cljs$core$last$$($attr$jscomp$92$$));return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:typeof $value$jscomp$929$$==="string"?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-content",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-name",children:$label$jscomp$50$$}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-input",
children:(0,$APP.$rumext$v2$jsx$$)("input",{value:$APP.$cljs$core$_deref$$($last_value$jscomp$1$$),onChange:$handle_change$jscomp$10_props_79547$$})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-actions",children:(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_delete$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-action-btn",children:$APP.$app$main$ui$icons$remove_icon$$})})]}):(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-nested-content",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-title",children:$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$name$$($APP.$cljs$core$last$$($attr$jscomp$92$$)))}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$182$$,$p__79549_value__$1$jscomp$60$$){var $key$jscomp$420$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79549_value__$1$jscomp$60$$,
0,null);$p__79549_value__$1$jscomp$60$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79549_value__$1$jscomp$60$$,1,null);$out_arr__44092__auto__$jscomp$182$$.push((0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__attr-row",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$attribute_value_STAR_$$,{attr:$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($attr$jscomp$92$$,$key$jscomp$420$$),value:$p__79549_value__$1$jscomp$60$$,
onChange:$on_change$jscomp$76$$,onDelete:$on_delete$jscomp$11$$},$key$jscomp$420$$)},$key$jscomp$420$$));return $out_arr__44092__auto__$jscomp$182$$},[],$value$jscomp$929$$)]})})},$app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($open_QMARK_$jscomp$25_props_79554$$){var $ids$jscomp$308$$=$open_QMARK_$jscomp$25_props_79554$$.ids,$attrs$jscomp$178_values$jscomp$96$$=$open_QMARK_$jscomp$25_props_79554$$.values,$state_STAR_$jscomp$21$$=
$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$open_QMARK_$jscomp$25_props_79554$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$21$$);$attrs$jscomp$178_values$jscomp$96$$=$APP.$cljs$cst$1898$svg_attrs$$.$cljs$core$IFn$_invoke$arity$1$($attrs$jscomp$178_values$jscomp$96$$);var $has_attributes_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$attrs$jscomp$178_values$jscomp$96$$)||$APP.$cljs$core$seq$$($attrs$jscomp$178_values$jscomp$96$$)!=
null,$toggle_content$jscomp$12$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$21$$,$APP.$cljs$core$not$$)}),$handle_change$jscomp$11$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$308$$)],function($attr$jscomp$93$$,$value$jscomp$930$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$308$$,
function($shape$jscomp$1024$$){return $APP.$cljs$core$assoc_in$$($shape$jscomp$1024$$,$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1898$svg_attrs$$],null),$attr$jscomp$93$$),$value$jscomp$930$$)}))}),$handle_delete$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$308$$)],function($attr$jscomp$94$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shapes$update_shapes$cljs$0core$0IFn$0_invoke$0arity$02$$($ids$jscomp$308$$,
function($shape$jscomp$1025_shape__$1$jscomp$108$$){var $update_path$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1898$svg_attrs$$],null),$APP.$cljs$core$butlast$$($attr$jscomp$94$$));$shape$jscomp$1025_shape__$1$jscomp$108$$=$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1025_shape__$1$jscomp$108$$,$update_path$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$core$last$$($attr$jscomp$94$$));
return $APP.$cljs$core$empty_QMARK_$$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1025_shape__$1$jscomp$108$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1898$svg_attrs$$,$APP.$cljs$cst$1921$style$$],null)))?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($shape$jscomp$1025_shape__$1$jscomp$108$$,$APP.$cljs$cst$1898$svg_attrs$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$1921$style$$):$shape$jscomp$1025_shape__$1$jscomp$108$$}))});
return $APP.$cljs$core$empty_QMARK_$$($attrs$jscomp$178_values$jscomp$96$$)?null:(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__element-set-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_attributes_QMARK_$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$25_props_79554$$),
onCollapsed:$toggle_content$jscomp$12$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.options.svg-attrs.title"),className:$has_attributes_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_svg_attrs__title-spacing-svg-attrs"})}),$APP.$cljs$core$truth_$$($open_QMARK_$jscomp$25_props_79554$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_svg_attrs__element-set-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$183$$,
$attr_value$jscomp$6_p__79556$$){var $attr_key$jscomp$6$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$6_p__79556$$,0,null);$attr_value$jscomp$6_p__79556$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($attr_value$jscomp$6_p__79556$$,1,null);$out_arr__44092__auto__$jscomp$183$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$attribute_value_STAR_$$,{attr:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$attr_key$jscomp$6$$],null),value:$attr_value$jscomp$6_p__79556$$,onChange:$handle_change$jscomp$11$$,onDelete:$handle_delete$jscomp$2$$},$attr_key$jscomp$6$$));return $out_arr__44092__auto__$jscomp$183$$},[],$attrs$jscomp$178_values$jscomp$96$$)}):null]})},function($old_props$jscomp$12$$,$new_props$jscomp$13$$){var $old_values$jscomp$5$$=$old_props$jscomp$12$$.values,$new_values$jscomp$5$$=$new_props$jscomp$13$$.values;return $old_props$jscomp$12$$.ids===$new_props$jscomp$13$$.ids&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($old_values$jscomp$5$$,
$APP.$cljs$cst$1898$svg_attrs$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($new_values$jscomp$5$$,$APP.$cljs$cst$1898$svg_attrs$$)});var $app$main$ui$workspace$sidebar$options$menus$color_selection$xf_COLON_map_shape_id$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2554$shape_id$$),$app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$=function($p1__79562_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__79562_SHARP_$$,function($new_props_79578$$,$old_props_79579$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_79578$$.shapes,$old_props_79579$$.shapes)})}(function($colors$jscomp$26_map__79580_props_79577$$){var $shapes$jscomp$219$$=
$colors$jscomp$26_map__79580_props_79577$$.shapes,$file_id$jscomp$414$$=$colors$jscomp$26_map__79580_props_79577$$.fileId,$libraries$jscomp$153$$=$colors$jscomp$26_map__79580_props_79577$$.libraries;$colors$jscomp$26_map__79580_props_79577$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$414$$),$APP.$rumext$v2$adapt$$($shapes$jscomp$219$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$153$$)],function(){return $app$main$ui$workspace$sidebar$options$menus$color_selection$prepare_colors$$($shapes$jscomp$219$$,
$file_id$jscomp$414$$,$libraries$jscomp$153$$)});var $map__79580__$1_open_QMARK_$jscomp$26$$=$APP.$cljs$core$__destructure_map$$($colors$jscomp$26_map__79580_props_79577$$),$groups$jscomp$18$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79580__$1_open_QMARK_$jscomp$26$$,$APP.$cljs$cst$4449$groups$$),$library_colors$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79580__$1_open_QMARK_$jscomp$26$$,$cljs$cst$5812$library_colors$$);$colors$jscomp$26_map__79580_props_79577$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79580__$1_open_QMARK_$jscomp$26$$,$APP.$cljs$cst$2220$colors$$);var $token_colors$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79580__$1_open_QMARK_$jscomp$26$$,$cljs$cst$5811$token_colors$$),$open_STAR_$jscomp$10$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);$map__79580__$1_open_QMARK_$jscomp$26$$=$APP.$cljs$core$_deref$$($open_STAR_$jscomp$10$$);var $has_colors_QMARK_$jscomp$1$$=$APP.$cljs$core$seq$$($colors$jscomp$26_map__79580_props_79577$$)!=
null||$APP.$cljs$core$seq$$($library_colors$jscomp$3$$)!=null,$toggle_content$jscomp$13$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($open_STAR_$jscomp$10$$,$APP.$cljs$core$not$$)}),$expand_lib_color$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$expand_color$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$expand_token_color$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$prev_colors_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$groups_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null);$APP.$rumext$v2$set_ref_val_BANG_$$($groups_ref$$,$groups$jscomp$18$$);var $on_change$jscomp$77$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($color_operations$jscomp$3_old_color$jscomp$4$$,$new_color$jscomp$4$$,$color_79609_from_picker_QMARK_$$){var $prev_colors$jscomp$1$$=$APP.$rumext$v2$ref_val$$($prev_colors_ref$$),$old_color__$1$jscomp$1_vec__79581$$=$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$($APP.$rumext$v2$ref_val$$($groups_ref$$),
$color_operations$jscomp$3_old_color$jscomp$4$$,$prev_colors$jscomp$1$$);$color_operations$jscomp$3_old_color$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($old_color__$1$jscomp$1_vec__79581$$,0,null);$old_color__$1$jscomp$1_vec__79581$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($old_color__$1$jscomp$1_vec__79581$$,1,null);$APP.$cljs$core$truth_$$($color_79609_from_picker_QMARK_$$)&&($color_79609_from_picker_QMARK_$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($new_color$jscomp$4$$,
$APP.$cljs$cst$725$name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$]))),$APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($prev_colors$jscomp$1$$,$color_79609_from_picker_QMARK_$$)));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_color_in_selected$$($color_operations$jscomp$3_old_color$jscomp$4$$,$new_color$jscomp$4$$,$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($old_color__$1$jscomp$1_vec__79581$$,
$APP.$cljs$cst$4253$token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4252$has_token_applied$$]))))}),$on_open$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$PersistentVector$EMPTY$$)}),$on_close$jscomp$33$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$PersistentVector$EMPTY$$)}),
$on_detach$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$18$$)],function($color$jscomp$176$$){var $color_operations$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($groups$jscomp$18$$,$color$jscomp$176$$),$color_SINGLEQUOTE_$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$176$$,$APP.$cljs$cst$1741$ref_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1742$ref_file$$]));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$colors$change_color_in_selected$$($color_operations$jscomp$4$$,$color_SINGLEQUOTE_$$,$color$jscomp$176$$))}),$on_detach_token$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_colors$jscomp$1$$),$APP.$rumext$v2$adapt$$($groups$jscomp$18$$)],function($token_name$jscomp$29$$){var $prev_colors$jscomp$2$$=$APP.$rumext$v2$ref_val$$($prev_colors_ref$$),
$token_color$jscomp$2$$=$APP.$cljs$core$some$$(function($p1__79563_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4253$token_name$$.$cljs$core$IFn$_invoke$arity$1$($p1__79563_SHARP_$$),$token_name$jscomp$29$$)?$p1__79563_SHARP_$$:null},$token_colors$jscomp$1$$),$G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$=$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$($groups$jscomp$18$$,$token_color$jscomp$2$$,
$prev_colors$jscomp$2$$),$G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$,1,null);$G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$=$APP.$cljs$core$seq$$($G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$);
for(var $attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$=null,$G__79618_color_79621_count__79589$$=0,$i__79590$$=0;;)if($i__79590$$<$G__79618_color_79621_count__79589$$){$G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$=$attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__79590$$);var $attr_79610$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4225$prop$$.$cljs$core$IFn$_invoke$arity$1$($G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$),
$APP.$cljs$cst$2914$stroke$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1745$stroke_color$$,null],null),null):new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1408$fill$$,null],null),null),$color_79611$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($token_color$jscomp$2$$,$APP.$cljs$cst$4253$token_name$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4252$has_token_applied$$])));$APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($prev_colors$jscomp$2$$,$color_79611$$));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$29$$,$APP.$cljs$cst$2009$attributes$$,
$attr_79610$$,$APP.$cljs$cst$4722$shape_ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2554$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$)],null)],null)));$i__79590$$+=1}else if($G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$=$APP.$cljs$core$seq$$($G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$))$G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$=
$G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$,$APP.$cljs$core$chunked_seq_QMARK_$$($G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$)?($attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$=$APP.$cljs$core$_chunked_first$$($G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$),$G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$=$APP.$cljs$core$_chunked_rest$$($G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$),$G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$=
$attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$,$G__79618_color_79621_count__79589$$=$APP.$cljs$core$count$$($attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$),$attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$=$G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$):($G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$=$APP.$cljs$core$first$$($G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$),$attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4225$prop$$.$cljs$core$IFn$_invoke$arity$1$($G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$),
$APP.$cljs$cst$2914$stroke$$)?new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1745$stroke_color$$,null],null),null):new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1408$fill$$,null],null),null),$G__79618_color_79621_count__79589$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($token_color$jscomp$2$$,
$APP.$cljs$cst$4253$token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4252$has_token_applied$$]))),$APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($prev_colors$jscomp$2$$,$G__79618_color_79621_count__79589$$)),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,
$token_name$jscomp$29$$,$APP.$cljs$cst$2009$attributes$$,$attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$,$APP.$cljs$cst$4722$shape_ids$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$2554$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($G__79617_op$jscomp$21_temp__5825__auto__$jscomp$390_vec__79584$$)],null)],null))),$G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$=$APP.$cljs$core$next$$($G__79616_color_operations$jscomp$5_seq__79587_seq__79587__$1$$),
$attr_79620_c__5548__auto__$jscomp$47_chunk__79588$$=null,$G__79618_color_79621_count__79589$$=0),$i__79590$$=0;else return null}),$select_only$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$18$$)],function($color$jscomp$177_color_operations$jscomp$6_ids$jscomp$310$$){$color$jscomp$177_color_operations$jscomp$6_ids$jscomp$310$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($groups$jscomp$18$$,$color$jscomp$177_color_operations$jscomp$6_ids$jscomp$310$$);
$color$jscomp$177_color_operations$jscomp$6_ids$jscomp$310$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$app$common$data$ordered_set$$.$cljs$core$IFn$_invoke$arity$0$(),$app$main$ui$workspace$sidebar$options$menus$color_selection$xf_COLON_map_shape_id$$,$color$jscomp$177_color_operations$jscomp$6_ids$jscomp$310$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$selection$select_shapes$$($color$jscomp$177_color_operations$jscomp$6_ids$jscomp$310$$))}),
$on_token_change$jscomp$7$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($groups$jscomp$18$$)],function($___$1$jscomp$2098_prev_colors$jscomp$3$$,$token$jscomp$146$$,$old_color$jscomp$5_vec__79591$$){$___$1$jscomp$2098_prev_colors$jscomp$3$$=$APP.$rumext$v2$ref_val$$($prev_colors_ref$$);var $color$jscomp$178_new_color$jscomp$5_resolved_value$jscomp$3$$=$APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$146$$);$color$jscomp$178_new_color$jscomp$5_resolved_value$jscomp$3$$=
$APP.$app$main$data$workspace$tokens$application$value__GT_color$$($color$jscomp$178_new_color$jscomp$5_resolved_value$jscomp$3$$);$color$jscomp$178_new_color$jscomp$5_resolved_value$jscomp$3$$=$APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($color$jscomp$178_new_color$jscomp$5_resolved_value$jscomp$3$$,$APP.$cljs$cst$725$name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$296$path$$])));
$old_color$jscomp$5_vec__79591$$=$app$main$ui$workspace$sidebar$options$menus$color_selection$retrieve_color_operations$$($groups$jscomp$18$$,$old_color$jscomp$5_vec__79591$$,$___$1$jscomp$2098_prev_colors$jscomp$3$$);var $color_operations$jscomp$7$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($old_color$jscomp$5_vec__79591$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($old_color$jscomp$5_vec__79591$$,1,null);$APP.$rumext$v2$set_ref_val_BANG_$$($prev_colors_ref$$,
$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($___$1$jscomp$2098_prev_colors$jscomp$3$$,$color$jscomp$178_new_color$jscomp$5_resolved_value$jscomp$3$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$apply_token_on_color_selected$$($color_operations$jscomp$7$$,$token$jscomp$146$$))});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.selection-color.section"),
className:"main_ui_workspace_sidebar_options_menus_color_selection__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:$has_colors_QMARK_$jscomp$1$$,collapsed:$APP.$cljs$core$not$$($map__79580__$1_open_QMARK_$jscomp$26$$),onCollapsed:$toggle_content$jscomp$13$$,title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.selection-color"),
className:$has_colors_QMARK_$jscomp$1$$?"":"main_ui_workspace_sidebar_options_menus_color_selection__title-spacing-selected-colors"})}),$APP.$cljs$core$truth_$$($map__79580__$1_open_QMARK_$jscomp$26$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__element-content",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__selected-color-group",children:[function(){var $library_colors_extract$$=
$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($expand_lib_color$$))?$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(3,$library_colors$jscomp$3$$):$library_colors$jscomp$3$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$184$$,$p__79595$$){var $index$jscomp$529$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79595$$,0,null),$color$jscomp$179$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79595$$,1,null);
$out_arr__44092__auto__$jscomp$184$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{origin:$cljs$cst$5710$color_selection$$,onClose:$on_close$jscomp$33$$,index:$index$jscomp$529$$,onChange:function($p1__79565_SHARP_$$,$p2__79566_SHARP_$$){return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$3$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$179$$,$p1__79565_SHARP_$$,$p2__79566_SHARP_$$):$on_change$jscomp$77$$($color$jscomp$179$$,
$p1__79565_SHARP_$$,$p2__79566_SHARP_$$)},onTokenChange:function($p1__79567_SHARP_$$,$p2__79568_SHARP_$$){return $on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__79567_SHARP_$$,$p2__79568_SHARP_$$,$color$jscomp$179$$):$on_token_change$jscomp$7$$($p1__79567_SHARP_$$,$p2__79568_SHARP_$$,$color$jscomp$179$$)},onDetach:function($p1__79564_SHARP_$$){return $on_detach$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$?$on_detach$jscomp$5$$.$cljs$core$IFn$_invoke$arity$2$($color$jscomp$179$$,
$p1__79564_SHARP_$$):$on_detach$jscomp$5$$($color$jscomp$179$$,$p1__79564_SHARP_$$)},selectOnly:$select_only$jscomp$2$$,color:$color$jscomp$179$$,onOpen:$on_open$jscomp$4$$},$index$jscomp$529$$));return $out_arr__44092__auto__$jscomp$184$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($library_colors_extract$$))}(),$APP.$cljs$core$_deref$$($expand_lib_color$$)===!1&&3<$APP.$cljs$core$count$$($library_colors$jscomp$3$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$cljs$core$reset_BANG_$$($expand_lib_color$$,
!0)},className:"main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.more-lib-colors")}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__selected-color-group",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$185$$,$p__79599$$){var $index$jscomp$530$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79599$$,
0,null),$color$jscomp$180$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79599$$,1,null);$out_arr__44092__auto__$jscomp$185$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{onTokenChange:function($p1__79571_SHARP_$$,$p2__79572_SHARP_$$){return $on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__79571_SHARP_$$,$p2__79572_SHARP_$$,$color$jscomp$180$$):$on_token_change$jscomp$7$$($p1__79571_SHARP_$$,
$p2__79572_SHARP_$$,$color$jscomp$180$$)},selectOnly:$select_only$jscomp$2$$,color:$color$jscomp$180$$,index:$index$jscomp$530$$,onClose:$on_close$jscomp$33$$,origin:$cljs$cst$5710$color_selection$$,onChange:function($p1__79569_SHARP_$$,$p2__79570_SHARP_$$){return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$3$?$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$3$($color$jscomp$180$$,$p1__79569_SHARP_$$,$p2__79570_SHARP_$$):$on_change$jscomp$77$$($color$jscomp$180$$,$p1__79569_SHARP_$$,$p2__79570_SHARP_$$)},
onOpen:$on_open$jscomp$4$$},$index$jscomp$530$$));return $out_arr__44092__auto__$jscomp$185$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($expand_color$$))?$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(3,$colors$jscomp$26_map__79580_props_79577$$):$colors$jscomp$26_map__79580_props_79577$$)),$APP.$cljs$core$_deref$$($expand_color$$)===!1&&3<$APP.$cljs$core$count$$($colors$jscomp$26_map__79580_props_79577$$)?(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:function(){return $APP.$cljs$core$reset_BANG_$$($expand_color$$,!0)},className:"main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.more-colors")}):null]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_color_selection__selected-color-group",children:[function(){var $token_color_extract$$=$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($expand_token_color$$))?
$APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(3,$token_colors$jscomp$1$$):$token_colors$jscomp$1$$;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$186$$,$p__79605$$){var $index$jscomp$531$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79605$$,0,null),$token_color$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__79605$$,1,null);$out_arr__44092__auto__$jscomp$186$$.push(function(){var $color$jscomp$181$$=
$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($token_color$jscomp$3$$,$APP.$cljs$cst$4253$token_name$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$4252$has_token_applied$$]));return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{origin:$cljs$cst$5710$color_selection$$,onClose:$on_close$jscomp$33$$,index:$index$jscomp$531$$,onChange:function($p1__79573_SHARP_$$,$p2__79574_SHARP_$$){return $on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$3$?
$on_change$jscomp$77$$.$cljs$core$IFn$_invoke$arity$3$($token_color$jscomp$3$$,$p1__79573_SHARP_$$,$p2__79574_SHARP_$$):$on_change$jscomp$77$$($token_color$jscomp$3$$,$p1__79573_SHARP_$$,$p2__79574_SHARP_$$)},onTokenChange:function($p1__79575_SHARP_$$,$p2__79576_SHARP_$$){return $on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$?$on_token_change$jscomp$7$$.$cljs$core$IFn$_invoke$arity$3$($p1__79575_SHARP_$$,$p2__79576_SHARP_$$,$token_color$jscomp$3$$):$on_token_change$jscomp$7$$($p1__79575_SHARP_$$,
$p2__79576_SHARP_$$,$token_color$jscomp$3$$)},onDetachToken:$on_detach_token$jscomp$14$$,appliedToken:$APP.$cljs$cst$4253$token_name$$.$cljs$core$IFn$_invoke$arity$1$($token_color$jscomp$3$$),selectOnly:$select_only$jscomp$2$$,color:$color$jscomp$181$$,onOpen:$on_open$jscomp$4$$},$index$jscomp$531$$)}());return $out_arr__44092__auto__$jscomp$186$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($token_color_extract$$))}(),$APP.$cljs$core$_deref$$($expand_token_color$$)===
!1&&3<$APP.$cljs$core$count$$($token_colors$jscomp$1$$)?(0,$APP.$rumext$v2$jsx$$)("button",{onClick:function(){return $APP.$cljs$core$reset_BANG_$$($expand_token_color$$,!0)},className:"main_ui_workspace_sidebar_options_menus_color_selection__more-colors-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.more-token-colors")}):null]})]}):null]})});var $app$main$data$workspace$grid$add_frame_grid_79680$$,$app$main$data$workspace$grid$remove_frame_grid_79684$$,$app$main$data$workspace$grid$set_frame_grid_79688$$,$app$main$data$workspace$grid$set_default_grid_79691$$;var $app$main$ui$workspace$sidebar$options$menus$frame_grid$lens_COLON_default_grids$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2063$default_grids$$,$APP.$app$main$refs$workspace_page$$),$app$main$ui$workspace$sidebar$options$menus$frame_grid$grid_options_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_remove$jscomp$7_props_79704$$){var $default_grid_params$$=$on_remove$jscomp$7_props_79704$$.defaultGridParams,$index$jscomp$536$$=
$on_remove$jscomp$7_props_79704$$.index,$frame_height$$=$on_remove$jscomp$7_props_79704$$.frameHeight,$frame_width$$=$on_remove$jscomp$7_props_79704$$.frameWidth,$grid$jscomp$15$$=$on_remove$jscomp$7_props_79704$$.grid,$shape_id$jscomp$164$$=$on_remove$jscomp$7_props_79704$$.shapeId,$on_change$jscomp$78$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$164$$),$APP.$rumext$v2$adapt$$($index$jscomp$536$$)],function($p1__79701_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid$set_frame_grid$$($shape_id$jscomp$164$$,
$index$jscomp$536$$,$p1__79701_SHARP_$$))});$on_remove$jscomp$7_props_79704$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$164$$),$APP.$rumext$v2$adapt$$($index$jscomp$536$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid$remove_frame_grid$$($shape_id$jscomp$164$$,$index$jscomp$536$$))});var $on_save_default$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__79702_SHARP_$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid$set_default_grid$$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($p1__79702_SHARP_$$),
$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($p1__79702_SHARP_$$)))}),$size_options$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$sidebar$options$menus$frame_grid$get_size_options$$),$state_STAR_$jscomp$22$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$cljs$cst$5817$show_advanced_options$$,!1,$cljs$cst$5818$show_more_options$$,!1],null)),$show_more_options_QMARK__state$jscomp$1212$$=
$APP.$cljs$core$_deref$$($state_STAR_$jscomp$22$$),$open_QMARK_$jscomp$27$$=$cljs$cst$5817$show_advanced_options$$.$cljs$core$IFn$_invoke$arity$1$($show_more_options_QMARK__state$jscomp$1212$$);$show_more_options_QMARK__state$jscomp$1212$$=$cljs$cst$5818$show_more_options$$.$cljs$core$IFn$_invoke$arity$1$($show_more_options_QMARK__state$jscomp$1212$$);var $is_hidden_QMARK_$$=$APP.$cljs$core$not$$($APP.$cljs$cst$1949$display$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$)),$map__79705__$1_toggle_advanced_options$$=
$APP.$cljs$core$__destructure_map$$($grid$jscomp$15$$),$type$jscomp$671$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79705__$1_toggle_advanced_options$$,$APP.$cljs$cst$139$type$$),$display$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79705__$1_toggle_advanced_options$$,$APP.$cljs$cst$1949$display$$),$params$jscomp$430$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79705__$1_toggle_advanced_options$$,$APP.$cljs$cst$1435$params$$);$map__79705__$1_toggle_advanced_options$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$22$$,$APP.$cljs$core$update$$,$cljs$cst$5817$show_advanced_options$$,$APP.$cljs$core$not$$)});var $toggle_more_options$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$22$$,$APP.$cljs$core$update$$,$cljs$cst$5818$show_more_options$$,
$APP.$cljs$core$not$$)}),$close_more_options$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($state_STAR_$jscomp$22$$,$APP.$cljs$core$assoc$$,$cljs$cst$5818$show_more_options$$,!1)}),$handle_toggle_visibility$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function(){var $G__79706$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($grid$jscomp$15$$,
$APP.$cljs$cst$1949$display$$,function($p1__79703_SHARP_$$){return $p1__79703_SHARP_$$==null?!1:$APP.$cljs$core$not$$($p1__79703_SHARP_$$)});return $on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$($G__79706$$):$on_change$jscomp$78$$($G__79706$$)}),$handle_change_type$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function($G__79707_grid_type$jscomp$2$$){var $defaults$jscomp$6$$=
$G__79707_grid_type$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$?$G__79707_grid_type$jscomp$2$$.$cljs$core$IFn$_invoke$arity$1$($default_grid_params$$):$G__79707_grid_type$jscomp$2$$($default_grid_params$$);$G__79707_grid_type$jscomp$2$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($grid$jscomp$15$$,$APP.$cljs$cst$139$type$$,$G__79707_grid_type$jscomp$2$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1435$params$$,$defaults$jscomp$6$$]));return $on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$?
$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$($G__79707_grid_type$jscomp$2$$):$on_change$jscomp$78$$($G__79707_grid_type$jscomp$2$$)}),$handle_change$jscomp$12$$=function(){function $G__79729$$($var_args$jscomp$1462$$){var $G__79730__i_keys_path$jscomp$1$$=null;if(arguments.length>0){$G__79730__i_keys_path$jscomp$1$$=0;for(var $G__79730__a$$=Array(arguments.length-0);$G__79730__i_keys_path$jscomp$1$$<$G__79730__a$$.length;)$G__79730__a$$[$G__79730__i_keys_path$jscomp$1$$]=arguments[$G__79730__i_keys_path$jscomp$1$$+
0],++$G__79730__i_keys_path$jscomp$1$$;$G__79730__i_keys_path$jscomp$1$$=new $APP.$cljs$core$IndexedSeq$$($G__79730__a$$,0,null)}return $G__79729__delegate$$.call(this,$G__79730__i_keys_path$jscomp$1$$)}function $G__79729__delegate$$($keys_path$$){return function($G__79708_value$jscomp$932$$){$G__79708_value$jscomp$932$$=$APP.$cljs$core$assoc_in$$($grid$jscomp$15$$,$keys_path$$,$G__79708_value$jscomp$932$$);return $on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$($G__79708_value$jscomp$932$$):
$on_change$jscomp$78$$($G__79708_value$jscomp$932$$)}}$G__79729$$.$cljs$lang$maxFixedArity$=0;$G__79729$$.$cljs$lang$applyTo$=function($arglist__79731_keys_path$jscomp$2$$){$arglist__79731_keys_path$jscomp$2$$=$APP.$cljs$core$seq$$($arglist__79731_keys_path$jscomp$2$$);return $G__79729__delegate$$($arglist__79731_keys_path$jscomp$2$$)};$G__79729$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__79729__delegate$$;return $G__79729$$}(),$handle_change_size$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],
function($G__79710_size$jscomp$164$$){var $map__79709_margin$jscomp$5$$=$APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$),$item_length$jscomp$2_map__79709__$1$$=$APP.$cljs$core$__destructure_map$$($map__79709_margin$jscomp$5$$);$map__79709_margin$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item_length$jscomp$2_map__79709__$1$$,$APP.$cljs$cst$1946$margin$$);var $gutter$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item_length$jscomp$2_map__79709__$1$$,
$APP.$cljs$cst$1948$gutter$$);$item_length$jscomp$2_map__79709__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($item_length$jscomp$2_map__79709__$1$$,$APP.$cljs$cst$1947$item_length$$);var $frame_length$jscomp$2$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$))?$frame_width$$:$frame_height$$;$G__79710_size$jscomp$164$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($grid$jscomp$15$$,
$APP.$cljs$cst$1435$params$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$874$size$$,$G__79710_size$jscomp$164$$,$APP.$cljs$cst$1947$item_length$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__79710_size$jscomp$164$$==null?($frame_length$jscomp$2$$-($map__79709_margin$jscomp$5$$+($map__79709_margin$jscomp$5$$-$gutter$jscomp$4$$))-$gutter$jscomp$4$$*12)/12:$item_length$jscomp$2_map__79709__$1$$]));return $on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$($G__79710_size$jscomp$164$$):
$on_change$jscomp$78$$($G__79710_size$jscomp$164$$)}),$handle_change_item_length$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function($G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$){$G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$=$G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$===0?null:$G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$;var $size$jscomp$165$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$15$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$874$size$$],null));$G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$variadic$($grid$jscomp$15$$,$APP.$cljs$cst$1435$params$$,$APP.$cljs$core$assoc$$,$APP.$cljs$cst$874$size$$,$G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$==null&&$size$jscomp$165$$==null?12:$size$jscomp$165$$,$APP.$cljs$cst$1947$item_length$$,
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$]));return $on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$($G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$):$on_change$jscomp$78$$($G__79711_item_length$jscomp$3_item_length__$1$jscomp$3$$)}),$handle_change_color$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],
function($G__79712_color$jscomp$182_color__$1$jscomp$35$$){$G__79712_color$jscomp$182_color__$1$jscomp$35$$=$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$variadic$($G__79712_color$jscomp$182_color__$1$jscomp$35$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$]));$G__79712_color$jscomp$182_color__$1$jscomp$35$$=$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$5$($grid$jscomp$15$$,$APP.$cljs$cst$1435$params$$,$APP.$cljs$core$assoc$$,
$APP.$cljs$cst$1303$color$$,$G__79712_color$jscomp$182_color__$1$jscomp$35$$);return $on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$($G__79712_color$jscomp$182_color__$1$jscomp$35$$):$on_change$jscomp$78$$($G__79712_color$jscomp$182_color__$1$jscomp$35$$)}),$handle_detach_color$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function(){var $G__79713$$=$APP.$cljs$core$update_in$$.$cljs$core$IFn$_invoke$arity$5$($grid$jscomp$15$$,
new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$1303$color$$],null),$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$266$id$$,$APP.$cljs$cst$1649$file_id$$);return $on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$($G__79713$$):$on_change$jscomp$78$$($G__79713$$)}),$handle_use_default$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],
function(){var $params__$1$jscomp$57$$=function(){var $fexpr__79714$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$);return $fexpr__79714$$.$cljs$core$IFn$_invoke$arity$1$?$fexpr__79714$$.$cljs$core$IFn$_invoke$arity$1$($default_grid_params$$):$fexpr__79714$$($default_grid_params$$)}(),$G__79715_79732_color$jscomp$183_params__$2$jscomp$7$$=function(){var $or__5025__auto__$jscomp$1265$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($params__$1$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$260$value$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1265$$)?$or__5025__auto__$jscomp$1265$$:$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($params__$1$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1303$color$$],null))}();$G__79715_79732_color$jscomp$183_params__$2$jscomp$7$$=
$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($APP.$cljs$core$assoc_in$$($params__$1$jscomp$57$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1303$color$$],null),$G__79715_79732_color$jscomp$183_params__$2$jscomp$7$$),$APP.$cljs$cst$1303$color$$,$APP.$cljs$core$dissoc$$,$APP.$cljs$cst$260$value$$);$APP.$cljs$core$truth_$$($on_change$jscomp$78$$)&&($G__79715_79732_color$jscomp$183_params__$2$jscomp$7$$=
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($grid$jscomp$15$$,$APP.$cljs$cst$1435$params$$,$G__79715_79732_color$jscomp$183_params__$2$jscomp$7$$),$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$78$$.$cljs$core$IFn$_invoke$arity$1$($G__79715_79732_color$jscomp$183_params__$2$jscomp$7$$):$on_change$jscomp$78$$($G__79715_79732_color$jscomp$183_params__$2$jscomp$7$$));return $close_more_options$$.$cljs$core$IFn$_invoke$arity$0$?$close_more_options$$.$cljs$core$IFn$_invoke$arity$0$():
$close_more_options$$()}),$handle_set_as_default$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($grid$jscomp$15$$)],function(){$on_save_default$$.$cljs$core$IFn$_invoke$arity$1$?$on_save_default$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$):$on_save_default$$($grid$jscomp$15$$);return $close_more_options$$.$cljs$core$IFn$_invoke$arity$0$?$close_more_options$$.$cljs$core$IFn$_invoke$arity$0$():$close_more_options$$()}),$is_default$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1435$params$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$),
function(){var $G__79716$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$);return $default_grid_params$$.$cljs$core$IFn$_invoke$arity$1$?$default_grid_params$$.$cljs$core$IFn$_invoke$arity$1$($G__79716$$):$default_grid_params$$($G__79716$$)}());return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__grid-option",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__grid-title",
children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__option-row "+($is_hidden_QMARK_$$?"main_ui_workspace_sidebar_options_menus_frame_grid__hidden":""),children:[(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$map__79705__$1_toggle_advanced_options$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__show-options "+($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$27$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__selected":""),children:$APP.$app$main$ui$icons$menu$$}),
(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__type-select-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,{"class":"main_ui_workspace_sidebar_options_menus_frame_grid__grid-type-select","default-value":$type$jscomp$671$$,options:new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1912$square$$,
$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.square")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$216$column$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.column")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1661$row$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.row")],
null)],null),"on-change":$handle_change_type$jscomp$1$$})}),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$671$$,$APP.$cljs$cst$1912$square$$)?(0,$APP.$rumext$v2$jsx$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.size"),className:"main_ui_workspace_sidebar_options_menus_frame_grid__grid-size",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{min:.01,value:function(){var $or__5025__auto__$jscomp$1266$$=
$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$430$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1266$$)?$or__5025__auto__$jscomp$1266$$:""}(),noValidate:!0,className:"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",onChange:$handle_change$jscomp$12$$($APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$874$size$$)})}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__editable-select-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$editable_select$editable_select$$,
{value:$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$430$$),type:"number","class":"main_ui_workspace_sidebar_options_menus_frame_grid__column-select","input-class":"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",min:1,options:$size_options$jscomp$3$$,placeholder:"Auto","on-change":$handle_change_size$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__actions",children:[(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.guides.toggle-guide"),onClick:$handle_toggle_visibility$jscomp$1$$,icon:$APP.$cljs$core$truth_$$($display$jscomp$2$$)?"shown":"hide"}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.guides.remove-guide"),onClick:$on_remove$jscomp$7_props_79704$$,icon:"remove"})]})]}),
$APP.$cljs$core$truth_$$($APP.$cljs$cst$1949$display$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$15$$))?(0,$APP.$rumext$v2$jsxs$$)($app$main$ui$workspace$sidebar$options$common$advanced_options_STAR_$$,{className:"main_ui_workspace_sidebar_options_menus_frame_grid__grid-advanced-options",isVisible:$open_QMARK_$jscomp$27$$,onClose:$map__79705__$1_toggle_advanced_options$$,children:[$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1912$square$$,$type$jscomp$671$$)?(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_frame_grid__square-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{color:$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$430$$),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.color"),disableGradient:!0,
disableImage:!0,origin:$APP.$cljs$cst$2065$guides$$,onChange:$handle_change_color$jscomp$2$$,onDetach:$handle_detach_color$$}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle_more_options$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options "+($APP.$cljs$core$truth_$$($show_more_options_QMARK__state$jscomp$1212$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__selected":""),children:$APP.$app$main$ui$icons$menu$$})]}),$APP.$cljs$core$truth_$$($show_more_options_QMARK__state$jscomp$1212$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__second-row",children:[(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$is_default$jscomp$1$$,onClick:$handle_use_default$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__btn-options "+($is_default$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_frame_grid__disabled":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.use-default")})}),
(0,$APP.$rumext$v2$jsx$$)("button",{disabled:$is_default$jscomp$1$$,onClick:$handle_set_as_default$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__btn-options "+($is_default$jscomp$1$$?"main_ui_workspace_sidebar_options_menus_frame_grid__disabled":""),children:(0,$APP.$rumext$v2$jsx$$)("span",{children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.set-default")})})]}):null]}):null,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,
$type$jscomp$671$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row$$,$type$jscomp$671$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__column-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__orientation-select-wrapper",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$select$select$$,
{"data-mousetrap-dont-stop":!0,"default-value":$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$430$$),"class":"main_ui_workspace_sidebar_options_menus_frame_grid__orientation-select",options:new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$1674$stretch$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.stretch")],
null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$2296$label$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$671$$,$APP.$cljs$cst$1661$row$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.top"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.left")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1672$center$$,$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.center")],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$260$value$$,$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$2296$label$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$671$$,$APP.$cljs$cst$1661$row$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.bottom"):$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.type.right")],
null)],null),"on-change":$handle_change$jscomp$12$$($APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$139$type$$)})}),(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__color-wrapper",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$rows$color_row$color_row_STAR_$$,{color:$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$430$$),title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.color"),
disableGradient:!0,disableImage:!0,origin:$APP.$cljs$cst$2065$guides$$,onChange:$handle_change_color$jscomp$2$$,onDetach:$handle_detach_color$$})})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__advanced-row",children:[(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row$$,$type$jscomp$671$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.height"):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.width"),className:"main_ui_workspace_sidebar_options_menus_frame_grid__height",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__icon-text",children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row$$,$type$jscomp$671$$)?"H":"W"}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"Auto",
onChange:$handle_change_item_length$$,nillable:!0,className:"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",value:function(){var $or__5025__auto__$jscomp$1267$$=$APP.$cljs$cst$1947$item_length$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$430$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1267$$)?$or__5025__auto__$jscomp$1267$$:""}()})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.gutter"),
className:"main_ui_workspace_sidebar_options_menus_frame_grid__gutter",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__icon "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$671$$,$APP.$cljs$cst$1661$row$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__rotated":""),children:$APP.$app$main$ui$icons$gap_horizontal$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"0",
onChange:$handle_change$jscomp$12$$($APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$1948$gutter$$),nillable:!0,className:"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",value:function(){var $or__5025__auto__$jscomp$1268$$=$APP.$cljs$cst$1948$gutter$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$430$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1268$$)?$or__5025__auto__$jscomp$1268$$:0}()})]}),(0,$APP.$rumext$v2$jsxs$$)("div",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.margin"),
className:"main_ui_workspace_sidebar_options_menus_frame_grid__margin",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__icon "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$671$$,$APP.$cljs$cst$216$column$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__rotated":""),children:$APP.$app$main$ui$icons$grid_margin$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$components$numeric_input$numeric_input_STAR_$$,{placeholder:"0",
onChange:$handle_change$jscomp$12$$($APP.$cljs$cst$1435$params$$,$APP.$cljs$cst$1946$margin$$),nillable:!0,className:"main_ui_workspace_sidebar_options_menus_frame_grid__numeric-input",value:function(){var $or__5025__auto__$jscomp$1269$$=$APP.$cljs$cst$1946$margin$$.$cljs$core$IFn$_invoke$arity$1$($params$jscomp$430$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1269$$)?$or__5025__auto__$jscomp$1269$$:0}()})]}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$toggle_more_options$jscomp$1$$,
disabled:$is_default$jscomp$1$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__show-more-options "+($APP.$cljs$core$truth_$$($show_more_options_QMARK__state$jscomp$1212$$)?"main_ui_workspace_sidebar_options_menus_frame_grid__selected":""),children:$APP.$app$main$ui$icons$menu$$}),$APP.$cljs$core$truth_$$($show_more_options_QMARK__state$jscomp$1212$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__more-options",children:[(0,$APP.$rumext$v2$jsx$$)("button",
{onClick:$handle_use_default$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__option-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.use-default")}),(0,$APP.$rumext$v2$jsx$$)("button",{onClick:$handle_set_as_default$$,className:"main_ui_workspace_sidebar_options_menus_frame_grid__option-btn",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.grid.params.set-default")})]}):null]})]}):null]}):null]})}),
$app$main$ui$workspace$sidebar$options$menus$frame_grid$frame_grid_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($open_QMARK_$jscomp$28_props_79718$$){var $grids$jscomp$2$$=$open_QMARK_$jscomp$28_props_79718$$.grids,$frame_height$jscomp$1$$=$open_QMARK_$jscomp$28_props_79718$$.frameHeight,$frame_width$jscomp$1$$=$open_QMARK_$jscomp$28_props_79718$$.frameWidth,$id$jscomp$976$$=$open_QMARK_$jscomp$28_props_79718$$.id,$state_STAR_$jscomp$23$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!0);
$open_QMARK_$jscomp$28_props_79718$$=$APP.$cljs$core$_deref$$($state_STAR_$jscomp$23$$);var $has_frame_grids_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$grids$jscomp$2$$)||$APP.$cljs$core$seq$$($grids$jscomp$2$$)!=null,$toggle_content$jscomp$14$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($state_STAR_$jscomp$23$$,$APP.$cljs$core$not$$)}),$default_grids$jscomp$1$$=
$APP.$rumext$v2$deref$$($app$main$ui$workspace$sidebar$options$menus$frame_grid$lens_COLON_default_grids$$),$default_grid_params$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($default_grids$jscomp$1$$)],function(){return $APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$grid$default_grid_params$$,$default_grids$jscomp$1$$]))}),$handle_create_grid$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$976$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid$add_frame_grid$$($id$jscomp$976$$))});return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__element-set",children:[(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__element-title",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,
{collapsable:$has_frame_grids_QMARK_$$,collapsed:$APP.$cljs$core$not$$($open_QMARK_$jscomp$28_props_79718$$),onCollapsed:$toggle_content$jscomp$14$$,className:$has_frame_grids_QMARK_$$?"":"main_ui_workspace_sidebar_options_menus_frame_grid__title-spacing-board-grid",title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.guides.title"),children:(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.guides.add-guide"),
onClick:$handle_create_grid$$,icon:"add"})})}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($open_QMARK_$jscomp$28_props_79718$$)?$APP.$cljs$core$seq$$($grids$jscomp$2$$):$open_QMARK_$jscomp$28_props_79718$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_frame_grid__element-set-content",children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$187$$,$grid$jscomp$16_p__79719$$){var $index$jscomp$537$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($grid$jscomp$16_p__79719$$,
0,null);$grid$jscomp$16_p__79719$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($grid$jscomp$16_p__79719$$,1,null);$out_arr__44092__auto__$jscomp$187$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$frame_grid$grid_options_STAR_$$,{shapeId:$id$jscomp$976$$,grid:$grid$jscomp$16_p__79719$$,index:$index$jscomp$537$$,frameWidth:$frame_width$jscomp$1$$,frameHeight:$frame_height$jscomp$1$$,defaultGridParams:$default_grid_params$jscomp$1$$},[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$976$$),
"-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$537$$)].join("")));return $out_arr__44092__auto__$jscomp$187$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$grids$jscomp$2$$))}):null]})},function($old_props$jscomp$13$$,$new_props$jscomp$14$$){return $old_props$jscomp$13$$.grids===$new_props$jscomp$14$$.grids&&$old_props$jscomp$13$$.id===$new_props$jscomp$14$$.id&&$old_props$jscomp$13$$.frameWidth===$new_props$jscomp$14$$.frameWidth&&
$old_props$jscomp$13$$.frameHeight===$new_props$jscomp$14$$.frameHeight});var $app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1244$token_typography_row$$),$app$main$ui$workspace$sidebar$options$menus$text$text_menu_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($main_menu_open_QMARK__props_79756$$){var $file_id$jscomp$416$$=$main_menu_open_QMARK__props_79756$$.fileId,$libraries$jscomp$155$$=$main_menu_open_QMARK__props_79756$$.libraries,$ids$jscomp$313$$=
$main_menu_open_QMARK__props_79756$$.ids,$type$jscomp$673$$=$main_menu_open_QMARK__props_79756$$.type,$typographies$jscomp$11$$=$main_menu_open_QMARK__props_79756$$.typographies,$values$jscomp$102$$=$main_menu_open_QMARK__props_79756$$.values,$applied_tokens$jscomp$24_listbox_id$jscomp$3$$=$main_menu_open_QMARK__props_79756$$.appliedTokens,$menu_state_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$5004$main_menu$$,
!0,$cljs$cst$5829$more_options$$,!1],null)),$menu_state$jscomp$4_more_options_open_QMARK_$$=$APP.$cljs$core$_deref$$($menu_state_STAR_$$);$main_menu_open_QMARK__props_79756$$=$APP.$cljs$cst$5004$main_menu$$.$cljs$core$IFn$_invoke$arity$1$($menu_state$jscomp$4_more_options_open_QMARK_$$);$menu_state$jscomp$4_more_options_open_QMARK_$$=$cljs$cst$5829$more_options$$.$cljs$core$IFn$_invoke$arity$1$($menu_state$jscomp$4_more_options_open_QMARK_$$);var $token_dropdown_open_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$token_dropdown_open_QMARK_$$=$APP.$cljs$core$_deref$$($token_dropdown_open_STAR_$$),$applied_token_name$jscomp$2$$=$APP.$cljs$cst$1997$typography$$.$cljs$core$IFn$_invoke$arity$1$($applied_tokens$jscomp$24_listbox_id$jscomp$3$$),$current_token_name_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$($applied_token_name$jscomp$2$$),$current_token_name$$=$APP.$cljs$core$_deref$$($current_token_name_STAR_$$),$active_tokens$jscomp$7$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$active_tokens_by_type$$),
$typography_tokens$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($active_tokens$jscomp$7$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$filter_tokens_for_input$$($active_tokens$jscomp$7$$,$APP.$cljs$cst$1997$typography$$)});$applied_tokens$jscomp$24_listbox_id$jscomp$3$$=(0,$APP.$rumext$v2$use_id$$)();var $nodes_ref$jscomp$6$$=(0,$APP.$rumext$v2$use_ref$$)(null),$dropdown_ref$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$dropdown_options$jscomp$2$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography_tokens$$)],function(){return $app$main$ui$workspace$tokens$management$forms$controls$utils$get_token_dropdown_options$$($typography_tokens$$,null)}),$selected_token_id_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $and__5023__auto__$jscomp$inline_9082$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$current_token_name$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9082$$?$current_token_name$$:$and__5023__auto__$jscomp$inline_9082$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$options$menus$text$get_option_by_name$$($dropdown_options$jscomp$2$$,$current_token_name$$)):null}),$selected_token_id$$=$APP.$cljs$core$_deref$$($selected_token_id_STAR_$$),$typography_id$jscomp$10$$=$APP.$cljs$cst$1762$typography_ref_id$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$102$$),
$typography_file_id$$=$APP.$cljs$cst$1647$typography_ref_file$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$102$$),$typography$jscomp$37$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography_id$jscomp$10$$),$APP.$rumext$v2$adapt$$($typography_file_id$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$416$$),$APP.$rumext$v2$adapt$$($libraries$jscomp$155$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($typography_id$jscomp$10$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_id$jscomp$10$$,
$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_file_id$$,$file_id$jscomp$416$$):$typography_id$jscomp$10$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($libraries$jscomp$155$$,new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$typography_file_id$$,$APP.$cljs$cst$142$data$$,$APP.$cljs$cst$2223$typographies$$,$typography_id$jscomp$10$$],
null)),$APP.$cljs$cst$1649$file_id$$,$typography_file_id$$):$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($typography_id$jscomp$10$$)?$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_id$jscomp$10$$,$APP.$cljs$cst$1621$multiple$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_file_id$$,$file_id$jscomp$416$$):$typography_id$jscomp$10$$)?$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($typographies$jscomp$11$$,$typography_id$jscomp$10$$):null}),$multiple_QMARK_$jscomp$10$$=
$APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($p1__79755_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p1__79755_SHARP_$$,$APP.$cljs$cst$1621$multiple$$)},$APP.$cljs$core$vals$$($values$jscomp$102$$)),$apply_token_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$313$$),$APP.$rumext$v2$adapt$$($typography_tokens$$)],function($id$jscomp$982$$){var $token$jscomp$148$$=$app$main$ui$workspace$sidebar$options$menus$text$find_token_by_id$$($app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$($typography_tokens$$),
$id$jscomp$982$$);$APP.$cljs$core$reset_BANG_$$($selected_token_id_STAR_$$,$id$jscomp$982$$);$APP.$cljs$core$reset_BANG_$$($token_dropdown_open_STAR_$$,!1);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$apply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$313$$,$APP.$cljs$cst$2009$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1997$typography$$,null],null),null),$APP.$cljs$cst$1136$token$$,$token$jscomp$148$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_typography$$],null)))}),$label$jscomp$53$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($type$jscomp$673$$)],function(){switch($type$jscomp$673$$ instanceof $APP.$cljs$core$Keyword$$?$type$jscomp$673$$.$fqn$:null){case "multiple":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.title-selection");
case "group":return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.title-group");default:return $APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.title")}}),$set_option_ref$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($node$jscomp$431$$){var $state$jscomp$1214$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$6$$),{}),$id$jscomp$983$$=
$APP.$app$util$dom$get_data$$($node$jscomp$431$$,"id");$APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$6$$,$APP.$app$util$object$set_BANG_$$($state$jscomp$1214$$,$id$jscomp$983$$,$node$jscomp$431$$));return function(){var $state__$1$jscomp$60$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$rumext$v2$ref_val$$($nodes_ref$jscomp$6$$),{});return $APP.$rumext$v2$set_ref_val_BANG_$$($nodes_ref$jscomp$6$$,$APP.$app$util$object$unset_BANG_$$($state__$1$jscomp$60$$,$id$jscomp$983$$))}}),
$toggle_main_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($menu_state_STAR_$$,$APP.$cljs$core$update$$,$APP.$cljs$cst$5004$main_menu$$,$APP.$cljs$core$not$$)}),$toggle_more_options$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($menu_state_STAR_$$,$APP.$cljs$core$update$$,$cljs$cst$5829$more_options$$,
$APP.$cljs$core$not$$)}),$toggle_token_dropdown$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($token_dropdown_open_STAR_$$,$APP.$cljs$core$not$$)}),$on_option_click$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($apply_token_BANG_$$)],function($event$jscomp$565_id$jscomp$984$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$565_id$jscomp$984$$);$event$jscomp$565_id$jscomp$984$$=
$APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$565_id$jscomp$984$$),"id");return $apply_token_BANG_$$.$cljs$core$IFn$_invoke$arity$1$?$apply_token_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$565_id$jscomp$984$$):$apply_token_BANG_$$($event$jscomp$565_id$jscomp$984$$)}),$emit_update_BANG_$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($values$jscomp$102$$)],function($ids__$1$jscomp$30$$,$attrs$jscomp$179$$){var $updated_attrs$jscomp$2$$=
$APP.$cljs$core$select_keys$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$get_default_text_attrs$$(),$values$jscomp$102$$,$attrs$jscomp$179$$])),$APP.$app$common$types$text$text_node_attrs$$);$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor-wasm/v1")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts_v3$v3_update_text_editor_styles$$($APP.$cljs$core$first$$($ids__$1$jscomp$30$$),
$attrs$jscomp$179$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$texts$save_font$$($updated_attrs$jscomp$2$$),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$texts$update_all_attrs$$($ids__$1$jscomp$30$$,$attrs$jscomp$179$$)]))}),$on_change$jscomp$84$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$313$$),$APP.$rumext$v2$adapt$$($emit_update_BANG_$$)],
function($attrs$jscomp$180$$){return $emit_update_BANG_$$.$cljs$core$IFn$_invoke$arity$2$?$emit_update_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$313$$,$attrs$jscomp$180$$):$emit_update_BANG_$$($ids$jscomp$313$$,$attrs$jscomp$180$$)}),$on_convert_to_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($values$jscomp$102$$),$APP.$rumext$v2$adapt$$($ids$jscomp$313$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$416$$),$APP.$rumext$v2$adapt$$($emit_update_BANG_$$)],
function(){var $G__79759_set_values_typography__$1$jscomp$3$$=$APP.$cljs$core$select_keys$$($APP.$app$common$data$without_nils$$.$cljs$core$IFn$_invoke$arity$1$($values$jscomp$102$$),$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$common$types$text$text_font_attrs$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$text_spacing_attrs$$,$APP.$app$common$types$text$text_transform_attrs$$])));$G__79759_set_values_typography__$1$jscomp$3$$=
$app$main$data$workspace$texts$generate_typography_name$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$common$types$text$default_typography$$,$G__79759_set_values_typography__$1$jscomp$3$$])));var $id$jscomp$985$$=$APP.$app$common$uuid$next$$();$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$add_typography$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__79759_set_values_typography__$1$jscomp$3$$,
$APP.$cljs$cst$266$id$$,$id$jscomp$985$$),!1));$G__79759_set_values_typography__$1$jscomp$3$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1762$typography_ref_id$$,$id$jscomp$985$$,$APP.$cljs$cst$1647$typography_ref_file$$,$file_id$jscomp$416$$],null);return $emit_update_BANG_$$.$cljs$core$IFn$_invoke$arity$2$?$emit_update_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$313$$,$G__79759_set_values_typography__$1$jscomp$3$$):$emit_update_BANG_$$($ids$jscomp$313$$,$G__79759_set_values_typography__$1$jscomp$3$$)}),
$handle_detach_typography$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_change$jscomp$84$$)],function(){var $G__79760$$=new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1647$typography_ref_file$$,null,$APP.$cljs$cst$1762$typography_ref_id$$,null],null);return $on_change$jscomp$84$$.$cljs$core$IFn$_invoke$arity$1$?$on_change$jscomp$84$$.$cljs$core$IFn$_invoke$arity$1$($G__79760$$):$on_change$jscomp$84$$($G__79760$$)}),$handle_change_typography$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($typography$jscomp$37$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$416$$)],function($changes$jscomp$333$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$libraries$update_typography$$($APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$typography$jscomp$37$$,$changes$jscomp$333$$])),$file_id$jscomp$416$$))}),
$detach_token$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$313$$)],function($token_name$jscomp$31$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$application$unapply_token$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$4253$token_name$$,$token_name$jscomp$31$$,$APP.$cljs$cst$2009$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
1,[$APP.$cljs$cst$1997$typography$$,null],null),null),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$313$$],null)))}),$handle_detach_all_tokens$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$313$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$tokens$application$unapply_multiple_tokens$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2009$attributes$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1997$typography$$,null],null),null),$APP.$cljs$cst$4722$shape_ids$$,$ids$jscomp$313$$],null)))}),$expand_stream$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$beicon$v2$core$filter$$($APP.$potok$v2$core$type_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$4719$expand_text_more_options$$),$APP.$app$main$store$stream$$)}),$common_props_on_text_blur$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(100,
function(){return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$("INPUT",$APP.$app$util$dom$get_tag_name$$($APP.$app$util$globals$document$$.activeElement))?$APP.$app$util$dom$focus_BANG_$$($APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"text-editor/v2")?$APP.$app$util$dom$query$cljs$0core$0IFn$0_invoke$0arity$01$$('[data-itype\x3d"editor"]'):$APP.$goog$dom$getElementByClass$$("public-DraftEditor-content")):null})});$common_props_on_text_blur$$=
{ids:$ids$jscomp$313$$,values:$values$jscomp$102$$,onChange:$on_change$jscomp$84$$,showRecent:!0,onBlur:$common_props_on_text_blur$$};$app$main$ui$hooks$use_stream$cljs$0core$0IFn$0_invoke$0arity$02$$($expand_stream$jscomp$1$$,function(){return $APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$4$($menu_state_STAR_$$,$APP.$cljs$core$assoc$$,$cljs$cst$5829$more_options$$,!0)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$2$$)],
function(){return $APP.$cljs$core$reset_BANG_$$($current_token_name_STAR_$$,$applied_token_name$jscomp$2$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($applied_token_name$jscomp$2$$),$APP.$rumext$v2$adapt$$($dropdown_options$jscomp$2$$)],function(){var $and__5023__auto__$jscomp$inline_9084$$=$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$applied_token_name$jscomp$2$$);return $APP.$cljs$core$reset_BANG_$$($selected_token_id_STAR_$$,
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9084$$?$applied_token_name$jscomp$2$$:$and__5023__auto__$jscomp$inline_9084$$)?$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($app$main$ui$workspace$sidebar$options$menus$text$get_option_by_name$$($dropdown_options$jscomp$2$$,$applied_token_name$jscomp$2$$)):null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($token_dropdown_open_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($token_dropdown_open_QMARK_$$)?
$APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(0,function(){var $G__79761$$=$APP.$rumext$v2$ref_val$$($dropdown_ref$jscomp$1$$);return $G__79761$$==null?null:$APP.$app$util$dom$focus_BANG_$$($G__79761$$)}):null});return(0,$APP.$rumext$v2$jsxs$$)("section",{"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.text-options.text-section"),className:"main_ui_workspace_sidebar_options_menus_text__element-set",children:[(0,$APP.$rumext$v2$jsxs$$)("div",
{className:"main_ui_workspace_sidebar_options_menus_text__element-title",children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$components$title_bar$title_bar_STAR_$$,{collapsable:!0,collapsed:$APP.$cljs$core$not$$($main_menu_open_QMARK__props_79756$$),onCollapsed:$toggle_main_menu$$,title:$label$jscomp$53$$,className:"main_ui_workspace_sidebar_options_menus_text__title-spacing-text",children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&
$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$($typography_tokens$$)!=null&&$APP.$cljs$core$not$$($typography$jscomp$37$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("ds.inputs.numeric-input.open-token-list-dropdown"),onClick:$toggle_token_dropdown$$,tooltipPlacement:"top-left",icon:"tokens"}):null,$APP.$cljs$core$not$$($typography$jscomp$37$$)&&$APP.$cljs$core$not$$($multiple_QMARK_$jscomp$10$$)&&
$APP.$cljs$core$not$$($applied_token_name$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.convert-to-typography"),onClick:$on_convert_to_typography$$,tooltipPlacement:"top-left",icon:"add"}):null]})}),$APP.$cljs$core$truth_$$($app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$?$token_dropdown_open_QMARK_$$:
$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$controls$shared$searchable_options_dropdown$searchable_options_dropdown_STAR_$$,{onClick:$on_option_click$jscomp$3$$,id:$applied_tokens$jscomp$24_listbox_id$jscomp$3$$,options:$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$($dropdown_options$jscomp$2$$),selected:$selected_token_id$$,align:"right",placeholder:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.search-by-token"),
ref:$set_option_ref$jscomp$4$$}):null]}),$APP.$cljs$core$truth_$$($main_menu_open_QMARK__props_79756$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__element-content",children:[$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,$current_token_name$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_id$jscomp$10$$,
$APP.$cljs$cst$1621$multiple$$)?(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__multiple-typography",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_text__multiple-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.text.mixed-tokens-and-assets")})}):$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1621$multiple$$,
$current_token_name$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__multiple-typography",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_text__multiple-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.text.mixed-tokens")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.text.multiple-token-tooltip"),
tooltipPlacement:"top-left",onClick:$handle_detach_all_tokens$$,icon:"detach"})]}):$APP.$cljs$core$truth_$$($app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$?$current_token_name$$:$app$main$ui$workspace$sidebar$options$menus$text$token_typography_row_enabled_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$token_typography_row$token_typography_row_STAR_$$,{tokenName:$current_token_name$$,detachToken:$detach_token$jscomp$5$$,activeTokens:$app$main$ui$workspace$sidebar$options$menus$text$resolve_delay$$($typography_tokens$$)}):
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_id$jscomp$10$$,$APP.$cljs$cst$1621$multiple$$)?(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__multiple-typography",children:[(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_sidebar_options_menus_text__multiple-text",children:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.text.mixed-typography")}),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.libraries.text.multiple-assets-tooltip"),onClick:$handle_detach_typography$$,tooltipPlacement:"top-left",icon:"detach"})]}):$APP.$cljs$core$truth_$$($typography$jscomp$37$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$typography$typography_entry_STAR_$$,{fileId:$typography_file_id$$,typography:$typography$jscomp$37$$,isLocal:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($typography_file_id$$,
$file_id$jscomp$416$$),onDetach:$handle_detach_typography$$,onChange:$handle_change_typography$$}):(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$typography$text_options_STAR_$$,$common_props_on_text_blur$$),(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__text-align-options",children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$text_align_options_STAR_$$,$common_props_on_text_blur$$),
(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$grow_options_STAR_$$,$common_props_on_text_blur$$),(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.options"),"data-testid":"text-align-options-button",onClick:$toggle_more_options$jscomp$2$$,icon:"menu"})]}),$APP.$cljs$core$truth_$$($menu_state$jscomp$4_more_options_open_QMARK_$$)?
(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_menus_text__text-decoration-options",children:[(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$vertical_align_STAR_$$,$common_props_on_text_blur$$),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$text_decoration_options_STAR_$$,{...$common_props_on_text_blur$$,tokenApplied:$current_token_name$$}),(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$sidebar$options$menus$text$text_direction_options_STAR_$$,
$common_props_on_text_blur$$)]}):null]}):null]})},function($n_props$jscomp$2$$,$o_props$jscomp$2$$){var $o_values$jscomp$2$$=$o_props$jscomp$2$$.values,$n_values$jscomp$2$$=$n_props$jscomp$2$$.values;return $n_props$jscomp$2$$.ids===$o_props$jscomp$2$$.ids&&$n_props$jscomp$2$$.type===$o_props$jscomp$2$$.type&&$n_props$jscomp$2$$.appliedTokens===$o_props$jscomp$2$$.appliedTokens&&$n_props$jscomp$2$$.fileId===$o_props$jscomp$2$$.fileId&&$n_props$jscomp$2$$.typographies===$o_props$jscomp$2$$.typographies&&
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1639$fills$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1639$fills$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1764$font_family$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1764$font_family$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,
$APP.$cljs$cst$1763$font_id$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1763$font_id$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1766$font_size$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1766$font_size$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1768$font_style$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,
$APP.$cljs$cst$1768$font_style$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1765$font_variant_id$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1765$font_variant_id$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1767$font_weight$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1767$font_weight$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,
$APP.$cljs$cst$1776$grow_type$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1776$grow_type$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1772$letter_spacing$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1772$letter_spacing$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1771$line_height$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,
$APP.$cljs$cst$1771$line_height$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1769$text_align$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1769$text_align$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1774$text_decoration$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1774$text_decoration$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,
$APP.$cljs$cst$1770$text_direction$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1770$text_direction$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1775$text_transform$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1775$text_transform$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1647$typography_ref_file$$)===
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1647$typography_ref_file$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1762$typography_ref_id$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,$APP.$cljs$cst$1762$typography_ref_id$$)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($o_values$jscomp$2$$,$APP.$cljs$cst$1773$vertical_align$$)===$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($n_values$jscomp$2$$,
$APP.$cljs$cst$1773$vertical_align$$)});var $app$main$ui$workspace$sidebar$options$shapes$multiple$type__GT_read_mode$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$296$path$$,$APP.$cljs$cst$1613$group$$,$APP.$cljs$cst$1611$frame$$,$APP.$cljs$cst$1422$circle$$,$APP.$cljs$cst$1618$svg_raw$$,$APP.$cljs$cst$1617$image$$,$APP.$cljs$cst$1615$bool$$,$APP.$cljs$cst$1616$rect$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,
$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,
$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,
$APP.$cljs$cst$342$children$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$342$children$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$342$children$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,
$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,
$APP.$cljs$cst$342$children$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,
$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,
$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,
$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,
$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,
$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,
$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,
$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$cljs$cst$5834$ignore$$]),$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$APP.$cljs$cst$1197$background_blur$$,$cljs$cst$5831$layout_item$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$APP.$cljs$cst$1817$shape$$,
$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1593$text$$,$cljs$cst$5834$ignore$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1817$shape$$,$APP.$cljs$cst$1593$text$$])]),$app$main$ui$workspace$sidebar$options$shapes$multiple$group__GT_attrs$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5830$constraint$$,$APP.$cljs$cst$2914$stroke$$,$cljs$cst$5831$layout_item$$,
$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$2080$layout_container$$,$cljs$cst$5832$measure$$,$APP.$cljs$cst$1877$exports$$,$cljs$cst$5833$layer$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1593$text$$],[$app$main$ui$workspace$sidebar$options$menus$constraints$constraint_attrs$$,$app$main$ui$workspace$sidebar$options$menus$stroke$stroke_attrs$$,$app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_attrs$$,$app$main$ui$workspace$sidebar$options$menus$fill$fill_attrs$$,
$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$,$app$main$ui$workspace$sidebar$options$menus$measures$measure_attrs$$,$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$,$app$main$ui$workspace$sidebar$options$menus$layer$layer_attrs$$,$app$main$ui$workspace$sidebar$options$menus$blur$blur_attrs$$,$app$main$ui$workspace$sidebar$options$menus$shadow$shadow_attrs$$,$APP.$app$common$types$text$text_all_attrs$$]),$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_keys$$=
new $APP.$cljs$core$PersistentVector$$(null,7,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1921$style$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1655$offset_x$$,$APP.$cljs$cst$1656$offset_y$$,$APP.$cljs$cst$1658$blur$$,$APP.$cljs$cst$1657$spread$$,$APP.$cljs$cst$1625$hidden$$],null),$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_keys$$=new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$260$value$$,
$APP.$cljs$cst$1625$hidden$$],null),$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$=function $app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$($shapes$jscomp$221$$,$objects$jscomp$804$$,$attr_group$$){function $merge_token_values$$($acc$jscomp$166$$,$shape_attrs$jscomp$1$$,$applied_tokens$jscomp$27$$){return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__79777_SHARP_$$,$p2__79778_SHARP_$$){return $merge_shape_attr$$($p1__79777_SHARP_$$,
$applied_tokens$jscomp$27$$,$p2__79778_SHARP_$$)},$acc$jscomp$166$$,$shape_attrs$jscomp$1$$)}function $merge_shape_attr$$($acc$jscomp$165$$,$applied_tokens$jscomp$26$$,$shape_attr$jscomp$2_token_attrs$jscomp$4$$){$shape_attr$jscomp$2_token_attrs$jscomp$4$$=$APP.$app$common$types$token$shape_attr__GT_token_attrs$$.$cljs$core$IFn$_invoke$arity$1$($shape_attr$jscomp$2_token_attrs$jscomp$4$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__79775_SHARP_$$,$p2__79776_SHARP_$$){var $new_val$jscomp$inline_9089$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_tokens$jscomp$26$$,$p2__79776_SHARP_$$),$existing$jscomp$inline_9090$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($p1__79775_SHARP_$$,$p2__79776_SHARP_$$,$cljs$cst$5835$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_shapes_DOT_multiple_SLASH_not_found$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($existing$jscomp$inline_9090$$,$cljs$cst$5835$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_DOT_options_DOT_shapes_DOT_multiple_SLASH_not_found$$)?
$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79775_SHARP_$$,$p2__79776_SHARP_$$,$new_val$jscomp$inline_9089$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($existing$jscomp$inline_9090$$,$new_val$jscomp$inline_9089$$)?$p1__79775_SHARP_$$:$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__79775_SHARP_$$,$p2__79776_SHARP_$$,$APP.$cljs$cst$1621$multiple$$)},$acc$jscomp$165$$,$shape_attr$jscomp$2_token_attrs$jscomp$4$$)}function $merge_attrs$$($v1$jscomp$41$$,$v2$jscomp$33$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_group$$,
$APP.$cljs$cst$1659$shadow$$)?$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$v1$jscomp$41$$,$v2$jscomp$33$$],null),$attrs$jscomp$181$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_eq$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$shadow_sel$$):$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_group$$,$APP.$cljs$cst$1658$blur$$)?$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$04$$(new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$v1$jscomp$41$$,$v2$jscomp$33$$],null),$attrs$jscomp$181$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_eq$$,$app$main$ui$workspace$sidebar$options$shapes$multiple$blur_sel$$):$APP.$app$common$attrs$get_attrs_multi$cljs$0core$0IFn$0_invoke$0arity$02$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$v1$jscomp$41$$,$v2$jscomp$33$$],null),$attrs$jscomp$181$$)}var $attrs$jscomp$181$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$group__GT_attrs$$.$cljs$core$IFn$_invoke$arity$1$?
$app$main$ui$workspace$sidebar$options$shapes$multiple$group__GT_attrs$$.$cljs$core$IFn$_invoke$arity$1$($attr_group$$):$app$main$ui$workspace$sidebar$options$shapes$multiple$group__GT_attrs$$($attr_group$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$,$id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$){var $ids$jscomp$314$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$,
0,null),$values$jscomp$103$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$,1,null);$children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$,2,null);var $content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$=$APP.$cljs$core$__destructure_map$$($id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$);
$id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$,$APP.$cljs$cst$266$id$$);var $editable_attrs_type$jscomp$674$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$,$APP.$cljs$cst$139$type$$),$applied_tokens$jscomp$28$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$,
$APP.$cljs$cst$1881$applied_tokens$$),$read_mode_shape_attrs$jscomp$2$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$sidebar$options$shapes$multiple$type__GT_read_mode$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$editable_attrs_type$jscomp$674$$,$attr_group$$],null));$editable_attrs_type$jscomp$674$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$shape$attrs$editable_attrs$$,
$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$)),$attrs$jscomp$181$$);switch($read_mode_shape_attrs$jscomp$2$$ instanceof $APP.$cljs$core$Keyword$$?$read_mode_shape_attrs$jscomp$2$$.$fqn$:null){case "ignore":return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$ids$jscomp$314$$,$values$jscomp$103$$],null);case "shape":var $shape_values$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($p1__79779_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1__79779_SHARP_$$,null],null)}),$editable_attrs_type$jscomp$674$$),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_group$$,$cljs$cst$5832$measure$$)?$app$main$ui$workspace$sidebar$options$menus$measures$select_measure_keys$$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$):$APP.$cljs$core$select_keys$$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$,
$editable_attrs_type$jscomp$674$$)]));$content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$=function(){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($attr_group$$,$cljs$cst$5833$layer$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$3$($shape_values$$,$APP.$cljs$cst$1625$hidden$$,function($p1__79780_SHARP_$$){return $p1__79780_SHARP_$$==null?!1:$p1__79780_SHARP_$$}):$shape_values$$}();$children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$=$merge_token_values$$($children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$,
$editable_attrs_type$jscomp$674$$,$applied_tokens$jscomp$28$$);return new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$314$$,$id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$),$merge_attrs$$($values$jscomp$103$$,$content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$),$children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$],null);case "text":return $read_mode_shape_attrs$jscomp$2$$=
$APP.$cljs$core$select_keys$$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$,$attrs$jscomp$181$$),$content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$=$app$common$attrs$get_text_attrs_multi$$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$,$attrs$jscomp$181$$),$content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$=$merge_attrs$$($merge_attrs$$($values$jscomp$103$$,$read_mode_shape_attrs$jscomp$2$$),$content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$),
$children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$=$merge_token_values$$($children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$,$editable_attrs_type$jscomp$674$$,$applied_tokens$jscomp$28$$),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($ids$jscomp$314$$,$id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$),$content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$,
$children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$],null);case "children":return $children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__79781_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$804$$,$p1__79781_SHARP_$$)},$APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$2$($content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$,$APP.$cljs$core$PersistentVector$EMPTY$$)),
$id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$.$cljs$core$IFn$_invoke$arity$3$?$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$.$cljs$core$IFn$_invoke$arity$3$($children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$,$objects$jscomp$804$$,$attr_group$$):$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$($children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$,
$objects$jscomp$804$$,$attr_group$$),$children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$,0,null),$content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$,1,null),$id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$,
2,null),new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$($ids$jscomp$314$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$children$jscomp$301_new_ids$jscomp$1_new_token_acc_p__79783_token_acc$$])),$merge_attrs$$($values$jscomp$103$$,$content_attrs_map__79788__$1_new_values$jscomp$6_shape_values__$1$$),$id$jscomp$986_p__79784_tokens$jscomp$54_vec__79791$$],null);
default:return $APP.$cljs$core$PersistentVector$EMPTY$$}},new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$],null),$shapes$jscomp$221$$)},$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$=function($f$jscomp$753$$){var $mem$jscomp$1$$=new $APP.$module$app$common$weak$impl_weak_map$$.$WeakEqMap$({hash:$APP.$cljs$core$hash$$,
equals:$APP.$cljs$core$_EQ_$$});return function(){function $G__45319$$($var_args$jscomp$919$$){var $G__45321__i_args$jscomp$235$$=null;if(arguments.length>0){$G__45321__i_args$jscomp$235$$=0;for(var $G__45321__a$$=Array(arguments.length-0);$G__45321__i_args$jscomp$235$$<$G__45321__a$$.length;)$G__45321__a$$[$G__45321__i_args$jscomp$235$$]=arguments[$G__45321__i_args$jscomp$235$$+0],++$G__45321__i_args$jscomp$235$$;$G__45321__i_args$jscomp$235$$=new $APP.$cljs$core$IndexedSeq$$($G__45321__a$$,0,null)}return $G__45319__delegate$$.call(this,
$G__45321__i_args$jscomp$235$$)}function $G__45319__delegate$$($args$jscomp$234$$){var $ret$jscomp$144_v$jscomp$514$$=$mem$jscomp$1$$.get($args$jscomp$234$$);return void 0===$ret$jscomp$144_v$jscomp$514$$?($ret$jscomp$144_v$jscomp$514$$=$APP.$cljs$core$apply$$.$cljs$core$IFn$_invoke$arity$2$($f$jscomp$753$$,$args$jscomp$234$$),$mem$jscomp$1$$.set($args$jscomp$234$$,$ret$jscomp$144_v$jscomp$514$$),$ret$jscomp$144_v$jscomp$514$$):$ret$jscomp$144_v$jscomp$514$$}$G__45319$$.$cljs$lang$maxFixedArity$=
0;$G__45319$$.$cljs$lang$applyTo$=function($arglist__45322_args$jscomp$236$$){$arglist__45322_args$jscomp$236$$=$APP.$cljs$core$seq$$($arglist__45322_args$jscomp$236$$);return $G__45319__delegate$$($arglist__45322_args$jscomp$236$$)};$G__45319$$.$cljs$core$IFn$_invoke$arity$variadic$=$G__45319__delegate$$;return $G__45319$$}()}($app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$),$app$main$ui$workspace$sidebar$options$shapes$multiple$options_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($page_id$jscomp$435_props_79796$$){var $shapes_with_children$jscomp$2$$=
$page_id$jscomp$435_props_79796$$.shapesWithChildren,$shapes$jscomp$222$$=$page_id$jscomp$435_props_79796$$.shapes,$file_id$jscomp$417$$=$page_id$jscomp$435_props_79796$$.fileId,$libraries$jscomp$156$$=$page_id$jscomp$435_props_79796$$.libraries;$page_id$jscomp$435_props_79796$$=$page_id$jscomp$435_props_79796$$.pageId;var $shape_ids$jscomp$111$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$222$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$app$common$data$xf_COLON_map_id$$,$shapes$jscomp$222$$)}),$typographies$jscomp$12$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),$is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_ids$jscomp$111$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($shape_ids$jscomp$111$$)});$is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$);
var $is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_ids$jscomp$111$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($shape_ids$jscomp$111$$)});$is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$3$$);var $is_grid_parent_QMARK_$jscomp$3_is_grid_parent_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_ids$jscomp$111$$)],
function(){return $app$main$refs$grid_layout_child_QMARK_$$($shape_ids$jscomp$111$$)});$is_grid_parent_QMARK_$jscomp$3_is_grid_parent_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($is_grid_parent_QMARK_$jscomp$3_is_grid_parent_ref$jscomp$3$$);var $has_flex_layout_container_QMARK_$$=$APP.$cljs$core$some$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$,$shapes$jscomp$222$$),$all_layout_child_QMARK__all_layout_child_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_ids$jscomp$111$$)],
function(){return $app$main$refs$all_layout_child_QMARK_$$($shape_ids$jscomp$111$$)});$all_layout_child_QMARK__all_layout_child_ref$$=$APP.$rumext$v2$deref$$($all_layout_child_QMARK__all_layout_child_ref$$);var $all_flex_layout_container_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$222$$)],function(){return $APP.$cljs$core$every_QMARK_$$($APP.$app$common$types$shape$layout$flex_layout_QMARK_$$,$shapes$jscomp$222$$)}),$show_caps_QMARK_$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$222$$)],function(){return $APP.$cljs$core$some$$(function($p1__79795_SHARP_$$){return $APP.$app$common$files$helpers$path_shape_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($p1__79795_SHARP_$$)&&$APP.$app$common$types$path$shape_with_open_path_QMARK_$$($p1__79795_SHARP_$$)},$shapes$jscomp$222$$)}),$has_text_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$222$$)],
function(){return $APP.$cljs$core$some$$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$shapes$jscomp$222$$)}),$objects$jscomp$806$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes_with_children$jscomp$2$$)],function(){var $objects$jscomp$807$$=$APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$shapes_with_children$jscomp$2$$);return $APP.$cljs$core$reduce_kv$$(function($objects__$1$jscomp$40$$,$id$jscomp$987$$,
$JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$){a:{for(;;){var $parent$jscomp$inline_9096_parent_id$jscomp$inline_9095$$=$APP.$cljs$cst$1624$parent_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$);$parent$jscomp$inline_9096_parent_id$jscomp$inline_9095$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$40$$,$parent$jscomp$inline_9096_parent_id$jscomp$inline_9095$$);if($JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$==
null||$APP.$cljs$core$contains_QMARK_$$($shape_ids$jscomp$111$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$))){$JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$=!1;break a}if($APP.$app$common$files$helpers$bool_shape_QMARK_$$($parent$jscomp$inline_9096_parent_id$jscomp$inline_9095$$)){$JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$=!0;break a}$JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$=
$parent$jscomp$inline_9096_parent_id$jscomp$inline_9095$$}$JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$=void 0}return $JSCompiler_inline_result$jscomp$1848_object$jscomp$40_shape$jscomp$inline_9094$$?$APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($objects__$1$jscomp$40$$,$id$jscomp$987$$):$objects__$1$jscomp$40$$},$objects$jscomp$807$$,$objects$jscomp$807$$)}),$layer_tokens_vec__79797$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,
$objects$jscomp$806$$,$cljs$cst$5833$layer$$),$layer_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_tokens_vec__79797$$,0,null),$layer_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_tokens_vec__79797$$,1,null);$layer_tokens_vec__79797$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_tokens_vec__79797$$,2,null);var $text_tokens_vec__79800$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,
$objects$jscomp$806$$,$APP.$cljs$cst$1593$text$$),$text_ids$jscomp$9$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens_vec__79800$$,0,null),$text_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens_vec__79800$$,1,null);$text_tokens_vec__79800$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens_vec__79800$$,2,null);var $constraint_values$jscomp$3_vec__79803$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,
$objects$jscomp$806$$,$cljs$cst$5830$constraint$$),$constraint_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($constraint_values$jscomp$3_vec__79803$$,0,null);$constraint_values$jscomp$3_vec__79803$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($constraint_values$jscomp$3_vec__79803$$,1,null);var $fill_tokens_vec__79806$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,$objects$jscomp$806$$,$APP.$cljs$cst$1408$fill$$),$fill_ids$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens_vec__79806$$,0,null),$fill_values$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens_vec__79806$$,1,null);$fill_tokens_vec__79806$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens_vec__79806$$,2,null);var $shadow_values_vec__79809$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,$objects$jscomp$806$$,$APP.$cljs$cst$1659$shadow$$),$shadow_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shadow_values_vec__79809$$,
0,null);$shadow_values_vec__79809$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shadow_values_vec__79809$$,1,null);var $blur_values$jscomp$2_vec__79812$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,$objects$jscomp$806$$,$APP.$cljs$cst$1658$blur$$),$blur_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_values$jscomp$2_vec__79812$$,0,null);$blur_values$jscomp$2_vec__79812$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_values$jscomp$2_vec__79812$$,
1,null);var $stroke_tokens_vec__79815$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,$objects$jscomp$806$$,$APP.$cljs$cst$2914$stroke$$),$stroke_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens_vec__79815$$,0,null),$stroke_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens_vec__79815$$,1,null);$stroke_tokens_vec__79815$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens_vec__79815$$,
2,null);var $exports_values_vec__79818$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,$objects$jscomp$806$$,$APP.$cljs$cst$1877$exports$$),$exports_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($exports_values_vec__79818$$,0,null);$exports_values_vec__79818$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($exports_values_vec__79818$$,1,null);var $layout_container_tokens_vec__79821$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,
$objects$jscomp$806$$,$APP.$cljs$cst$2080$layout_container$$),$layout_container_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_container_tokens_vec__79821$$,0,null),$layout_container_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_container_tokens_vec__79821$$,1,null);$layout_container_tokens_vec__79821$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_container_tokens_vec__79821$$,2,null);var $layout_item_tokens_vec__79824$$=
$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$222$$,$objects$jscomp$806$$,$cljs$cst$5831$layout_item$$),$layout_item_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_tokens_vec__79824$$,0,null),$layout_item_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_tokens_vec__79824$$,1,null);$layout_item_tokens_vec__79824$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_tokens_vec__79824$$,
2,null);var $components$jscomp$24$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes$jscomp$222$$)],function(){return $APP.$cljs$core$not_empty$$($APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$types$component$instance_head_QMARK_$$,$shapes$jscomp$222$$))}),$workspace_modifiers$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_modifiers$$),$shapes__$1$jscomp$36$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($workspace_modifiers$$),
$APP.$rumext$v2$adapt$$($shapes$jscomp$222$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$(function($shape$jscomp$1031$$){var $modifiers$jscomp$114_shape_id$jscomp$166$$=$shape$jscomp$1031$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1031$$,$APP.$cljs$cst$266$id$$);$modifiers$jscomp$114_shape_id$jscomp$166$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($workspace_modifiers$$,
$modifiers$jscomp$114_shape_id$jscomp$166$$),$APP.$cljs$cst$1816$modifiers$$);return $APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1031$$,$modifiers$jscomp$114_shape_id$jscomp$166$$)}),$shapes$jscomp$222$$)}),$measure_tokens_vec__79827$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs_STAR_$$($shapes__$1$jscomp$36$$,$objects$jscomp$806$$,$cljs$cst$5832$measure$$),$measure_ids$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_tokens_vec__79827$$,
0,null),$measure_values$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_tokens_vec__79827$$,1,null);$measure_tokens_vec__79827$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_tokens_vec__79827$$,2,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_shapes_multiple__options",children:[$APP.$cljs$core$empty_QMARK_$$($layer_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,
{type:$APP.$cljs$cst$1621$multiple$$,ids:$layer_ids$$,appliedTokens:$layer_tokens_vec__79797$$,values:$layer_values$jscomp$3$$}),$APP.$cljs$core$empty_QMARK_$$($measure_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,{type:$APP.$cljs$cst$1621$multiple$$,ids:$measure_ids$$,values:$measure_values$jscomp$3$$,appliedTokens:$measure_tokens_vec__79827$$,shapes:$shapes__$1$jscomp$36$$}),$components$jscomp$24$$!=null?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$component$component_menu_STAR_$$,
{shapes:$components$jscomp$24$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,{type:$APP.$cljs$cst$1621$multiple$$,ids:$layout_container_ids$$,values:$layout_container_values$jscomp$3$$,appliedTokens:$layout_container_tokens_vec__79821$$,multiple:!0}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$)?$is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$:
$has_flex_layout_container_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,{type:$APP.$cljs$cst$1621$multiple$$,ids:$layout_item_ids$$,isLayoutChild:$all_layout_child_QMARK__all_layout_child_ref$$,isLayoutContainer:$all_flex_layout_container_QMARK_$$,isFlexParent:$is_flex_parent_QMARK_$jscomp$3_is_flex_parent_ref$jscomp$3$$,isGridParent:$is_grid_parent_QMARK_$jscomp$3_is_grid_parent_ref$jscomp$3$$,appliedTokens:$layout_item_tokens_vec__79824$$,
values:$layout_item_values$jscomp$3$$}):null,$APP.$cljs$core$empty_QMARK_$$($constraint_ids$$)||$is_layout_child_QMARK_$jscomp$4_is_layout_child_ref$jscomp$3$$?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$constraint_ids$$,values:$constraint_values$jscomp$3_vec__79803$$}),$APP.$cljs$core$empty_QMARK_$$($text_ids$jscomp$9$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$text$text_menu_STAR_$$,{type:$APP.$cljs$cst$1621$multiple$$,
ids:$text_ids$jscomp$9$$,values:$text_values$jscomp$3$$,appliedTokens:$text_tokens_vec__79800$$,libraries:$libraries$jscomp$156$$,fileId:$file_id$jscomp$417$$,typographies:$typographies$jscomp$12$$}),$APP.$cljs$core$empty_QMARK_$$($fill_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,{type:$APP.$cljs$cst$1621$multiple$$,ids:$fill_ids$$,values:$fill_values$$,appliedTokens:$fill_tokens_vec__79806$$}),$APP.$cljs$core$empty_QMARK_$$($stroke_ids$$)?
null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{type:$APP.$cljs$cst$1621$multiple$$,ids:$stroke_ids$$,showCaps:$show_caps_QMARK_$$,values:$stroke_values$jscomp$3$$,disableStrokeStyle:$has_text_QMARK_$$,appliedTokens:$stroke_tokens_vec__79815$$}),$APP.$cljs$core$empty_QMARK_$$($shapes__$1$jscomp$36$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$,{fileId:$file_id$jscomp$417$$,
type:$APP.$cljs$cst$1621$multiple$$,shapes:$APP.$cljs$core$vals$$($objects$jscomp$806$$),libraries:$libraries$jscomp$156$$}),$APP.$cljs$core$empty_QMARK_$$($shadow_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{type:$APP.$cljs$cst$1621$multiple$$,ids:$shadow_ids$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shadow_values_vec__79809$$,$APP.$cljs$cst$1659$shadow$$)}),$APP.$cljs$core$empty_QMARK_$$($blur_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,
{type:$APP.$cljs$cst$1621$multiple$$,ids:$blur_ids$$,values:$blur_values$jscomp$2_vec__79812$$}),$APP.$cljs$core$empty_QMARK_$$($exports_ids$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$APP.$cljs$cst$1621$multiple$$,ids:$exports_ids$$,shapes:$shapes__$1$jscomp$36$$,values:$exports_values_vec__79818$$,pageId:$page_id$jscomp$435_props_79796$$,fileId:$file_id$jscomp$417$$})]})},function($new_props$jscomp$15$$,$old_props$jscomp$14$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$15$$.shapes,
$old_props$jscomp$14$$.shapes)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$15$$.shapesWithChildren,$old_props$jscomp$14$$.shapesWithChildren)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$15$$.pageId,$old_props$jscomp$14$$.pageId)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$15$$.fileId,$old_props$jscomp$14$$.fileId)});var $app$main$ui$workspace$sidebar$options$shapes$group$options_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_79835_type$jscomp$676$$){var $shapes_with_children$jscomp$3$$=$props_79835_type$jscomp$676$$.shapesWithChildren,$file_id$jscomp$418$$=$props_79835_type$jscomp$676$$.fileId,$libraries$jscomp$157$$=$props_79835_type$jscomp$676$$.libraries,$page_id$jscomp$436$$=$props_79835_type$jscomp$676$$.pageId,$shape$jscomp$1032$$=$props_79835_type$jscomp$676$$.shape,
$id$jscomp$988$$=$shape$jscomp$1032$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1032$$,$APP.$cljs$cst$266$id$$);$props_79835_type$jscomp$676$$=$shape$jscomp$1032$$?.type??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1032$$,$APP.$cljs$cst$139$type$$);var $ids$jscomp$315$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$988$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$id$jscomp$988$$],null)}),$shapes$jscomp$223$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1032$$)],function(){return new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$shape$jscomp$1032$$],null)}),$typographies$jscomp$13$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_file_typography$$),$applied_tokens$jscomp$29$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1032$$,
$APP.$cljs$cst$1881$applied_tokens$$),$objects$jscomp$808$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shapes_with_children$jscomp$3$$)],function(){return $APP.$app$common$data$index_by$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$266$id$$,$shapes_with_children$jscomp$3$$)}),$layout_container_values$jscomp$4$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1032$$,$app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_flex_attrs$$),
$svg_values$$=$APP.$cljs$core$select_keys$$($shape$jscomp$1032$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1898$svg_attrs$$],null)),$is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$315$$)],function(){return $app$main$refs$is_layout_child_QMARK_$$($ids$jscomp$315$$)}),$is_layout_child_QMARK_$jscomp$5$$=
$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$);$is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$315$$)],function(){return $app$main$refs$flex_layout_child_QMARK_$$($ids$jscomp$315$$)});$is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$=$APP.$rumext$v2$deref$$($is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$);
var $is_grid_parent_ref$jscomp$4_is_layout_child_absolute_QMARK_$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$315$$)],function(){return $app$main$refs$grid_layout_child_QMARK_$$($ids$jscomp$315$$)}),$is_grid_parent_QMARK_$jscomp$4$$=$APP.$rumext$v2$deref$$($is_grid_parent_ref$jscomp$4_is_layout_child_absolute_QMARK_$jscomp$3$$);$is_grid_parent_ref$jscomp$4_is_layout_child_absolute_QMARK_$jscomp$3$$=$APP.$app$common$types$shape$layout$item_absolute_QMARK_$cljs$0core$0IFn$0_invoke$0arity$01$$($shape$jscomp$1032$$);
var $parents$jscomp$16_parents_by_ids_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($ids$jscomp$315$$)],function(){return $app$main$refs$parents_by_ids$$($ids$jscomp$315$$)});$parents$jscomp$16_parents_by_ids_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($parents$jscomp$16_parents_by_ids_ref$jscomp$3$$);var $measure_values$jscomp$4_vec__79837$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,$objects$jscomp$808$$,
$cljs$cst$5832$measure$$),$measure_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_values$jscomp$4_vec__79837$$,0,null);$measure_values$jscomp$4_vec__79837$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($measure_values$jscomp$4_vec__79837$$,1,null);var $layer_values$jscomp$4_vec__79840$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,$objects$jscomp$808$$,$cljs$cst$5833$layer$$),$layer_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_values$jscomp$4_vec__79840$$,
0,null);$layer_values$jscomp$4_vec__79840$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layer_values$jscomp$4_vec__79840$$,1,null);var $constraint_values$jscomp$4_vec__79843$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,$objects$jscomp$808$$,$cljs$cst$5830$constraint$$),$constraint_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($constraint_values$jscomp$4_vec__79843$$,0,null);$constraint_values$jscomp$4_vec__79843$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($constraint_values$jscomp$4_vec__79843$$,1,null);var $fill_tokens$jscomp$1_vec__79846$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,$objects$jscomp$808$$,$APP.$cljs$cst$1408$fill$$),$fill_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens$jscomp$1_vec__79846$$,0,null),$fill_values$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens$jscomp$1_vec__79846$$,
1,null);$fill_tokens$jscomp$1_vec__79846$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($fill_tokens$jscomp$1_vec__79846$$,2,null);var $shadow_ids$jscomp$1_vec__79849$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,$objects$jscomp$808$$,$APP.$cljs$cst$1659$shadow$$);$shadow_ids$jscomp$1_vec__79849$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($shadow_ids$jscomp$1_vec__79849$$,0,null);var $blur_values$jscomp$3_vec__79852$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,
$objects$jscomp$808$$,$APP.$cljs$cst$1658$blur$$),$blur_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_values$jscomp$3_vec__79852$$,0,null);$blur_values$jscomp$3_vec__79852$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($blur_values$jscomp$3_vec__79852$$,1,null);var $stroke_tokens$jscomp$1_vec__79855$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,$objects$jscomp$808$$,$APP.$cljs$cst$2914$stroke$$),$stroke_ids$jscomp$1$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens$jscomp$1_vec__79855$$,0,null),$stroke_values$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens$jscomp$1_vec__79855$$,1,null);$stroke_tokens$jscomp$1_vec__79855$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($stroke_tokens$jscomp$1_vec__79855$$,2,null);var $text_tokens$jscomp$1_vec__79858$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,$objects$jscomp$808$$,
$APP.$cljs$cst$1593$text$$),$text_ids$jscomp$10$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens$jscomp$1_vec__79858$$,0,null),$text_values$jscomp$4$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens$jscomp$1_vec__79858$$,1,null);$text_tokens$jscomp$1_vec__79858$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_tokens$jscomp$1_vec__79858$$,2,null);var $layout_item_values$jscomp$4_vec__79861$$=$app$main$ui$workspace$sidebar$options$shapes$multiple$get_attrs$$($shapes$jscomp$223$$,
$objects$jscomp$808$$,$cljs$cst$5831$layout_item$$),$layout_item_ids$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_values$jscomp$4_vec__79861$$,0,null);$layout_item_values$jscomp$4_vec__79861$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($layout_item_values$jscomp$4_vec__79861$$,1,null);return(0,$APP.$rumext$v2$jsxs$$)("div",{className:"main_ui_workspace_sidebar_options_shapes_group__options",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layer$layer_menu_STAR_$$,
{type:$props_79835_type$jscomp$676$$,ids:$layer_ids$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$29$$,values:$layer_values$jscomp$4_vec__79840$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$measures$measures_menu_STAR_$$,{type:$props_79835_type$jscomp$676$$,ids:$measure_ids$jscomp$1$$,appliedTokens:$applied_tokens$jscomp$29$$,values:$measure_values$jscomp$4_vec__79837$$,shapes:$shapes$jscomp$223$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_container$layout_container_menu_STAR_$$,
{type:$props_79835_type$jscomp$676$$,ids:new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1032$$)],null),values:$layout_container_values$jscomp$4$$,appliedTokens:$applied_tokens$jscomp$29$$,multiple:!1}),$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$861$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($ids$jscomp$315$$),1);return $and__5023__auto__$jscomp$861$$?
$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$5$$)?$is_grid_parent_QMARK_$jscomp$4$$:$is_layout_child_QMARK_$jscomp$5$$:$and__5023__auto__$jscomp$861$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$grid_cell$options_STAR_$$,{shapeId:$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($parents$jscomp$16_parents_by_ids_ref$jscomp$3$$)),cell:$APP.$app$common$types$shape$layout$get_cell_by_shape_id$$($APP.$cljs$core$first$$($parents$jscomp$16_parents_by_ids_ref$jscomp$3$$),
$APP.$cljs$core$first$$($ids$jscomp$315$$))}):null,$APP.$cljs$core$truth_$$($is_layout_child_QMARK_$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$layout_item$layout_item_menu_STAR_$$,{type:$props_79835_type$jscomp$676$$,ids:$layout_item_ids$jscomp$1$$,isLayoutChild:!0,isLayoutContainer:!1,isFlexParent:$is_flex_parent_QMARK_$jscomp$4_is_flex_parent_ref$jscomp$4_is_layout_child_ref$jscomp$4$$,isGridParent:$is_grid_parent_QMARK_$jscomp$4$$,appliedTokens:$applied_tokens$jscomp$29$$,
values:$layout_item_values$jscomp$4_vec__79861$$}):null,!$is_layout_child_QMARK_$jscomp$5$$||$is_grid_parent_ref$jscomp$4_is_layout_child_absolute_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$constraints$constraints_menu_STAR_$$,{ids:$constraint_ids$jscomp$1$$,values:$constraint_values$jscomp$4_vec__79843$$}):null,$APP.$cljs$core$empty_QMARK_$$($fill_ids$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$fill$fill_menu_STAR_$$,
{type:$props_79835_type$jscomp$676$$,ids:$fill_ids$jscomp$1$$,values:$fill_values$jscomp$1$$,appliedTokens:$fill_tokens$jscomp$1_vec__79846$$}),$APP.$cljs$core$empty_QMARK_$$($stroke_ids$jscomp$1$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$stroke$stroke_menu_STAR_$$,{type:$props_79835_type$jscomp$676$$,ids:$stroke_ids$jscomp$1$$,values:$stroke_values$jscomp$4$$,appliedTokens:$stroke_tokens$jscomp$1_vec__79855$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$color_selection$color_selection_menu_STAR_$$,
{type:$props_79835_type$jscomp$676$$,shapes:$APP.$cljs$core$vals$$($objects$jscomp$808$$),fileId:$file_id$jscomp$418$$,libraries:$libraries$jscomp$157$$}),$APP.$cljs$core$empty_QMARK_$$($shadow_ids$jscomp$1_vec__79849$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$shadow$shadow_menu_STAR_$$,{ids:$ids$jscomp$315$$,values:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1032$$,$APP.$cljs$cst$1659$shadow$$),type:$props_79835_type$jscomp$676$$}),$APP.$cljs$core$empty_QMARK_$$($blur_ids$jscomp$1$$)?
null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$blur$blur_menu_STAR_$$,{type:$props_79835_type$jscomp$676$$,ids:$blur_ids$jscomp$1$$,values:$blur_values$jscomp$3_vec__79852$$}),$APP.$cljs$core$empty_QMARK_$$($text_ids$jscomp$10$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$text$text_menu_STAR_$$,{type:$props_79835_type$jscomp$676$$,ids:$text_ids$jscomp$10$$,values:$text_values$jscomp$4$$,appliedTokens:$text_tokens$jscomp$1_vec__79858$$,
libraries:$libraries$jscomp$157$$,fileId:$file_id$jscomp$418$$,typographies:$typographies$jscomp$13$$}),$APP.$cljs$core$empty_QMARK_$$($svg_values$$)?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$svg_attrs$svg_attrs_menu_STAR_$$,{ids:$ids$jscomp$315$$,values:$svg_values$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$menus$exports$exports_menu_STAR_$$,{type:$props_79835_type$jscomp$676$$,ids:$ids$jscomp$315$$,shapes:$shapes$jscomp$223$$,values:$APP.$cljs$core$select_keys$$($shape$jscomp$1032$$,
$app$main$ui$workspace$sidebar$options$menus$exports$exports_attrs$$),pageId:$page_id$jscomp$436$$,fileId:$file_id$jscomp$418$$})]})});var $app$main$ui$workspace$sidebar$options$shapes$svg_raw$svg_elements$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,13,[$APP.$cljs$cst$296$path$$,null,$APP.$cljs$cst$2707$textPath$$,null,$APP.$cljs$cst$219$symbol$$,null,$APP.$cljs$cst$1422$circle$$,null,$APP.$cljs$cst$1750$g$$,null,$APP.$cljs$cst$209$line$$,null,$APP.$cljs$cst$1543$svg$$,null,$APP.$cljs$cst$2741$ellipse$$,null,$APP.$cljs$cst$1617$image$$,null,$APP.$cljs$cst$2754$polyline$$,null,$APP.$cljs$cst$1616$rect$$,
null,$APP.$cljs$cst$2761$polygon$$,null,$APP.$cljs$cst$1593$text$$,null],null),null);var $app$main$ui$workspace$sidebar$options$shape_options_STAR_$$=$rumext$v2$throttle$$(function($props_79900$$){var $shapes_with_children$jscomp$4$$=$props_79900$$.shapesWithChildren,$shapes$jscomp$228$$=$props_79900$$.shapes,$file_id$jscomp$424$$=$props_79900$$.fileId,$libraries$jscomp$160$$=$props_79900$$.libraries,$page_id$jscomp$442$$=$props_79900$$.pageId;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$(1,$APP.$cljs$core$count$$($props_79900$$.selected))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$single_shape_options_STAR_$$,
{pageId:$page_id$jscomp$442$$,fileId:$file_id$jscomp$424$$,libraries:$libraries$jscomp$160$$,shape:$APP.$cljs$core$first$$($shapes$jscomp$228$$),shapesWithChildren:$shapes_with_children$jscomp$4$$}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$shapes$multiple$options_STAR_$$,{shapesWithChildren:$shapes_with_children$jscomp$4$$,shapes:$shapes$jscomp$228$$,pageId:$page_id$jscomp$442$$,fileId:$file_id$jscomp$424$$,libraries:$libraries$jscomp$160$$})},200),$app$main$ui$workspace$sidebar$options$options_tabs$$=
new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.design"),$APP.$cljs$cst$266$id$$,"design"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.prototype"),$APP.$cljs$cst$266$id$$,"prototype"],null),
new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.options.inspect"),$APP.$cljs$cst$266$id$$,"inspect"],null)],null),$app$main$ui$workspace$sidebar$options$options_toolbox_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($objects$jscomp$812_objects_ref_props_79946$$){var $on_expand$jscomp$3$$=$objects$jscomp$812_objects_ref_props_79946$$.onExpand,$on_change_section$jscomp$2$$=$objects$jscomp$812_objects_ref_props_79946$$.onChangeSection,
$selected$jscomp$179$$=$objects$jscomp$812_objects_ref_props_79946$$.selected,$file_id$jscomp$428$$=$objects$jscomp$812_objects_ref_props_79946$$.fileId,$section$jscomp$31$$=$objects$jscomp$812_objects_ref_props_79946$$.section,$page_id$jscomp$446$$=$objects$jscomp$812_objects_ref_props_79946$$.pageId;$objects$jscomp$812_objects_ref_props_79946$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($page_id$jscomp$446$$),$APP.$rumext$v2$adapt$$($file_id$jscomp$428$$)],
function(){return $app$main$ui$workspace$sidebar$options$make_page_objects_ref$$($file_id$jscomp$428$$,$page_id$jscomp$446$$)});$objects$jscomp$812_objects_ref_props_79946$$=$APP.$rumext$v2$deref$$($objects$jscomp$812_objects_ref_props_79946$$);return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$options$options_content_STAR_$$,{objects:$objects$jscomp$812_objects_ref_props_79946$$,selected:$selected$jscomp$179$$,fileId:$file_id$jscomp$428$$,pageId:$page_id$jscomp$446$$,section:$section$jscomp$31$$,
onChangeSection:$on_change_section$jscomp$2$$,onExpand:$on_expand$jscomp$3$$})});var $app$main$ui$workspace$sidebar$sitemap$ref_COLON_file_with_pages$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($map__79934__$1_p__79933$$){$map__79934__$1_p__79933$$=$APP.$cljs$core$__destructure_map$$($map__79934__$1_p__79933$$);var $data$jscomp$491$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__79934__$1_p__79933$$,$APP.$cljs$cst$142$data$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($map__79934__$1_p__79933$$,
$APP.$cljs$cst$142$data$$),$APP.$cljs$cst$2236$pages$$,$APP.$cljs$cst$2236$pages$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$491$$))},$APP.$app$main$refs$file$$,$APP.$cljs$core$_EQ_$$);var $app$main$ui$workspace$sidebar$versions$versions$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4537$workspace_versions$$,$APP.$app$main$store$state$$);var $app$main$data$workspace$tokens$remapping$remap_tokens_80045$$,$app$main$data$workspace$tokens$remapping$bulk_remap_tokens_80053$$;$APP.$app$common$logging$loggers$$.set("app.main.data.workspace.tokens.remapping",$APP.$app$common$logging$level__GT_int$$($APP.$cljs$cst$1162$warn$$));var $app$main$ui$workspace$tokens$management$context_menu$shape_attribute_actions_map$$=function(){function $line_height$jscomp$21$$($p1__80096_SHARP_$$){return $app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1771$line_height$$,null],null),null),"Line Height",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($p1__80096_SHARP_$$,$APP.$cljs$cst$4727$on_update_shape$$,
$APP.$app$main$data$workspace$tokens$application$update_line_height$$))}var $stroke_width$jscomp$10$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1660$stroke_width$$,null],null),null),"Stroke Width"),$font_size$jscomp$13$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1766$font_size$$,null],null),null),"Font Size"),$letter_spacing$jscomp$8$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1772$letter_spacing$$,null],null),null),"Letter Spacing"),$font_family$jscomp$10$$=
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1764$font_family$$,null],null),null),"Font Family"),$text_case$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1995$text_case$$,null],null),null),"Text Case"),$text_decoration$jscomp$6$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1774$text_decoration$$,null],null),null),"Text Decoration"),$font_weight$jscomp$12$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1767$font_weight$$,null],null),null),"Font Weight"),$typography$jscomp$39$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1997$typography$$,null],null),null),"Typography"),$border_radius$$=
$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$tokens$management$context_menu$all_or_separate_actions$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$cljs$cst$5878$attribute_labels$$,new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1651$r1$$,"Top Left",$APP.$cljs$cst$1652$r2$$,"Top Right",$APP.$cljs$cst$1654$r4$$,"Bottom Left",$APP.$cljs$cst$1653$r3$$,"Bottom Right"],null),$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.radius"),
$cljs$cst$5879$on_update_shape_all$$,$APP.$app$main$data$workspace$tokens$application$update_shape_radius$$,$APP.$cljs$cst$4727$on_update_shape$$,$app$main$ui$workspace$tokens$management$context_menu$update_shape_radius_for_corners$$],null));return $APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1771$line_height$$,$APP.$cljs$cst$1993$sizing$$,$APP.$cljs$cst$1794$rotation$$,$APP.$cljs$cst$1303$color$$,$APP.$cljs$cst$1994$number$$,$APP.$cljs$cst$1766$font_size$$,$APP.$cljs$cst$1767$font_weight$$,
$APP.$cljs$cst$1995$text_case$$,$APP.$cljs$cst$1996$dimensions$$,$APP.$cljs$cst$1660$stroke_width$$,$APP.$cljs$cst$1740$opacity$$,$APP.$cljs$cst$1997$typography$$,$APP.$cljs$cst$1774$text_decoration$$,$APP.$cljs$cst$1772$letter_spacing$$,$APP.$cljs$cst$1659$shadow$$,$APP.$cljs$cst$1998$border_radius$$,$APP.$cljs$cst$1764$font_family$$,$APP.$cljs$cst$1999$spacing$$],[$line_height$jscomp$21$$,$app$main$ui$workspace$tokens$management$context_menu$sizing_attribute_actions$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,
new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1794$rotation$$,null],null),null),"Rotation"),function($context_data$jscomp$2$$){return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1408$fill$$,null],null),null),"Fill",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($context_data$jscomp$2$$,
$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_fill$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.color")]))),$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1745$stroke_color$$,null],null),null),
"Stroke",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($context_data$jscomp$2$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_stroke_color$$)))},function($JSCompiler_inline_result$jscomp$1858_context_data$jscomp$3_line_height__$1$jscomp$inline_9123$$){var $JSCompiler_temp_const$jscomp$1856$$=$APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$,$JSCompiler_temp_const$jscomp$1855$$=$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1794$rotation$$,null],null),null),"Rotation",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($JSCompiler_inline_result$jscomp$1858_context_data$jscomp$3_line_height__$1$jscomp$inline_9123$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_rotation$$));$JSCompiler_inline_result$jscomp$1858_context_data$jscomp$3_line_height__$1$jscomp$inline_9123$$=$line_height$jscomp$21$$($JSCompiler_inline_result$jscomp$1858_context_data$jscomp$3_line_height__$1$jscomp$inline_9123$$);
$JSCompiler_inline_result$jscomp$1858_context_data$jscomp$3_line_height__$1$jscomp$inline_9123$$=$APP.$cljs$core$seq$$($JSCompiler_inline_result$jscomp$1858_context_data$jscomp$3_line_height__$1$jscomp$inline_9123$$)?$JSCompiler_inline_result$jscomp$1858_context_data$jscomp$3_line_height__$1$jscomp$inline_9123$$:null;return $JSCompiler_temp_const$jscomp$1856$$.call($APP.$cljs$core$concat$$,$JSCompiler_temp_const$jscomp$1855$$,$JSCompiler_inline_result$jscomp$1858_context_data$jscomp$3_line_height__$1$jscomp$inline_9123$$)},
$font_size$jscomp$13$$,$font_weight$jscomp$12$$,$text_case$$,function($context_data$jscomp$4$$){return $app$main$ui$workspace$tokens$management$context_menu$clean_separators$$($APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$seq$$($app$main$ui$workspace$tokens$management$context_menu$sizing_attribute_actions$$($context_data$jscomp$4$$))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$939$title$$,"Sizing",$cljs$cst$5884$submenu$$,$APP.$cljs$cst$1993$sizing$$],null)],null):null,$APP.$cljs$core$seq$$($app$main$ui$workspace$tokens$management$context_menu$spacing_attribute_actions$$($context_data$jscomp$4$$))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"Spacing",$cljs$cst$5884$submenu$$,$APP.$cljs$cst$1999$spacing$$],null)],null):null,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1477$separator$$],null),$APP.$cljs$core$seq$$($border_radius$$($context_data$jscomp$4$$))?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$939$title$$,"Border Radius",$cljs$cst$5884$submenu$$,$APP.$cljs$cst$1998$border_radius$$],null)],null):null,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$1477$separator$$],null),$stroke_width$jscomp$10$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($context_data$jscomp$4$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_stroke_width$$)),new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1477$separator$$],null),$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1515$x$$,null],null),null),"X",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($context_data$jscomp$4$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_shape_position$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$275$hint$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.axis")]))),$app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$(new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1516$y$$,null],null),null),"Y",$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($context_data$jscomp$4$$,$APP.$cljs$cst$4727$on_update_shape$$,$APP.$app$main$data$workspace$tokens$application$update_shape_position$$))])))},$stroke_width$jscomp$10$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,
new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1740$opacity$$,null],null),null),"Opacity"),$typography$jscomp$39$$,$text_decoration$jscomp$6$$,$letter_spacing$jscomp$8$$,$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$tokens$management$context_menu$generic_attribute_actions$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1659$shadow$$,null],null),null),"Shadow"),$border_radius$$,$font_family$jscomp$10$$,
$app$main$ui$workspace$tokens$management$context_menu$spacing_attribute_actions$$])}(),$app$main$ui$workspace$tokens$management$context_menu$tokens_menu_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$2214$token_context_menu$$,$APP.$app$main$refs$workspace_tokens$$),$app$main$ui$workspace$tokens$management$context_menu$menu_tree$$=function $app$main$ui$workspace$tokens$management$context_menu$menu_tree$$($entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$){$entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$=
$APP.$rumext$v2$util$wrap_props$$($entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$);var $map__80106__$1$$=$APP.$cljs$core$__destructure_map$$($entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$);$entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80106__$1$$,$APP.$cljs$cst$3050$selected_shapes$$);var $submenu_offset$jscomp$1$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80106__$1$$,$cljs$cst$5887$submenu_offset$$),$type$jscomp$684$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80106__$1$$,$APP.$cljs$cst$139$type$$),$errors$jscomp$31$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80106__$1$$,$APP.$cljs$cst$570$errors$$),$shape_types$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$,
$entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$)),$editing_ref_not_editing_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$);$editing_ref_not_editing_QMARK_$$=$APP.$cljs$core$empty_QMARK_$$($editing_ref_not_editing_QMARK_$$);$entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$=$errors$jscomp$31$$==null&&$APP.$cljs$core$seq$$($entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$)&&
$editing_ref_not_editing_QMARK_$$&&$APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($shape_types$$,new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1613$group$$,null],null),null))?$type$jscomp$684$$!=null?$app$main$ui$workspace$tokens$management$context_menu$menu_actions$$($map__80106__$1$$):$app$main$ui$workspace$tokens$management$context_menu$selection_actions$$($map__80106__$1$$):$app$main$ui$workspace$tokens$management$context_menu$default_actions$$($map__80106__$1$$);
$entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$=$app$main$ui$workspace$tokens$management$context_menu$clean_separators$$($entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$);return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$198$$,$map__80113_map__80113__$1_p__80109$$){var $index$jscomp$547$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80113_map__80113__$1_p__80109$$,
0,null);$map__80113_map__80113__$1_p__80109$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($map__80113_map__80113__$1_p__80109$$,1,null);$map__80113_map__80113__$1_p__80109$$=$APP.$cljs$core$__destructure_map$$($map__80113_map__80113__$1_p__80109$$);var $title$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80113_map__80113__$1_p__80109$$,$APP.$cljs$cst$939$title$$),$action$jscomp$7$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80113_map__80113__$1_p__80109$$,
$APP.$cljs$cst$2694$action$$),$selected_QMARK_$jscomp$8$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80113_map__80113__$1_p__80109$$,$cljs$cst$5877$selected_QMARK_$$),$hint$jscomp$21$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80113_map__80113__$1_p__80109$$,$APP.$cljs$cst$275$hint$$),$submenu$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80113_map__80113__$1_p__80109$$,$cljs$cst$5884$submenu$$),$no_selectable$jscomp$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80113_map__80113__$1_p__80109$$,
$cljs$cst$5886$no_selectable$$);$out_arr__44092__auto__$jscomp$198$$.push((0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$Fragment$$,{children:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1477$separator$$,$map__80113_map__80113__$1_p__80109$$)?(0,$APP.$rumext$v2$jsx$$)("li",{className:"main_ui_workspace_tokens_management_context_menu__separator"}):$APP.$cljs$core$truth_$$($submenu$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$context_menu$menu_entry$$,{title:$title$jscomp$49$$,
hint:$hint$jscomp$21$$,"no-selectable":!0,"submenu-offset":$submenu_offset$jscomp$1$$,children:(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$tokens$management$context_menu$menu_tree$$,$APP.$rumext$v2$util$map__GT_obj$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($map__80106__$1$$,$APP.$cljs$cst$139$type$$,$submenu$$)))}):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$context_menu$menu_entry$$,{title:$title$jscomp$49$$,"on-click":$action$jscomp$7$$,hint:$hint$jscomp$21$$,
"no-selectable":$no_selectable$jscomp$1$$,"selected?":$selected_QMARK_$jscomp$8$$})},""+($title$jscomp$49$$??"")+" "+($index$jscomp$547$$??"")));return $out_arr__44092__auto__$jscomp$198$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($entries$jscomp$44_entries__$1$jscomp$6_map__80106_props_80105_selected_shapes$jscomp$21$$))};$APP.$cljs$core$set$$($APP.$cljs$core$list$$("token-status-partial","token-status-full","token-status-non-applied"));var $app$main$ui$workspace$tokens$management$token_pill$attribute_dictionary$$=$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1091$p2$$,$APP.$cljs$cst$1693$p4$$,$APP.$cljs$cst$1692$p3$$,$APP.$cljs$cst$1794$rotation$$,$APP.$cljs$cst$1745$stroke_color$$,$APP.$cljs$cst$1408$fill$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1093$p1$$,$APP.$cljs$cst$1711$layout_item_max_w$$,$APP.$cljs$cst$1687$column_gap$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1660$stroke_width$$,
$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1740$opacity$$,$APP.$cljs$cst$1712$layout_item_min_w$$,$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1710$layout_item_min_h$$,$APP.$cljs$cst$1709$layout_item_max_h$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1686$row_gap$$],"Y;Right;Left;Bottom;Rotation;Stroke Color;Fill;Width;Top Right;Top;Max Width;Column Gap;Bottom Right;Stroke Width;Top Left;Opacity;Min Width;X;Bottom Left;Min Height;Max Height;Height;Row Gap".split(";")),$app$main$ui$workspace$tokens$management$token_pill$dimensions_dictionary$$=
$APP.$cljs$core$PersistentHashMap$fromArrays$$([$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1091$p2$$,$APP.$cljs$cst$1693$p4$$,$APP.$cljs$cst$1692$p3$$,$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$1652$r2$$,$APP.$cljs$cst$1093$p1$$,$APP.$cljs$cst$1711$layout_item_max_w$$,$APP.$cljs$cst$1687$column_gap$$,$APP.$cljs$cst$1653$r3$$,$APP.$cljs$cst$1660$stroke_width$$,$APP.$cljs$cst$1651$r1$$,$APP.$cljs$cst$1712$layout_item_min_w$$,$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1654$r4$$,$APP.$cljs$cst$1710$layout_item_min_h$$,
$APP.$cljs$cst$1709$layout_item_max_h$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1686$row_gap$$],[$APP.$cljs$cst$1516$y$$,$APP.$cljs$cst$1999$spacing$$,$APP.$cljs$cst$1999$spacing$$,$APP.$cljs$cst$1999$spacing$$,$APP.$cljs$cst$1993$sizing$$,$APP.$cljs$cst$1998$border_radius$$,$APP.$cljs$cst$1999$spacing$$,$APP.$cljs$cst$1993$sizing$$,$APP.$cljs$cst$1999$spacing$$,$APP.$cljs$cst$1998$border_radius$$,$APP.$cljs$cst$1660$stroke_width$$,$APP.$cljs$cst$1998$border_radius$$,$APP.$cljs$cst$1993$sizing$$,
$APP.$cljs$cst$1515$x$$,$APP.$cljs$cst$1998$border_radius$$,$APP.$cljs$cst$1993$sizing$$,$APP.$cljs$cst$1993$sizing$$,$APP.$cljs$cst$1993$sizing$$,$APP.$cljs$cst$1999$spacing$$]),$app$main$ui$workspace$tokens$management$token_pill$xf_COLON_map_id$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$),$app$main$ui$workspace$tokens$management$token_pill$token_types_with_status_icon$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,
8,[$APP.$cljs$cst$1993$sizing$$,null,$APP.$cljs$cst$1794$rotation$$,null,$APP.$cljs$cst$1303$color$$,null,$APP.$cljs$cst$1996$dimensions$$,null,$APP.$cljs$cst$1660$stroke_width$$,null,$APP.$cljs$cst$1740$opacity$$,null,$APP.$cljs$cst$1998$border_radius$$,null,$APP.$cljs$cst$1999$spacing$$,null],null),null),$app$main$ui$workspace$tokens$management$token_pill$token_pill_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($has_selected_QMARK__map__80138__$1_props_80137$$){var $active_theme_tokens$$=
$has_selected_QMARK__map__80138__$1_props_80137$$.activeThemeTokens,$selected_shapes$jscomp$25$$=$has_selected_QMARK__map__80138__$1_props_80137$$.selectedShapes,$disabled_QMARK_$jscomp$8_is_selected_inside_layout$jscomp$2$$=$has_selected_QMARK__map__80138__$1_props_80137$$.isSelectedInsideLayout,$on_context_menu$jscomp$13$$=$has_selected_QMARK__map__80138__$1_props_80137$$.onContextMenu,$on_click$jscomp$51$$=$has_selected_QMARK__map__80138__$1_props_80137$$.onClick,$token$jscomp$164$$=$has_selected_QMARK__map__80138__$1_props_80137$$.token;
$has_selected_QMARK__map__80138__$1_props_80137$$=$APP.$cljs$core$__destructure_map$$($token$jscomp$164$$);var $name$jscomp$468$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_selected_QMARK__map__80138__$1_props_80137$$,$APP.$cljs$cst$725$name$$),$color$jscomp$187_value$jscomp$947$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_selected_QMARK__map__80138__$1_props_80137$$,$APP.$cljs$cst$260$value$$),$type$jscomp$686$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($has_selected_QMARK__map__80138__$1_props_80137$$,
$APP.$cljs$cst$139$type$$),$resolved_token$jscomp$17$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_tokens$$,$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$164$$)),$errors$jscomp$34$$=$APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$17$$);$has_selected_QMARK__map__80138__$1_props_80137$$=$APP.$cljs$core$count$$($selected_shapes$jscomp$25$$)>0;var $is_reference_QMARK__status_icon_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$164$$),
"{"),$contains_path_QMARK_$$=$APP.$cuerdas$core$includes_QMARK_$$($name$jscomp$468$$,"."),$attributes$jscomp$88_token_status_id$$=function(){var $$$jscomp$36$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$workspace$tokens$application$token_properties$$,$type$jscomp$686$$);return $APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4737$all_attributes$$.$cljs$core$IFn$_invoke$arity$1$($$$jscomp$36$$),$APP.$cljs$cst$2009$attributes$$.$cljs$core$IFn$_invoke$arity$1$($$$jscomp$36$$))}(),
$full_applied_QMARK_$$=$has_selected_QMARK__map__80138__$1_props_80137$$?$app$main$ui$workspace$tokens$management$token_pill$applied_all_attributes_QMARK_$$($token$jscomp$164$$,$selected_shapes$jscomp$25$$,$attributes$jscomp$88_token_status_id$$):!0,$applied_QMARK__on_context_menu__$1$jscomp$2$$=$has_selected_QMARK__map__80138__$1_props_80137$$?$APP.$app$common$files$tokens$shapes_token_applied_QMARK_$$($token$jscomp$164$$,$selected_shapes$jscomp$25$$,$attributes$jscomp$88_token_status_id$$):!1,$half_applied_QMARK_$$=
$APP.$cljs$core$truth_$$($applied_QMARK__on_context_menu__$1$jscomp$2$$)?!$full_applied_QMARK_$$:$applied_QMARK__on_context_menu__$1$jscomp$2$$;$disabled_QMARK_$jscomp$8_is_selected_inside_layout$jscomp$2$$=$has_selected_QMARK__map__80138__$1_props_80137$$&&$APP.$cljs$core$not$$($applied_QMARK__on_context_menu__$1$jscomp$2$$)&&$APP.$cljs$core$not$$($half_applied_QMARK_$$)&&$APP.$cljs$core$not$$($app$main$ui$workspace$tokens$management$token_pill$attributes_match_selection_QMARK_$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($selected_shapes$jscomp$25$$,
$attributes$jscomp$88_token_status_id$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$cljs$cst$5892$selected_inside_layout_QMARK_$$,$disabled_QMARK_$jscomp$8_is_selected_inside_layout$jscomp$2$$],null)])));var $can_edit_QMARK_$jscomp$3$$=$APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($APP.$app$main$refs$permissions$$)),$is_viewer_QMARK_$$=$APP.$cljs$core$not$$($can_edit_QMARK_$jscomp$3$$),$ref_not_in_active_set$jscomp$1$$=
$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$4708$tokenscript$$)?$APP.$cljs$core$seq$$($APP.$cljs$cst$570$errors$$.$cljs$core$IFn$_invoke$arity$1$($resolved_token$jscomp$17$$)):$APP.$cljs$core$truth_$$($is_reference_QMARK__status_icon_QMARK_$$)?!$app$main$ui$workspace$tokens$management$token_pill$contains_reference_value_QMARK_$$($color$jscomp$187_value$jscomp$947$$,$active_theme_tokens$$):$is_reference_QMARK__status_icon_QMARK_$$,$name_collision$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$4674$error_DOT_token_SLASH_name_collision$$,
$APP.$cljs$cst$945$error_SLASH_code$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($errors$jscomp$34$$))),$no_valid_value$jscomp$1$$=$APP.$cljs$core$seq$$($errors$jscomp$34$$),$errors_QMARK_$jscomp$1$$=$APP.$cljs$core$truth_$$($ref_not_in_active_set$jscomp$1$$)?$ref_not_in_active_set$jscomp$1$$:$no_valid_value$jscomp$1$$||$name_collision$$;$color$jscomp$187_value$jscomp$947$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$164$$),
$APP.$cljs$cst$1303$color$$)?function(){var $or__5025__auto__$jscomp$1301$$=$app$main$data$workspace$tokens$color$resolved_token_bullet_color$$($resolved_token$jscomp$17$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1301$$)?$or__5025__auto__$jscomp$1301$$:$app$main$data$workspace$tokens$color$resolved_token_bullet_color$$($token$jscomp$164$$)}():null;$is_reference_QMARK__status_icon_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($app$main$ui$workspace$tokens$management$token_pill$token_types_with_status_icon$$,
$type$jscomp$686$$);var $on_click__$1$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($errors_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_click$jscomp$51$$),$APP.$rumext$v2$adapt$$($token$jscomp$164$$)],function($event$jscomp$590$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$590$$);var $and__5023__auto__$jscomp$inline_9131$$=$APP.$cljs$core$not$$($APP.$cljs$core$seq$$($errors$jscomp$34$$));return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$inline_9131$$?
$on_click$jscomp$51$$:$and__5023__auto__$jscomp$inline_9131$$)?$on_click$jscomp$51$$.$cljs$core$IFn$_invoke$arity$2$?$on_click$jscomp$51$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$590$$,$token$jscomp$164$$):$on_click$jscomp$51$$($event$jscomp$590$$,$token$jscomp$164$$):null});$attributes$jscomp$88_token_status_id$$=$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?"token-status-partial":$full_applied_QMARK_$$?"token-status-full":"token-status-non-applied";$applied_QMARK__on_context_menu__$1$jscomp$2$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($can_edit_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($on_context_menu$jscomp$13$$),$APP.$rumext$v2$adapt$$($token$jscomp$164$$)],function($e$jscomp$360$$){$APP.$app$util$dom$stop_propagation$$($e$jscomp$360$$);return $APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?$on_context_menu$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$?$on_context_menu$jscomp$13$$.$cljs$core$IFn$_invoke$arity$2$($e$jscomp$360$$,$token$jscomp$164$$):
$on_context_menu$jscomp$13$$($e$jscomp$360$$,$token$jscomp$164$$):null});var $on_click__$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($errors_QMARK_$jscomp$1$$),$APP.$rumext$v2$adapt$$($on_click__$1$jscomp$3$$)],function($event$jscomp$591$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$591$$);var $JSCompiler_inline_result$jscomp$1863_and__5023__auto____$1$jscomp$inline_9133$$=$APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?($JSCompiler_inline_result$jscomp$1863_and__5023__auto____$1$jscomp$inline_9133$$=
$APP.$cljs$core$not$$($APP.$cljs$core$seq$$($errors$jscomp$34$$)))?$on_click__$1$jscomp$3$$:$JSCompiler_inline_result$jscomp$1863_and__5023__auto____$1$jscomp$inline_9133$$:$can_edit_QMARK_$jscomp$3$$;return $APP.$cljs$core$truth_$$($JSCompiler_inline_result$jscomp$1863_and__5023__auto____$1$jscomp$inline_9133$$)?$on_click__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$?$on_click__$1$jscomp$3$$.$cljs$core$IFn$_invoke$arity$1$($event$jscomp$591$$):$on_click__$1$jscomp$3$$($event$jscomp$591$$):null}),
$on_hover$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($selected_shapes$jscomp$25$$),$APP.$rumext$v2$adapt$$($is_viewer_QMARK_$$),$APP.$rumext$v2$adapt$$($active_theme_tokens$$),$APP.$rumext$v2$adapt$$($token$jscomp$164$$),$APP.$rumext$v2$adapt$$($half_applied_QMARK_$$),$APP.$rumext$v2$adapt$$($no_valid_value$jscomp$1$$),$APP.$rumext$v2$adapt$$($ref_not_in_active_set$jscomp$1$$),$APP.$rumext$v2$adapt$$($name_collision$$),$APP.$rumext$v2$adapt$$($errors$jscomp$34$$)],
function($event$jscomp$592_node$jscomp$436$$){$event$jscomp$592_node$jscomp$436$$=$APP.$app$util$dom$get_current_target$$($event$jscomp$592_node$jscomp$436$$);var $map__80131$jscomp$inline_13887_theme_token$jscomp$1_title$jscomp$inline_13889$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($active_theme_tokens$$,$name$jscomp$468$$),$app_token_vals$jscomp$inline_13891_is_applied_QMARK_$jscomp$inline_13893_shape$jscomp$inline_13872$$=$APP.$cljs$core$first$$($selected_shapes$jscomp$25$$),$base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$=
$APP.$cljs$core$__destructure_map$$($token$jscomp$164$$);var $name$jscomp$inline_13881_title$jscomp$51$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$,$APP.$cljs$cst$725$name$$);var $type$jscomp$inline_13882$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$,$APP.$cljs$cst$139$type$$),$resolved_value$jscomp$inline_13883_resolved_value__$1$jscomp$inline_13886$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$,$APP.$cljs$cst$4686$resolved_value$$);$base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$,$APP.$cljs$cst$260$value$$);var $applied_to$jscomp$inline_13894_map__80131__$1$jscomp$inline_13888_resolved_value_theme$jscomp$inline_13885$$=
$APP.$cljs$cst$4686$resolved_value$$.$cljs$core$IFn$_invoke$arity$1$($map__80131$jscomp$inline_13887_theme_token$jscomp$1_title$jscomp$inline_13889$$);$resolved_value$jscomp$inline_13883_resolved_value__$1$jscomp$inline_13886$$=$APP.$cljs$core$truth_$$($applied_to$jscomp$inline_13894_map__80131__$1$jscomp$inline_13888_resolved_value_theme$jscomp$inline_13885$$)?$applied_to$jscomp$inline_13894_map__80131__$1$jscomp$inline_13888_resolved_value_theme$jscomp$inline_13885$$:$resolved_value$jscomp$inline_13883_resolved_value__$1$jscomp$inline_13886$$;
$map__80131$jscomp$inline_13887_theme_token$jscomp$1_title$jscomp$inline_13889$$=$app$main$data$workspace$tokens$application$get_token_properties$$($map__80131$jscomp$inline_13887_theme_token$jscomp$1_title$jscomp$inline_13889$$);$applied_to$jscomp$inline_13894_map__80131__$1$jscomp$inline_13888_resolved_value_theme$jscomp$inline_13885$$=$APP.$cljs$core$__destructure_map$$($map__80131$jscomp$inline_13887_theme_token$jscomp$1_title$jscomp$inline_13889$$);$map__80131$jscomp$inline_13887_theme_token$jscomp$1_title$jscomp$inline_13889$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($applied_to$jscomp$inline_13894_map__80131__$1$jscomp$inline_13888_resolved_value_theme$jscomp$inline_13885$$,$APP.$cljs$cst$939$title$$);var $app_token_keys$jscomp$inline_13892_applied_tokens$jscomp$inline_13890_grouped_values$jscomp$inline_13895$$=$APP.$cljs$cst$1881$applied_tokens$$.$cljs$core$IFn$_invoke$arity$1$($app_token_vals$jscomp$inline_13891_is_applied_QMARK_$jscomp$inline_13893_shape$jscomp$inline_13872$$);$app_token_vals$jscomp$inline_13891_is_applied_QMARK_$jscomp$inline_13893_shape$jscomp$inline_13872$$=
$APP.$cljs$core$set$$($APP.$cljs$core$vals$$($app_token_keys$jscomp$inline_13892_applied_tokens$jscomp$inline_13890_grouped_values$jscomp$inline_13895$$));$app_token_keys$jscomp$inline_13892_applied_tokens$jscomp$inline_13890_grouped_values$jscomp$inline_13895$$=$APP.$cljs$core$keys$$($app_token_keys$jscomp$inline_13892_applied_tokens$jscomp$inline_13890_grouped_values$jscomp$inline_13895$$);$app_token_vals$jscomp$inline_13891_is_applied_QMARK_$jscomp$inline_13893_shape$jscomp$inline_13872$$=$APP.$cljs$core$contains_QMARK_$$($app_token_vals$jscomp$inline_13891_is_applied_QMARK_$jscomp$inline_13893_shape$jscomp$inline_13872$$,
$name$jscomp$inline_13881_title$jscomp$51$$);$applied_to$jscomp$inline_13894_map__80131__$1$jscomp$inline_13888_resolved_value_theme$jscomp$inline_13885$$=$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?$app$main$ui$workspace$tokens$management$token_pill$partially_applied_attr$$($app_token_keys$jscomp$inline_13892_applied_tokens$jscomp$inline_13890_grouped_values$jscomp$inline_13895$$,$app_token_vals$jscomp$inline_13891_is_applied_QMARK_$jscomp$inline_13893_shape$jscomp$inline_13872$$,$applied_to$jscomp$inline_13894_map__80131__$1$jscomp$inline_13888_resolved_value_theme$jscomp$inline_13885$$):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.all");$app_token_keys$jscomp$inline_13892_applied_tokens$jscomp$inline_13890_grouped_values$jscomp$inline_13895$$=$APP.$cljs$core$group_by$$($app$main$ui$workspace$tokens$management$token_pill$dimensions_dictionary$$,$app_token_keys$jscomp$inline_13892_applied_tokens$jscomp$inline_13890_grouped_values$jscomp$inline_13895$$);$base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$="Token: "+($name$jscomp$inline_13881_title$jscomp$51$$??
"")+"\n"+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.original-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$)]))??"")+"\n"+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.resolved-value",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$tokens$format$format_token_value$$($resolved_value$jscomp$inline_13883_resolved_value__$1$jscomp$inline_13886$$)]))??
"")+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$164$$),$APP.$cljs$cst$1994$number$$)?"\n"+($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.more-options")??""):null)??"");$name$jscomp$inline_13881_title$jscomp$51$$=$APP.$cljs$core$truth_$$($ref_not_in_active_set$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.tokens.ref-not-valid",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$name$jscomp$inline_13881_title$jscomp$51$$])):
$APP.$cljs$core$truth_$$($name_collision$$)?$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($errors$jscomp$34$$)):$APP.$cljs$core$truth_$$($no_valid_value$jscomp$1$$)?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.value-not-valid"):$APP.$cljs$core$truth_$$($app_token_vals$jscomp$inline_13891_is_applied_QMARK_$jscomp$inline_13893_shape$jscomp$inline_13872$$?$is_viewer_QMARK_$$:$app_token_vals$jscomp$inline_13891_is_applied_QMARK_$jscomp$inline_13893_shape$jscomp$inline_13872$$)?
$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$("\n",new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.applied-to"),$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1996$dimensions$$,$type$jscomp$inline_13882$$)?$app$main$ui$workspace$tokens$management$token_pill$translate_and_format$$($app_token_keys$jscomp$inline_13892_applied_tokens$jscomp$inline_13890_grouped_values$jscomp$inline_13895$$):
["- ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__80131$jscomp$inline_13887_theme_token$jscomp$1_title$jscomp$inline_13889$$),": ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($applied_to$jscomp$inline_13894_map__80131__$1$jscomp$inline_13888_resolved_value_theme$jscomp$inline_13885$$)].join("")],null)):$base_title$jscomp$inline_13896_map__80130__$1$jscomp$inline_13880_value$jscomp$inline_13884$$;return $APP.$app$util$dom$set_attribute_BANG_$$($event$jscomp$592_node$jscomp$436$$,
"title",$name$jscomp$inline_13881_title$jscomp$51$$)});return(0,$APP.$rumext$v2$jsxs$$)("button",{id:["token-pill-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$164$$))].join(""),type:"button",onFocus:$on_hover$$,onClick:$on_click__$2$$,onMouseEnter:$on_hover$$,onContextMenu:$applied_QMARK__on_context_menu__$1$jscomp$2$$,className:"main_ui_workspace_tokens_management_token_pill__token-pill "+(!$is_reference_QMARK__status_icon_QMARK_$$&&
$APP.$cljs$core$not$$($errors_QMARK_$jscomp$1$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-no-icon":"")+" "+($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-default":"")+" "+($disabled_QMARK_$jscomp$8_is_selected_inside_layout$jscomp$2$$?"main_ui_workspace_tokens_management_token_pill__token-pill-disabled":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?$has_selected_QMARK__map__80138__$1_props_80137$$?
$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?$half_applied_QMARK_$$:$full_applied_QMARK_$$:$has_selected_QMARK__map__80138__$1_props_80137$$:$can_edit_QMARK_$jscomp$3$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-applied":"")+" "+($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($can_edit_QMARK_$jscomp$3$$)?$errors_QMARK_$jscomp$1$$:$can_edit_QMARK_$jscomp$3$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-invalid":"")+" "+($APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$890$$=
$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?$half_applied_QMARK_$$:$full_applied_QMARK_$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$890$$)?$APP.$cljs$core$truth_$$($errors_QMARK_$jscomp$1$$)?$can_edit_QMARK_$jscomp$3$$:$errors_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$890$$}())?"main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied":"")+" "+($is_viewer_QMARK_$$?"main_ui_workspace_tokens_management_token_pill__token-pill-viewer":"")+" "+($APP.$cljs$core$truth_$$($is_viewer_QMARK_$$?
$has_selected_QMARK__map__80138__$1_props_80137$$?$APP.$cljs$core$truth_$$($half_applied_QMARK_$$)?$half_applied_QMARK_$$:$full_applied_QMARK_$$:$has_selected_QMARK__map__80138__$1_props_80137$$:$is_viewer_QMARK_$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-applied-viewer":"")+" "+($APP.$cljs$core$truth_$$($is_viewer_QMARK_$$?$errors_QMARK_$jscomp$1$$:$is_viewer_QMARK_$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-invalid-viewer":"")+" "+($APP.$cljs$core$truth_$$($is_viewer_QMARK_$$?
$full_applied_QMARK_$$?$errors_QMARK_$jscomp$1$$:$full_applied_QMARK_$$:$is_viewer_QMARK_$$)?"main_ui_workspace_tokens_management_token_pill__token-pill-invalid-applied-viewer":""),children:[$APP.$cljs$core$truth_$$($errors_QMARK_$jscomp$1$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"broken-link",className:"main_ui_workspace_tokens_management_token_pill__token-pill-icon","aria-label":$name_collision$$?$app$main$data$workspace$tokens$errors$resolve_error_message$$($APP.$cljs$core$first$$($errors$jscomp$34$$)):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.tokens.missing-reference")}):$APP.$cljs$core$truth_$$($color$jscomp$187_value$jscomp$947$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$utilities$swatch$swatch_STAR_$$,{background:$color$jscomp$187_value$jscomp$947$$,size:"small"}):$is_reference_QMARK__status_icon_QMARK_$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$foundations$utilities$token$token_status$token_status_icon_STAR_$$,{iconId:$attributes$jscomp$88_token_status_id$$,className:"main_ui_workspace_tokens_management_token_pill__token-pill-icon"}):
null,$APP.$cljs$core$truth_$$($contains_path_QMARK_$$)?function(){var $last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$=$APP.$cuerdas$core$last_index_of$cljs$0core$0IFn$0_invoke$0arity$02$$($name$jscomp$468$$,".");$last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$=$APP.$cljs$core$truth_$$($last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$3$($name$jscomp$468$$,
0,$last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$+1),$APP.$cljs$core$subs$$.$cljs$core$IFn$_invoke$arity$2$($name$jscomp$468$$,$last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$+1)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$name$jscomp$468$$,""],null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$,0,null);$last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$,1,null);return(0,$APP.$rumext$v2$jsx$$)("span",{"aria-label":$name$jscomp$468$$,className:"main_ui_workspace_tokens_management_token_pill__divided-name-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("span",{className:"main_ui_workspace_tokens_management_token_pill__last-name-wrapper",children:$last_part_temp__5823__auto__$jscomp$inline_9136_vec__80140$$})})}():(0,$APP.$rumext$v2$jsx$$)("span",
{"aria-label":$name$jscomp$468$$,className:"main_ui_workspace_tokens_management_token_pill__name-wrapper",children:$name$jscomp$468$$})]})});var $app$main$ui$workspace$tokens$management$token_tree$folder_node_STAR_$$=function $app$main$ui$workspace$tokens$management$token_tree$folder_node_STAR_$$($is_folder_expanded_props_80146$$){var $active_theme_tokens$jscomp$1$$=$is_folder_expanded_props_80146$$.activeThemeTokens,$folded_token_paths$$=$is_folder_expanded_props_80146$$.foldedTokenPaths,$selected_shapes$jscomp$26$$=$is_folder_expanded_props_80146$$.selectedShapes,$is_selected_inside_layout$jscomp$3$$=$is_folder_expanded_props_80146$$.isSelectedInsideLayout,
$on_token_pill_click$jscomp$3$$=$is_folder_expanded_props_80146$$.onTokenPillClick,$selected_token_set_id$jscomp$2$$=$is_folder_expanded_props_80146$$.selectedTokenSetId,$type$jscomp$687$$=$is_folder_expanded_props_80146$$.type,$node$jscomp$437$$=$is_folder_expanded_props_80146$$.node,$on_pill_context_menu$$=$is_folder_expanded_props_80146$$.onPillContextMenu,$on_node_context_menu$$=$is_folder_expanded_props_80146$$.onNodeContextMenu,$tokens_lib$jscomp$42$$=$is_folder_expanded_props_80146$$.tokensLib,
$full_path$jscomp$2$$=[$APP.$cljs$core$name$$($type$jscomp$687$$),".",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$437$$))].join("");$is_folder_expanded_props_80146$$=!$APP.$cljs$core$contains_QMARK_$$($APP.$cljs$core$set$$($APP.$cljs$core$truth_$$($folded_token_paths$$)?$folded_token_paths$$:$APP.$cljs$core$PersistentVector$EMPTY$$),$full_path$jscomp$2$$);var $children$jscomp$305$$=$APP.$cljs$cst$342$children$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$437$$),
$sorted_children$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($children$jscomp$305$$)],function(){var $groups$jscomp$19_sorted_groups_vec__80147$$=$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($g$jscomp$162_p__80150$$,$item$jscomp$141$$){var $l$jscomp$110$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($g$jscomp$162_p__80150$$,0,null);$g$jscomp$162_p__80150$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($g$jscomp$162_p__80150$$,
1,null);return $APP.$cljs$core$truth_$$($APP.$cljs$cst$2015$leaf$$.$cljs$core$IFn$_invoke$arity$1$($item$jscomp$141$$))?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($l$jscomp$110$$,$item$jscomp$141$$),$g$jscomp$162_p__80150$$],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$l$jscomp$110$$,$APP.$cljs$core$conj$$.$cljs$core$IFn$_invoke$arity$2$($g$jscomp$162_p__80150$$,
$item$jscomp$141$$)],null)},new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$],null),$children$jscomp$305$$),$leafs_sorted_leafs$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($groups$jscomp$19_sorted_groups_vec__80147$$,0,null);$groups$jscomp$19_sorted_groups_vec__80147$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($groups$jscomp$19_sorted_groups_vec__80147$$,
1,null);$leafs_sorted_leafs$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$725$name$$,$app$common$data$natural_compare$$,$leafs_sorted_leafs$$);$groups$jscomp$19_sorted_groups_vec__80147$$=$APP.$cljs$core$sort_by$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$cst$725$name$$,$app$common$data$natural_compare$$,$groups$jscomp$19_sorted_groups_vec__80147$$);return $APP.$cljs$core$concat$$.$cljs$core$IFn$_invoke$arity$2$($leafs_sorted_leafs$$,$groups$jscomp$19_sorted_groups_vec__80147$$)}),
$swap_folder_expanded$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($full_path$jscomp$2$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$tokens$library_edit$toggle_token_path$$($full_path$jscomp$2$$))}),$node_context_menu_prep$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_node_context_menu$$),$APP.$rumext$v2$adapt$$($node$jscomp$437$$)],function($event$jscomp$593$$){return $APP.$cljs$core$truth_$$($on_node_context_menu$$)?
$on_node_context_menu$$.$cljs$core$IFn$_invoke$arity$2$?$on_node_context_menu$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$593$$,$node$jscomp$437$$):$on_node_context_menu$$($event$jscomp$593$$,$node$jscomp$437$$):null});return(0,$APP.$rumext$v2$jsxs$$)("li",{className:"main_ui_workspace_tokens_management_token_tree__folder-node",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$ds$layers$layer_button$layer_button_STAR_$$,{label:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$437$$),
expanded:$is_folder_expanded_props_80146$$,"aria-expanded":$is_folder_expanded_props_80146$$,"aria-controls":["folder-children-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$437$$))].join(""),isExpandable:$APP.$cljs$core$not$$($APP.$cljs$cst$2015$leaf$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$437$$)),onToggleExpand:$swap_folder_expanded$$,onContextMenu:$node_context_menu_prep$$}),$is_folder_expanded_props_80146$$?
(0,$APP.$rumext$v2$jsx$$)("div",{id:["folder-children-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($node$jscomp$437$$))].join(""),className:"main_ui_workspace_tokens_management_token_tree__folder-children-wrapper",children:$APP.$cljs$core$seq$$($children$jscomp$305$$)?$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$199$$,$JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$){var $JSCompiler_temp_const$jscomp$1864$$=
$out_arr__44092__auto__$jscomp$199$$.push;if($APP.$cljs$core$not$$($APP.$cljs$cst$2015$leaf$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$)))$JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$=(0,$APP.$rumext$v2$jsx$$)("ul",{className:"main_ui_workspace_tokens_management_token_tree__node-parent",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_tree$folder_node_STAR_$$,{foldedTokenPaths:$folded_token_paths$$,
tokensLib:$tokens_lib$jscomp$42$$,onPillContextMenu:$on_pill_context_menu$$,onTokenPillClick:$on_token_pill_click$jscomp$3$$,onNodeContextMenu:$on_node_context_menu$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$3$$,type:$type$jscomp$687$$,activeThemeTokens:$active_theme_tokens$jscomp$1$$,selectedShapes:$selected_shapes$jscomp$26$$,selectedTokenSetId:$selected_token_set_id$jscomp$2$$,node:$JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$})},$APP.$cljs$cst$296$path$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$));
else{$JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2015$leaf$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$));var $token$jscomp$inline_9139$$=$APP.$app$common$types$tokens_lib$get_token$$($tokens_lib$jscomp$42$$,$selected_token_set_id$jscomp$2$$,$JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$);$JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$=
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$management$token_pill$token_pill_STAR_$$,{token:$token$jscomp$inline_9139$$,selectedShapes:$selected_shapes$jscomp$26$$,isSelectedInsideLayout:$is_selected_inside_layout$jscomp$3$$,activeThemeTokens:$active_theme_tokens$jscomp$1$$,onClick:$on_token_pill_click$jscomp$3$$,onContextMenu:$on_pill_context_menu$$},$JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$)}$JSCompiler_temp_const$jscomp$1864$$.call($out_arr__44092__auto__$jscomp$199$$,
$JSCompiler_temp$jscomp$1866_child$jscomp$124_id$jscomp$inline_9138$$);return $out_arr__44092__auto__$jscomp$199$$},[],$sorted_children$$):null}):null]})};var $app$main$ui$workspace$tokens$management$group$ref_COLON_folded_token_paths$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$4775$folded_token_paths$$),$APP.$app$main$refs$workspace_tokens$$),$app$main$ui$workspace$tokens$management$group$ref_COLON_unfolded_token_types$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$okulary$core$key$$($APP.$cljs$cst$4768$unfolded_token_types$$),$APP.$app$main$refs$workspace_tokens$$);var $app$main$ui$workspace$tokens$management$node_context_menu$tokens_node_menu_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4806$token_node_context_menu$$,$APP.$app$main$refs$workspace_tokens$$);var $app$main$ui$workspace$tokens$sets$context_menu$ref_COLON_token_sets_context_menu$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$4808$token_set_context_menu$$,$APP.$app$main$refs$workspace_tokens$$);var $app$main$ui$workspace$sidebar$toggle_collapse_left_sidebar$$=$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$main$store$emit_BANG_$$,(0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($cljs$cst$5729$collapse_left_sidebar$$)),$app$main$ui$workspace$sidebar$collapsed_button_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function(){return(0,$APP.$rumext$v2$jsx$$)("div",{id:"left-sidebar-aside","data-width":"0",className:"main_ui_workspace_sidebar__collapsed-sidebar",
children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar__collapsed-title",children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.expand"),onClick:$app$main$ui$workspace$sidebar$toggle_collapse_left_sidebar$$,className:"main_ui_workspace_sidebar__collapsed-button",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$foundations$assets$icon$icon_STAR_$$,{iconId:"arrow",size:"s","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.expand")})})})})}),
$app$main$ui$workspace$sidebar$layers_content_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_80272_width$jscomp$208$$){var $layout$jscomp$26$$=$props_80272_width$jscomp$208$$.layout;$props_80272_width$jscomp$208$$=$props_80272_width$jscomp$208$$.width;var $map__80274_on_pointer_down$jscomp$4$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($APP.$cljs$cst$3763$sitemap$$,200,38,"0.6",$APP.$cljs$cst$1516$y$$,!1,null,null),$height$jscomp$178_map__80274__$1$$=
$APP.$cljs$core$__destructure_map$$($map__80274_on_pointer_down$jscomp$4$$);$map__80274_on_pointer_down$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$178_map__80274__$1$$,$APP.$cljs$cst$4610$on_pointer_down$$);var $on_lost_pointer_capture$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$178_map__80274__$1$$,$APP.$cljs$cst$4611$on_lost_pointer_capture$$),$on_pointer_move$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$178_map__80274__$1$$,
$APP.$cljs$cst$4612$on_pointer_move$$);$height$jscomp$178_map__80274__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$178_map__80274__$1$$,$APP.$cljs$cst$874$size$$);var $sitemap_collapsed_STAR_$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5910$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_SLASH_sitemap_collapsed$$,!1),$sitemap_collapsed_QMARK_$$=$APP.$cljs$core$_deref$$($sitemap_collapsed_STAR_$$),$on_toggle_sitemap_collapsed$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($sitemap_collapsed_STAR_$$,
$APP.$cljs$core$not$$)});return(0,$APP.$rumext$v2$jsxs$$)("article",{style:{"--height":""+($height$jscomp$178_map__80274__$1$$??"")+"px"},className:"main_ui_workspace_sidebar__layers-tab",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$sitemap$sitemap_STAR_$$,{layout:$layout$jscomp$26$$,height:$APP.$cljs$core$truth_$$($sitemap_collapsed_QMARK_$$)?32:$height$jscomp$178_map__80274__$1$$,collapsed:$sitemap_collapsed_QMARK_$$,onToggleCollapsed:$on_toggle_sitemap_collapsed$$}),$sitemap_collapsed_QMARK_$$?
null:(0,$APP.$rumext$v2$jsx$$)("div",{onPointerDown:$map__80274_on_pointer_down$jscomp$4$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$2$$,onPointerMove:$on_pointer_move$jscomp$3$$,className:"main_ui_workspace_sidebar__resize-area-horiz",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar__resize-handle-horiz"})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers$layers_toolbox_STAR_$$,{sizeParent:$props_80272_width$jscomp$208$$})]})}),$app$main$ui$workspace$sidebar$left_sidebar_STAR_$$=
(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($project$jscomp$22_props_80277$$){var $layout$jscomp$27$$=$project$jscomp$22_props_80277$$.layout,$resolved_active_tokens$jscomp$2$$=$project$jscomp$22_props_80277$$.resolvedActiveTokens,$file$jscomp$177$$=$project$jscomp$22_props_80277$$.file,$active_tokens$jscomp$10$$=$project$jscomp$22_props_80277$$.activeTokens,$tokens_lib$jscomp$54$$=$project$jscomp$22_props_80277$$.tokensLib,$options_mode$jscomp$2_shortcuts_QMARK_$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$options_mode_global$$);
$project$jscomp$22_props_80277$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$project$$);var $file_id$jscomp$430$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$177$$,$APP.$cljs$cst$266$id$$),$design_tokens_QMARK_$$=$APP.$app$main$features$use_feature$$("design-tokens/v1"),$mode_inspect_QMARK_$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($options_mode$jscomp$2_shortcuts_QMARK_$$,$APP.$cljs$cst$2683$inspect$$);$options_mode$jscomp$2_shortcuts_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$27$$,
$APP.$cljs$cst$2961$shortcuts$$);var $show_debug_QMARK_$$=$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$27$$,$cljs$cst$5753$debug_panel$$),$section$jscomp$35$$=$mode_inspect_QMARK_$$||$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$27$$,$APP.$cljs$cst$3777$layers$$)?$APP.$cljs$cst$3777$layers$$:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$27$$,$APP.$cljs$cst$3767$assets$$)?$APP.$cljs$cst$3767$assets$$:$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$27$$,$APP.$cljs$cst$2108$tokens$$)?$APP.$cljs$cst$2108$tokens$$:
null,$map__80282_on_pointer_down$jscomp$5$$=$APP.$app$main$ui$hooks$resize$use_resize_hook$cljs$0core$0IFn$0_invoke$0arity$08$$($cljs$cst$5911$left_sidebar$$,318,318,500,$APP.$cljs$cst$1515$x$$,!1,$APP.$cljs$cst$257$left$$,null),$map__80282__$1_on_tab_change$$=$APP.$cljs$core$__destructure_map$$($map__80282_on_pointer_down$jscomp$5$$);$map__80282_on_pointer_down$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80282__$1_on_tab_change$$,$APP.$cljs$cst$4610$on_pointer_down$$);
var $on_lost_pointer_capture$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80282__$1_on_tab_change$$,$APP.$cljs$cst$4611$on_lost_pointer_capture$$),$on_pointer_move$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80282__$1_on_tab_change$$,$APP.$cljs$cst$4612$on_pointer_move$$),$parent_ref$jscomp$3$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80282__$1_on_tab_change$$,$APP.$cljs$cst$4613$parent_ref$$),$width$jscomp$209$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80282__$1_on_tab_change$$,
$APP.$cljs$cst$874$size$$);$map__80282__$1_on_tab_change$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($id$jscomp$1020$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1620$layout$$,$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($id$jscomp$1020$$)])));return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1020$$,
"tokens")?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-tokens-tab"],null))):null});var $tabs$jscomp$5$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($mode_inspect_QMARK_$$),$APP.$rumext$v2$adapt$$($design_tokens_QMARK_$$)],function(){return $mode_inspect_QMARK_$$?new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers"),$APP.$cljs$cst$266$id$$,"layers"],null)],null):$design_tokens_QMARK_$$?new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers"),
$APP.$cljs$cst$266$id$$,"layers"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.assets"),$APP.$cljs$cst$266$id$$,"assets"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,"Tokens",$APP.$cljs$cst$266$id$$,"tokens"],null)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.sidebar.layers"),$APP.$cljs$cst$266$id$$,"layers"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.assets"),$APP.$cljs$cst$266$id$$,"assets"],null)],null)}),$aside_class$$="main_ui_workspace_sidebar__left-settings-bar "+($width$jscomp$209$$<=300?"two-row":"")+" "+($width$jscomp$209$$>300&&$width$jscomp$209$$<=
400?"three-row":"")+" "+($width$jscomp$209$$>400?"four-row":""),$tabs_action_button$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$collapse_button_STAR_$$,{})});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$sidebar$$),{value:$APP.$cljs$cst$257$left$$,children:(0,$APP.$rumext$v2$jsxs$$)("aside",{ref:$parent_ref$jscomp$3$$,id:"left-sidebar-aside","data-testid":"left-sidebar",
"data-width":$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($width$jscomp$209$$),onContextMenu:$app$util$dom$prevent_default_context_menu$$,style:{"--left-sidebar-width":""+($width$jscomp$209$$??"")+"px"},className:$aside_class$$,children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$left_header$left_header_STAR_$$,{file:$file$jscomp$177$$,layout:$layout$jscomp$27$$,project:$project$jscomp$22_props_80277$$,className:"main_ui_workspace_sidebar__left-header"}),(0,$APP.$rumext$v2$jsx$$)("div",
{onPointerDown:$map__80282_on_pointer_down$jscomp$5$$,onLostPointerCapture:$on_lost_pointer_capture$jscomp$3$$,onPointerMove:$on_pointer_move$jscomp$4$$,className:"main_ui_workspace_sidebar__resize-area"}),$options_mode$jscomp$2_shortcuts_QMARK_$$===!0?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$shortcuts$shortcuts_container_STAR_$$,{className:"main_ui_workspace_sidebar__settings-bar-content"}):$show_debug_QMARK_$$===!0?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$debug$debug_panel_STAR_$$,
{className:"main_ui_workspace_sidebar__settings-bar-content"}):(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_sidebar__settings-bar-content",children:$APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,{tabs:$tabs$jscomp$5$$,"default":"layers",selected:$APP.$cljs$core$name$$($section$jscomp$35$$),onChange:$map__80282__$1_on_tab_change$$,className:"main_ui_workspace_sidebar__left-sidebar-tabs",actionButtonPosition:"start",actionButton:$tabs_action_button$$,
children:function(){var $G__80283__$1$$=$section$jscomp$35$$ instanceof $APP.$cljs$core$Keyword$$?$section$jscomp$35$$.$fqn$:null;switch($G__80283__$1$$){case "assets":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$assets$assets_toolbox_STAR_$$,{size:$width$jscomp$209$$-58,fileId:$file_id$jscomp$430$$});case "tokens":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$tokens$sidebar$tokens_sidebar_tab_STAR_$$,{tokensLib:$tokens_lib$jscomp$54$$,activeTokens:$active_tokens$jscomp$10$$,
resolvedActiveTokens:$resolved_active_tokens$jscomp$2$$});case "layers":return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$layers_content_STAR_$$,{layout:$layout$jscomp$27$$,width:$width$jscomp$209$$});default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__80283__$1$$)].join(""));}}()})})]})})}),$app$main$ui$workspace$sidebar$history_content_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function(){var $selected_STAR_$jscomp$2$$=$app$main$ui$hooks$use_persisted_state$$($cljs$cst$5912$app_DOT_main_DOT_ui_DOT_workspace_DOT_sidebar_SLASH_history_sidebar$$,
"history"),$selected$jscomp$187$$=$APP.$cljs$core$_deref$$($selected_STAR_$jscomp$2$$),$on_change_tab$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__80285_SHARP_$$){return $APP.$cljs$core$reset_BANG_$$($selected_STAR_$jscomp$2$$,$p1__80285_SHARP_$$)}),$tabs$jscomp$6$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.tab.history"),$APP.$cljs$cst$266$id$$,"history"],null),new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2296$label$$,$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.versions.tab.actions"),$APP.$cljs$cst$266$id$$,"actions"],null)],null)}),$button$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$ds$buttons$icon_button$icon_button_STAR_$$,
{variant:"ghost","aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("labels.close"),onClick:$app$main$ui$workspace$sidebar$on_close_document_history$$,icon:"close"})});a:switch($selected$jscomp$187$$){case "history":var $JSCompiler_inline_result$jscomp$1883$$=(0,$APP.$rumext$v2$jsx$$)("article",{className:"main_ui_workspace_sidebar__history-tab",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$versions$versions_toolbox_STAR_$$,{})});break a;case "actions":$JSCompiler_inline_result$jscomp$1883$$=
(0,$APP.$rumext$v2$jsx$$)("article",{className:"main_ui_workspace_sidebar__versions-tab",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$sidebar$history$history_toolbox_STAR_$$,{})});break a;default:throw Error(["No matching clause: ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($selected$jscomp$187$$)].join(""));}return $APP.$rumext$v2$jsx$$($APP.$app$main$ui$ds$layout$tab_switcher$tab_switcher_STAR_$$,{tabs:$tabs$jscomp$6$$,selected:$selected$jscomp$187$$,onChange:$on_change_tab$jscomp$2$$,
className:"main_ui_workspace_sidebar__left-sidebar-tabs",actionButtonPosition:"end",actionButton:$button$jscomp$3$$,children:$JSCompiler_inline_result$jscomp$1883$$})});var $shadow$js$shim$module$0$0zip_js$0zip$$=shadow$bridge("@zip.js/zip.js");var $app$util$zip$reader$$=function $app$util$zip$reader$$($G__80271_blob$jscomp$39_breader$$){if($G__80271_blob$jscomp$39_breader$$ instanceof Blob)return $G__80271_blob$jscomp$39_breader$$=new $shadow$js$shim$module$0$0zip_js$0zip$$.BlobReader($G__80271_blob$jscomp$39_breader$$),new $shadow$js$shim$module$0$0zip_js$0zip$$.ZipReader($G__80271_blob$jscomp$39_breader$$);if($G__80271_blob$jscomp$39_breader$$ instanceof Uint8Array)return $G__80271_blob$jscomp$39_breader$$=new $shadow$js$shim$module$0$0zip_js$0zip$$.Uint8ArrayReader($G__80271_blob$jscomp$39_breader$$),
new $shadow$js$shim$module$0$0zip_js$0zip$$.ZipReader($G__80271_blob$jscomp$39_breader$$,{useWebWorkers:!1});if($G__80271_blob$jscomp$39_breader$$ instanceof ArrayBuffer)return $G__80271_blob$jscomp$39_breader$$=new Uint8Array($G__80271_blob$jscomp$39_breader$$),$app$util$zip$reader$$.$cljs$core$IFn$_invoke$arity$1$?$app$util$zip$reader$$.$cljs$core$IFn$_invoke$arity$1$($G__80271_blob$jscomp$39_breader$$):$app$util$zip$reader$$($G__80271_blob$jscomp$39_breader$$);throw $APP.$cljs$core$ex_info$cljs$0core$0IFn$0_invoke$0arity$03$$("invalid data received for zip/reader",
$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$139$type$$,$APP.$cljs$cst$272$assertion$$,$cljs$cst$5913$coce$$,$APP.$cljs$cst$1760$invalid_type$$,$APP.$cljs$cst$275$hint$$,"invalid data received for zip/reader"],null),null])),null);};$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$27$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$27$$,$cljs$cst$5907$tokens_SLASH_export$$,$app$main$ui$workspace$tokens$export$0$export_modal_STAR_$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$28$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$28$$,$cljs$cst$5908$tokens_SLASH_import$$,$app$main$ui$workspace$tokens$import$0$import_modal_STAR_$$)});var $app$main$ui$workspace$tokens$management$forms$validators$default_validators$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[function($token$jscomp$188_token_value$jscomp$10$$){$token$jscomp$188_token_value$jscomp$10$$=$APP.$cljs$cst$260$value$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$188_token_value$jscomp$10$$);return $APP.$cljs$core$empty_QMARK_$$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($token$jscomp$188_token_value$jscomp$10$$))?
$APP.$app$main$data$workspace$tokens$errors$get_error_code$$($APP.$cljs$cst$4660$error_DOT_token_SLASH_empty_input$$):null},$app$main$ui$workspace$tokens$management$forms$validators$check_self_reference$$],null);var $app$main$ui$workspace$tokens$management$forms$shadow$default_token_shadow$$=new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1655$offset_x$$,"4",$APP.$cljs$cst$1656$offset_y$$,"4",$APP.$cljs$cst$1658$blur$$,"4",$APP.$cljs$cst$1657$spread$$,"0"],null);$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$29$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$29$$,$cljs$cst$5930$tokens_SLASH_boolean$$,$app$main$ui$workspace$tokens$management$forms$modals$boolean_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$30$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$30$$,$APP.$cljs$cst$4740$tokens_SLASH_border_radius$$,$app$main$ui$workspace$tokens$management$forms$modals$border_radius_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$31$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$31$$,$APP.$cljs$cst$4742$tokens_SLASH_shadow$$,$app$main$ui$workspace$tokens$management$forms$modals$box_shadow_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$32$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$32$$,$APP.$cljs$cst$4743$tokens_SLASH_color$$,$app$main$ui$workspace$tokens$management$forms$modals$color_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$33$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$33$$,$APP.$cljs$cst$4753$tokens_SLASH_dimensions$$,$app$main$ui$workspace$tokens$management$forms$modals$dimensions_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$34$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$34$$,$APP.$cljs$cst$4746$tokens_SLASH_font_family$$,$app$main$ui$workspace$tokens$management$forms$modals$font_familiy_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$35$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$35$$,$APP.$cljs$cst$4744$tokens_SLASH_font_size$$,$app$main$ui$workspace$tokens$management$forms$modals$font_size_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$36$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$36$$,$APP.$cljs$cst$4748$tokens_SLASH_font_weight$$,$app$main$ui$workspace$tokens$management$forms$modals$font_weight_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$37$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$37$$,$APP.$cljs$cst$4745$tokens_SLASH_letter_spacing$$,$app$main$ui$workspace$tokens$management$forms$modals$letter_spacing_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$38$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$38$$,$APP.$cljs$cst$4755$tokens_SLASH_number$$,$app$main$ui$workspace$tokens$management$forms$modals$number_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$39$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$39$$,$APP.$cljs$cst$4754$tokens_SLASH_opacity$$,$app$main$ui$workspace$tokens$management$forms$modals$opacity_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$40$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$40$$,$cljs$cst$5931$tokens_SLASH_other$$,$app$main$ui$workspace$tokens$management$forms$modals$other_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$41$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$41$$,$APP.$cljs$cst$4756$tokens_SLASH_rotation$$,$app$main$ui$workspace$tokens$management$forms$modals$rotation_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$42$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$42$$,$APP.$cljs$cst$4752$tokens_SLASH_sizing$$,$app$main$ui$workspace$tokens$management$forms$modals$sizing_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$43$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$43$$,$APP.$cljs$cst$4757$tokens_SLASH_spacing$$,$app$main$ui$workspace$tokens$management$forms$modals$spacing_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$44$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$44$$,$cljs$cst$5932$tokens_SLASH_string$$,$app$main$ui$workspace$tokens$management$forms$modals$string_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$45$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$45$$,$APP.$cljs$cst$4751$tokens_SLASH_stroke_width$$,$app$main$ui$workspace$tokens$management$forms$modals$stroke_width_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$46$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$46$$,$APP.$cljs$cst$4747$tokens_SLASH_text_case$$,$app$main$ui$workspace$tokens$management$forms$modals$text_case_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$47$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$47$$,$APP.$cljs$cst$4750$tokens_SLASH_text_decoration$$,$app$main$ui$workspace$tokens$management$forms$modals$text_decoration_modal$$)});
$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$48$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$48$$,$APP.$cljs$cst$4749$tokens_SLASH_typography$$,$app$main$ui$workspace$tokens$management$forms$modals$typography_modal$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$49$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$49$$,$cljs$cst$5903$tokens_SLASH_rename_node$$,$app$main$ui$workspace$tokens$management$forms$rename_node_modal$rename_node_modal$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$50$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$50$$,$cljs$cst$5899$tokens_SLASH_remapping_confirmation$$,$app$main$ui$workspace$tokens$remapping_modal$token_remapping_modal$$)});var $app$main$data$workspace$tokens$typography$set_base_font_size_80605$$;$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$51$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$51$$,$cljs$cst$5909$tokens_SLASH_settings$$,$app$main$ui$workspace$tokens$settings$token_settings_modal_STAR_$$)});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$52$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$52$$,$cljs$cst$5906$tokens_SLASH_themes$$,$app$main$ui$workspace$tokens$themes$create_modal$token_themes_modal$$)});var $app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$main$ui$workspace$viewport$viewport_ref$current_observer$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$app$main$ui$workspace$viewport$viewport_ref$viewport_brect$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$(null);var $app$main$ui$workspace$shapes$text$editor$default_decorator$$;$app$main$ui$workspace$shapes$text$editor$default_decorator$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.createDecorator("PENPOT_SELECTION",function($props_80737$$){return(0,$APP.$rumext$v2$jsx$$)("span",{style:{background:"#ccc",display:"inline-block"},children:$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($props_80737$$,"children")})});
var $app$main$ui$workspace$shapes$text$editor$empty_editor_state$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.createEditorState(null,$app$main$ui$workspace$shapes$text$editor$default_decorator$$),$app$main$ui$workspace$shapes$text$editor$text_shape_edit_html$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$((0,$APP.$rumext$v2$forward_ref$$)(function($content$jscomp$258_props_80763$$){function $on_key_up$jscomp$1$$($event$jscomp$652$$){$APP.$app$util$dom$stop_propagation$$($event$jscomp$652$$);
return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$652$$))?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()])):null}var $map__80774__$1$$=$APP.$cljs$core$__destructure_map$$($APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($content$jscomp$258_props_80763$$,"shape")),$id$jscomp$1034_self_ref$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80774__$1$$,$APP.$cljs$cst$266$id$$);$content$jscomp$258_props_80763$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80774__$1$$,$APP.$cljs$cst$1642$content$$);var $on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$),$state$jscomp$1230$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$3$($on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$,
$id$jscomp$1034_self_ref$$,$app$main$ui$workspace$shapes$text$editor$empty_editor_state$$);$id$jscomp$1034_self_ref$$=(0,$APP.$rumext$v2$use_ref$$)();$on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__80774__$1$$))],function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($map__80774__$1$$))});
$on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$=$APP.$rumext$v2$deref$$($on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$);var $shape__$1$jscomp$111$$=$on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($map__80774__$1$$,$on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$):$map__80774__$1$$,
$blurred$$=$APP.$rumext$v2$use_var$cljs$0core$0IFn$0_invoke$0arity$01$$(!1);$on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape__$1$jscomp$111$$),$APP.$rumext$v2$adapt$$($state$jscomp$1230$$)],function($event$jscomp$653$$){var $is_empty_QMARK_$$=$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.isCurrentEmpty($state$jscomp$1230$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$653$$);
$APP.$app$util$dom$prevent_default$$($event$jscomp$653$$);$APP.$cljs$core$not$$($is_empty_QMARK_$$)&&($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4072$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$initialize_editor_state$$($shape__$1$jscomp$111$$)));return $APP.$cljs$core$reset_BANG_$$($blurred$$,!0)});var $on_focus$jscomp$19$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape__$1$jscomp$111$$),
$APP.$rumext$v2$adapt$$($state$jscomp$1230$$)],function(){return $APP.$cljs$core$reset_BANG_$$($blurred$$,!1)}),$prev_value$jscomp$1$$=(0,$APP.$rumext$v2$use_ref$$)($state$jscomp$1230$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($state$jscomp$1230$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($prev_value$jscomp$1$$,$state$jscomp$1230$$)});var $handle_change$jscomp$19$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($state__$1$jscomp$62$$){var $old_state$jscomp$1_prev_data$jscomp$1$$=
$APP.$rumext$v2$ref_val$$($prev_value$jscomp$1$$);if($state__$1$jscomp$62$$!=null&&$old_state$jscomp$1_prev_data$jscomp$1$$!=null){var $block_changes$jscomp$2_block_to_add_styles$$=$app$util$text_editor$get_content_changes$$($old_state$jscomp$1_prev_data$jscomp$1$$,$state__$1$jscomp$62$$);$old_state$jscomp$1_prev_data$jscomp$1$$=$APP.$app$util$text_editor$get_editor_current_inline_styles$$($old_state$jscomp$1_prev_data$jscomp$1$$);var $block_to_setup$$=$app$main$ui$workspace$shapes$text$editor$get_blocks_to_setup$$($block_changes$jscomp$2_block_to_add_styles$$);
$block_changes$jscomp$2_block_to_add_styles$$=$app$main$ui$workspace$shapes$text$editor$get_blocks_to_add_styles$$($block_changes$jscomp$2_block_to_add_styles$$);return $app$util$text_editor$apply_block_styles_to_content$$($app$util$text_editor$setup_block_styles$$($state__$1$jscomp$62$$,$block_to_setup$$,$old_state$jscomp$1_prev_data$jscomp$1$$),$block_changes$jscomp$2_block_to_add_styles$$)}return $state__$1$jscomp$62$$}),$on_change$jscomp$101$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($val$jscomp$232$$){var $prev_val$jscomp$1$$=
$APP.$rumext$v2$ref_val$$($prev_value$jscomp$1$$),$styleOverride$$=$prev_val$jscomp$1$$.getInlineStyleOverride(),$keep_style_QMARK_$$=function(){var $and__5023__auto__$jscomp$956_and__5023__auto____$1$jscomp$163$$=$styleOverride$$!=null;return $and__5023__auto__$jscomp$956_and__5023__auto____$1$jscomp$163$$?($and__5023__auto__$jscomp$956_and__5023__auto____$1$jscomp$163$$=$prev_val$jscomp$1$$.getCurrentContent().equals($val$jscomp$232$$.getCurrentContent()),$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$956_and__5023__auto____$1$jscomp$163$$)?
$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.selectionEquals($prev_val$jscomp$1$$.getSelection(),$val$jscomp$232$$.getSelection()):$and__5023__auto__$jscomp$956_and__5023__auto____$1$jscomp$163$$):$and__5023__auto__$jscomp$956_and__5023__auto____$1$jscomp$163$$}(),$val__$1$jscomp$21$$=function(){var $G__80791_G__80791__$1_G__80791__$2$$=$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($val$jscomp$232$$):$handle_change$jscomp$19$$($val$jscomp$232$$);
$G__80791_G__80791__$1_G__80791__$2$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($blurred$$))?$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.addBlurSelectionEntity($G__80791_G__80791__$1_G__80791__$2$$):$G__80791_G__80791__$1_G__80791__$2$$;$G__80791_G__80791__$1_G__80791__$2$$=$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($blurred$$))?$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.removeBlurSelectionEntity($G__80791_G__80791__$1_G__80791__$2$$):$G__80791_G__80791__$1_G__80791__$2$$;
return $APP.$cljs$core$truth_$$($keep_style_QMARK_$$)?$APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.setInlineStyleOverride($G__80791_G__80791__$1_G__80791__$2$$,$styleOverride$$):$G__80791_G__80791__$1_G__80791__$2$$}();return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_editor_state$$($shape__$1$jscomp$111$$,$val__$1$jscomp$21$$))}),$on_editor$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($editor$jscomp$9$$){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$update_editor$$($editor$jscomp$9$$));
return $APP.$cljs$core$truth_$$($editor$jscomp$9$$)?($APP.$app$util$dom$add_class_BANG_$$($APP.$goog$dom$getElementByClass$$("public-DraftEditor-content"),"mousetrap"),$editor$jscomp$9$$.focus()):null}),$handle_return$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($___$2$jscomp$731_style_80828$$,$G__80792$jscomp$inline_9247_state_80829__$2_state__$1$jscomp$63$$){$___$2$jscomp$731_style_80828$$=$APP.$app$util$text_editor$get_editor_current_block_data$$($G__80792$jscomp$inline_9247_state_80829__$2_state__$1$jscomp$63$$);
$G__80792$jscomp$inline_9247_state_80829__$2_state__$1$jscomp$63$$=$app$util$text_editor$insert_text$$($G__80792$jscomp$inline_9247_state_80829__$2_state__$1$jscomp$63$$,"\n",$___$2$jscomp$731_style_80828$$);$G__80792$jscomp$inline_9247_state_80829__$2_state__$1$jscomp$63$$=$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($G__80792$jscomp$inline_9247_state_80829__$2_state__$1$jscomp$63$$):$handle_change$jscomp$19$$($G__80792$jscomp$inline_9247_state_80829__$2_state__$1$jscomp$63$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_editor_state$$($shape__$1$jscomp$111$$,$G__80792$jscomp$inline_9247_state_80829__$2_state__$1$jscomp$63$$));return"handled"}),$on_pointer_down$jscomp$12$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$654$$){$APP.$app$util$dom$class_QMARK_$$($APP.$app$util$dom$get_target$$($event$jscomp$654$$),"DraftEditor-root")&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$cursor_to_end$$($shape__$1$jscomp$111$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$focus_editor$$())});$APP.$rumext$v2$use_layout_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $keys$jscomp$57$$=new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$goog$events$listen$$(document,"keyup",$on_key_up$jscomp$1$$)],null);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$texts$initialize_editor_state$$($shape__$1$jscomp$111$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$texts$select_all$$($shape__$1$jscomp$111$$)]));return function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4072$app_DOT_main_DOT_data_DOT_workspace_DOT_texts_SLASH_finalize_editor_state$$);for(var $c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$=$APP.$cljs$core$seq$$($keys$jscomp$57$$),$G__80815_chunk__80785_seq__80784__$1$$=null,$G__80814_count__80786$$=
0,$i__80787$$=0;;)if($i__80787$$<$G__80814_count__80786$$){var $G__80816_key$jscomp$423$$=$G__80815_chunk__80785_seq__80784__$1$$.$cljs$core$IIndexed$_nth$arity$2$(null,$i__80787$$);$APP.$goog$events$unlistenByKey$$($G__80816_key$jscomp$423$$);$i__80787$$+=1}else if($c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$=$APP.$cljs$core$seq$$($c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$))$G__80815_chunk__80785_seq__80784__$1$$=$c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$,
$APP.$cljs$core$chunked_seq_QMARK_$$($G__80815_chunk__80785_seq__80784__$1$$)?($c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$=$APP.$cljs$core$_chunked_first$$($G__80815_chunk__80785_seq__80784__$1$$),$G__80814_count__80786$$=$APP.$cljs$core$_chunked_rest$$($G__80815_chunk__80785_seq__80784__$1$$),$G__80815_chunk__80785_seq__80784__$1$$=$c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$,$G__80816_key$jscomp$423$$=$APP.$cljs$core$count$$($c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$),
$c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$=$G__80814_count__80786$$,$G__80814_count__80786$$=$G__80816_key$jscomp$423$$):($G__80816_key$jscomp$423$$=$APP.$cljs$core$first$$($G__80815_chunk__80785_seq__80784__$1$$),$APP.$goog$events$unlistenByKey$$($G__80816_key$jscomp$423$$),$c__5548__auto__$jscomp$48_seq__80784_temp__5825__auto__$jscomp$429$$=$APP.$cljs$core$next$$($G__80815_chunk__80785_seq__80784__$1$$),$G__80815_chunk__80785_seq__80784__$1$$=null,$G__80814_count__80786$$=
0),$i__80787$$=0;else return null}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"text-editor "+($APP.$app$util$dom$classnames$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$ui$css_cursors$get_dynamic$$("text",$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$111$$)),!0,$APP.$cljs$cst$4987$align_top$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$2$($content$jscomp$258_props_80763$$,
"top"),"top"),$cljs$cst$5946$align_center$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$258_props_80763$$),"center"),$APP.$cljs$cst$4990$align_bottom$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($content$jscomp$258_props_80763$$),"bottom")]))??""),ref:$id$jscomp$1034_self_ref$$,style:{width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$111$$),
height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$111$$),opacity:$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($blurred$$))?0:null},onPointerDown:$on_pointer_down$jscomp$12$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$shadow$js$shim$module$0$0penpot$0draft_js$$.Editor,{stripPastedStyles:!0,onChange:$on_change$jscomp$101$$,blockRendererFn:function($JSCompiler_inline_result$jscomp$1898_p1__80762_SHARP_$$){a:switch($JSCompiler_inline_result$jscomp$1898_p1__80762_SHARP_$$.getType()){case "unstyled":$JSCompiler_inline_result$jscomp$1898_p1__80762_SHARP_$$=
{editable:!0,component:$app$main$ui$workspace$shapes$text$editor$block_component$$,props:{data:$APP.$app$util$text_editor$immutable_map__GT_map$$($JSCompiler_inline_result$jscomp$1898_p1__80762_SHARP_$$.getData()),shape:$shape__$1$jscomp$111$$}};break a;default:$JSCompiler_inline_result$jscomp$1898_p1__80762_SHARP_$$=null}return $JSCompiler_inline_result$jscomp$1898_p1__80762_SHARP_$$},handleReturn:$handle_return$$,style:{border:"1px solid red"},onFocus:$on_focus$jscomp$19$$,onBlur:$on_blur$jscomp$33_state_map$jscomp$2_text_modifier$jscomp$3_text_modifier_ref$jscomp$1$$,
ref:$on_editor$$,handlePastedText:function($G__80801$jscomp$inline_9252_state_80833__$1_text$jscomp$149$$){if($APP.$cljs$core$seq$$($G__80801$jscomp$inline_9252_state_80833__$1_text$jscomp$149$$)){var $current_block_styles_80830_style_80832$$=$APP.$app$util$text_editor$get_editor_current_block_data$$($state$jscomp$1230$$),$inline_styles_80831$$=$APP.$app$util$text_editor$get_editor_current_inline_styles$$($state$jscomp$1230$$);$current_block_styles_80830_style_80832$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$current_block_styles_80830_style_80832$$,
$inline_styles_80831$$]));$G__80801$jscomp$inline_9252_state_80833__$1_text$jscomp$149$$=$app$util$text_editor$insert_text$$($state$jscomp$1230$$,$G__80801$jscomp$inline_9252_state_80833__$1_text$jscomp$149$$,$current_block_styles_80830_style_80832$$);$G__80801$jscomp$inline_9252_state_80833__$1_text$jscomp$149$$=$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$?$handle_change$jscomp$19$$.$cljs$core$IFn$_invoke$arity$1$($G__80801$jscomp$inline_9252_state_80833__$1_text$jscomp$149$$):$handle_change$jscomp$19$$($G__80801$jscomp$inline_9252_state_80833__$1_text$jscomp$149$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$texts$update_editor_state$$($shape__$1$jscomp$111$$,$G__80801$jscomp$inline_9252_state_80833__$1_text$jscomp$149$$))}return"handled"},customStyleFn:$APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$02$$($app$main$ui$workspace$shapes$text$editor$styles_fn$$,$shape__$1$jscomp$111$$),editorState:$state$jscomp$1230$$})})}));var $app$main$ui$workspace$shapes$text$v2_editor$text_editor_html$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($align_center_QMARK__page$jscomp$173_props_80843$$){var $align_top_QMARK__render_wasm_QMARK_$jscomp$8$$=$align_center_QMARK__page$jscomp$173_props_80843$$["render-wasm?"]??!1,$shape$jscomp$1057$$=$align_center_QMARK__page$jscomp$173_props_80843$$.shape,$canvas_ref$jscomp$4$$=$align_center_QMARK__page$jscomp$173_props_80843$$["canvas-ref"],$content$jscomp$263$$=$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1057$$),
$shape_id$jscomp$172$$=$shape$jscomp$1057$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1057$$,$APP.$cljs$cst$266$id$$),$fill_color$jscomp$5$$=$app$main$ui$workspace$shapes$text$v2_editor$get_color_from_content$$($content$jscomp$263$$),$editor_ref$jscomp$2$$=(0,$APP.$rumext$v2$use_ref$$)(null),$container_ref$jscomp$4$$=(0,$APP.$rumext$v2$use_ref$$)(null);$align_center_QMARK__page$jscomp$173_props_80843$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_page$$);var $align_bottom_QMARK__objects$jscomp$817_vec__80847$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($align_center_QMARK__page$jscomp$173_props_80843$$,$APP.$cljs$cst$1636$objects$$),$frame$jscomp$83$$=$APP.$app$common$files$helpers$get_frame$cljs$0core$0IFn$0_invoke$0arity$02$$($align_bottom_QMARK__objects$jscomp$817_vec__80847$$,$shape_id$jscomp$172$$),$background_color$jscomp$3$$=$APP.$cljs$cst$2066$background$$.$cljs$core$IFn$_invoke$arity$1$($align_center_QMARK__page$jscomp$173_props_80843$$),$text_color$jscomp$3$$=function(){if($APP.$cljs$core$truth_$$($fill_color$jscomp$5$$))return $fill_color$jscomp$5$$;
var $or__5025__auto____$1$jscomp$148$$=$app$main$ui$workspace$shapes$text$v2_editor$get_default_text_color$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1611$frame$$,$frame$jscomp$83$$,$APP.$cljs$cst$3839$background_color$$,$background_color$jscomp$3$$],null));return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$148$$)?$or__5025__auto____$1$jscomp$148$$:"#000000"}();$align_bottom_QMARK__objects$jscomp$817_vec__80847$$=$app$main$ui$workspace$shapes$text$v2_editor$vertical_align_editor_classes$$($content$jscomp$263$$,
$align_top_QMARK__render_wasm_QMARK_$jscomp$8$$);$align_top_QMARK__render_wasm_QMARK_$jscomp$8$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($align_bottom_QMARK__objects$jscomp$817_vec__80847$$,0,null);$align_center_QMARK__page$jscomp$173_props_80843$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($align_bottom_QMARK__objects$jscomp$817_vec__80847$$,1,null);$align_bottom_QMARK__objects$jscomp$817_vec__80847$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($align_bottom_QMARK__objects$jscomp$817_vec__80847$$,
2,null);var $fonts$jscomp$37$$=$APP.$app$main$ui$hooks$use_equal_memo$$($APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($content$jscomp$263$$)],function(){var $extract_fn$jscomp$inline_9269$$=$APP.$cljs$core$juxt$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1763$font_id$$,$APP.$cljs$cst$1765$font_variant_id$$),$default$$jscomp$inline_9270$$=$extract_fn$jscomp$inline_9269$$($APP.$app$common$types$text$default_typography$$);return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$createAsIfByAssoc$$([$default$$jscomp$inline_9270$$]),
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($extract_fn$jscomp$inline_9269$$),$APP.$cljs$core$tree_seq$$($APP.$cljs$core$map_QMARK_$$,$APP.$cljs$cst$342$children$$,$content$jscomp$263$$))}));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($fonts$jscomp$37$$)],function(){return $app$main$ui$workspace$shapes$text$v2_editor$load_fonts_BANG_$$($fonts$jscomp$37$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$172$$)],
function(){return $app$main$ui$workspace$shapes$text$v2_editor$initialize_event_handlers$$($shape_id$jscomp$172$$,$content$jscomp$263$$,$editor_ref$jscomp$2$$,$canvas_ref$jscomp$4$$,$container_ref$jscomp$4$$,$text_color$jscomp$3$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_color$jscomp$3$$)],function(){return $APP.$app$util$dom$set_style_BANG_$$($APP.$rumext$v2$ref_val$$($container_ref$jscomp$4$$),"--text-editor-caret-color",$text_color$jscomp$3$$)});
return(0,$APP.$rumext$v2$jsx$$)("div",{ref:$container_ref$jscomp$4$$,"data-testid":"text-editor-container",style:{width:"var(--editor-container-width)",height:"var(--editor-container-height)",minWidth:"var(--editor-container-min-width, 1px)",minHeight:"var(--editor-container-min-height, 1px)"},className:""+($app$main$ui$css_cursors$get_dynamic$$("text",$APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1057$$))??"")+" main_ui_workspace_shapes_text_v2_editor__text-editor-container",
children:(0,$APP.$rumext$v2$jsx$$)("div",{role:"textbox","aria-multiline":!0,"data-x":$shape$jscomp$1057$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1057$$,$APP.$cljs$cst$1515$x$$),className:"mousetrap main_ui_workspace_shapes_text_v2_editor__text-editor-content "+(($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1057$$),$APP.$cljs$cst$1676$fixed$$)?"main_ui_workspace_shapes_text_v2_editor__grow-type-fixed":
"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1057$$),$APP.$cljs$cst$2046$auto_width$$)?"main_ui_workspace_shapes_text_v2_editor__grow-type-auto-width":"")+" "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1057$$),$APP.$cljs$cst$2045$auto_height$$)?"main_ui_workspace_shapes_text_v2_editor__grow-type-auto-height":"")+
" "+($APP.$cljs$core$truth_$$($align_top_QMARK__render_wasm_QMARK_$jscomp$8$$)?"main_ui_workspace_shapes_text_v2_editor__align-top":"")+" "+($APP.$cljs$core$truth_$$($align_center_QMARK__page$jscomp$173_props_80843$$)?"main_ui_workspace_shapes_text_v2_editor__align-center":"")+" "+($APP.$cljs$core$truth_$$($align_bottom_QMARK__objects$jscomp$817_vec__80847$$)?"main_ui_workspace_shapes_text_v2_editor__align-bottom":"")),"aria-autocomplete":"none","data-testid":"text-editor-content","data-y":$shape$jscomp$1057$$?.y??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1057$$,$APP.$cljs$cst$1516$y$$),ref:$editor_ref$jscomp$2$$,contentEditable:!0})})}),$app$main$ui$workspace$shapes$text$v2_editor$text_editor$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$((0,$APP.$rumext$v2$forward_ref$$)(function($canvas_ref$jscomp$5_props_80859$$){var $clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$125$$=$canvas_ref$jscomp$5_props_80859$$.modifiers,$shape$jscomp$1058$$=$canvas_ref$jscomp$5_props_80859$$.shape;
$canvas_ref$jscomp$5_props_80859$$=$canvas_ref$jscomp$5_props_80859$$["canvas-ref"];var $shape_id$jscomp$173$$=$shape$jscomp$1058$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1058$$,$APP.$cljs$cst$266$id$$),$modifiers__$1$jscomp$19$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$125$$,$shape_id$jscomp$173$$),$APP.$cljs$cst$1816$modifiers$$);$clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$125$$=
$APP.$app$render_wasm$api$fonts_from_text_content$$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1058$$),!1);var $fallback_families$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$){$JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$=$APP.$cljs$cst$1763$font_id$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$);
$APP.$cljs$core$truth_$$($APP.$cuerdas$core$includes_QMARK_$$($JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$,"gfont-noto-sans"))?($JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$=$APP.$cuerdas$core$replace$$($JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$,/gfont\-noto\-sans\-/,""),$JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$=
$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$)>=3?$APP.$cuerdas$core$capital$$($JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$):$APP.$cuerdas$core$upper$$($JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$)):$JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$=
"Noto Color Emoji";return $JSCompiler_inline_result$jscomp$1900_font$jscomp$51_font_id$jscomp$inline_9272_lang$jscomp$inline_9273$$},$clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$125$$);$clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$125$$="text-edition-clip"+($shape_id$jscomp$173$$??"");var $text_modifier_ref$jscomp$4_transform$jscomp$109_vec__80861$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1058$$))],
function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1058$$))}),$text_modifier$jscomp$6$$=$APP.$rumext$v2$deref$$($text_modifier_ref$jscomp$4_transform$jscomp$109_vec__80861$$),$maybe_zoom$jscomp$1$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1351$safari$$)?$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_zoom$$):null,$vbox$jscomp$42$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$vbox$$),$shape__$1$jscomp$114$$=
function(){var $G__80866__$1$$=$text_modifier$jscomp$6$$!=null?$APP.$app$main$data$workspace$texts$apply_text_modifier$$($shape$jscomp$1058$$,$text_modifier$jscomp$6$$):$shape$jscomp$1058$$;return $modifiers__$1$jscomp$19$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__80866__$1$$,$modifiers__$1$jscomp$19$$):$G__80866__$1$$}(),$render_wasm_QMARK_$jscomp$9$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),
"render-wasm/v1")});$text_modifier_ref$jscomp$4_transform$jscomp$109_vec__80861$$=$APP.$cljs$core$truth_$$($render_wasm_QMARK_$jscomp$9$$)?function(){var $map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$=$APP.$app$render_wasm$api$get_text_dimensions$cljs$0core$0IFn$0_invoke$0arity$01$$($shape_id$jscomp$173$$);$map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$=$APP.$cljs$core$__destructure_map$$($map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$);
var $max_height$jscomp$4_width$jscomp$219$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$,$APP.$cljs$cst$290$width$$),$height$jscomp$187$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$,$APP.$cljs$cst$1527$height$$);$map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_selrect$$);
var $transform$jscomp$110_vec__80868$$=$app$main$data$helpers$get_selrect$$($map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$,$shape__$1$jscomp$114$$);$map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$110_vec__80868$$,0,null);$transform$jscomp$110_vec__80868$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($transform$jscomp$110_vec__80868$$,1,null);var $selrect_height$jscomp$1$$=
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$),$selrect_width$jscomp$1$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$),$max_width$jscomp$8_overlay_width$$=$max_height$jscomp$4_width$jscomp$219$$>$selrect_width$jscomp$1$$?$max_height$jscomp$4_width$jscomp$219$$:$selrect_width$jscomp$1$$;$max_height$jscomp$4_width$jscomp$219$$=
$height$jscomp$187$$>$selrect_height$jscomp$1$$?$height$jscomp$187$$:$selrect_height$jscomp$1$$;var $viewport_width$$=function(){var $or__5025__auto__$jscomp$1369$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$42$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1369$$)?$or__5025__auto__$jscomp$1369$$:0}();$max_width$jscomp$8_overlay_width$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$114$$),
$APP.$cljs$cst$2046$auto_width$$)?$max_width$jscomp$8_overlay_width$$+$viewport_width$$:$max_width$jscomp$8_overlay_width$$;var $valign$jscomp$1$$=$APP.$cljs$cst$1773$vertical_align$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$114$$)),$y$jscomp$497$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$);return new $APP.$cljs$core$PersistentVector$$(null,
2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($map__80867_map__80867__$1_selrect$jscomp$86_selrect_transform$jscomp$2$$,$APP.$cljs$cst$1516$y$$,function(){switch($valign$jscomp$1$$){case "bottom":return $y$jscomp$497$$+($selrect_height$jscomp$1$$-$height$jscomp$187$$);case "center":return $y$jscomp$497$$+($selrect_height$jscomp$1$$-$height$jscomp$187$$)/2;default:return $y$jscomp$497$$}}(),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$290$width$$,
$max_width$jscomp$8_overlay_width$$,$APP.$cljs$cst$1527$height$$,$max_height$jscomp$4_width$jscomp$219$$,$cljs$cst$5947$selrect_width$$,$selrect_width$jscomp$1$$,$cljs$cst$5948$selrect_height$$,$selrect_height$jscomp$1$$])),$transform$jscomp$110_vec__80868$$],null)}():function(){var $bounds$jscomp$86_height$jscomp$188$$=$APP.$app$common$geom$shapes$text$shape__GT_rect$$($shape__$1$jscomp$114$$),$x$jscomp$1276$$=Math.min($bounds$jscomp$86_height$jscomp$188$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$86_height$jscomp$188$$,
$APP.$cljs$cst$1515$x$$),$shape__$1$jscomp$114$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1515$x$$)),$y$jscomp$498$$=Math.min($bounds$jscomp$86_height$jscomp$188$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$86_height$jscomp$188$$,$APP.$cljs$cst$1516$y$$),$shape__$1$jscomp$114$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1516$y$$)),$width$jscomp$220$$=Math.max($bounds$jscomp$86_height$jscomp$188$$?.width??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$86_height$jscomp$188$$,$APP.$cljs$cst$290$width$$),$shape__$1$jscomp$114$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$290$width$$));$bounds$jscomp$86_height$jscomp$188$$=Math.max($bounds$jscomp$86_height$jscomp$188$$?.height??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($bounds$jscomp$86_height$jscomp$188$$,$APP.$cljs$cst$1527$height$$),$shape__$1$jscomp$114$$?.height??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1527$height$$));return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$rect$make_rect$$.$cljs$core$IFn$_invoke$arity$4$($x$jscomp$1276$$,$y$jscomp$498$$,$width$jscomp$220$$,$bounds$jscomp$86_height$jscomp$188$$),$APP.$app$common$geom$shapes$transform_matrix$$.$cljs$core$IFn$_invoke$arity$1$($shape__$1$jscomp$114$$)],null)}();var $map__80864_map__80864__$1_style$jscomp$80$$=
$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_modifier_ref$jscomp$4_transform$jscomp$109_vec__80861$$,0,null);$map__80864_map__80864__$1_style$jscomp$80$$=$APP.$cljs$core$__destructure_map$$($map__80864_map__80864__$1_style$jscomp$80$$);var $x$jscomp$1275$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80864_map__80864__$1_style$jscomp$80$$,$APP.$cljs$cst$1515$x$$),$y$jscomp$496$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80864_map__80864__$1_style$jscomp$80$$,
$APP.$cljs$cst$1516$y$$),$width$jscomp$218$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80864_map__80864__$1_style$jscomp$80$$,$APP.$cljs$cst$290$width$$),$height$jscomp$186$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80864_map__80864__$1_style$jscomp$80$$,$APP.$cljs$cst$1527$height$$),$selrect_width$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80864_map__80864__$1_style$jscomp$80$$,$cljs$cst$5947$selrect_width$$),$selrect_height$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__80864_map__80864__$1_style$jscomp$80$$,
$cljs$cst$5948$selrect_height$$);$text_modifier_ref$jscomp$4_transform$jscomp$109_vec__80861$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_modifier_ref$jscomp$4_transform$jscomp$109_vec__80861$$,1,null);$map__80864_map__80864__$1_style$jscomp$80$$=function(){var $G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$={pointerEvents:"all"};$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$=$APP.$cljs$core$truth_$$($render_wasm_QMARK_$jscomp$9$$)?
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$,{"--editor-container-width":"auto","--editor-container-height":"auto","--editor-container-min-width":""+((1>$selrect_width$$?1:$selrect_width$$)??"")+"px","--editor-container-min-height":""+((1>$selrect_height$$?1:$selrect_height$$)??"")+"px","--fallback-families":$APP.$cljs$core$seq$$($fallback_families$$)?""+($APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(", ",
$fallback_families$$)??""):"sourcesanspro",display:"flex"}):$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$;$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$=$APP.$cljs$core$not$$($render_wasm_QMARK_$jscomp$9$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$,{"--editor-container-width":""+((1>$width$jscomp$218$$?1:$width$jscomp$218$$)??"")+"px",
"--editor-container-height":""+((1>$height$jscomp$186$$?1:$height$jscomp$186$$)??"")+"px"}):$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$;$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$=$APP.$cljs$core$not$$($render_wasm_QMARK_$jscomp$9$$)&&!$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1352$safari_16$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$,
{transform:"translate("+(($shape__$1$jscomp$114$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1515$x$$))-$x$jscomp$1275$$)+"px, "+(($shape__$1$jscomp$114$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1516$y$$))-$y$jscomp$496$$)+"px)"}):$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$;$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$=$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1351$safari$$)&&
!$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1352$safari_16$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$,{height:"100%",display:"flex",flexDirection:"column",justifyContent:$app$main$ui$workspace$shapes$text$v2_editor$shape__GT_justify$$($shape__$1$jscomp$114$$)}):$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$;$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$=
$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1358$safari_26$$)||$APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1353$safari_18$$)?$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$,{position:"fixed","transform-origin":"top left",transform:"scale("+($maybe_zoom$jscomp$1$$??"")+")"}):$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$;return $APP.$app$config$check_browser_QMARK_$$($APP.$cljs$cst$1352$safari_16$$)?
$APP.$app$util$object$merge_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$,{position:"fixed",left:0,top:($shape__$1$jscomp$114$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($shape__$1$jscomp$114$$,$APP.$cljs$cst$1516$y$$))-$y$jscomp$496$$,"transform-origin":"top left",transform:$maybe_zoom$jscomp$1$$!=null?"scale("+($maybe_zoom$jscomp$1$$??"")+")":null}):$G__80876_G__80876__$1_G__80876__$2_G__80876__$3_G__80876__$4_G__80876__$5$$}();
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"text-editor",clipPath:"url(#"+($clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$125$$??"")+")",transform:""+($text_modifier_ref$jscomp$4_transform$jscomp$109_vec__80861$$??""),"data-testid":"text-editor",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$3_fallback_fonts$jscomp$3_modifiers$jscomp$125$$,children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$x$jscomp$1275$$,y:$y$jscomp$496$$,
width:$width$jscomp$218$$,height:$height$jscomp$186$$})})}),(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$x$jscomp$1275$$,y:$y$jscomp$496$$,width:$width$jscomp$218$$,height:$height$jscomp$186$$,children:(0,$APP.$rumext$v2$jsx$$)("div",{style:$map__80864_map__80864__$1_style$jscomp$80$$,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$v2_editor$text_editor_html$$,{shape:$shape__$1$jscomp$114$$,"canvas-ref":$canvas_ref$jscomp$5_props_80859$$,"render-wasm?":$render_wasm_QMARK_$jscomp$9$$},
""+($shape_id$jscomp$173$$??""))})})]})}));var $app$util$text_svg_position$load_promises$$=$APP.$cljs$core$atom$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$core$PersistentArrayMap$EMPTY$$);var $app$main$ui$workspace$shapes$text$viewport_texts_html$text_container$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($handle_update_props_80858$$){var $shape$jscomp$1065$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_update_props_80858$$,"shape"),$on_update$jscomp$2$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_update_props_80858$$,"on-update");$handle_update_props_80858$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1065$$),
$APP.$rumext$v2$adapt$$($on_update$jscomp$2$$)],function($node$jscomp$471$$){return $node$jscomp$471$$!=null?$on_update$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$?$on_update$jscomp$2$$.$cljs$core$IFn$_invoke$arity$2$($shape$jscomp$1065$$,$node$jscomp$471$$):$on_update$jscomp$2$$($shape$jscomp$1065$$,$node$jscomp$471$$):null});return(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$shapes$text$html_text$text_shape_STAR_$$,{ref:$handle_update_props_80858$$,shape:$shape$jscomp$1065$$,growType:$APP.$cljs$cst$1776$grow_type$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1065$$)},
["shape-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1065$$))].join(""))}),$app$main$ui$workspace$shapes$text$viewport_texts_html$viewport_text_editing$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$){var $shape$jscomp$1070$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$,
"shape"),$shape_id$jscomp$176$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1070$$);$handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor_state$$);var $workspace_v2_editor_state$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_v2_editor_state$$),$workspace_editor$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_editor$$),$editor_state$jscomp$11$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$,$shape_id$jscomp$176$$),$v2_editor_state$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($workspace_v2_editor_state$$,$shape_id$jscomp$176$$);$handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape_id$jscomp$176$$)],
function(){return $APP.$app$main$refs$workspace_text_modifier_by_id$$($shape_id$jscomp$176$$)});var $text_modifier$jscomp$7$$=$APP.$rumext$v2$deref$$($handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$),$shape__$1$jscomp$115$$=function(){if($editor_state$jscomp$11$$!=null){var $G__80880__$1_JSCompiler_temp$jscomp$1912_JSCompiler_temp$jscomp$1913_content$jscomp$inline_9286$$=$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1070$$);
var $content$jscomp$inline_9291_editor_content$jscomp$inline_9287$$=$APP.$cljs$core$truth_$$($editor_state$jscomp$11$$)?$app$util$text_editor$export_content$$($editor_state$jscomp$11$$.getCurrentContent()):null;$G__80880__$1_JSCompiler_temp$jscomp$1912_JSCompiler_temp$jscomp$1913_content$jscomp$inline_9286$$=$app$main$ui$workspace$shapes$text$viewport_texts_html$update_shape_with_content$$($shape$jscomp$1070$$,$G__80880__$1_JSCompiler_temp$jscomp$1912_JSCompiler_temp$jscomp$1913_content$jscomp$inline_9286$$,
$content$jscomp$inline_9291_editor_content$jscomp$inline_9287$$)}else $G__80880__$1_JSCompiler_temp$jscomp$1912_JSCompiler_temp$jscomp$1913_content$jscomp$inline_9286$$=$shape$jscomp$1070$$;if($v2_editor_state$$!=null&&$workspace_editor$$!=null){$content$jscomp$inline_9291_editor_content$jscomp$inline_9287$$=$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($G__80880__$1_JSCompiler_temp$jscomp$1912_JSCompiler_temp$jscomp$1913_content$jscomp$inline_9286$$);var $editor_content$jscomp$inline_9292$$=
$APP.$app$util$text$content$dom__GT_cljs$$($workspace_editor$$.root);$G__80880__$1_JSCompiler_temp$jscomp$1912_JSCompiler_temp$jscomp$1913_content$jscomp$inline_9286$$=$app$main$ui$workspace$shapes$text$viewport_texts_html$update_shape_with_content$$($G__80880__$1_JSCompiler_temp$jscomp$1912_JSCompiler_temp$jscomp$1913_content$jscomp$inline_9286$$,$content$jscomp$inline_9291_editor_content$jscomp$inline_9287$$,$editor_content$jscomp$inline_9292$$)}return $G__80880__$1_JSCompiler_temp$jscomp$1912_JSCompiler_temp$jscomp$1913_content$jscomp$inline_9286$$}();
$handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$=$text_modifier$jscomp$7$$!=null?function(){var $map__80881_width$jscomp$222$$=$APP.$app$main$data$workspace$texts$apply_text_modifier$$($shape__$1$jscomp$115$$,$text_modifier$jscomp$7$$),$height$jscomp$190_map__80881__$1$$=$APP.$cljs$core$__destructure_map$$($map__80881_width$jscomp$222$$);$map__80881_width$jscomp$222$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$190_map__80881__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$190_map__80881__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$190_map__80881__$1$$,$APP.$cljs$cst$1527$height$$);return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($shape__$1$jscomp$115$$,$APP.$cljs$cst$290$width$$,$map__80881_width$jscomp$222$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1527$height$$,$height$jscomp$190_map__80881__$1$$]))}():$shape__$1$jscomp$115$$;var $shape__$3$$=
$APP.$app$main$ui$hooks$use_equal_memo$$($handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$);$handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$01$$($app$main$ui$workspace$shapes$text$viewport_texts_html$update_text_modifier$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$3$$))],
function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$texts$remove_text_modifier$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape__$3$$)))}});return(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_container$$,{shape:$shape__$3$$,"on-update":$handle_update_shape$jscomp$2_props_80879_shape__$2$jscomp$13_text_modifier_ref$jscomp$5_workspace_editor_state$$})}),$app$main$ui$workspace$shapes$text$viewport_texts_html$viewport_texts$$=
(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$){var $objects$jscomp$818$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$,"objects"),$edition$jscomp$9$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$,"edition"),$modifiers$jscomp$127$$=$APP.$app$util$object$get$cljs$0core$0IFn$0_invoke$0arity$02$$($editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$,
"modifiers");$editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$818$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$common$files$helpers$text_shape_QMARK_$$,$APP.$cljs$core$second$$)),$objects$jscomp$818$$)});
var $text_shapes__$1$$=$APP.$app$main$ui$hooks$use_equal_memo$$($editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$);$editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes__$1$$),$APP.$rumext$v2$adapt$$($edition$jscomp$9$$)],function(){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes__$1$$,$edition$jscomp$9$$)});$editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$=
$APP.$app$main$ui$hooks$use_equal_memo$$($editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$);var $text_shapes_changes$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($text_shapes__$1$$),$APP.$rumext$v2$adapt$$($edition$jscomp$9$$)],function(){return $APP.$cljs$core$dissoc$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes__$1$$,$edition$jscomp$9$$)}),$text_shapes_modifiers$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($modifiers$jscomp$127$$),
$APP.$rumext$v2$adapt$$($text_shapes__$1$$)],function(){return $APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentArrayMap$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifiers__$1$jscomp$20_p__80886$$){var $id$jscomp$1042$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers__$1$jscomp$20_p__80886$$,0,null);$modifiers__$1$jscomp$20_p__80886$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($modifiers__$1$jscomp$20_p__80886$$,
1,null);var $temp__5825__auto__$jscomp$432$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($text_shapes__$1$$,$id$jscomp$1042$$);return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$432$$)?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$id$jscomp$1042$$,$APP.$app$common$data$patch_object$$.$cljs$core$IFn$_invoke$arity$2$($temp__5825__auto__$jscomp$432$$,$modifiers__$1$jscomp$20_p__80886$$)],null):null}),$modifiers$jscomp$127$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $fonts$jscomp$38_text_nodes$jscomp$1$$=
$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$0variadic$$(function($p1__80884_SHARP_$$){return $APP.$app$common$types$text$node_seq$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$app$common$types$text$is_text_node_QMARK_$$,$APP.$cljs$cst$1642$content$$.$cljs$core$IFn$_invoke$arity$1$($p1__80884_SHARP_$$))},$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vals$$($text_shapes__$1$$)]));$fonts$jscomp$38_text_nodes$jscomp$1$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentHashSet$EMPTY$$,
$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$cljs$cst$1763$font_id$$),$fonts$jscomp$38_text_nodes$jscomp$1$$);return $APP.$cljs$core$run_BANG_$$($APP.$app$main$fonts$ensure_loaded_BANG_$$,$fonts$jscomp$38_text_nodes$jscomp$1$$)});return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$viewport_text_editing$$,
{shape:$editing_shape_editing_shape__$1_props_80885_text_shapes$jscomp$4$$}):null,(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_modifiers_renderer$$,{"text-shapes":$text_shapes_modifiers$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$shapes$text$viewport_texts_html$text_changes_renderer$$,{"text-shapes":$text_shapes_changes$$})]})},function($new_props$jscomp$16$$,$old_props$jscomp$15$$){return $new_props$jscomp$16$$.objects===$old_props$jscomp$15$$.objects&&
$new_props$jscomp$16$$.modifiers===$old_props$jscomp$15$$.modifiers&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props$jscomp$16$$.edition,$old_props$jscomp$15$$.edition)});var $app$main$ui$workspace$top_toolbar$image_upload_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){var $ref$jscomp$58$$=(0,$APP.$rumext$v2$use_ref$$)(null),$file_id$jscomp$434$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$current_file_id$$),$on_click$jscomp$56$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()]));
return $APP.$app$util$dom$click$$($APP.$rumext$v2$ref_val$$($ref$jscomp$58$$))}),$on_selected$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$434$$)],function($blobs$jscomp$3_params$jscomp$433$$){var $vbox$jscomp$43_y$jscomp$499$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$vbox$$),$x$jscomp$1277$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$43_y$jscomp$499$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$43_y$jscomp$499$$)/
2;$vbox$jscomp$43_y$jscomp$499$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$43_y$jscomp$499$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox$jscomp$43_y$jscomp$499$$)/2;$blobs$jscomp$3_params$jscomp$433$$=new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$1649$file_id$$,$file_id$jscomp$434$$,$APP.$cljs$cst$3748$blobs$$,$APP.$cljs$core$seq$$($blobs$jscomp$3_params$jscomp$433$$),$APP.$cljs$cst$1681$position$$,$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($x$jscomp$1277$$,
$vbox$jscomp$43_y$jscomp$499$$)],null);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$media$upload_media_workspace$$($blobs$jscomp$3_params$jscomp$433$$))});return(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsxs$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.image",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4949$insert_image$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.image",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4949$insert_image$$)])),onClick:$on_click$jscomp$56$$,className:"main_ui_workspace_top_toolbar__main-toolbar-options-button",children:[$APP.$app$main$ui$icons$img$$,(0,$APP.$rumext$v2$jsx$$)($APP.$app$main$ui$components$file_uploader$file_uploader$$,{"input-id":"image-upload",
accept:$APP.$app$main$data$workspace$media$accept_image_types$$,multi:!0,ref:$ref$jscomp$58$$,"on-selected":$on_selected$jscomp$1$$})]})})}),$app$main$ui$workspace$top_toolbar$toolbar_hidden_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$02$$(function($edition$jscomp$10_state$jscomp$1231$$){var $visibility$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$10_state$jscomp$1231$$,$APP.$cljs$cst$3803$hide_toolbar$$),$path_edit_state$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$10_state$jscomp$1231$$,
$APP.$cljs$cst$1940$edit_path$$),$selected$jscomp$190$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$10_state$jscomp$1231$$,$APP.$cljs$cst$1938$selected$$);$edition$jscomp$10_state$jscomp$1231$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($edition$jscomp$10_state$jscomp$1231$$,$APP.$cljs$cst$2207$edition$$);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected$jscomp$190$$),1)&&$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($path_edit_state$$,
$edition$jscomp$10_state$jscomp$1231$$)!=null?!0:$visibility$$},$APP.$app$main$refs$workspace_local$$),$app$main$ui$workspace$top_toolbar$top_toolbar_STAR_$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($drawtool_props_80882$$){var $layout$jscomp$30$$=$drawtool_props_80882$$.layout;$drawtool_props_80882$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_drawing_tool$$);var $edition$jscomp$11$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$),$profile$jscomp$86_read_only_QMARK_$jscomp$23$$=
$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$props$jscomp$384_test_tooltip_board_text$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($profile$jscomp$86_read_only_QMARK_$jscomp$23$$,$APP.$cljs$cst$575$props$$);$profile$jscomp$86_read_only_QMARK_$jscomp$23$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$);var $rulers_QMARK_$jscomp$4$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$rulers_QMARK_$$),$hide_toolbar_QMARK_$$=$APP.$rumext$v2$deref$$($app$main$ui$workspace$top_toolbar$toolbar_hidden_ref$$),
$interrupt$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()]))}),$select_drawtool$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$659$$){var $tool$jscomp$3$$=$APP.$cljs$core$keyword$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_data$$($APP.$app$util$dom$get_current_target$$($event$jscomp$659$$),
"tool"));$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2177$interrupt$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$workspace$edition$clear_edition_mode$$()]));return $APP.$app$util$timers$schedule$cljs$0core$0IFn$0_invoke$0arity$02$$(100,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$drawing$select_for_drawing$$($tool$jscomp$3$$))})}),$toggle_debug_panel$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout$jscomp$30$$)],function(){$APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$cljs$cst$5729$collapse_left_sidebar$$)&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($cljs$cst$5729$collapse_left_sidebar$$));return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$workspace$layout$remove_layout_flag$$($APP.$cljs$cst$2961$shortcuts$$),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$core$vary_meta$cljs$0core$0IFn$0_invoke$0arity$04$$((0,$APP.$app$main$data$workspace$toggle_layout_flag$$)($cljs$cst$5753$debug_panel$$),$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace-left-toolbar")]))}),$toggle_toolbar$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$660$$){$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$660$$));
return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$common$toggle_toolbar_visibility$$())});$props$jscomp$384_test_tooltip_board_text$$=$APP.$cljs$core$not$$($APP.$cljs$cst$3801$workspace_visited$$.$cljs$core$IFn$_invoke$arity$1$($props$jscomp$384_test_tooltip_board_text$$))?$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.frame-first-time",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4906$draw_frame$$)])):
$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.frame",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4906$draw_frame$$)]));return $profile$jscomp$86_read_only_QMARK_$jscomp$23$$?null:(0,$APP.$rumext$v2$jsxs$$)("aside",{className:"main_ui_workspace_top_toolbar__main-toolbar "+($APP.$cljs$core$not$$($rulers_QMARK_$jscomp$4$$)?"main_ui_workspace_top_toolbar__main-toolbar-no-rulers":"")+
" "+($APP.$cljs$core$truth_$$($hide_toolbar_QMARK_$$)?"main_ui_workspace_top_toolbar__main-toolbar-hidden":""),children:[(0,$APP.$rumext$v2$jsxs$$)("ul",{"data-testid":"toolbar-options",className:"main_ui_workspace_top_toolbar__main-toolbar-options",children:[(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.move",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$1804$move$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.move",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$1804$move$$)])),onClick:$interrupt$$,className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($drawtool_props_80882$$==null&&$APP.$cljs$core$not$$($edition$jscomp$11$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$move$$})}),
(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$props$jscomp$384_test_tooltip_board_text$$,"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.frame",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4906$draw_frame$$)])),onClick:$select_drawtool$$,"data-tool":"frame","data-testid":"artboard-btn",
className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80882$$,$APP.$cljs$cst$1611$frame$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$board$$})}),(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.rect",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4927$draw_rect$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.rect",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4927$draw_rect$$)])),onClick:$select_drawtool$$,"data-tool":"rect","data-testid":"rect-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80882$$,$APP.$cljs$cst$1616$rect$$)?
"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$rectangle$$})}),(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.ellipse",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4909$draw_ellipse$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.ellipse",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4909$draw_ellipse$$)])),onClick:$select_drawtool$$,"data-tool":"circle","data-testid":"ellipse-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80882$$,$APP.$cljs$cst$1422$circle$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$ellipse$$})}),
(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.text",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4925$draw_text$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.text",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4925$draw_text$$)])),
onClick:$select_drawtool$$,"data-tool":"text",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80882$$,$APP.$cljs$cst$1593$text$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$text$$})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$top_toolbar$image_upload_STAR_$$,{}),(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.curve",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4995$draw_curve$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.curve",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4995$draw_curve$$)])),onClick:$select_drawtool$$,"data-tool":"curve","data-testid":"curve-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+
($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80882$$,$APP.$cljs$cst$2060$curve$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$curve$$})}),(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.path",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4928$draw_path$$)])),
"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.path",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$4928$draw_path$$)])),onClick:$select_drawtool$$,"data-tool":"path","data-testid":"path-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($drawtool_props_80882$$,$APP.$cljs$cst$296$path$$)?"main_ui_workspace_top_toolbar__selected":
""),children:$APP.$app$main$ui$icons$path$$})}),$APP.$app$main$features$active_feature_QMARK_$$($APP.$cljs$core$_deref$$($APP.$app$main$store$state$$),"plugins/runtime")?(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.plugins",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$3222$plugins$$)])),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("workspace.toolbar.plugins",
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$shortcuts$get_tooltip$$($APP.$cljs$cst$3222$plugins$$)])),onClick:function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$app$main$data$event$event$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2319$app_DOT_main_DOT_data_DOT_event_SLASH_name$$,"open-plugins-manager",$APP.$cljs$cst$2286$app_DOT_main_DOT_data_DOT_event_SLASH_origin$$,"workspace:toolbar"],
null)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$app$main$data$modal$show$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$5006$plugin_management$$,$APP.$cljs$core$PersistentArrayMap$EMPTY$$)]))},"data-tool":"plugins","data-testid":"plugins-btn",className:"main_ui_workspace_top_toolbar__main-toolbar-options-button",children:$APP.$app$main$ui$icons$puzzle$$})}):null,$APP.$cljs$core$truth_$$($APP.$cljs$core$_STAR_assert_STAR_$$)?(0,$APP.$rumext$v2$jsx$$)("li",{children:(0,$APP.$rumext$v2$jsx$$)("button",
{title:"Debugging tool",onClick:$toggle_debug_panel$$,className:"main_ui_workspace_top_toolbar__main-toolbar-options-button "+($APP.$cljs$core$contains_QMARK_$$($layout$jscomp$30$$,$cljs$cst$5753$debug_panel$$)?"main_ui_workspace_top_toolbar__selected":""),children:$APP.$app$main$ui$icons$bug$$})}):null,$APP.$cljs$core$contains_QMARK_$$($APP.$app$config$flags$$,$APP.$cljs$cst$1237$mcp$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$top_toolbar$mcp_indicator_STAR_$$,{}):null]})]}),(0,$APP.$rumext$v2$jsx$$)("button",
{title:$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.toggle-toolbar"),"aria-label":$APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$1$("workspace.toolbar.toggle-toolbar"),onClick:$toggle_toolbar$$,className:"main_ui_workspace_top_toolbar__toolbar-handler",children:(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_top_toolbar__toolbar-handler-btn"})})]})});var $app$main$ui$workspace$viewport$actions$invalid_paste_targets$$=new $APP.$cljs$core$PersistentHashSet$$(null,new $APP.$cljs$core$PersistentArrayMap$$(null,2,["INPUT",null,"TEXTAREA",null],null),null);var $app$main$ui$workspace$viewport$comments$comments_layer_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_80936_vport$jscomp$11$$){var $zoom$jscomp$91$$=$props_80936_vport$jscomp$11$$.zoom,$file_id$jscomp$435$$=$props_80936_vport$jscomp$11$$.fileId,$vbox$jscomp$44_vport_w$$=$props_80936_vport$jscomp$11$$.vbox,$page_id$jscomp$452$$=$props_80936_vport$jscomp$11$$.pageId;$props_80936_vport$jscomp$11$$=$props_80936_vport$jscomp$11$$.vport;var $pos_x$jscomp$6_vbox_x$jscomp$1$$=
$vbox$jscomp$44_vport_w$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$44_vport_w$$,$APP.$cljs$cst$1515$x$$),$pos_y$jscomp$6_vbox_y$jscomp$1$$=$vbox$jscomp$44_vport_w$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($vbox$jscomp$44_vport_w$$,$APP.$cljs$cst$1516$y$$);$vbox$jscomp$44_vport_w$$=$props_80936_vport$jscomp$11$$?.width??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80936_vport$jscomp$11$$,$APP.$cljs$cst$290$width$$);var $vport_h$$=$props_80936_vport$jscomp$11$$?.height??
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($props_80936_vport$jscomp$11$$,$APP.$cljs$cst$1527$height$$);$pos_x$jscomp$6_vbox_x$jscomp$1$$=-$pos_x$jscomp$6_vbox_x$jscomp$1$$*$zoom$jscomp$91$$;$pos_y$jscomp$6_vbox_y$jscomp$1$$=-$pos_y$jscomp$6_vbox_y$jscomp$1$$*$zoom$jscomp$91$$;var $profile$jscomp$87$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$profile$$),$local$jscomp$32$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$comments_local$$),$threads_map$jscomp$7$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$threads$$),
$threads$jscomp$12$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($threads_map$jscomp$7$$),$APP.$rumext$v2$adapt$$($local$jscomp$32$$),$APP.$rumext$v2$adapt$$($profile$jscomp$87$$),$APP.$rumext$v2$adapt$$($page_id$jscomp$452$$)],function(){return $APP.$app$main$data$comments$apply_filters$$($local$jscomp$32$$,$profile$jscomp$87$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80935_SHARP_$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$2051$page_id$$.$cljs$core$IFn$_invoke$arity$1$($p1__80935_SHARP_$$),
$page_id$jscomp$452$$)},$APP.$cljs$core$vals$$($threads_map$jscomp$7$$)))}),$viewport$jscomp$7$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$variadic$($props_80936_vport$jscomp$11$$,$APP.$cljs$cst$1655$offset_x$$,$pos_x$jscomp$6_vbox_x$jscomp$1$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1656$offset_y$$,$pos_y$jscomp$6_vbox_y$jscomp$1$$])),$on_draft_cancel$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$2177$interrupt$$)}),
$on_draft_submit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($draft$jscomp$3$$){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$comments$create_thread_on_workspace$cljs$0core$0IFn$0_invoke$0arity$03$$($draft$jscomp$3$$,$APP.$cljs$core$identity$$,!0))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id$jscomp$435$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$comments$initialize_comments$$($file_id$jscomp$435$$));
return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$4341$app_DOT_main_DOT_data_DOT_workspace_DOT_comments_SLASH_finalize$$)}});return(0,$APP.$rumext$v2$jsx$$)("div",{className:"main_ui_workspace_viewport_comments__comments-section",children:(0,$APP.$rumext$v2$jsx$$)("div",{id:"comments",style:{width:""+($vbox$jscomp$44_vport_w$$??"")+"px",height:""+($vport_h$$??"")+"px"},className:"main_ui_workspace_viewport_comments__workspace-comments-container",
children:(0,$APP.$rumext$v2$jsxs$$)("div",{style:{transform:"translate("+($pos_x$jscomp$6_vbox_x$jscomp$1$$??"")+"px, "+($pos_y$jscomp$6_vbox_y$jscomp$1$$??"")+"px)"},className:"main_ui_workspace_viewport_comments__threads",children:[$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$215$$,$JSCompiler_inline_result$jscomp$1919_thread_group$jscomp$3$$){var $JSCompiler_temp_const$jscomp$1917$$=$out_arr__44092__auto__$jscomp$215$$.push,$group_QMARK_$jscomp$inline_9336$$=
$APP.$cljs$core$count$$($JSCompiler_inline_result$jscomp$1919_thread_group$jscomp$3$$)>1,$thread$jscomp$inline_9337$$=$APP.$cljs$core$first$$($JSCompiler_inline_result$jscomp$1919_thread_group$jscomp$3$$);$JSCompiler_inline_result$jscomp$1919_thread_group$jscomp$3$$=$group_QMARK_$jscomp$inline_9336$$?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$comments$comment_floating_group_wrapper_STAR_$$,{threadGroup:$JSCompiler_inline_result$jscomp$1919_thread_group$jscomp$3$$,zoom:$zoom$jscomp$91$$},
$APP.$cljs$cst$3479$seqn$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$inline_9337$$)):(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$comments$comment_floating_bubble_wrapper_STAR_$$,{thread:$thread$jscomp$inline_9337$$,zoom:$zoom$jscomp$91$$,isOpen:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$inline_9337$$),$APP.$cljs$cst$3487$open$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$32$$))},$APP.$cljs$cst$3479$seqn$$.$cljs$core$IFn$_invoke$arity$1$($thread$jscomp$inline_9337$$));
$JSCompiler_temp_const$jscomp$1917$$.call($out_arr__44092__auto__$jscomp$215$$,$JSCompiler_inline_result$jscomp$1919_thread_group$jscomp$3$$);return $out_arr__44092__auto__$jscomp$215$$},[],$APP.$app$main$ui$comments$group_bubbles$cljs$0core$0IFn$0_invoke$0arity$04$$($zoom$jscomp$91$$,$threads$jscomp$12$$,$APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$PersistentVector$EMPTY$$)),function(){var $temp__5825__auto__$jscomp$440_temp__5825__auto____$1$jscomp$24$$=$APP.$cljs$cst$3487$open$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$32$$);
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$440_temp__5825__auto____$1$jscomp$24$$)?($temp__5825__auto__$jscomp$440_temp__5825__auto____$1$jscomp$24$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($threads_map$jscomp$7$$,$temp__5825__auto__$jscomp$440_temp__5825__auto____$1$jscomp$24$$),$APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$440_temp__5825__auto____$1$jscomp$24$$)?$APP.$cljs$core$seq$$($APP.$app$main$data$comments$apply_filters$$($local$jscomp$32$$,$profile$jscomp$87$$,
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$temp__5825__auto__$jscomp$440_temp__5825__auto____$1$jscomp$24$$],null)))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$comments$comment_floating_thread_wrapper_STAR_$$,{thread:$temp__5825__auto__$jscomp$440_temp__5825__auto____$1$jscomp$24$$,viewport:$viewport$jscomp$7$$,zoom:$zoom$jscomp$91$$}):null:null):null}(),function(){var $temp__5825__auto__$jscomp$441$$=$APP.$cljs$cst$3488$draft$$.$cljs$core$IFn$_invoke$arity$1$($local$jscomp$32$$);
return $APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$441$$)?$APP.$rumext$v2$jsx$$($APP.$app$main$ui$comments$comment_floating_thread_draft_STAR_$$,{draft:$temp__5825__auto__$jscomp$441$$,onCancel:$on_draft_cancel$jscomp$1$$,onSubmit:$on_draft_submit$jscomp$1$$,viewport:$viewport$jscomp$7$$,zoom:$zoom$jscomp$91$$}):null}()]})})})});var $app$main$ui$workspace$viewport$debug$debug_drop_zones_STAR_$$=function($p1__80960_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__80960_SHARP_$$,function($new_props_80963$$,$old_props_80964$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80963$$.objects,$old_props_80964$$.objects)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80963$$["selected-shapes"],$old_props_80964$$["selected-shapes"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80963$$["hover-top-frame-id"],
$old_props_80964$$["hover-top-frame-id"])})}(function($bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$){var $selected_shapes$jscomp$32$$=$bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$.selectedShapes,$hover_top_frame_id$jscomp$3_shape$jscomp$1077$$=$bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$.hoverTopFrameId,$zoom$jscomp$94$$=$bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$.zoom,$objects$jscomp$823$$=
$bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$.objects;$bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($selected_shapes$jscomp$32$$),1)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1611$frame$$,$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$first$$($selected_shapes$jscomp$32$$)))?$APP.$cljs$core$first$$($selected_shapes$jscomp$32$$):
null;$hover_top_frame_id$jscomp$3_shape$jscomp$1077$$=$APP.$cljs$core$truth_$$($bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$)?$bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$823$$,$hover_top_frame_id$jscomp$3_shape$jscomp$1077$$);$bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$=$APP.$app$common$data$lazy_map$$($APP.$cljs$core$keys$$($objects$jscomp$823$$),
function($p1__80961_SHARP_$$){return $APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$823$$,$p1__80961_SHARP_$$),$APP.$cljs$cst$1609$points$$)});return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hover_top_frame_id$jscomp$3_shape$jscomp$1077$$)?$APP.$cljs$cst$1620$layout$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$3_shape$jscomp$1077$$):$hover_top_frame_id$jscomp$3_shape$jscomp$1077$$)?($bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$=
$APP.$app$common$geom$shapes$flex_layout$drop_area$get_drop_areas$$($hover_top_frame_id$jscomp$3_shape$jscomp$1077$$,$objects$jscomp$823$$,$bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$),(0,$APP.$rumext$v2$jsx$$)("g",{className:"debug-layout",pointerEvents:"none",transform:$APP.$app$common$geom$shapes$transform_str$$.$cljs$core$IFn$_invoke$arity$1$($hover_top_frame_id$jscomp$3_shape$jscomp$1077$$),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$218$$,
$drop_area_p__80965$$){var $idx$jscomp$131$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_area_p__80965$$,0,null);$drop_area_p__80965$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($drop_area_p__80965$$,1,null);$out_arr__44092__auto__$jscomp$218$$.push((0,$APP.$rumext$v2$jsxs$$)("g",{className:"drop-area",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$),
width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$),style:{fill:"blue",fillOpacity:.3,stroke:"red",strokeWidth:$zoom$jscomp$94$$/1,strokeDasharray:""+3/$zoom$jscomp$94$$+" "+6/$zoom$jscomp$94$$}}),(0,$APP.$rumext$v2$jsx$$)("text",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$),
width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$),alignmentBaseline:"hanging",fill:"black",children:$APP.$cljs$cst$1801$index$$.$cljs$core$IFn$_invoke$arity$1$($drop_area_p__80965$$)})]},"drop-area-"+($idx$jscomp$131$$??"")));return $out_arr__44092__auto__$jscomp$218$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($bounds$jscomp$89_drop_areas$jscomp$2_props_80962_selected_frame$jscomp$3$$))})):
null}),$app$main$ui$workspace$viewport$debug$shape_parent_bound_STAR_$$=function($p1__80970_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__80970_SHARP_$$,function($new_props_80973$$,$old_props_80974$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80973$$.shape,$old_props_80974$$.shape)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_80973$$.parent,$old_props_80974$$.parent)})}(function($i1$jscomp$4_props_80972$$){var $zoom$jscomp$95$$=$i1$jscomp$4_props_80972$$.zoom,
$i2$jscomp$4_parent$jscomp$303$$=$i1$jscomp$4_props_80972$$.parent,$i4$jscomp$1_vec__80976$$=$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80972$$.shape),$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($i2$jscomp$4_parent$jscomp$303$$));$i1$jscomp$4_props_80972$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i4$jscomp$1_vec__80976$$,0,null);$i2$jscomp$4_parent$jscomp$303$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i4$jscomp$1_vec__80976$$,
1,null);var $i3$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i4$jscomp$1_vec__80976$$,2,null);$i4$jscomp$1_vec__80976$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($i4$jscomp$1_vec__80976$$,3,null);return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)("polygon",{points:$APP.$cuerdas$core$join$$.$cljs$core$IFn$_invoke$arity$2$(",",$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__80971_SHARP_$$){return""+
($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($p1__80971_SHARP_$$)??"")+","+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($p1__80971_SHARP_$$)??"")},new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$i1$jscomp$4_props_80972$$,$i2$jscomp$4_parent$jscomp$303$$,$i3$jscomp$1$$,$i4$jscomp$1_vec__80976$$],null))),style:{fill:"none",stroke:"red",strokeWidth:1/$zoom$jscomp$95$$}}),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80972$$),
y1:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80972$$),x2:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($i2$jscomp$4_parent$jscomp$303$$),y2:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($i2$jscomp$4_parent$jscomp$303$$),style:{stroke:"green",strokeWidth:1/$zoom$jscomp$95$$}}),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80972$$),y1:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($i1$jscomp$4_props_80972$$),
x2:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($i4$jscomp$1_vec__80976$$),y2:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($i4$jscomp$1_vec__80976$$),style:{stroke:"blue",strokeWidth:1/$zoom$jscomp$95$$}})]})});var $app$main$ui$workspace$viewport$frame_grid$grid_display_frame_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($clip_area_parents_ref_props_81041$$){var $zoom$jscomp$107$$=$clip_area_parents_ref_props_81041$$.zoom,$frame$jscomp$86$$=$clip_area_parents_ref_props_81041$$.frame,$transforming$$=$clip_area_parents_ref_props_81041$$.transforming,$frame_id$jscomp$157$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$86$$);$clip_area_parents_ref_props_81041$$=
$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$157$$)],function(){return $app$main$refs$shape_parents$$($frame_id$jscomp$157$$)});var $parents$jscomp$22$$=$APP.$rumext$v2$deref$$($clip_area_parents_ref_props_81041$$);$clip_area_parents_ref_props_81041$$=$app$main$ui$workspace$viewport$frame_grid$frame_clip_area$$($frame$jscomp$86$$,$parents$jscomp$22$$);var $clip_id$jscomp$6$$=""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$86$$)??
"")+"-grid-clip",$transform_QMARK_$$=function(){var $or__5025__auto__$jscomp$1391$$=$APP.$cljs$core$contains_QMARK_$$($transforming$$,$frame_id$jscomp$157$$);return $or__5025__auto__$jscomp$1391$$?$or__5025__auto__$jscomp$1391$$:$APP.$cljs$core$some$$(function($p1__81040_SHARP_$$){return $APP.$cljs$core$contains_QMARK_$$($transforming$$,$p1__81040_SHARP_$$)},$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$266$id$$,$parents$jscomp$22$$))}();return $APP.$cljs$core$truth_$$($transform_QMARK_$$)?
null:(0,$APP.$rumext$v2$jsxs$$)("g",{clipPath:"url(#"+($clip_id$jscomp$6$$??"")+")",children:[(0,$APP.$rumext$v2$jsx$$)("defs",{children:(0,$APP.$rumext$v2$jsx$$)("clipPath",{id:$clip_id$jscomp$6$$,children:(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($clip_area_parents_ref_props_81041$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($clip_area_parents_ref_props_81041$$),width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($clip_area_parents_ref_props_81041$$),
height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($clip_area_parents_ref_props_81041$$)})})}),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$225$$,$p__81046$$){var $index$jscomp$566$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81046$$,0,null),$grid$jscomp$19$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81046$$,1,null);$out_arr__44092__auto__$jscomp$225$$.push(function(){var $props$jscomp$387$$=
{key:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$86$$)),"-grid-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($index$jscomp$566$$)].join(""),frame:$frame$jscomp$86$$,zoom:$zoom$jscomp$107$$,grid:$grid$jscomp$19$$},$G__81050_G__81050__$1$$=$APP.$cljs$cst$139$type$$.$cljs$core$IFn$_invoke$arity$1$($grid$jscomp$19$$);$G__81050_G__81050__$1$$=$G__81050_G__81050__$1$$ instanceof $APP.$cljs$core$Keyword$$?$G__81050_G__81050__$1$$.$fqn$:
null;switch($G__81050_G__81050__$1$$){case "square":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$frame_grid$square_grid_STAR_$$,$props$jscomp$387$$);case "column":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$frame_grid$layout_grid_STAR_$$,$props$jscomp$387$$);case "row":return(0,$APP.$rumext$v2$create_element$$)($app$main$ui$workspace$viewport$frame_grid$layout_grid_STAR_$$,$props$jscomp$387$$);default:throw Error(["No matching clause: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($G__81050_G__81050__$1$$)].join(""));}}());return $out_arr__44092__auto__$jscomp$225$$},[],$APP.$cljs$core$map_indexed$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$core$vector$$,$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1949$display$$,$APP.$cljs$cst$2058$grids$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$86$$))))]})}),$app$main$ui$workspace$viewport$frame_grid$frame_grid_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($frames$jscomp$32_props_81055$$){var $zoom$jscomp$108$$=
$frames$jscomp$32_props_81055$$.zoom,$clip_rulers$$=$frames$jscomp$32_props_81055$$.clipRulers??!1,$transform$jscomp$113$$=$frames$jscomp$32_props_81055$$.transform,$selected$jscomp$197$$=$frames$jscomp$32_props_81055$$.selected,$vbox$jscomp$54$$=$frames$jscomp$32_props_81055$$.vbox,$focus$jscomp$18$$=$frames$jscomp$32_props_81055$$.focus;$frames$jscomp$32_props_81055$$=$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($app$main$ui$workspace$viewport$frame_grid$has_grid_QMARK_$$,$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_frames$$));
var $transforming$jscomp$1$$=$transform$jscomp$113$$!=null?$selected$jscomp$197$$:null;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"grid-display",style:{pointerEvents:"none"},clipPath:$APP.$cljs$core$truth_$$($clip_rulers$$)?"url(#clip-frame-grid)":null,children:[$APP.$cljs$core$truth_$$($clip_rulers$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$rulers$rulers_clip_path_STAR_$$,{id:"clip-frame-grid",vbox:$vbox$jscomp$54$$,zoom:$zoom$jscomp$108$$}):null,$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$226$$,
$frame$jscomp$87$$){$out_arr__44092__auto__$jscomp$226$$.push($APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$87$$,0))&&($APP.$cljs$core$empty_QMARK_$$($focus$jscomp$18$$)||$APP.$cljs$core$contains_QMARK_$$($focus$jscomp$18$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$87$$)))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$frame_grid$grid_display_frame_STAR_$$,{zoom:$zoom$jscomp$108$$,frame:$frame$jscomp$87$$,
transforming:$transforming$jscomp$1$$},["grid-",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$87$$))].join("")):null);return $out_arr__44092__auto__$jscomp$226$$},[],$frames$jscomp$32_props_81055$$)]})});var $app$main$ui$workspace$viewport$gradients$gradient_handlers_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_81059_shape$jscomp$1083_shape_ref$jscomp$3$$){var $zoom$jscomp$112$$=$props_81059_shape$jscomp$1083_shape_ref$jscomp$3$$.zoom,$id$jscomp$1051$$=$props_81059_shape$jscomp$1083_shape_ref$jscomp$3$$.id;$props_81059_shape$jscomp$1083_shape_ref$jscomp$3$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($id$jscomp$1051$$)],
function(){return $app$main$refs$object_by_id$$($id$jscomp$1051$$)});$props_81059_shape$jscomp$1083_shape_ref$jscomp$3$$=$APP.$rumext$v2$deref$$($props_81059_shape$jscomp$1083_shape_ref$jscomp$3$$);var $editing_stop$jscomp$4_state$jscomp$1234$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$colorpicker$$),$gradient$jscomp$30$$=$APP.$cljs$cst$1730$gradient$$.$cljs$core$IFn$_invoke$arity$1$($editing_stop$jscomp$4_state$jscomp$1234$$),$stops$jscomp$23$$=$APP.$app$main$features$use_feature$$("render-wasm/v1")?
$APP.$cljs$core$vec$$($APP.$cljs$core$take$$.$cljs$core$IFn$_invoke$arity$2$(16,$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($editing_stop$jscomp$4_state$jscomp$1234$$))):$APP.$cljs$cst$1739$stops$$.$cljs$core$IFn$_invoke$arity$1$($editing_stop$jscomp$4_state$jscomp$1234$$);$editing_stop$jscomp$4_state$jscomp$1234$$=$APP.$cljs$cst$4229$editing_stop$$.$cljs$core$IFn$_invoke$arity$1$($editing_stop$jscomp$4_state$jscomp$1234$$);return $gradient$jscomp$30$$!=null&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1051$$,
$APP.$cljs$cst$2554$shape_id$$.$cljs$core$IFn$_invoke$arity$1$($gradient$jscomp$30$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$gradients$gradient_handlers_impl_STAR_$$,{zoom:$zoom$jscomp$112$$,gradient:$gradient$jscomp$30$$,stops:$stops$jscomp$23$$,editing:$editing_stop$jscomp$4_state$jscomp$1234$$,shape:$props_81059_shape$jscomp$1083_shape_ref$jscomp$3$$}):null});var $app$main$ui$workspace$viewport$grid_layout_editor$grid_cell$$=function($component__44608__auto__$jscomp$1$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($component__44608__auto__$jscomp$1$$,function($new_props_81107$$,$old_props_81108$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81107$$.zoom,$old_props_81108$$.zoom)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81107$$["on-clear-modifiers"],$old_props_81108$$["on-clear-modifiers"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81107$$["on-set-modifiers"],
$old_props_81108$$["on-set-modifiers"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81107$$.shape,$old_props_81108$$.shape)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81107$$["layout-data"],$old_props_81108$$["layout-data"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81107$$.cell,$old_props_81108$$.cell)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81107$$["selected?"],$old_props_81108$$["selected?"])&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81107$$["hover?"],
$old_props_81108$$["hover?"])})}(function($cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$){var $layout_data$jscomp$20$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$["layout-data"],$selected_QMARK_$jscomp$22$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$["selected?"],$cell$jscomp$47$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$.cell,$hover_QMARK_$jscomp$10$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$["hover?"],$zoom$jscomp$116$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$.zoom,
$on_clear_modifiers$jscomp$1$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$["on-clear-modifiers"],$on_set_modifiers$jscomp$1$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$["on-set-modifiers"],$shape$jscomp$1086$$=$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$.shape;$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$=$APP.$app$common$geom$shapes$grid_layout$positions$cell_bounds$$($layout_data$jscomp$20$$,$cell$jscomp$47$$);var $cell_origin$jscomp$3_handle_pointer_leave$$=
$APP.$app$common$geom$shapes$points$origin$$($cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$),$cell_width$jscomp$3$$=$APP.$app$common$geom$shapes$points$width_points$$($cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$),$cell_height$jscomp$1$$=$APP.$app$common$geom$shapes$points$height_points$$($cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$),$cell_center$jscomp$1$$=$APP.$app$common$geom$shapes$common$points__GT_center$$($cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$),
$cell_origin__$1$jscomp$1$$=$APP.$app$common$geom$point$transform$$($cell_origin$jscomp$3_handle_pointer_leave$$,$APP.$app$common$geom$matrix$transform_in$$($cell_center$jscomp$1$$,$APP.$cljs$cst$1793$transform_inverse$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$)));$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$))],
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$hover_grid_cell$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),!0))});$cell_origin$jscomp$3_handle_pointer_leave$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$hover_grid_cell$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),!1))});var $handle_pointer_down$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$)),
$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)),$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$22$$)],function($JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$){if($app$util$dom$left_mouse_QMARK_$$($JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$))if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$22$$)?
$APP.$app$util$keyboard$mod_QMARK_$$($JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$)||$JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$.shiftKey:$selected_QMARK_$jscomp$22$$))$JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$remove_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)));else if($APP.$cljs$core$not$$($selected_QMARK_$jscomp$22$$)&&$APP.$app$util$keyboard$mod_QMARK_$$($JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$)){$JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$=
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$;var $JSCompiler_inline_result$jscomp$11254_grid_id$jscomp$inline_14003$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$);var $cell_id$jscomp$inline_14004$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$);$JSCompiler_inline_result$jscomp$11254_grid_id$jscomp$inline_14003$$=$app$main$data$workspace$grid_layout$editor$add_to_selection$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_inline_result$jscomp$11254_grid_id$jscomp$inline_14003$$,
$cell_id$jscomp$inline_14004$$,!1);$JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$=$JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$.call($APP.$app$main$store$emit_BANG_$$,$JSCompiler_inline_result$jscomp$11254_grid_id$jscomp$inline_14003$$)}else $JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$=
$APP.$cljs$core$not$$($selected_QMARK_$jscomp$22$$)&&$JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$.shiftKey?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$add_to_selection$cljs$0core$0IFn$0_invoke$0arity$03$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),
!0)):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$set_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)));else $JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$=null;return $JSCompiler_temp$jscomp$11249_JSCompiler_temp$jscomp$11250_JSCompiler_temp$jscomp$11251_JSCompiler_temp_const$jscomp$11252_event$jscomp$696$$}),
$handle_context_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$)),$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)),$APP.$rumext$v2$adapt$$($selected_QMARK_$jscomp$22$$)],function($event$jscomp$697_position$jscomp$227$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$697_position$jscomp$227$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$697_position$jscomp$227$$);
$event$jscomp$697_position$jscomp$227$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$697_position$jscomp$227$$);return $APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$22$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_grid_cell_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$position$$,$event$jscomp$697_position$jscomp$227$$,$APP.$cljs$cst$4487$grid_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$)],
null))):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$workspace$grid_layout$editor$set_selection$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$),$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$show_grid_cell_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$position$$,$event$jscomp$697_position$jscomp$227$$,
$APP.$cljs$cst$4487$grid_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$)],null))]))});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"cell-editor",children:[$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3077$grid_cells$$)?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"debug-cell",pointerEvents:"none",transform:""+($APP.$app$common$geom$matrix$transform_in$$($cell_center$jscomp$1$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$))??
""),children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),width:$cell_width$jscomp$3$$,height:$cell_height$jscomp$1$$,fill:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),$APP.$cljs$cst$1677$auto$$)?"green":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),
$APP.$cljs$cst$1678$manual$$)?"red":$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$),$APP.$cljs$cst$1679$area$$)?"yellow":"black",fillOpacity:.2}),$APP.$cljs$core$seq$$($APP.$cljs$cst$1619$shapes$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$))?(0,$APP.$rumext$v2$jsx$$)("circle",{cx:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+$cell_width$jscomp$3$$+-(7/$zoom$jscomp$116$$),
cy:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+7/$zoom$jscomp$116$$,r:5/$zoom$jscomp$116$$,fill:"red"}):null]}):null,(0,$APP.$rumext$v2$jsx$$)("rect",{width:$cell_width$jscomp$3$$,height:$cell_height$jscomp$1$$,className:$APP.$app$util$dom$classnames$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$(["main_ui_workspace_viewport_grid_layout_editor__grid-cell-outline",!0,"main_ui_workspace_viewport_grid_layout_editor__hover",
$hover_QMARK_$jscomp$10$$,"main_ui_workspace_viewport_grid_layout_editor__selected",$selected_QMARK_$jscomp$22$$])),x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),transform:""+($APP.$app$common$geom$matrix$transform_in$$($cell_center$jscomp$1$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$))??""),onContextMenu:$handle_context_menu$$,y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),
onPointerDown:$handle_pointer_down$jscomp$3$$,onPointerLeave:$cell_origin$jscomp$3_handle_pointer_leave$$,onPointerEnter:$cell_bounds$jscomp$5_handle_pointer_enter_props_81106$$}),$APP.$cljs$core$truth_$$($APP.$cljs$cst$1680$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$grid_cell_area_label$$,{origin:$cell_origin__$1$jscomp$1$$,width:$cell_width$jscomp$3$$,zoom:$zoom$jscomp$116$$,text:$APP.$cljs$cst$1680$area_name$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)}):
null,$APP.$cljs$core$truth_$$($selected_QMARK_$jscomp$22$$)?function(){var $handlers$jscomp$8$$=new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1567$top$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+-10/$zoom$jscomp$116$$,
$cell_width$jscomp$3$$,20/$zoom$jscomp$116$$,$APP.$cljs$cst$1661$row$$],null),new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$258$right$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+$cell_width$jscomp$3$$+-10/$zoom$jscomp$116$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),20/$zoom$jscomp$116$$,$cell_height$jscomp$1$$,$APP.$cljs$cst$216$column$$],null),new $APP.$cljs$core$PersistentVector$$(null,
6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1568$bottom$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+$cell_height$jscomp$1$$+-10/$zoom$jscomp$116$$,$cell_width$jscomp$3$$,20/$zoom$jscomp$116$$,$APP.$cljs$cst$1661$row$$],null),new $APP.$cljs$core$PersistentVector$$(null,6,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$257$left$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$)+
-10/$zoom$jscomp$116$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($cell_origin__$1$jscomp$1$$),20/$zoom$jscomp$116$$,$cell_height$jscomp$1$$,$APP.$cljs$cst$216$column$$],null)],null);return(0,$APP.$rumext$v2$jsx$$)("g",{transform:""+($APP.$app$common$geom$matrix$transform_in$$($cell_center$jscomp$1$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1086$$))??""),children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$228$$,
$dir$jscomp$10_p__81118$$){var $handler$jscomp$50$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__81118$$,0,null),$x$jscomp$1287$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__81118$$,1,null),$y$jscomp$510$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__81118$$,2,null),$width$jscomp$237$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__81118$$,3,null),$height$jscomp$204$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__81118$$,
4,null);$dir$jscomp$10_p__81118$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($dir$jscomp$10_p__81118$$,5,null);$out_arr__44092__auto__$jscomp$228$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$resize_cell_handler$$,{y:$y$jscomp$510$$,width:$width$jscomp$237$$,"on-clear-modifiers":$on_clear_modifiers$jscomp$1$$,"on-set-modifiers":$on_set_modifiers$jscomp$1$$,shape:$shape$jscomp$1086$$,x:$x$jscomp$1287$$,"layout-data":$layout_data$jscomp$20$$,cell:$cell$jscomp$47$$,
handler:$handler$jscomp$50$$,direction:$dir$jscomp$10_p__81118$$,height:$height$jscomp$204$$},"resize-"+($APP.$app$common$data$name$$($handler$jscomp$50$$)??"")+"-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$47$$)??"")));return $out_arr__44092__auto__$jscomp$228$$},[],$handlers$jscomp$8$$)})}():null]})}),$app$main$ui$workspace$viewport$grid_layout_editor$track$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($on_clear_modifiers$jscomp$5_props_81176$$){var $shape$jscomp$1090$$=
$on_clear_modifiers$jscomp$5_props_81176$$.shape,$zoom$jscomp$121$$=$on_clear_modifiers$jscomp$5_props_81176$$.zoom,$type$jscomp$721$$=$on_clear_modifiers$jscomp$5_props_81176$$.type,$index$jscomp$574$$=$on_clear_modifiers$jscomp$5_props_81176$$.index,$snap_pixel_QMARK_$jscomp$12$$=$on_clear_modifiers$jscomp$5_props_81176$$["snap-pixel?"],$track_data$$=$on_clear_modifiers$jscomp$5_props_81176$$["track-data"],$layout_data$jscomp$22$$=$on_clear_modifiers$jscomp$5_props_81176$$["layout-data"],$hovering_QMARK_$jscomp$4$$=
$on_clear_modifiers$jscomp$5_props_81176$$["hovering?"],$drop_QMARK_$jscomp$2$$=$on_clear_modifiers$jscomp$5_props_81176$$["drop?"],$on_start_reorder_track$$=$on_clear_modifiers$jscomp$5_props_81176$$["on-start-reorder-track"],$on_move_reorder_track$$=$on_clear_modifiers$jscomp$5_props_81176$$["on-move-reorder-track"],$on_end_reorder_track$$=$on_clear_modifiers$jscomp$5_props_81176$$["on-end-reorder-track"],$on_set_modifiers$jscomp$5$$=$on_clear_modifiers$jscomp$5_props_81176$$["on-set-modifiers"];
$on_clear_modifiers$jscomp$5_props_81176$$=$on_clear_modifiers$jscomp$5_props_81176$$["on-clear-modifiers"];var $track_input_ref$$=(0,$APP.$rumext$v2$use_ref$$)(),$start_p$jscomp$18_vec__81180$$=$APP.$app$common$types$shape$layout$gaps$$($shape$jscomp$1090$$),$layout_gap_row$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_p$jscomp$18_vec__81180$$,0,null),$layout_gap_col$jscomp$15$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($start_p$jscomp$18_vec__81180$$,
1,null),$bounds$jscomp$94$$=$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$);$start_p$jscomp$18_vec__81180$$=$APP.$cljs$cst$3716$start_p$$.$cljs$core$IFn$_invoke$arity$1$($track_data$$);var $hpt$$=$APP.$app$common$geom$shapes$points$project_point$$($bounds$jscomp$94$$,$APP.$cljs$cst$1907$h$$,$start_p$jscomp$18_vec__81180$$),$vpt$$=$APP.$app$common$geom$shapes$points$project_point$$($bounds$jscomp$94$$,$APP.$cljs$cst$3723$v$$,$start_p$jscomp$18_vec__81180$$),$marker_p$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,$APP.$cljs$cst$216$column$$)?function(){var $G__81187$$=$APP.$app$common$geom$point$subtract$$($hpt$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$94$$,20/$zoom$jscomp$121$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$574$$,0)?$APP.$app$common$geom$point$subtract$$($G__81187$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$94$$,$layout_gap_col$jscomp$15$$/
2)):$G__81187$$}():function(){var $G__81188$$=$APP.$app$common$geom$point$subtract$$($vpt$$,$APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$94$$,20/$zoom$jscomp$121$$));return $APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($index$jscomp$574$$,0)?$APP.$app$common$geom$point$subtract$$($G__81188$$,$APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$94$$,$layout_gap_row$jscomp$15$$/2)):$G__81188$$}(),$text_p$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,
$APP.$cljs$cst$216$column$$)?$hpt$$:$vpt$$,$handle_blur_track_input$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$))],function($event$jscomp$698_target$jscomp$167$$){$event$jscomp$698_target$jscomp$167$$=$APP.$app$util$dom$get_target$$($event$jscomp$698_target$jscomp$167$$);var $track_type$jscomp$1_value$jscomp$1008$$=$APP.$cuerdas$core$upper$$($APP.$app$util$dom$get_input_value$$($event$jscomp$698_target$jscomp$167$$)),
$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$=$APP.$app$common$data$parse_integer$cljs$0core$0IFn$0_invoke$0arity$01$$($track_type$jscomp$1_value$jscomp$1008$$);$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$=$APP.$cljs$core$truth_$$($track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$)?0>$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$?0:$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$:
null;$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$=$APP.$cuerdas$core$ends_with_QMARK_$$($track_type$jscomp$1_value$jscomp$1008$$,"%")?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1675$percent$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$,50)],null):$APP.$cuerdas$core$ends_with_QMARK_$$($track_type$jscomp$1_value$jscomp$1008$$,
"FR")?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1665$flex$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$,1)],null):$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1676$fixed$$,$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$,
100)],null):new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1677$auto$$,null],null);$track_type$jscomp$1_value$jscomp$1008$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$,0,null);$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$,
1,null);$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$=$track_type$jscomp$1_value$jscomp$1008$$!=null?new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$139$type$$,$track_type$jscomp$1_value$jscomp$1008$$,$APP.$cljs$cst$260$value$$,$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$],null):null;$app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($track_input_ref$$),$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$));
return $track_type$jscomp$1_value$jscomp$1008$$!=null?($APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$change_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$)],null),$type$jscomp$721$$,$index$jscomp$574$$,$track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$)),$APP.$app$util$dom$set_data_BANG_$$($event$jscomp$698_target$jscomp$167$$,
"default-value",$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data__$1_value__$1$jscomp$84_value_int_value_int__$1_vec__81189$$))):$APP.$app$util$object$set_BANG_$$($event$jscomp$698_target$jscomp$167$$,"value",$APP.$app$util$dom$get_attribute$$($event$jscomp$698_target$jscomp$167$$,"data-default-value"))}),$handle_keydown_track_input$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$699$$){var $enter_QMARK_$jscomp$7$$=(0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$699$$),
$esc_QMARK_$jscomp$9$$=(0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$699$$);$APP.$cljs$core$truth_$$($enter_QMARK_$jscomp$7$$)&&$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$699$$));return $APP.$cljs$core$truth_$$($esc_QMARK_$jscomp$9$$)?$APP.$app$util$dom$blur_BANG_$$($APP.$app$util$dom$get_target$$($event$jscomp$699$$)):null}),$handle_pointer_enter$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$)),
$APP.$rumext$v2$adapt$$($type$jscomp$721$$),$APP.$rumext$v2$adapt$$($index$jscomp$574$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$hover_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$)],null),$type$jscomp$721$$,$index$jscomp$574$$,!0))}),$handle_pointer_leave$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$)),
$APP.$rumext$v2$adapt$$($type$jscomp$721$$),$APP.$rumext$v2$adapt$$($index$jscomp$574$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$hover_layout_track$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$)],null),$type$jscomp$721$$,$index$jscomp$574$$,!1))}),$track_before$jscomp$3_track_list_prop$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,
$APP.$cljs$cst$216$column$$)?$APP.$cljs$cst$3715$column_tracks$$:$APP.$cljs$cst$3714$row_tracks$$,$text_height_vec__81183$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,$APP.$cljs$cst$216$column$$)?new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($text_p$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($text_p$$)-36/$zoom$jscomp$121$$,function(){var $y__5111__auto__$jscomp$176$$=
$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_data$$);return 0>$y__5111__auto__$jscomp$176$$?0:$y__5111__auto__$jscomp$176$$}(),36/$zoom$jscomp$121$$],null):new $APP.$cljs$core$PersistentVector$$(null,4,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($text_p$$)-function(){var $y__5111__auto__$jscomp$177$$=$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_data$$);return 0>$y__5111__auto__$jscomp$177$$?0:$y__5111__auto__$jscomp$177$$}(),
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($text_p$$)-36/$zoom$jscomp$121$$,function(){var $y__5111__auto__$jscomp$178$$=$APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($track_data$$);return 0>$y__5111__auto__$jscomp$178$$?0:$y__5111__auto__$jscomp$178$$}(),36/$zoom$jscomp$121$$],null),$text_x$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_height_vec__81183$$,0,null),$text_y$jscomp$3$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_height_vec__81183$$,
1,null),$text_width$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_height_vec__81183$$,2,null);$text_height_vec__81183$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($text_height_vec__81183$$,3,null);var $handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__81186$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_start_reorder_track$$),$APP.$rumext$v2$adapt$$($type$jscomp$721$$),$APP.$rumext$v2$adapt$$($index$jscomp$574$$)],
function(){return $on_start_reorder_track$$.$cljs$core$IFn$_invoke$arity$2$?$on_start_reorder_track$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,$index$jscomp$574$$):$on_start_reorder_track$$($type$jscomp$721$$,$index$jscomp$574$$)}),$handle_drag_end$jscomp$2_handle_lost_pointer_capture$jscomp$4$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_end_reorder_track$$),$APP.$rumext$v2$adapt$$($type$jscomp$721$$),$APP.$rumext$v2$adapt$$($index$jscomp$574$$)],
function($G__81199_event$jscomp$700$$,$position$jscomp$231$$){$G__81199_event$jscomp$700$$=!$APP.$app$util$keyboard$mod_QMARK_$$($G__81199_event$jscomp$700$$);return $on_end_reorder_track$$.$cljs$core$IFn$_invoke$arity$4$?$on_end_reorder_track$$.$cljs$core$IFn$_invoke$arity$4$($type$jscomp$721$$,$index$jscomp$574$$,$position$jscomp$231$$,$G__81199_event$jscomp$700$$):$on_end_reorder_track$$($type$jscomp$721$$,$index$jscomp$574$$,$position$jscomp$231$$,$G__81199_event$jscomp$700$$)}),$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__81186__$1$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_move_reorder_track$$),$APP.$rumext$v2$adapt$$($type$jscomp$721$$),$APP.$rumext$v2$adapt$$($index$jscomp$574$$)],function($_$jscomp$3129$$,$position$jscomp$232$$){return $on_move_reorder_track$$.$cljs$core$IFn$_invoke$arity$3$?$on_move_reorder_track$$.$cljs$core$IFn$_invoke$arity$3$($type$jscomp$721$$,$index$jscomp$574$$,$position$jscomp$232$$):$on_move_reorder_track$$($type$jscomp$721$$,$index$jscomp$574$$,$position$jscomp$232$$)}),
$handle_show_track_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$){$APP.$app$util$dom$stop_propagation$$($G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$);$APP.$app$util$dom$prevent_default$$($G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$);$G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$=
$APP.$app$util$dom$get_client_position$$($G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$);$G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$,
$APP.$cljs$cst$1516$y$$,$APP.$cljs$core$_PLUS_$$,40):$G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$;$G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,$APP.$cljs$cst$1661$row$$)?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$,
$APP.$cljs$cst$1515$x$$,$APP.$cljs$core$_PLUS_$$,30):$G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$;return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_track_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1681$position$$,$G__81201$jscomp$inline_9389_G__81201__$1$jscomp$inline_9390_event$jscomp$701_position$jscomp$233$$,$APP.$cljs$cst$4487$grid_id$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$),
$APP.$cljs$cst$139$type$$,$type$jscomp$721$$,$APP.$cljs$cst$1801$index$$,$index$jscomp$574$$],null)))}),$small_QMARK__trackwidth$$=$text_width$jscomp$1$$*$zoom$jscomp$121$$,$medium_QMARK_$$=$small_QMARK__trackwidth$$>=60&&$small_QMARK__trackwidth$$<110;$small_QMARK__trackwidth$$=$small_QMARK__trackwidth$$<60;$track_before$jscomp$3_track_list_prop$$=$APP.$cljs$core$get_in$$.$cljs$core$IFn$_invoke$arity$2$($layout_data$jscomp$22$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$track_before$jscomp$3_track_list_prop$$,$index$jscomp$574$$-1],null));$handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__81186$$=$app$main$ui$workspace$viewport$grid_layout_editor$use_drag$$(new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$cljs$cst$5959$on_drag_start$$,$handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__81186$$,$cljs$cst$5960$on_drag_end$$,$handle_drag_end$jscomp$2_handle_lost_pointer_capture$jscomp$4$$,$cljs$cst$5962$on_drag_position$$,$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__81186__$1$$],
null));$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__81186__$1$$=$APP.$cljs$core$__destructure_map$$($handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__81186$$);$handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__81186$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__81186__$1$$,$cljs$cst$5963$handle_pointer_down$$);$handle_drag_end$jscomp$2_handle_lost_pointer_capture$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__81186__$1$$,
$cljs$cst$5964$handle_lost_pointer_capture$$);$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__81186__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__81186__$1$$,$cljs$cst$5965$handle_pointer_move$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($track_data$$)],function(){return $app$util$dom$set_value_BANG_$$($APP.$rumext$v2$ref_val$$($track_input_ref$$),$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data$$))});
return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"track",children:[(0,$APP.$rumext$v2$jsxs$$)("g",{onPointerEnter:$handle_pointer_enter$jscomp$1$$,onPointerLeave:$handle_pointer_leave$jscomp$1$$,transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,$APP.$cljs$cst$216$column$$)?""+($APP.$app$common$geom$matrix$transform_in$$($text_p$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$))??""):""+($APP.$app$common$geom$matrix$transform_in$$($text_p$$,
$APP.$app$common$geom$matrix$rotate$cljs$0core$0IFn$0_invoke$0arity$02$$($APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1090$$),-90))??""),children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$text_x$jscomp$3$$+18/$zoom$jscomp$121$$,y:$text_y$jscomp$3$$,width:$text_width$jscomp$1$$-36/$zoom$jscomp$121$$,height:$text_height_vec__81183$$-5/$zoom$jscomp$121$$,rx:3/$zoom$jscomp$121$$,style:{cursor:"pointer"},opacity:$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($hovering_QMARK_$jscomp$4$$)?
!$small_QMARK__trackwidth$$:$hovering_QMARK_$jscomp$4$$)?.2:0,className:"main_ui_workspace_viewport_grid_layout_editor__grid-editor-header-hover"}),$small_QMARK__trackwidth$$?null:(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$text_x$jscomp$3$$,y:$text_y$jscomp$3$$,width:$text_width$jscomp$1$$,height:$text_height_vec__81183$$,children:(0,$APP.$rumext$v2$jsxs$$)("div",{"data-testid":"grid-track-editor-wrapper",onContextMenu:$handle_show_track_menu$$,onPointerDown:$handle_drag_start$jscomp$1_handle_pointer_down$jscomp$6_map__81186$$,
onLostPointerCapture:$handle_drag_end$jscomp$2_handle_lost_pointer_capture$jscomp$4$$,onPointerMove:$handle_drag_position$jscomp$2_handle_pointer_move$jscomp$4_map__81186__$1$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-editor-wrapper",children:[(0,$APP.$rumext$v2$jsx$$)("input",{ref:$track_input_ref$$,style:{},type:"text",defaultValue:$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data$$),"data-default-value":$app$main$ui$workspace$viewport$grid_layout_editor$format_size$$($track_data$$),
onKeyDown:$handle_keydown_track_input$$,onBlur:$handle_blur_track_input$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-editor-label"}),$medium_QMARK_$$||$small_QMARK__trackwidth$$?null:(0,$APP.$rumext$v2$jsx$$)("button",{"data-testid":"grid-track-options-btn",onClick:$handle_show_track_menu$$,className:"main_ui_workspace_viewport_grid_layout_editor__grid-editor-button",children:$APP.$app$main$ui$icons$menu$$})]})})]}),(0,$APP.$rumext$v2$jsx$$)("g",{transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$721$$,
$APP.$cljs$cst$1661$row$$)?"rotate(-90 "+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($marker_p$$)??"")+" "+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($marker_p$$)??"")+")":null,children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$,{zoom:$zoom$jscomp$121$$,index:$index$jscomp$574$$,value:""+($index$jscomp$574$$+1??""),"track-before":$track_before$jscomp$3_track_list_prop$$,"snap-pixel?":$snap_pixel_QMARK_$jscomp$12$$,type:$type$jscomp$721$$,
"on-clear-modifiers":$on_clear_modifiers$jscomp$5_props_81176$$,"track-after":$track_data$$,center:$marker_p$$,"on-set-modifiers":$on_set_modifiers$jscomp$5$$,shape:$shape$jscomp$1090$$})}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$,{zoom:$zoom$jscomp$121$$,index:$index$jscomp$574$$,"track-before":$track_before$jscomp$3_track_list_prop$$,"snap-pixel?":$snap_pixel_QMARK_$jscomp$12$$,type:$type$jscomp$721$$,"on-clear-modifiers":$on_clear_modifiers$jscomp$5_props_81176$$,
"track-after":$track_data$$,"on-set-modifiers":$on_set_modifiers$jscomp$5$$,"start-p":$start_p$jscomp$18_vec__81180$$,shape:$shape$jscomp$1090$$,"layout-data":$layout_data$jscomp$22$$,"drop?":$drop_QMARK_$jscomp$2$$})]})}),$app$main$ui$workspace$viewport$grid_layout_editor$editor$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_81215_view_only$$){function $vv$jscomp$16$$($p1__81208_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_vv$$($bounds$jscomp$95$$,$p1__81208_SHARP_$$)}function $hv$jscomp$16$$($p1__81207_SHARP_$$){return $APP.$app$common$geom$shapes$points$start_hv$$($bounds$jscomp$95$$,
$p1__81207_SHARP_$$)}var $base_shape$jscomp$1$$=$props_81215_view_only$$.shape,$objects$jscomp$827$$=$props_81215_view_only$$.objects,$modifiers$jscomp$133$$=$props_81215_view_only$$.modifiers,$zoom$jscomp$122$$=$props_81215_view_only$$.zoom;$props_81215_view_only$$=$props_81215_view_only$$["view-only"];var $st_modif$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$shape$jscomp$1091$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_shape$jscomp$1$$),
$APP.$rumext$v2$adapt$$($modifiers$jscomp$133$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($st_modif$$))],function(){var $G__81218__$1$$=$modifiers$jscomp$133$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($base_shape$jscomp$1$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$133$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base_shape$jscomp$1$$)),$APP.$cljs$cst$1816$modifiers$$)):
$base_shape$jscomp$1$$;return $APP.$cljs$core$_deref$$($st_modif$$)!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($G__81218__$1$$,$APP.$cljs$core$_deref$$($st_modif$$)):$G__81218__$1$$}),$snap_pixel_QMARK_$jscomp$13$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$snap_pixel_QMARK_$$),$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))],
function(){return $app$main$refs$workspace_grid_edition_id$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))});$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$=$APP.$rumext$v2$deref$$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$);var $hover_cells$$=$APP.$cljs$cst$2212$hover$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$),
$selected_cells$jscomp$1$$=$APP.$cljs$cst$1938$selected$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$),$hover_columns$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__81219$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81219$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81219$$,
1,null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__81224$$){var $t$jscomp$100$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81224$$,0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81224$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($t$jscomp$100$$,$APP.$cljs$cst$216$column$$)},$APP.$cljs$cst$4476$hover_track$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$)))),
$hover_rows$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$PersistentHashSet$EMPTY$$,$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p__81228$$){$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81228$$,0,null);return $APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81228$$,1,null)},$APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$(function($p__81232$$){var $t$jscomp$101$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81232$$,
0,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($p__81232$$,1,null);return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($t$jscomp$101$$,$APP.$cljs$cst$1661$row$$)},$APP.$cljs$cst$4476$hover_track$$.$cljs$core$IFn$_invoke$arity$1$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$)))),$bounds$jscomp$95$$=$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$),$origin$jscomp$74$$=$APP.$app$common$geom$shapes$points$origin$$($bounds$jscomp$95$$),
$layout_data$jscomp$23$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($shape$jscomp$1091$$),$APP.$rumext$v2$adapt$$($modifiers$jscomp$133$$)],function(){var $children$jscomp$313_objects__$1$jscomp$41$$=$APP.$app$common$geom$shapes$apply_objects_modifiers$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$827$$,$modifiers$jscomp$133$$),$children_bounds$jscomp$2_ids$jscomp$322$$=$APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($children$jscomp$313_objects__$1$jscomp$41$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$)),$objects__$2$jscomp$1$$=$app$common$geom$shapes$update_shapes_geometry$$($children$jscomp$313_objects__$1$jscomp$41$$,$APP.$cljs$core$reverse$$($children_bounds$jscomp$2_ids$jscomp$322$$));$children$jscomp$313_objects__$1$jscomp$41$$=$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81209_SHARP_$$){return new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$common$geom$shapes$points$parent_coords_bounds$$($APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($p1__81209_SHARP_$$),
$APP.$cljs$cst$1609$points$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$)),$p1__81209_SHARP_$$],null)},$APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects__$2$jscomp$1$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$),new $APP.$cljs$core$PersistentArrayMap$$(null,1,[$APP.$cljs$cst$1626$remove_hidden$$,!0],null)));$children_bounds$jscomp$2_ids$jscomp$322$$=$APP.$app$common$data$lazy_map$$($children_bounds$jscomp$2_ids$jscomp$322$$,
function($p1__81210_SHARP_$$){return $APP.$app$common$geom$shapes$shape__GT_points$$($APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($objects__$2$jscomp$1$$,$p1__81210_SHARP_$$))});return $APP.$app$common$geom$shapes$grid_layout$calc_layout_data$$.$cljs$core$IFn$_invoke$arity$5$($shape$jscomp$1091$$,$bounds$jscomp$95$$,$children$jscomp$313_objects__$1$jscomp$41$$,$children_bounds$jscomp$2_ids$jscomp$322$$,$objects__$2$jscomp$1$$)});$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$=
$APP.$cljs$core$__destructure_map$$($layout_data$jscomp$23$$);var $row_tracks$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$,$APP.$cljs$cst$3714$row_tracks$$),$column_tracks$jscomp$6$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$,$APP.$cljs$cst$3715$column_tracks$$),$column_total_size$jscomp$2$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$,$APP.$cljs$cst$3717$column_total_size$$),$column_total_gap$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$,$APP.$cljs$cst$3718$column_total_gap$$),$row_total_size$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$,
$APP.$cljs$cst$3722$row_total_size$$),$row_total_gap$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$,$APP.$cljs$cst$3720$row_total_gap$$),$width$jscomp$239$$=function(){var $x__5110__auto__$jscomp$179$$=$APP.$app$common$geom$shapes$points$width_points$$($bounds$jscomp$95$$),$map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$=$APP.$cljs$core$__destructure_map$$($shape$jscomp$1091$$);
var $JSCompiler_inline_result$jscomp$1540_layout_padding_type$jscomp$inline_9394_y__5111__auto__$jscomp$179$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$,$APP.$cljs$cst$1690$layout_padding_type$$);$map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$,
$APP.$cljs$cst$1691$layout_padding$$);var $map__47874__$1$jscomp$inline_9396_pad_left$jscomp$inline_9398$$=$APP.$cljs$core$__destructure_map$$($map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$);$map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47874__$1$jscomp$inline_9396_pad_left$jscomp$inline_9398$$,$APP.$cljs$cst$1091$p2$$);$map__47874__$1$jscomp$inline_9396_pad_left$jscomp$inline_9398$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47874__$1$jscomp$inline_9396_pad_left$jscomp$inline_9398$$,$APP.$cljs$cst$1693$p4$$);$JSCompiler_inline_result$jscomp$1540_layout_padding_type$jscomp$inline_9394_y__5111__auto__$jscomp$179$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1668$simple$$,$JSCompiler_inline_result$jscomp$1540_layout_padding_type$jscomp$inline_9394_y__5111__auto__$jscomp$179$$)?$map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$+
$map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$:$map__47873__$1$jscomp$inline_9393_map__47874$jscomp$inline_9395_pad_right$jscomp$inline_9397$$+$map__47874__$1$jscomp$inline_9396_pad_left$jscomp$inline_9398$$;$JSCompiler_inline_result$jscomp$1540_layout_padding_type$jscomp$inline_9394_y__5111__auto__$jscomp$179$$=$column_total_size$jscomp$2$$+$column_total_gap$jscomp$2$$+$JSCompiler_inline_result$jscomp$1540_layout_padding_type$jscomp$inline_9394_y__5111__auto__$jscomp$179$$;
return $x__5110__auto__$jscomp$179$$>$JSCompiler_inline_result$jscomp$1540_layout_padding_type$jscomp$inline_9394_y__5111__auto__$jscomp$179$$?$x__5110__auto__$jscomp$179$$:$JSCompiler_inline_result$jscomp$1540_layout_padding_type$jscomp$inline_9394_y__5111__auto__$jscomp$179$$}(),$height$jscomp$206$$=function(){var $x__5110__auto__$jscomp$180$$=$APP.$app$common$geom$shapes$points$height_points$$($bounds$jscomp$95$$),$map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$=
$APP.$cljs$core$__destructure_map$$($shape$jscomp$1091$$);var $JSCompiler_inline_result$jscomp$1539_layout_padding_type$jscomp$inline_9402_y__5111__auto__$jscomp$180$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$,$APP.$cljs$cst$1690$layout_padding_type$$);$map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$,
$APP.$cljs$cst$1691$layout_padding$$);var $map__47877__$1$jscomp$inline_9404_pad_bottom$jscomp$inline_9406$$=$APP.$cljs$core$__destructure_map$$($map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$);$map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47877__$1$jscomp$inline_9404_pad_bottom$jscomp$inline_9406$$,$APP.$cljs$cst$1093$p1$$);$map__47877__$1$jscomp$inline_9404_pad_bottom$jscomp$inline_9406$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__47877__$1$jscomp$inline_9404_pad_bottom$jscomp$inline_9406$$,$APP.$cljs$cst$1692$p3$$);$JSCompiler_inline_result$jscomp$1539_layout_padding_type$jscomp$inline_9402_y__5111__auto__$jscomp$180$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1668$simple$$,$JSCompiler_inline_result$jscomp$1539_layout_padding_type$jscomp$inline_9402_y__5111__auto__$jscomp$180$$)?$map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$+
$map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$:$map__47876__$1$jscomp$inline_9401_map__47877$jscomp$inline_9403_pad_top$jscomp$inline_9405$$+$map__47877__$1$jscomp$inline_9404_pad_bottom$jscomp$inline_9406$$;$JSCompiler_inline_result$jscomp$1539_layout_padding_type$jscomp$inline_9402_y__5111__auto__$jscomp$180$$=$row_total_size$jscomp$2$$+$row_total_gap$jscomp$2$$+$JSCompiler_inline_result$jscomp$1539_layout_padding_type$jscomp$inline_9402_y__5111__auto__$jscomp$180$$;
return $x__5110__auto__$jscomp$180$$>$JSCompiler_inline_result$jscomp$1539_layout_padding_type$jscomp$inline_9402_y__5111__auto__$jscomp$180$$?$x__5110__auto__$jscomp$180$$:$JSCompiler_inline_result$jscomp$1539_layout_padding_type$jscomp$inline_9402_y__5111__auto__$jscomp$180$$}();$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$702$$){return $app$util$dom$left_mouse_QMARK_$$($event$jscomp$702$$)?
$APP.$app$util$dom$stop_propagation$$($event$jscomp$702$$):null});var $handle_add_column$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,
[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$)],null),$APP.$cljs$cst$216$column$$,$APP.$app$common$types$shape$layout$default_track_value$$))}),$handle_add_row$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$shape_layout$add_layout_track$cljs$0core$0IFn$0_invoke$0arity$03$$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$)],null),$APP.$cljs$cst$1661$row$$,$APP.$app$common$types$shape$layout$default_track_value$$))}),$target_tracks_STAR_$$=(0,$APP.$rumext$v2$use_ref$$)(null),$drop_track_type_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$drop_track_target_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(null),$handle_start_reorder_track$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout_data$jscomp$23$$)],function($type$jscomp$722$$){var $line_vec$jscomp$1$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$722$$,$APP.$cljs$cst$216$column$$)?$vv$jscomp$16$$(1):$hv$jscomp$16$$(1),$last_point$jscomp$5_tracks$jscomp$6$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$722$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($bounds$jscomp$95$$,
1):$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$02$$($bounds$jscomp$95$$,3),$mid_points$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($type$jscomp$722$$,$APP.$cljs$cst$216$column$$)?$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81212_SHARP_$$){return $APP.$app$common$geom$point$add$$($APP.$cljs$cst$3716$start_p$$.$cljs$core$IFn$_invoke$arity$1$($p1__81212_SHARP_$$),$hv$jscomp$16$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p1__81212_SHARP_$$)/
2))},$APP.$cljs$cst$3715$column_tracks$$.$cljs$core$IFn$_invoke$arity$1$($layout_data$jscomp$23$$)):$APP.$cljs$core$mapv$$.$cljs$core$IFn$_invoke$arity$2$(function($p1__81213_SHARP_$$){return $APP.$app$common$geom$point$add$$($APP.$cljs$cst$3716$start_p$$.$cljs$core$IFn$_invoke$arity$1$($p1__81213_SHARP_$$),$vv$jscomp$16$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($p1__81213_SHARP_$$)/2))},$APP.$cljs$cst$3714$row_tracks$$.$cljs$core$IFn$_invoke$arity$1$($layout_data$jscomp$23$$));
$last_point$jscomp$5_tracks$jscomp$6$$=$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$02$$(function($current$jscomp$60_p__81242$$){var $index$jscomp$575$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($current$jscomp$60_p__81242$$,0,null),$prev$jscomp$21_vec__81246$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($current$jscomp$60_p__81242$$,1,null);$current$jscomp$60_p__81242$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($prev$jscomp$21_vec__81246$$,0,null);
$prev$jscomp$21_vec__81246$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($prev$jscomp$21_vec__81246$$,1,null);return $prev$jscomp$21_vec__81246$$!=null?new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$prev$jscomp$21_vec__81246$$,$current$jscomp$60_p__81242$$,$line_vec$jscomp$1$$],null),$index$jscomp$575$$-1],null):null},$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$with_prev$$($APP.$app$common$data$concat_vec$$.$cljs$core$IFn$_invoke$arity$variadic$(new $APP.$cljs$core$PersistentVector$$(null,
1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$origin$jscomp$74$$],null),$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$mid_points$$,new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$last_point$jscomp$5_tracks$jscomp$6$$],null)])))));$APP.$rumext$v2$set_ref_val_BANG_$$($target_tracks_STAR_$$,$last_point$jscomp$5_tracks$jscomp$6$$);return $APP.$cljs$core$reset_BANG_$$($drop_track_type_STAR_$$,$type$jscomp$722$$)}),$handle_move_reorder_track$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($_type$jscomp$3_index$jscomp$576$$,$_from_idx$jscomp$1$$,$position$jscomp$234$$){$_type$jscomp$3_index$jscomp$576$$=$APP.$cljs$core$second$$($APP.$app$common$data$seek$cljs$0core$0IFn$0_invoke$0arity$02$$(function($line_2$jscomp$inline_9409_p__81249$$){var $v$jscomp$689_vec__81253$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($line_2$jscomp$inline_9409_p__81249$$,0,null),$p1$jscomp$87$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$689_vec__81253$$,
0,null),$p2$jscomp$68$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$689_vec__81253$$,1,null);$v$jscomp$689_vec__81253$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($v$jscomp$689_vec__81253$$,2,null);$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($line_2$jscomp$inline_9409_p__81249$$,1,null);$line_2$jscomp$inline_9409_p__81249$$=new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p2$jscomp$68$$,$v$jscomp$689_vec__81253$$],
null);return $APP.$app$common$geom$line$line_value$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$p1$jscomp$87$$,$v$jscomp$689_vec__81253$$],null),$position$jscomp$234$$)*$APP.$app$common$geom$line$line_value$$($line_2$jscomp$inline_9409_p__81249$$,$position$jscomp$234$$)<0},$APP.$rumext$v2$ref_val$$($target_tracks_STAR_$$)));return $_type$jscomp$3_index$jscomp$576$$!=null?$APP.$cljs$core$reset_BANG_$$($drop_track_target_STAR_$$,$_type$jscomp$3_index$jscomp$576$$):
null}),$handle_end_reorder_track$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($base_shape$jscomp$1$$),$APP.$rumext$v2$adapt$$($APP.$cljs$core$_deref$$($drop_track_target_STAR_$$))],function($type$jscomp$723$$,$from_index$jscomp$13$$,$_position$jscomp$1_temp__5825__auto___81372$$,$move_content_QMARK_$jscomp$6$$){$_position$jscomp$1_temp__5825__auto___81372$$=$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$);if($APP.$cljs$core$truth_$$($_position$jscomp$1_temp__5825__auto___81372$$)){var $ids_81374$$=
new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($base_shape$jscomp$1$$)],null);$from_index$jscomp$13$$<$_position$jscomp$1_temp__5825__auto___81372$$?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$reorder_layout_track$$($ids_81374$$,$type$jscomp$723$$,$from_index$jscomp$13$$,$_position$jscomp$1_temp__5825__auto___81372$$-1,$move_content_QMARK_$jscomp$6$$)):
$from_index$jscomp$13$$>$_position$jscomp$1_temp__5825__auto___81372$$&&$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$shape_layout$reorder_layout_track$$($ids_81374$$,$type$jscomp$723$$,$from_index$jscomp$13$$,$_position$jscomp$1_temp__5825__auto___81372$$-1,$move_content_QMARK_$jscomp$6$$))}$APP.$rumext$v2$set_ref_val_BANG_$$($target_tracks_STAR_$$,null);$APP.$cljs$core$reset_BANG_$$($drop_track_type_STAR_$$,null);return $APP.$cljs$core$reset_BANG_$$($drop_track_target_STAR_$$,
null)}),$handle_set_modifiers$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($modifier$jscomp$7$$){return $APP.$cljs$core$reset_BANG_$$($st_modif$$,$modifier$jscomp$7$$)}),$handle_clear_modifiers$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($st_modif$$,null)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$editor$stop_grid_layout_editing$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$)))}});
return $APP.$cljs$core$not$$($APP.$cljs$cst$1625$hidden$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))&&$APP.$cljs$core$not$$($APP.$cljs$cst$1628$blocked$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"grid-editor",pointerEvents:$APP.$cljs$core$truth_$$($props_81215_view_only$$)?"none":null,onPointerDown:$grid_edition$jscomp$2_grid_edition_id_ref_handle_pointer_down$jscomp$7_map__81216__$1$$,children:[(0,$APP.$rumext$v2$jsx$$)("g",{className:"cells",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$229$$,$cell$jscomp$48$$){$out_arr__44092__auto__$jscomp$229$$.push((0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$grid_cell$$,{zoom:$zoom$jscomp$122$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-set-modifiers":$handle_set_modifiers$$,shape:$base_shape$jscomp$1$$,"layout-data":$layout_data$jscomp$23$$,cell:$cell$jscomp$48$$,"selected?":$APP.$cljs$core$contains_QMARK_$$($selected_cells$jscomp$1$$,
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$48$$)),"hover?":$APP.$cljs$core$contains_QMARK_$$($hover_cells$$,$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$48$$))},"cell-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($cell$jscomp$48$$)??"")));return $out_arr__44092__auto__$jscomp$229$$},[],$APP.$app$common$types$shape$layout$get_cells$cljs$0core$0IFn$0_invoke$0arity$02$$($shape$jscomp$1091$$,new $APP.$cljs$core$PersistentArrayMap$$(null,1,
[$APP.$cljs$cst$1718$sort_QMARK_$$,!0],null)))}),$props_81215_view_only$$?null:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$grid_editor_frame$$,{zoom:$zoom$jscomp$122$$,bounds:$bounds$jscomp$95$$,width:$width$jscomp$239$$,height:$height$jscomp$206$$}),function(){var $start_p$jscomp$19$$=$APP.$app$common$geom$point$add$$($origin$jscomp$74$$,$hv$jscomp$16$$($width$jscomp$239$$+30/$zoom$jscomp$122$$));return(0,$APP.$rumext$v2$jsx$$)("g",
{transform:""+($APP.$app$common$geom$matrix$transform_in$$($start_p$jscomp$19$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))??""),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$plus_btn$$,{"start-p":$start_p$jscomp$19$$,zoom:$zoom$jscomp$122$$,type:$APP.$cljs$cst$216$column$$,"on-click":$handle_add_column$$})})}(),function(){var $start_p$jscomp$20$$=$APP.$app$common$geom$point$add$$($origin$jscomp$74$$,$vv$jscomp$16$$($height$jscomp$206$$+
30/$zoom$jscomp$122$$));return(0,$APP.$rumext$v2$jsx$$)("g",{transform:""+($APP.$app$common$geom$matrix$transform_in$$($start_p$jscomp$20$$,$APP.$cljs$cst$1294$transform$$.$cljs$core$IFn$_invoke$arity$1$($shape$jscomp$1091$$))??""),children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$plus_btn$$,{"start-p":$start_p$jscomp$20$$,zoom:$zoom$jscomp$122$$,type:$APP.$cljs$cst$1661$row$$,"on-click":$handle_add_row$$})})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$230$$,
$JSCompiler_temp_const$jscomp$1940_p__81261$$){var $JSCompiler_inline_result$jscomp$1942_idx$jscomp$136$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1940_p__81261$$,0,null),$column_data$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1940_p__81261$$,1,null);$JSCompiler_temp_const$jscomp$1940_p__81261$$=$out_arr__44092__auto__$jscomp$230$$.push;var $drop_QMARK_$jscomp$inline_9412$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,
$APP.$cljs$core$_deref$$($drop_track_type_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1942_idx$jscomp$136$$,$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$));$JSCompiler_inline_result$jscomp$1942_idx$jscomp$136$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track$$,{zoom:$zoom$jscomp$122$$,"hovering?":$APP.$cljs$core$contains_QMARK_$$($hover_columns$$,$JSCompiler_inline_result$jscomp$1942_idx$jscomp$136$$),
index:$JSCompiler_inline_result$jscomp$1942_idx$jscomp$136$$,"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$216$column$$,"track-data":$column_data$jscomp$1$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-start-reorder-track":$handle_start_reorder_track$$,"on-set-modifiers":$handle_set_modifiers$$,"on-end-reorder-track":$handle_end_reorder_track$$,shape:$shape$jscomp$1091$$,"layout-data":$layout_data$jscomp$23$$,"drop?":$drop_QMARK_$jscomp$inline_9412$$,"on-move-reorder-track":$handle_move_reorder_track$$},
"column-track-"+($JSCompiler_inline_result$jscomp$1942_idx$jscomp$136$$??""));$JSCompiler_temp_const$jscomp$1940_p__81261$$.call($out_arr__44092__auto__$jscomp$230$$,$JSCompiler_inline_result$jscomp$1942_idx$jscomp$136$$);return $out_arr__44092__auto__$jscomp$230$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($column_tracks$jscomp$6$$)),$APP.$cljs$core$empty_QMARK_$$($column_tracks$jscomp$6$$)?null:function(){var $JSCompiler_inline_result$jscomp$1944_end_p$jscomp$7_last_track$$=
$APP.$cljs$core$last$$($column_tracks$jscomp$6$$),$JSCompiler_temp_const$jscomp$1943_marker_p$jscomp$1_start_p$jscomp$21$$=$APP.$cljs$cst$3716$start_p$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1944_end_p$jscomp$7_last_track$$);$JSCompiler_inline_result$jscomp$1944_end_p$jscomp$7_last_track$$=$APP.$app$common$geom$point$add$$($JSCompiler_temp_const$jscomp$1943_marker_p$jscomp$1_start_p$jscomp$21$$,$hv$jscomp$16$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1944_end_p$jscomp$7_last_track$$)));
$JSCompiler_temp_const$jscomp$1943_marker_p$jscomp$1_start_p$jscomp$21$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$shapes$points$project_point$$($bounds$jscomp$95$$,$APP.$cljs$cst$1907$h$$,$JSCompiler_inline_result$jscomp$1944_end_p$jscomp$7_last_track$$),$vv$jscomp$16$$(20/$zoom$jscomp$122$$));$JSCompiler_temp_const$jscomp$1943_marker_p$jscomp$1_start_p$jscomp$21$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$,{zoom:$zoom$jscomp$122$$,
index:$APP.$cljs$core$count$$($column_tracks$jscomp$6$$),value:""+($APP.$cljs$core$count$$($column_tracks$jscomp$6$$)+1??""),"track-before":$APP.$cljs$core$last$$($column_tracks$jscomp$6$$),"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$216$column$$,"on-clear-modifiers":$handle_clear_modifiers$$,center:$JSCompiler_temp_const$jscomp$1943_marker_p$jscomp$1_start_p$jscomp$21$$,"on-set-modifiers":$handle_set_modifiers$$,shape:$shape$jscomp$1091$$});var $drop_QMARK_$jscomp$inline_9414$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$216$column$$,$APP.$cljs$core$_deref$$($drop_track_type_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($column_tracks$jscomp$6$$),$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$));$JSCompiler_inline_result$jscomp$1944_end_p$jscomp$7_last_track$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$,{zoom:$zoom$jscomp$122$$,index:$APP.$cljs$core$count$$($column_tracks$jscomp$6$$),
"last?":!0,"track-before":$APP.$cljs$core$last$$($column_tracks$jscomp$6$$),"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$216$column$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-set-modifiers":$handle_set_modifiers$$,"start-p":$JSCompiler_inline_result$jscomp$1944_end_p$jscomp$7_last_track$$,shape:$shape$jscomp$1091$$,"layout-data":$layout_data$jscomp$23$$,"drop?":$drop_QMARK_$jscomp$inline_9414$$});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"track",children:[$JSCompiler_temp_const$jscomp$1943_marker_p$jscomp$1_start_p$jscomp$21$$,
$JSCompiler_inline_result$jscomp$1944_end_p$jscomp$7_last_track$$]})}(),$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$231$$,$JSCompiler_temp_const$jscomp$1945_p__81266$$){var $JSCompiler_inline_result$jscomp$1947_idx$jscomp$137$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1945_p__81266$$,0,null),$row_data$jscomp$1$$=$APP.$cljs$core$nth$cljs$0core$0IFn$0_invoke$0arity$03$$($JSCompiler_temp_const$jscomp$1945_p__81266$$,
1,null);$JSCompiler_temp_const$jscomp$1945_p__81266$$=$out_arr__44092__auto__$jscomp$231$$.push;var $drop_QMARK_$jscomp$inline_9416$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row$$,$APP.$cljs$core$_deref$$($drop_track_type_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1947_idx$jscomp$137$$,$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$));$JSCompiler_inline_result$jscomp$1947_idx$jscomp$137$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track$$,
{zoom:$zoom$jscomp$122$$,"hovering?":$APP.$cljs$core$contains_QMARK_$$($hover_rows$$,$JSCompiler_inline_result$jscomp$1947_idx$jscomp$137$$),index:$JSCompiler_inline_result$jscomp$1947_idx$jscomp$137$$,"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$1661$row$$,"track-data":$row_data$jscomp$1$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-start-reorder-track":$handle_start_reorder_track$$,"on-set-modifiers":$handle_set_modifiers$$,"on-end-reorder-track":$handle_end_reorder_track$$,
shape:$shape$jscomp$1091$$,"layout-data":$layout_data$jscomp$23$$,"drop?":$drop_QMARK_$jscomp$inline_9416$$,"on-move-reorder-track":$handle_move_reorder_track$$},"row-track-"+($JSCompiler_inline_result$jscomp$1947_idx$jscomp$137$$??""));$JSCompiler_temp_const$jscomp$1945_p__81266$$.call($out_arr__44092__auto__$jscomp$231$$,$JSCompiler_inline_result$jscomp$1947_idx$jscomp$137$$);return $out_arr__44092__auto__$jscomp$231$$},[],$APP.$app$common$data$enumerate$cljs$0core$0IFn$0_invoke$0arity$02$$($row_tracks$jscomp$6$$)),
$APP.$cljs$core$empty_QMARK_$$($row_tracks$jscomp$6$$)?null:function(){var $JSCompiler_inline_result$jscomp$1949_end_p$jscomp$8_last_track$jscomp$1$$=$APP.$cljs$core$last$$($row_tracks$jscomp$6$$),$JSCompiler_temp_const$jscomp$1948_marker_p$jscomp$2_start_p$jscomp$22$$=$APP.$cljs$cst$3716$start_p$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1949_end_p$jscomp$8_last_track$jscomp$1$$);$JSCompiler_inline_result$jscomp$1949_end_p$jscomp$8_last_track$jscomp$1$$=$APP.$app$common$geom$point$add$$($JSCompiler_temp_const$jscomp$1948_marker_p$jscomp$2_start_p$jscomp$22$$,
$vv$jscomp$16$$($APP.$cljs$cst$874$size$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_inline_result$jscomp$1949_end_p$jscomp$8_last_track$jscomp$1$$)));$JSCompiler_temp_const$jscomp$1948_marker_p$jscomp$2_start_p$jscomp$22$$=$APP.$app$common$geom$point$subtract$$($APP.$app$common$geom$shapes$points$project_point$$($bounds$jscomp$95$$,$APP.$cljs$cst$3723$v$$,$JSCompiler_inline_result$jscomp$1949_end_p$jscomp$8_last_track$jscomp$1$$),$hv$jscomp$16$$(20/$zoom$jscomp$122$$));$JSCompiler_temp_const$jscomp$1948_marker_p$jscomp$2_start_p$jscomp$22$$=
(0,$APP.$rumext$v2$jsx$$)("g",{transform:"rotate(-90 "+($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$1948_marker_p$jscomp$2_start_p$jscomp$22$$)??"")+" "+($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($JSCompiler_temp_const$jscomp$1948_marker_p$jscomp$2_start_p$jscomp$22$$)??"")+")",children:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$track_marker$$,{zoom:$zoom$jscomp$122$$,index:$APP.$cljs$core$count$$($row_tracks$jscomp$6$$),
value:""+($APP.$cljs$core$count$$($row_tracks$jscomp$6$$)+1??""),"track-before":$APP.$cljs$core$last$$($row_tracks$jscomp$6$$),"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$1661$row$$,"on-clear-modifiers":$handle_clear_modifiers$$,center:$JSCompiler_temp_const$jscomp$1948_marker_p$jscomp$2_start_p$jscomp$22$$,"on-set-modifiers":$handle_set_modifiers$$,shape:$shape$jscomp$1091$$})});var $drop_QMARK_$jscomp$inline_9418$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1661$row$$,
$APP.$cljs$core$_deref$$($drop_track_type_STAR_$$))&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$count$$($row_tracks$jscomp$6$$),$APP.$cljs$core$_deref$$($drop_track_target_STAR_$$));$JSCompiler_inline_result$jscomp$1949_end_p$jscomp$8_last_track$jscomp$1$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$grid_layout_editor$resize_track_handler$$,{zoom:$zoom$jscomp$122$$,index:$APP.$cljs$core$count$$($row_tracks$jscomp$6$$),"last?":!0,"track-before":$APP.$cljs$core$last$$($row_tracks$jscomp$6$$),
"snap-pixel?":$snap_pixel_QMARK_$jscomp$13$$,type:$APP.$cljs$cst$1661$row$$,"on-clear-modifiers":$handle_clear_modifiers$$,"on-set-modifiers":$handle_set_modifiers$$,"start-p":$JSCompiler_inline_result$jscomp$1949_end_p$jscomp$8_last_track$jscomp$1$$,shape:$shape$jscomp$1091$$,"layout-data":$layout_data$jscomp$23$$,"drop?":$drop_QMARK_$jscomp$inline_9418$$});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"track",children:[$JSCompiler_temp_const$jscomp$1948_marker_p$jscomp$2_start_p$jscomp$22$$,$JSCompiler_inline_result$jscomp$1949_end_p$jscomp$8_last_track$jscomp$1$$]})}()]})]}):
null});var $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$=function $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$($var_args$jscomp$1476$$){switch(arguments.length){case 2:return $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$(arguments[0],arguments[1]);case 3:return $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$3$(arguments[0],arguments[1],arguments[2]);default:throw Error(["Invalid arity: ",
$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(arguments.length)].join(""));}};$app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$=function($zoom$jscomp$127$$,$vbox$jscomp$59$$){return $APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$,$zoom$jscomp$127$$,$vbox$jscomp$59$$)};
$app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$3$=function($rule_area_size_zoom$jscomp$128$$,$p__81116_x$jscomp$1288$$,$axis$jscomp$55_p__81117$$){var $height$jscomp$207_map__81119__$1_y2$jscomp$45$$=$APP.$cljs$core$__destructure_map$$($p__81116_x$jscomp$1288$$);$p__81116_x$jscomp$1288$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$207_map__81119__$1_y2$jscomp$45$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$511$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$207_map__81119__$1_y2$jscomp$45$$,
$APP.$cljs$cst$1516$y$$),$width$jscomp$240_x2$jscomp$43$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$207_map__81119__$1_y2$jscomp$45$$,$APP.$cljs$cst$290$width$$);$height$jscomp$207_map__81119__$1_y2$jscomp$45$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$207_map__81119__$1_y2$jscomp$45$$,$APP.$cljs$cst$1527$height$$);var $map__81120__$1_position$jscomp$237$$=$APP.$cljs$core$__destructure_map$$($axis$jscomp$55_p__81117$$);$axis$jscomp$55_p__81117$$=
$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81120__$1_position$jscomp$237$$,$APP.$cljs$cst$2062$axis$$);$map__81120__$1_position$jscomp$237$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81120__$1_position$jscomp$237$$,$APP.$cljs$cst$1681$position$$);$rule_area_size_zoom$jscomp$128$$=22/$rule_area_size_zoom$jscomp$128$$;$width$jscomp$240_x2$jscomp$43$$=$p__81116_x$jscomp$1288$$+$width$jscomp$240_x2$jscomp$43$$;$height$jscomp$207_map__81119__$1_y2$jscomp$45$$=$y$jscomp$511$$+
$height$jscomp$207_map__81119__$1_y2$jscomp$45$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$55_p__81117$$,$APP.$cljs$cst$1515$x$$)?$map__81120__$1_position$jscomp$237$$>=$p__81116_x$jscomp$1288$$+$rule_area_size_zoom$jscomp$128$$&&$map__81120__$1_position$jscomp$237$$<=$width$jscomp$240_x2$jscomp$43$$:$map__81120__$1_position$jscomp$237$$>=$y$jscomp$511$$+$rule_area_size_zoom$jscomp$128$$&&$map__81120__$1_position$jscomp$237$$<=$height$jscomp$207_map__81119__$1_y2$jscomp$45$$};
$app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$lang$maxFixedArity$=3;
var $app$main$ui$workspace$viewport$guides$guide_pill_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$){var $axis$jscomp$57$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.axis,$zoom$jscomp$130$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.zoom,$color$jscomp$192$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.color,$input_ref$jscomp$13$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.inputRef,
$display_value$jscomp$1_pos$jscomp$162$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.pos,$editing$jscomp$6$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.editing,$on_double_click$jscomp$5$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.onDoubleClick,$frame_offset$jscomp$11_input_w$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.frameOffset,$on_input_key_down$jscomp$1$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.onInputKeyDown,
$on_input_blur$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.onInputBlur;$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$=$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$.vbox;var $rect_y$jscomp$2_rulers_pos$jscomp$inline_9424$$=15/$zoom$jscomp$130$$,$guide_pill_width$jscomp$inline_9425_rect_width$jscomp$2$$=34/$zoom$jscomp$130$$,$guide_pill_height$jscomp$inline_9426_rect_height$jscomp$2$$=20/$zoom$jscomp$130$$;$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$=
$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$57$$,$APP.$cljs$cst$1515$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,6,[$cljs$cst$5986$rect_x$$,$display_value$jscomp$1_pos$jscomp$162$$-$guide_pill_width$jscomp$inline_9425_rect_width$jscomp$2$$/2,$cljs$cst$5987$rect_y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$)+$rect_y$jscomp$2_rulers_pos$jscomp$inline_9424$$+-($guide_pill_width$jscomp$inline_9425_rect_width$jscomp$2$$/
2)+3/$zoom$jscomp$130$$,$cljs$cst$5988$rect_width$$,$guide_pill_width$jscomp$inline_9425_rect_width$jscomp$2$$,$cljs$cst$5989$rect_height$$,$guide_pill_height$jscomp$inline_9426_rect_height$jscomp$2$$,$cljs$cst$5950$text_x$$,$display_value$jscomp$1_pos$jscomp$162$$,$cljs$cst$5951$text_y$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$)+$rect_y$jscomp$2_rulers_pos$jscomp$inline_9424$$+-(3/$zoom$jscomp$130$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
6,[$cljs$cst$5986$rect_x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$)+$rect_y$jscomp$2_rulers_pos$jscomp$inline_9424$$+-($guide_pill_height$jscomp$inline_9426_rect_height$jscomp$2$$/2)+-(4/$zoom$jscomp$130$$),$cljs$cst$5987$rect_y$$,$display_value$jscomp$1_pos$jscomp$162$$-$guide_pill_width$jscomp$inline_9425_rect_width$jscomp$2$$/2,$cljs$cst$5988$rect_width$$,$guide_pill_height$jscomp$inline_9426_rect_height$jscomp$2$$,
$cljs$cst$5989$rect_height$$,$guide_pill_width$jscomp$inline_9425_rect_width$jscomp$2$$,$cljs$cst$5950$text_x$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$)+$rect_y$jscomp$2_rulers_pos$jscomp$inline_9424$$+-(3/$zoom$jscomp$130$$),$cljs$cst$5951$text_y$$,$display_value$jscomp$1_pos$jscomp$162$$],null);var $map__81132__$1_text_y$jscomp$4$$=$APP.$cljs$core$__destructure_map$$($map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$);
$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81132__$1_text_y$jscomp$4$$,$cljs$cst$5986$rect_x$$);$rect_y$jscomp$2_rulers_pos$jscomp$inline_9424$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81132__$1_text_y$jscomp$4$$,$cljs$cst$5987$rect_y$$);$guide_pill_width$jscomp$inline_9425_rect_width$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81132__$1_text_y$jscomp$4$$,$cljs$cst$5988$rect_width$$);
$guide_pill_height$jscomp$inline_9426_rect_height$jscomp$2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81132__$1_text_y$jscomp$4$$,$cljs$cst$5989$rect_height$$);var $text_x$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81132__$1_text_y$jscomp$4$$,$cljs$cst$5950$text_x$$);$map__81132__$1_text_y$jscomp$4$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81132__$1_text_y$jscomp$4$$,$cljs$cst$5951$text_y$$);var $corner_radius$$=4/$zoom$jscomp$130$$;
$display_value$jscomp$1_pos$jscomp$162$$=$APP.$app$main$ui$formats$format_number$cljs$0core$0IFn$0_invoke$0arity$02$$($display_value$jscomp$1_pos$jscomp$162$$-$frame_offset$jscomp$11_input_w$$);$frame_offset$jscomp$11_input_w$$=34/$zoom$jscomp$130$$;var $input_h$$=20/$zoom$jscomp$130$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"guide-pill",children:[(0,$APP.$rumext$v2$jsx$$)("rect",{x:$map__81132_props_81126_rect_x$jscomp$2_vbox$jscomp$inline_9421$$,y:$rect_y$jscomp$2_rulers_pos$jscomp$inline_9424$$,
width:$guide_pill_width$jscomp$inline_9425_rect_width$jscomp$2$$,height:$guide_pill_height$jscomp$inline_9426_rect_height$jscomp$2$$,rx:$corner_radius$$,ry:$corner_radius$$,style:{fill:$color$jscomp$192$$},onDoubleClick:$on_double_click$jscomp$5$$}),$APP.$cljs$core$truth_$$($editing$jscomp$6$$)?(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$text_x$jscomp$4$$-$frame_offset$jscomp$11_input_w$$/2,y:$map__81132__$1_text_y$jscomp$4$$-$input_h$$/2,width:$frame_offset$jscomp$11_input_w$$,height:$input_h$$,
transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$57$$,$APP.$cljs$cst$1516$y$$)?["rotate(-90 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($text_x$jscomp$4$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81132__$1_text_y$jscomp$4$$),")"].join(""):null,children:(0,$APP.$rumext$v2$jsx$$)("input",{style:{width:"100%",height:"100%",margin:0,fontFamily:"worksans",border:"none",padding:0,outline:"none",fontSize:[$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(12/
$zoom$jscomp$130$$),"px"].join(""),MozAppearance:"textfield",background:"transparent",color:"#FFFFFF",textAlign:"center"},onBlur:$on_input_blur$$,type:"number",ref:$input_ref$jscomp$13$$,onPointerDown:$APP.$app$util$dom$stop_propagation$$,defaultValue:$display_value$jscomp$1_pos$jscomp$162$$,onKeyDown:$on_input_key_down$jscomp$1$$,autoFocus:!0,step:"any"})}):(0,$APP.$rumext$v2$jsx$$)("text",{x:$text_x$jscomp$4$$,y:$map__81132__$1_text_y$jscomp$4$$,textAnchor:"middle",dominantBaseline:"middle",transform:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$57$$,
$APP.$cljs$cst$1516$y$$)?["rotate(-90 ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($text_x$jscomp$4$$),",",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$($map__81132__$1_text_y$jscomp$4$$),")"].join(""):null,style:{fontSize:12/$zoom$jscomp$130$$,fontFamily:"worksans",fill:"#FFFFFF",pointerEvents:"none"},children:$display_value$jscomp$1_pos$jscomp$162$$})]})}),$app$main$ui$workspace$viewport$guides$guide_line_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_81135_width$jscomp$241$$){var $axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$=
$props_81135_width$jscomp$241$$.axis,$hover_QMARK_$jscomp$11_map__81140_x1$jscomp$47$$=$props_81135_width$jscomp$241$$["hover?"],$dash$jscomp$2_x2$jscomp$44_zoom$jscomp$131$$=$props_81135_width$jscomp$241$$.zoom,$frame$jscomp$92_l1_x1$$=$props_81135_width$jscomp$241$$.frame,$color$jscomp$193$$=$props_81135_width$jscomp$241$$.color,$l2_y2_vbox$jscomp$62$$=$props_81135_width$jscomp$241$$.vbox,$l2_y1_pos$jscomp$163$$=$props_81135_width$jscomp$241$$.pos,$show_main_QMARK__y1$jscomp$49$$=$props_81135_width$jscomp$241$$.showMain??
!0;$props_81135_width$jscomp$241$$=1/$dash$jscomp$2_x2$jscomp$44_zoom$jscomp$131$$;var $main_opacity$$=$APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$11_map__81140_x1$jscomp$47$$)?1:.7;$dash$jscomp$2_x2$jscomp$44_zoom$jscomp$131$$=["0, ",$APP.$cljs$core$str$$.$cljs$core$IFn$_invoke$arity$1$(6/$dash$jscomp$2_x2$jscomp$44_zoom$jscomp$131$$)].join("");if($frame$jscomp$92_l1_x1$$!=null){$axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$,
$APP.$cljs$cst$1515$x$$)?$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5974$l2_x2$$,$cljs$cst$5975$l1_x2$$,$cljs$cst$5976$l3_x2$$,$cljs$cst$5977$l3_x1$$,$cljs$cst$5978$l1_y1$$,$cljs$cst$5979$l3_y1$$,$cljs$cst$5980$l3_y2$$,$cljs$cst$5981$l1_y2$$,$cljs$cst$5982$l2_x1$$,$cljs$cst$5983$l1_x1$$,$cljs$cst$5984$l2_y2$$,$cljs$cst$5985$l2_y1$$],[$l2_y1_pos$jscomp$163$$,$l2_y1_pos$jscomp$163$$,$l2_y1_pos$jscomp$163$$,$l2_y1_pos$jscomp$163$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$),
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$),$l2_y1_pos$jscomp$163$$,$l2_y1_pos$jscomp$163$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$)+
$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$)]):$APP.$cljs$core$PersistentHashMap$fromArrays$$([$cljs$cst$5974$l2_x2$$,$cljs$cst$5975$l1_x2$$,$cljs$cst$5976$l3_x2$$,$cljs$cst$5977$l3_x1$$,$cljs$cst$5978$l1_y1$$,$cljs$cst$5979$l3_y1$$,$cljs$cst$5980$l3_y2$$,$cljs$cst$5981$l1_y2$$,$cljs$cst$5982$l2_x1$$,$cljs$cst$5983$l1_x1$$,$cljs$cst$5984$l2_y2$$,$cljs$cst$5985$l2_y1$$],[$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$)+
$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$),$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$),$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$),$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$),$l2_y1_pos$jscomp$163$$,
$l2_y1_pos$jscomp$163$$,$l2_y1_pos$jscomp$163$$,$l2_y1_pos$jscomp$163$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$92_l1_x1$$),$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$),$l2_y1_pos$jscomp$163$$,$l2_y1_pos$jscomp$163$$]);var $l3_y2_map__81138__$1$$=$APP.$cljs$core$__destructure_map$$($axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$);$axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,
$cljs$cst$5982$l2_x1$$);$frame$jscomp$92_l1_x1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5983$l1_x1$$);$l2_y2_vbox$jscomp$62$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5984$l2_y2$$);$l2_y1_pos$jscomp$163$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5985$l2_y1$$);var $l2_x2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5974$l2_x2$$),
$l1_x2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5975$l1_x2$$),$l3_x2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5976$l3_x2$$),$l3_x1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5977$l3_x1$$),$l1_y1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5978$l1_y1$$),$l1_y2$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,
$cljs$cst$5981$l1_y2$$),$l3_y1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5979$l3_y1$$);$l3_y2_map__81138__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($l3_y2_map__81138__$1$$,$cljs$cst$5980$l3_y2$$);return(0,$APP.$rumext$v2$jsxs$$)("g",{children:[$APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$11_map__81140_x1$jscomp$47$$)?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$frame$jscomp$92_l1_x1$$,y1:$l1_y1$$,x2:$l1_x2$$,y2:$l1_y2$$,style:{stroke:$color$jscomp$193$$,
strokeOpacity:1,strokeDasharray:$dash$jscomp$2_x2$jscomp$44_zoom$jscomp$131$$,strokeLinecap:"round",strokeWidth:$props_81135_width$jscomp$241$$}}):null,$APP.$cljs$core$truth_$$($show_main_QMARK__y1$jscomp$49$$)?(0,$APP.$rumext$v2$jsx$$)("line",{x1:$axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$,y1:$l2_y1_pos$jscomp$163$$,x2:$l2_x2$$,y2:$l2_y2_vbox$jscomp$62$$,style:{stroke:$color$jscomp$193$$,strokeWidth:$props_81135_width$jscomp$241$$,strokeOpacity:$main_opacity$$}}):null,$APP.$cljs$core$truth_$$($hover_QMARK_$jscomp$11_map__81140_x1$jscomp$47$$)?
(0,$APP.$rumext$v2$jsx$$)("line",{x1:$l3_x1$$,y1:$l3_y1$$,x2:$l3_x2$$,y2:$l3_y2_map__81138__$1$$,style:{stroke:$color$jscomp$193$$,strokeOpacity:1,strokeWidth:$props_81135_width$jscomp$241$$,strokeDasharray:$dash$jscomp$2_x2$jscomp$44_zoom$jscomp$131$$,strokeLinecap:"round"}}):null]})}return $APP.$cljs$core$truth_$$($show_main_QMARK__y1$jscomp$49$$)?($hover_QMARK_$jscomp$11_map__81140_x1$jscomp$47$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$,
$APP.$cljs$cst$1515$x$$)?new $APP.$cljs$core$PersistentArrayMap$$(null,4,[$APP.$cljs$cst$1528$x1$$,$l2_y1_pos$jscomp$163$$,$APP.$cljs$cst$1529$y1$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$),$APP.$cljs$cst$1530$x2$$,$l2_y1_pos$jscomp$163$$,$APP.$cljs$cst$1531$y2$$,$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$)+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$)],null):new $APP.$cljs$core$PersistentArrayMap$$(null,
4,[$APP.$cljs$cst$1528$x1$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$),$APP.$cljs$cst$1529$y1$$,$l2_y1_pos$jscomp$163$$,$APP.$cljs$cst$1530$x2$$,$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$)+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($l2_y2_vbox$jscomp$62$$),$APP.$cljs$cst$1531$y2$$,$l2_y1_pos$jscomp$163$$],null),$axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$=$APP.$cljs$core$__destructure_map$$($hover_QMARK_$jscomp$11_map__81140_x1$jscomp$47$$),
$hover_QMARK_$jscomp$11_map__81140_x1$jscomp$47$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$,$APP.$cljs$cst$1528$x1$$),$show_main_QMARK__y1$jscomp$49$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$,$APP.$cljs$cst$1529$y1$$),$dash$jscomp$2_x2$jscomp$44_zoom$jscomp$131$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$,
$APP.$cljs$cst$1530$x2$$),$axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$,$APP.$cljs$cst$1531$y2$$),(0,$APP.$rumext$v2$jsx$$)("line",{x1:$hover_QMARK_$jscomp$11_map__81140_x1$jscomp$47$$,y1:$show_main_QMARK__y1$jscomp$49$$,x2:$dash$jscomp$2_x2$jscomp$44_zoom$jscomp$131$$,y2:$axis$jscomp$58_l2_x1_map__81138_map__81140__$1_y2$jscomp$46$$,style:{stroke:$color$jscomp$193$$,
strokeWidth:$props_81135_width$jscomp$241$$,strokeOpacity:$main_opacity$$}})):null}),$app$main$ui$workspace$viewport$guides$guide_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($guide_color_props_81149$$){var $zoom$jscomp$132$$=$guide_color_props_81149$$.zoom,$vbox$jscomp$63$$=$guide_color_props_81149$$.vbox,$guide$jscomp$15$$=$guide_color_props_81149$$.guide,$frame_modifier$$=$guide_color_props_81149$$.frameModifier,$frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$=
$guide_color_props_81149$$.getHoverFrame,$on_guide_change$jscomp$1$$=$guide_color_props_81149$$.onGuideChange,$disabled_guides$$=$guide_color_props_81149$$.disabledGuides,$hover_frame_move_vec$jscomp$5_on_input_key_down$jscomp$2$$=$guide_color_props_81149$$.hoverFrame,$is_hover$jscomp$5$$=$guide_color_props_81149$$.isHover,$frame_transform$$=$guide_color_props_81149$$.frameTransform,$on_guide_context_menu$$=$guide_color_props_81149$$.onGuideContextMenu,$axis$jscomp$59$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($guide$jscomp$15$$,
$APP.$cljs$cst$2062$axis$$);$guide_color_props_81149$$=function(){var $or__5025__auto__$jscomp$1393$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$15$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1393$$)?$or__5025__auto__$jscomp$1393$$:"#ff3277"}();var $read_only_QMARK_$jscomp$32$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$is_editing_STAR_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$is_editing$jscomp$7$$=
$APP.$cljs$core$_deref$$($is_editing_STAR_$$),$input_ref$jscomp$14$$=(0,$APP.$rumext$v2$use_ref$$)(null),$handle_change_position$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($on_guide_change$jscomp$1$$),$APP.$rumext$v2$adapt$$($guide$jscomp$15$$)],function($G__81152_changes$jscomp$338$$){return $APP.$cljs$core$truth_$$($on_guide_change$jscomp$1$$)?($G__81152_changes$jscomp$338$$=$APP.$cljs$core$merge$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$guide$jscomp$15$$,
$G__81152_changes$jscomp$338$$])),$on_guide_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__81152_changes$jscomp$338$$):$on_guide_change$jscomp$1$$($G__81152_changes$jscomp$338$$)):null});$frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$=$app$main$ui$workspace$viewport$guides$use_guide$$($handle_change_position$$,$frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,$zoom$jscomp$132$$,$guide$jscomp$15$$);
$frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$=$APP.$cljs$core$__destructure_map$$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$);var $on_pointer_enter$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,$cljs$cst$5971$on_pointer_enter$$),$on_pointer_leave$jscomp$14$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,
$cljs$cst$5972$on_pointer_leave$$),$on_pointer_down$jscomp$16$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,$APP.$cljs$cst$4610$on_pointer_down$$),$on_pointer_up$jscomp$5$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,$cljs$cst$5973$on_pointer_up$$),$on_lost_pointer_capture$jscomp$10$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,
$APP.$cljs$cst$4611$on_lost_pointer_capture$$),$on_pointer_move$jscomp$13$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,$APP.$cljs$cst$4612$on_pointer_move$$),$state$jscomp$1236$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,$APP.$cljs$cst$769$state$$);$frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$,
$APP.$cljs$cst$1611$frame$$);var $base_frame$jscomp$12$$=$APP.$cljs$core$truth_$$($frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$)?$frame$jscomp$93_get_hover_frame$jscomp$1_map__81151_map__81151__$1$$:$hover_frame_move_vec$jscomp$5_on_input_key_down$jscomp$2$$,$frame__$1$jscomp$9$$=function(){var $G__81157__$1$$=$frame_modifier$$!=null?$APP.$app$common$geom$shapes$transform_shape$$.$cljs$core$IFn$_invoke$arity$2$($base_frame$jscomp$12$$,$frame_modifier$$):$base_frame$jscomp$12$$;
return $frame_transform$$!=null?$APP.$app$common$geom$shapes$transforms$apply_transform$$($G__81157__$1$$,$frame_transform$$):$G__81157__$1$$}();$hover_frame_move_vec$jscomp$5_on_input_key_down$jscomp$2$$=$APP.$app$common$geom$point$to_vec$$($APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($base_frame$jscomp$12$$),$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($base_frame$jscomp$12$$)),$APP.$app$common$geom$point$point$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$9$$),
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$9$$)));var $pos$jscomp$164$$=function(){var $or__5025__auto__$jscomp$1395$$=$cljs$cst$5970$new_position$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1236$$));return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1395$$)?$or__5025__auto__$jscomp$1395$$:$APP.$cljs$cst$1681$position$$.$cljs$core$IFn$_invoke$arity$1$($guide$jscomp$15$$)}()+$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($hover_frame_move_vec$jscomp$5_on_input_key_down$jscomp$2$$,
$axis$jscomp$59$$),$frame_guide_outside_QMARK_$$=$frame__$1$jscomp$9$$!=null&&!$app$main$ui$workspace$viewport$guides$is_guide_inside_frame_QMARK_$$($APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$15$$,$APP.$cljs$cst$1681$position$$,$pos$jscomp$164$$),$frame__$1$jscomp$9$$),$frame_offset$jscomp$12$$=$frame__$1$jscomp$9$$!=null?$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$59$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$9$$):
$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$9$$):0,$accept_editing$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_offset$jscomp$12$$),$APP.$rumext$v2$adapt$$($on_guide_change$jscomp$1$$),$APP.$rumext$v2$adapt$$($guide$jscomp$15$$)],function(){var $G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$=$APP.$rumext$v2$ref_val$$($input_ref$jscomp$14$$);return $APP.$cljs$core$truth_$$($G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$)&&
($G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$=$APP.$app$common$data$parse_double$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$))),$APP.$cljs$core$reset_BANG_$$($is_editing_STAR_$$,!1),$G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$!=null&&$on_guide_change$jscomp$1$$!=null)?($G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$=$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($guide$jscomp$15$$,
$APP.$cljs$cst$1681$position$$,$G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$+$frame_offset$jscomp$12$$),$on_guide_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$?$on_guide_change$jscomp$1$$.$cljs$core$IFn$_invoke$arity$1$($G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$):$on_guide_change$jscomp$1$$($G__81158_parsed$jscomp$10_temp__5825__auto__$jscomp$443$$)):null}),$cancel_editing$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$cljs$core$reset_BANG_$$($is_editing_STAR_$$,
!1)});$hover_frame_move_vec$jscomp$5_on_input_key_down$jscomp$2$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($accept_editing$$),$APP.$rumext$v2$adapt$$($cancel_editing$$)],function($event$jscomp$706$$){return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$706$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$706$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$706$$),$accept_editing$$.$cljs$core$IFn$_invoke$arity$0$?
$accept_editing$$.$cljs$core$IFn$_invoke$arity$0$():$accept_editing$$()):$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$706$$))?($APP.$app$util$dom$prevent_default$$($event$jscomp$706$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$706$$),$cancel_editing$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_editing$$.$cljs$core$IFn$_invoke$arity$0$():$cancel_editing$$()):null});var $on_double_click$jscomp$6$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($read_only_QMARK_$jscomp$32$$)],
function($event$jscomp$707$$){if($APP.$cljs$core$truth_$$($read_only_QMARK_$jscomp$32$$))return null;$APP.$app$util$dom$stop_propagation$$($event$jscomp$707$$);return $APP.$cljs$core$reset_BANG_$$($is_editing_STAR_$$,!0)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($is_editing$jscomp$7$$)],function(){if($APP.$cljs$core$truth_$$($is_editing$jscomp$7$$)){var $G__81159$$=$APP.$rumext$v2$ref_val$$($input_ref$jscomp$14$$);return $G__81159$$==null?null:$APP.$app$util$dom$select_text_BANG_$$($G__81159$$)}return null});
return $frame__$1$jscomp$9$$==null||$APP.$app$common$files$helpers$root_frame_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($frame__$1$jscomp$9$$)&&$APP.$app$common$math$almost_zero_QMARK_$$($APP.$cljs$cst$1794$rotation$$.$cljs$core$IFn$_invoke$arity$2$($frame__$1$jscomp$9$$,0))?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"guide-area",opacity:$frame_guide_outside_QMARK_$$?0:null,children:[$APP.$cljs$core$truth_$$($disabled_guides$$)?null:function(){var $map__81164_x$jscomp$1289$$=$app$main$ui$workspace$viewport$guides$guide_area_axis$$($pos$jscomp$164$$,
$vbox$jscomp$63$$,$zoom$jscomp$132$$,$frame__$1$jscomp$9$$,$axis$jscomp$59$$),$height$jscomp$208_map__81164__$1$$=$APP.$cljs$core$__destructure_map$$($map__81164_x$jscomp$1289$$);$map__81164_x$jscomp$1289$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$208_map__81164__$1$$,$APP.$cljs$cst$1515$x$$);var $y$jscomp$512$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$208_map__81164__$1$$,$APP.$cljs$cst$1516$y$$),$width$jscomp$242$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$208_map__81164__$1$$,
$APP.$cljs$cst$290$width$$);$height$jscomp$208_map__81164__$1$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($height$jscomp$208_map__81164__$1$$,$APP.$cljs$cst$1527$height$$);return(0,$APP.$rumext$v2$jsx$$)("rect",{onDoubleClick:$on_double_click$jscomp$6$$,width:$width$jscomp$242$$,height:$height$jscomp$208_map__81164__$1$$,className:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$59$$,$APP.$cljs$cst$1515$x$$)?$app$main$ui$css_cursors$get_dynamic$$("resize-ew",0):$app$main$ui$css_cursors$get_dynamic$$("resize-ns",
0),x:$map__81164_x$jscomp$1289$$,onPointerUp:$on_pointer_up$jscomp$5$$,onContextMenu:function($event$jscomp$708$$){$APP.$app$util$dom$prevent_default$$($event$jscomp$708$$);$APP.$app$util$dom$stop_propagation$$($event$jscomp$708$$);return $APP.$cljs$core$truth_$$($on_guide_context_menu$$)?$on_guide_context_menu$$.$cljs$core$IFn$_invoke$arity$2$?$on_guide_context_menu$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$708$$,$guide$jscomp$15$$):$on_guide_context_menu$$($event$jscomp$708$$,$guide$jscomp$15$$):
null},style:{fill:"none",pointerEvents:$frame_guide_outside_QMARK_$$?"none":"fill"},onLostPointerCapture:$on_lost_pointer_capture$jscomp$10$$,y:$y$jscomp$512$$,onPointerMove:$on_pointer_move$jscomp$13$$,onPointerDown:$on_pointer_down$jscomp$16$$,onPointerLeave:$on_pointer_leave$jscomp$14$$,onPointerEnter:$on_pointer_enter$jscomp$14$$})}(),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_line_STAR_$$,{pos:$pos$jscomp$164$$,vbox:$vbox$jscomp$63$$,zoom:$zoom$jscomp$132$$,axis:$axis$jscomp$59$$,
color:$guide_color_props_81149$$,frame:$frame__$1$jscomp$9$$,"hover?":$APP.$cljs$core$truth_$$($is_hover$jscomp$5$$)?$is_hover$jscomp$5$$:$APP.$cljs$cst$2212$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1236$$))}),$APP.$cljs$core$truth_$$(function(){if($APP.$cljs$core$truth_$$($is_hover$jscomp$5$$))return $is_hover$jscomp$5$$;var $or__5025__auto____$1$jscomp$155$$=$APP.$cljs$cst$2212$hover$$.$cljs$core$IFn$_invoke$arity$1$($APP.$cljs$core$_deref$$($state$jscomp$1236$$));
return $APP.$cljs$core$truth_$$($or__5025__auto____$1$jscomp$155$$)?$or__5025__auto____$1$jscomp$155$$:$is_editing$jscomp$7$$}())?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_pill_STAR_$$,{inputRef:$input_ref$jscomp$14$$,onDoubleClick:$on_double_click$jscomp$6$$,pos:$pos$jscomp$164$$,onInputKeyDown:$hover_frame_move_vec$jscomp$5_on_input_key_down$jscomp$2$$,zoom:$zoom$jscomp$132$$,frameOffset:$frame_offset$jscomp$12$$,onInputBlur:$accept_editing$$,axis:$axis$jscomp$59$$,
vbox:$vbox$jscomp$63$$,editing:$is_editing$jscomp$7$$,color:$guide_color_props_81149$$}):null]}):null}),$app$main$ui$workspace$viewport$guides$viewport_guides_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_81259_visible_guides$$){var $wasm_guides$jscomp$2$$=$props_81259_visible_guides$$.wasmGuides,$on_guide_hover$jscomp$2$$=$props_81259_visible_guides$$.onGuideHover,$zoom$jscomp$137$$=$props_81259_visible_guides$$.zoom,$vbox$jscomp$67$$=$props_81259_visible_guides$$.vbox,
$on_guide_drag$jscomp$2$$=$props_81259_visible_guides$$.onGuideDrag,$modifiers$jscomp$134$$=$props_81259_visible_guides$$.modifiers,$guides$jscomp$15$$=$props_81259_visible_guides$$.guides,$disabled_guides$jscomp$2$$=$props_81259_visible_guides$$.disabledGuides,$wasm_guides_QMARK_$jscomp$2$$=$props_81259_visible_guides$$.wasmGuides,$hover_frame$jscomp$1$$=$props_81259_visible_guides$$.hoverFrame;$props_81259_visible_guides$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($guides$jscomp$15$$),
$APP.$rumext$v2$adapt$$($vbox$jscomp$67$$)],function(){return $APP.$cljs$core$filter$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$core$partial$cljs$0core$0IFn$0_invoke$0arity$03$$($app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$,$zoom$jscomp$137$$,$vbox$jscomp$67$$),$APP.$cljs$core$vals$$($guides$jscomp$15$$))});var $focus$jscomp$22$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_focus_selected$$),$hover_frame_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$get_hover_frame$jscomp$5$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function(){return $APP.$rumext$v2$ref_val$$($hover_frame_ref$$)}),$on_guide_change$jscomp$5$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($vbox$jscomp$67$$)],function($guide$jscomp$26$$){return $app$main$ui$workspace$viewport$guides$guide_inside_vbox_QMARK_$$.$cljs$core$IFn$_invoke$arity$3$($zoom$jscomp$137$$,$vbox$jscomp$67$$,$guide$jscomp$26$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$guides$update_guides$$($guide$jscomp$26$$)):
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$guides$remove_guide$$($guide$jscomp$26$$))}),$on_guide_context_menu$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$01$$(function($event$jscomp$716_position$jscomp$241$$,$guide$jscomp$27$$){$event$jscomp$716_position$jscomp$241$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$716_position$jscomp$241$$);return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_guide_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,
2,[$APP.$cljs$cst$1681$position$$,$event$jscomp$716_position$jscomp$241$$,$APP.$cljs$cst$3916$guide$$,$guide$jscomp$27$$],null)))}),$on_wasm_context_menu$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($wasm_guides$jscomp$2$$),$APP.$rumext$v2$adapt$$($zoom$jscomp$137$$),$APP.$rumext$v2$adapt$$($disabled_guides$jscomp$2$$)],function($event$jscomp$717$$){if($APP.$cljs$core$truth_$$($disabled_guides$jscomp$2$$))return null;var $position$jscomp$242$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$717$$),
$guide$jscomp$28_index$jscomp$578_pt$jscomp$37$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($position$jscomp$242$$);$guide$jscomp$28_index$jscomp$578_pt$jscomp$37$$=$APP.$cljs$core$truth_$$($guide$jscomp$28_index$jscomp$578_pt$jscomp$37$$)?$app$render_wasm$api$find_guide_at$$($guide$jscomp$28_index$jscomp$578_pt$jscomp$37$$,$zoom$jscomp$137$$):null;$guide$jscomp$28_index$jscomp$578_pt$jscomp$37$$=$app$main$ui$workspace$viewport$guides$guide_by_serialized_index$$($wasm_guides$jscomp$2$$,
$guide$jscomp$28_index$jscomp$578_pt$jscomp$37$$);return $APP.$cljs$core$truth_$$($guide$jscomp$28_index$jscomp$578_pt$jscomp$37$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$717$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$717$$),$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$show_guide_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$position$$,$position$jscomp$242$$,$APP.$cljs$cst$3916$guide$$,$guide$jscomp$28_index$jscomp$578_pt$jscomp$37$$],
null)))):null}),$frame_modifiers$$=$APP.$cljs$core$update_vals$$($APP.$cljs$core$group_by$$($APP.$cljs$cst$266$id$$,$modifiers$jscomp$134$$),$APP.$cljs$core$comp$$.$cljs$core$IFn$_invoke$arity$2$($APP.$cljs$cst$1294$transform$$,$APP.$cljs$core$first$$));$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($hover_frame$jscomp$1$$)],function(){return $APP.$rumext$v2$set_ref_val_BANG_$$($hover_frame_ref$$,$hover_frame$jscomp$1$$)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($wasm_guides_QMARK_$jscomp$2$$),
$APP.$rumext$v2$adapt$$($disabled_guides$jscomp$2$$),$APP.$rumext$v2$adapt$$($on_wasm_context_menu$$)],function(){if($APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($wasm_guides_QMARK_$jscomp$2$$)?$APP.$cljs$core$not$$($disabled_guides$jscomp$2$$):$wasm_guides_QMARK_$jscomp$2$$)){var $temp__5825__auto__$jscomp$450$$=$APP.$cljs$core$_deref$$($app$main$ui$workspace$viewport$viewport_ref$viewport_ref$$);if($APP.$cljs$core$truth_$$($temp__5825__auto__$jscomp$450$$))return $temp__5825__auto__$jscomp$450$$.addEventListener("contextmenu",
$on_wasm_context_menu$$,!0),function(){return $temp__5825__auto__$jscomp$450$$.removeEventListener("contextmenu",$on_wasm_context_menu$$,!0)}}return null});return(0,$APP.$rumext$v2$jsxs$$)("g",{className:"guides",pointerEvents:"none",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$new_guide_area_STAR_$$,{vbox:$vbox$jscomp$67$$,zoom:$zoom$jscomp$137$$,axis:$APP.$cljs$cst$1515$x$$,getHoverFrame:$get_hover_frame$jscomp$5$$,disabledGuides:$disabled_guides$jscomp$2$$}),(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$new_guide_area_STAR_$$,
{vbox:$vbox$jscomp$67$$,zoom:$zoom$jscomp$137$$,axis:$APP.$cljs$cst$1516$y$$,getHoverFrame:$get_hover_frame$jscomp$5$$,disabledGuides:$disabled_guides$jscomp$2$$}),$APP.$cljs$core$truth_$$($wasm_guides_QMARK_$jscomp$2$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$wasm_guide_overlay_layer_STAR_$$,{disabledGuides:$disabled_guides$jscomp$2$$,zoom:$zoom$jscomp$137$$,focus:$focus$jscomp$22$$,vbox:$vbox$jscomp$67$$,onGuideDrag:$on_guide_drag$jscomp$2$$,onGuideChange:$on_guide_change$jscomp$5$$,
onGuideHover:$on_guide_hover$jscomp$2$$,getHoverFrame:$get_hover_frame$jscomp$5$$,wasmGuides:$wasm_guides$jscomp$2$$}):null,$APP.$cljs$core$truth_$$($wasm_guides_QMARK_$jscomp$2$$)?null:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$232$$,$map__81277__$1_p__81276$$){$map__81277__$1_p__81276$$=$APP.$cljs$core$__destructure_map$$($map__81277__$1_p__81276$$);var $id$jscomp$1056$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81277__$1_p__81276$$,
$APP.$cljs$cst$266$id$$),$frame_id$jscomp$162$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81277__$1_p__81276$$,$APP.$cljs$cst$1612$frame_id$$);$out_arr__44092__auto__$jscomp$232$$.push($app$main$ui$workspace$viewport$guides$guide_visible_in_focus_QMARK_$$($focus$jscomp$22$$,$frame_id$jscomp$162$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$guides$guide_STAR_$$,{zoom:$zoom$jscomp$137$$,vbox:$vbox$jscomp$67$$,guide:$map__81277__$1_p__81276$$,getHoverFrame:$get_hover_frame$jscomp$5$$,
disabledGuides:$disabled_guides$jscomp$2$$,onGuideChange:$on_guide_change$jscomp$5$$,frameTransform:$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($frame_modifiers$$,$frame_id$jscomp$162$$),onGuideContextMenu:$on_guide_context_menu$jscomp$1$$},"guide-"+($id$jscomp$1056$$??"")):null);return $out_arr__44092__auto__$jscomp$232$$},[],$props_81259_visible_guides$$)]})});var $app$main$data$workspace$grid_layout$shortcuts$esc_pressed_81154$$,$app$main$data$workspace$grid_layout$shortcuts$shortcuts$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$4904$escape$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2957$tooltip$$,$APP.$app$main$data$shortcuts$esc$$(),$APP.$cljs$cst$1818$command$$,new $APP.$cljs$core$PersistentVector$$(null,3,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,["escape","enter","v"],null),$APP.$cljs$cst$516$fn$$,
function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$grid_layout$shortcuts$esc_pressed$$())}],null),$APP.$cljs$cst$4961$undo$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2957$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("Z"),$APP.$cljs$cst$1818$command$$,$APP.$app$main$data$shortcuts$c_mod$$("z"),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$undo$$)}],
null),$APP.$cljs$cst$4934$redo$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2957$tooltip$$,$APP.$app$main$data$shortcuts$meta$$("Y"),$APP.$cljs$cst$1818$command$$,new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$APP.$app$main$data$shortcuts$c_mod$$("shift+z"),$APP.$app$main$data$shortcuts$c_mod$$("y")],null),$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$undo$redo$$)}],
null),$APP.$cljs$cst$4957$increase_zoom$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2957$tooltip$$,"+",$APP.$cljs$cst$1818$command$$,"+",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$increase_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}],null),$APP.$cljs$cst$4952$decrease_zoom$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2957$tooltip$$,"-",$APP.$cljs$cst$1818$command$$,
"-",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$decrease_zoom$$.$cljs$core$IFn$_invoke$arity$1$(null))}],null),$APP.$cljs$cst$4960$reset_zoom$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2957$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("0"),$APP.$cljs$cst$1818$command$$,"shift+0",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$reset_zoom$$)}],
null),$APP.$cljs$cst$4918$fit_all$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2957$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("1"),$APP.$cljs$cst$1818$command$$,"shift+1",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_fit_all$$)}],null),$APP.$cljs$cst$4968$zoom_selected$$,new $APP.$cljs$core$PersistentArrayMap$$(null,3,[$APP.$cljs$cst$2957$tooltip$$,$APP.$app$main$data$shortcuts$shift$$("2"),
$APP.$cljs$cst$1818$command$$,"shift+2",$APP.$cljs$cst$516$fn$$,function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$zoom$zoom_to_selected_shape$$)}],null)],null);var $app$main$ui$workspace$viewport$outline$shape_outlines_render_STAR_$$=function($p1__81272_SHARP_$$){return(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)($p1__81272_SHARP_$$,function($new_props_81274$$,$old_props_81275$$){return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81274$$.shapes,$old_props_81275$$.shapes)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81274$$.zoom,$old_props_81275$$.zoom)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($new_props_81274$$.modifiers,
$old_props_81275$$.modifiers)})}(function($props_81273$$){var $zoom$jscomp$142$$=$props_81273$$.zoom,$modifiers$jscomp$136$$=$props_81273$$.modifiers;return $APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$233$$,$JSCompiler_inline_result$jscomp$1953_shape$jscomp$1094$$){var $JSCompiler_temp_const$jscomp$1951$$=$out_arr__44092__auto__$jscomp$233$$.push,$shape_id$jscomp$inline_9465$$=$JSCompiler_inline_result$jscomp$1953_shape$jscomp$1094$$?.id??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_inline_result$jscomp$1953_shape$jscomp$1094$$,
$APP.$cljs$cst$266$id$$),$modifier$jscomp$inline_9466$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($modifiers$jscomp$136$$,$shape_id$jscomp$inline_9465$$);$JSCompiler_inline_result$jscomp$1953_shape$jscomp$1094$$=(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$outline$outline_STAR_$$,{shape:$JSCompiler_inline_result$jscomp$1953_shape$jscomp$1094$$,modifier:$modifier$jscomp$inline_9466$$,zoom:$zoom$jscomp$142$$},"outline-"+($shape_id$jscomp$inline_9465$$??""));$JSCompiler_temp_const$jscomp$1951$$.call($out_arr__44092__auto__$jscomp$233$$,
$JSCompiler_inline_result$jscomp$1953_shape$jscomp$1094$$);return $out_arr__44092__auto__$jscomp$233$$},[],$props_81273$$.shapes)});var $app$main$ui$workspace$viewport$interactions$interactions_ref$$=$APP.$okulary$core$derived$cljs$0core$0IFn$0_invoke$0arity$03$$(function($p1__81298_SHARP_$$){return new $APP.$cljs$core$PersistentArrayMap$$(null,5,[$APP.$cljs$cst$4385$draw_interaction_to_frame$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__81298_SHARP_$$,$APP.$cljs$cst$4385$draw_interaction_to_frame$$),$APP.$cljs$cst$4382$editing_interaction_index$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__81298_SHARP_$$,
$APP.$cljs$cst$4382$editing_interaction_index$$),$APP.$cljs$cst$4389$move_overlay_index$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__81298_SHARP_$$,$APP.$cljs$cst$4389$move_overlay_index$$),$APP.$cljs$cst$4388$move_overlay_to$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__81298_SHARP_$$,$APP.$cljs$cst$4388$move_overlay_to$$),$APP.$cljs$cst$4384$draw_interaction_to$$,$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($p1__81298_SHARP_$$,$APP.$cljs$cst$4384$draw_interaction_to$$)],
null)},$APP.$app$main$refs$workspace_local$$,$APP.$cljs$core$_EQ_$$);var $app$main$ui$workspace$viewport$pixel_overlay$get_offscreen_canvas$$=function(){var $internal_state$jscomp$4$$={canvas:null};return function($new_canvas_width$jscomp$248$$,$height$jscomp$214$$){var $canvas$jscomp$23$$=$internal_state$jscomp$4$$.canvas;if($APP.$cljs$core$truth_$$($canvas$jscomp$23$$)){var $resized$jscomp$inline_9480$$=$APP.$cljs$core$volatile_BANG_$$(!1);$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($canvas$jscomp$23$$.width,$new_canvas_width$jscomp$248$$)||($APP.$app$util$object$set_BANG_$$($canvas$jscomp$23$$,
"width",$new_canvas_width$jscomp$248$$),$APP.$cljs$core$_vreset_BANG_$$($resized$jscomp$inline_9480$$,!0));$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($canvas$jscomp$23$$.height,$height$jscomp$214$$)||($APP.$app$util$object$set_BANG_$$($canvas$jscomp$23$$,"height",$height$jscomp$214$$),$APP.$cljs$core$_vreset_BANG_$$($resized$jscomp$inline_9480$$,!0));return $canvas$jscomp$23$$}$new_canvas_width$jscomp$248$$=new OffscreenCanvas($new_canvas_width$jscomp$248$$,$height$jscomp$214$$);$APP.$app$util$object$set_BANG_$$($internal_state$jscomp$4$$,
"canvas",$new_canvas_width$jscomp$248$$);return $new_canvas_width$jscomp$248$$}}(),$app$main$ui$workspace$viewport$pixel_overlay$get_pick_canvas$$=function(){var $internal_state$jscomp$5$$={canvas:null};return function(){var $c$jscomp$319_or__5025__auto__$jscomp$1414$$=$internal_state$jscomp$5$$.canvas;if($APP.$cljs$core$truth_$$($c$jscomp$319_or__5025__auto__$jscomp$1414$$))return $c$jscomp$319_or__5025__auto__$jscomp$1414$$;$c$jscomp$319_or__5025__auto__$jscomp$1414$$=new OffscreenCanvas(1,1);$APP.$app$util$object$set_BANG_$$($internal_state$jscomp$5$$,
"canvas",$c$jscomp$319_or__5025__auto__$jscomp$1414$$);return $c$jscomp$319_or__5025__auto__$jscomp$1414$$}}();var $app$main$ui$workspace$viewport$presence$session_cursor$$=(0,$APP.$rumext$v2$memo_SINGLEQUOTE_$$)(function($props_81327_transform$jscomp$118_zoom$jscomp$148$$){var $fullname$jscomp$6_fullname__$1_profile$jscomp$88$$=$props_81327_transform$jscomp$118_zoom$jscomp$148$$.profile,$bg_color_session$jscomp$5$$=$props_81327_transform$jscomp$118_zoom$jscomp$148$$.session;$props_81327_transform$jscomp$118_zoom$jscomp$148$$=$props_81327_transform$jscomp$118_zoom$jscomp$148$$.zoom;var $point$jscomp$89$$=
$APP.$cljs$cst$2171$point$$.$cljs$core$IFn$_invoke$arity$1$($bg_color_session$jscomp$5$$);$bg_color_session$jscomp$5$$=$APP.$cljs$cst$1303$color$$.$cljs$core$IFn$_invoke$arity$1$($bg_color_session$jscomp$5$$);$props_81327_transform$jscomp$118_zoom$jscomp$148$$="translate("+($point$jscomp$89$$?.x??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$89$$,$APP.$cljs$cst$1515$x$$)??"")+", "+($point$jscomp$89$$?.y??$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($point$jscomp$89$$,
$APP.$cljs$cst$1516$y$$)??"")+") scale("+1/$props_81327_transform$jscomp$118_zoom$jscomp$148$$+")";$fullname$jscomp$6_fullname__$1_profile$jscomp$88$$=$APP.$cljs$cst$1365$fullname$$.$cljs$core$IFn$_invoke$arity$1$($fullname$jscomp$6_fullname__$1_profile$jscomp$88$$);$fullname$jscomp$6_fullname__$1_profile$jscomp$88$$=$APP.$cljs$core$count$$($fullname$jscomp$6_fullname__$1_profile$jscomp$88$$)>16?""+($APP.$cuerdas$core$slice$cljs$0core$0IFn$0_invoke$0arity$03$$($fullname$jscomp$6_fullname__$1_profile$jscomp$88$$,
0,12)??"")+"...":$fullname$jscomp$6_fullname__$1_profile$jscomp$88$$;return(0,$APP.$rumext$v2$jsxs$$)("g",{transform:$props_81327_transform$jscomp$118_zoom$jscomp$148$$,className:"main_ui_workspace_viewport_presence__multiuser-cursor",children:[(0,$APP.$rumext$v2$jsx$$)("path",{fill:$bg_color_session$jscomp$5$$,d:"M11.58,-0.47L11.47,-0.35L0.34,10.77L0.30,10.96L-0.46,15.52L4.29,14.72L15.53,3.47L11.58,-0.47ZL11.58,-0.47ZL11.58,-0.47ZM11.58,1.3C12.31,2.05,13.02,2.742,13.76,3.47L4.0053,13.23C3.27,12.50,2.55,11.78,1.82,11.05L11.58,1.30ZL11.58,1.30ZM1.37,12.15L2.90,13.68L1.67,13.89L1.165,13.39L1.37,12.15ZL1.37,12.15Z"}),
(0,$APP.$rumext$v2$jsx$$)("g",{transform:"translate(17 -10)",children:(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:-.3,y:-12.5,width:300,height:120,children:(0,$APP.$rumext$v2$jsx$$)("div",{style:{backgroundColor:$bg_color_session$jscomp$5$$,color:"var(--app-white)"},className:"main_ui_workspace_viewport_presence__profile-name",children:$fullname$jscomp$6_fullname__$1_profile$jscomp$88$$})})})]})});var $app$main$ui$workspace$viewport$scroll_bars$viewport_scrollbars_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($bottom_padding_props_81386_show_h_scroll_QMARK_$$){function $on_pointer_up$jscomp$7$$(){$APP.$cljs$core$reset_BANG_$$($v_scrolling_QMARK_$$,!1);return $APP.$cljs$core$reset_BANG_$$($h_scrolling_QMARK_$$,!1)}function $on_pointer_down$jscomp$19$$($event$jscomp$730_start_pt$jscomp$6$$,$axis$jscomp$67$$){$event$jscomp$730_start_pt$jscomp$6$$=$APP.$app$util$dom$get_client_position$$($event$jscomp$730_start_pt$jscomp$6$$);
var $new_v_scrollbar_y$jscomp$1_viewport_point$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($event$jscomp$730_start_pt$jscomp$6$$),$new_h_scrollbar_x$jscomp$1$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($new_v_scrollbar_y$jscomp$1_viewport_point$$);$new_v_scrollbar_y$jscomp$1_viewport_point$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($new_v_scrollbar_y$jscomp$1_viewport_point$$);var $v_scrollbar_y_padding$$=$v_scrollbar_y__$2$$-$new_v_scrollbar_y$jscomp$1_viewport_point$$,
$h_scrollbar_x_padding$$=$h_scrollbar_x__$2$$-$new_h_scrollbar_x$jscomp$1$$,$height_factor_vbox_rect$$=new $APP.$cljs$core$PersistentArrayMap$$(null,8,[$APP.$cljs$cst$1515$x$$,$vbox_x$jscomp$2$$,$APP.$cljs$cst$1516$y$$,$vbox_y$jscomp$2$$,$APP.$cljs$cst$1528$x1$$,$vbox_x$jscomp$2$$,$APP.$cljs$cst$1529$y1$$,$vbox_y$jscomp$2$$,$APP.$cljs$cst$1530$x2$$,$vbox_x$jscomp$2$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$),$APP.$cljs$cst$1531$y2$$,$vbox_y$jscomp$2$$+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$),
$APP.$cljs$cst$290$width$$,$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$),$APP.$cljs$cst$1527$height$$,$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)],null),$containing_rect_width_factor$$=$APP.$app$common$geom$rect$join_rects$$(new $APP.$cljs$core$PersistentVector$$(null,2,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$base_objects_rect$$,$height_factor_vbox_rect$$],null));$height_factor_vbox_rect$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($containing_rect_width_factor$$)/
$vbox_height$jscomp$2$$;$containing_rect_width_factor$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($containing_rect_width_factor$$)/$vbox_width$jscomp$2$$;$APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$5$$,$event$jscomp$730_start_pt$jscomp$6$$);$APP.$rumext$v2$set_ref_val_BANG_$$($v_scrollbar_y_padding_ref$$,$v_scrollbar_y_padding$$);$APP.$rumext$v2$set_ref_val_BANG_$$($h_scrollbar_x_padding_ref$$,$h_scrollbar_x_padding$$);$APP.$rumext$v2$set_ref_val_BANG_$$($v_scrollbar_y_ref$$,
$new_v_scrollbar_y$jscomp$1_viewport_point$$+$v_scrollbar_y_padding$$);$APP.$rumext$v2$set_ref_val_BANG_$$($h_scrollbar_x_ref$$,$new_h_scrollbar_x$jscomp$1$$+$h_scrollbar_x_padding$$);$APP.$rumext$v2$set_ref_val_BANG_$$($vbox_y_ref$$,$vbox_y$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($vbox_x_ref$$,$vbox_x$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($scrollbar_height_ref$$,$scrollbar_height__$1$$);$APP.$rumext$v2$set_ref_val_BANG_$$($scrollbar_width_ref$$,$scrollbar_width__$1$$);$APP.$rumext$v2$set_ref_val_BANG_$$($height_factor_ref$$,
$height_factor_vbox_rect$$);$APP.$rumext$v2$set_ref_val_BANG_$$($width_factor_ref$$,$containing_rect_width_factor$$);$APP.$cljs$core$reset_BANG_$$($v_scrolling_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$67$$,$APP.$cljs$cst$1516$y$$));return $APP.$cljs$core$reset_BANG_$$($h_scrolling_QMARK_$$,$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$67$$,$APP.$cljs$cst$1515$x$$))}function $on_pointer_move$jscomp$15$$($current_pt$jscomp$5_event$jscomp$729$$,
$axis$jscomp$66$$){var $new_v_scrollbar_y_start_pt$jscomp$5_temp__5825__auto__$jscomp$456$$=function(){var $or__5025__auto__$jscomp$1417$$=$APP.$cljs$core$_deref$$($v_scrolling_QMARK_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1417$$)?$or__5025__auto__$jscomp$1417$$:$APP.$cljs$core$_deref$$($h_scrolling_QMARK_$$)}();if($APP.$cljs$core$truth_$$($new_v_scrollbar_y_start_pt$jscomp$5_temp__5825__auto__$jscomp$456$$)){$new_v_scrollbar_y_start_pt$jscomp$5_temp__5825__auto__$jscomp$456$$=
$APP.$rumext$v2$ref_val$$($start_ref$jscomp$5$$);$current_pt$jscomp$5_event$jscomp$729$$=$APP.$app$util$dom$get_client_position$$($current_pt$jscomp$5_event$jscomp$729$$);var $current_pt_viewport_new_h_scrollbar_x$$=$app$main$ui$workspace$viewport$viewport_ref$point__GT_viewport$$($current_pt$jscomp$5_event$jscomp$729$$),$y_delta$$=$APP.$rumext$v2$ref_val$$($height_factor_ref$$)*($APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($current_pt$jscomp$5_event$jscomp$729$$)-$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($new_v_scrollbar_y_start_pt$jscomp$5_temp__5825__auto__$jscomp$456$$))/
$zoom$jscomp$150$$,$x_delta$$=$APP.$rumext$v2$ref_val$$($width_factor_ref$$)*($APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($current_pt$jscomp$5_event$jscomp$729$$)-$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($new_v_scrollbar_y_start_pt$jscomp$5_temp__5825__auto__$jscomp$456$$))/$zoom$jscomp$150$$;$new_v_scrollbar_y_start_pt$jscomp$5_temp__5825__auto__$jscomp$456$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($current_pt_viewport_new_h_scrollbar_x$$)+$APP.$rumext$v2$ref_val$$($v_scrollbar_y_padding_ref$$);
$current_pt_viewport_new_h_scrollbar_x$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($current_pt_viewport_new_h_scrollbar_x$$)+$APP.$rumext$v2$ref_val$$($h_scrollbar_x_padding_ref$$);var $viewport_update$$=function(){var $G__81398$$=function(){var $G__81399$$=$APP.$cljs$core$PersistentArrayMap$EMPTY$$;return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$66$$,$APP.$cljs$cst$1516$y$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__81399$$,$APP.$cljs$cst$1516$y$$,
function($p1__81380_SHARP_$$){return $p1__81380_SHARP_$$+$y_delta$$}):$G__81399$$}();return $APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($axis$jscomp$66$$,$APP.$cljs$cst$1515$x$$)?$APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($G__81398$$,$APP.$cljs$cst$1515$x$$,function($p1__81381_SHARP_$$){return $p1__81381_SHARP_$$+$x_delta$$}):$G__81398$$}();$APP.$rumext$v2$set_ref_val_BANG_$$($vbox_y_ref$$,$vbox_y$jscomp$2$$);$APP.$rumext$v2$set_ref_val_BANG_$$($vbox_x_ref$$,$vbox_x$jscomp$2$$);
$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$viewport$update_viewport_position$$($viewport_update$$));$APP.$rumext$v2$set_ref_val_BANG_$$($v_scrollbar_y_ref$$,$new_v_scrollbar_y_start_pt$jscomp$5_temp__5825__auto__$jscomp$456$$);$APP.$rumext$v2$set_ref_val_BANG_$$($h_scrollbar_x_ref$$,$current_pt_viewport_new_h_scrollbar_x$$);return $APP.$rumext$v2$set_ref_val_BANG_$$($start_ref$jscomp$5$$,$current_pt$jscomp$5_event$jscomp$729$$)}return null}var $zoom$jscomp$150$$=
$bottom_padding_props_81386_show_h_scroll_QMARK_$$.zoom,$objects$jscomp$836$$=$bottom_padding_props_81386_show_h_scroll_QMARK_$$.objects,$show_v_scroll_QMARK__vbox$jscomp$70$$=$bottom_padding_props_81386_show_h_scroll_QMARK_$$.vbox;$bottom_padding_props_81386_show_h_scroll_QMARK_$$=$bottom_padding_props_81386_show_h_scroll_QMARK_$$.bottomPadding;var $v_scrolling_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$h_scrolling_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),
$start_ref$jscomp$5$$=(0,$APP.$rumext$v2$use_ref$$)(null),$v_scrollbar_y_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$h_scrollbar_x_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$v_scrollbar_y_stored$$=$APP.$rumext$v2$ref_val$$($v_scrollbar_y_ref$$),$h_scrollbar_x_stored$$=$APP.$rumext$v2$ref_val$$($h_scrollbar_x_ref$$),$v_scrollbar_y_padding_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$h_scrollbar_x_padding_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$scrollbar_height_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),
$scrollbar_width_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$scrollbar_height_stored$$=$APP.$rumext$v2$ref_val$$($scrollbar_height_ref$$),$scrollbar_width_stored$$=$APP.$rumext$v2$ref_val$$($scrollbar_width_ref$$),$height_factor_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$width_factor_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$vbox_y_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$vbox_x_ref$$=(0,$APP.$rumext$v2$use_ref$$)(null),$vbox_x$jscomp$2$$=$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($show_v_scroll_QMARK__vbox$jscomp$70$$),
$vbox_y$jscomp$2$$=$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($show_v_scroll_QMARK__vbox$jscomp$70$$),$base_objects_rect$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($objects$jscomp$836$$)],function(){return $APP.$app$common$geom$shapes$shapes__GT_rect$$($APP.$app$common$files$helpers$get_immediate_children$cljs$0core$0IFn$0_invoke$0arity$03$$($objects$jscomp$836$$,$APP.$app$common$uuid$zero$$,null))}),$vbox__$1$$=$bottom_padding_props_81386_show_h_scroll_QMARK_$$!=
null?$APP.$cljs$core$update$$.$cljs$core$IFn$_invoke$arity$4$($show_v_scroll_QMARK__vbox$jscomp$70$$,$APP.$cljs$cst$1527$height$$,$APP.$cljs$core$_$$,$bottom_padding_props_81386_show_h_scroll_QMARK_$$/$zoom$jscomp$150$$):$show_v_scroll_QMARK__vbox$jscomp$70$$,$inv_zoom$jscomp$2$$=1/$zoom$jscomp$150$$,$vbox_height$jscomp$2$$=$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)-$inv_zoom$jscomp$2$$*14,$vbox_width$jscomp$2$$=$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)-
$inv_zoom$jscomp$2$$*14,$top_offset$jscomp$2$$=function(){var $x__5110__auto__$jscomp$181$$=$vbox_y$jscomp$2$$-$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$);return $x__5110__auto__$jscomp$181$$>0?$x__5110__auto__$jscomp$181$$:0}()*$vbox_height$jscomp$2$$/$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$),$left_offset$jscomp$2$$=function(){var $x__5110__auto__$jscomp$182$$=$vbox_x$jscomp$2$$-$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$);
return $x__5110__auto__$jscomp$182$$>0?$x__5110__auto__$jscomp$182$$:0}()*$vbox_width$jscomp$2$$/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$),$bottom_offset$jscomp$2$$=function(){var $x__5110__auto__$jscomp$183$$=$APP.$cljs$cst$1531$y2$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$)-($vbox_y$jscomp$2$$+$vbox_height$jscomp$2$$);return $x__5110__auto__$jscomp$183$$>0?$x__5110__auto__$jscomp$183$$:0}()*$vbox_height$jscomp$2$$/$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$),
$right_offset$jscomp$1$$=function(){var $x__5110__auto__$jscomp$184$$=$APP.$cljs$cst$1530$x2$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$)-($vbox_x$jscomp$2$$+$vbox_width$jscomp$2$$);return $x__5110__auto__$jscomp$184$$>0?$x__5110__auto__$jscomp$184$$:0}()*$vbox_width$jscomp$2$$/$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($base_objects_rect$$);$show_v_scroll_QMARK__vbox$jscomp$70$$=function(){var $or__5025__auto__$jscomp$1415$$=$APP.$cljs$core$_deref$$($v_scrolling_QMARK_$$);
return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1415$$)?$or__5025__auto__$jscomp$1415$$:$top_offset$jscomp$2$$>0||$bottom_offset$jscomp$2$$>0}();$bottom_padding_props_81386_show_h_scroll_QMARK_$$=function(){var $or__5025__auto__$jscomp$1416$$=$APP.$cljs$core$_deref$$($h_scrolling_QMARK_$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1416$$)?$or__5025__auto__$jscomp$1416$$:$left_offset$jscomp$2$$>0||$right_offset$jscomp$1$$>0}();var $v_scrollbar_x$$=$vbox_x$jscomp$2$$+$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)+
$inv_zoom$jscomp$2$$*-10,$v_scrollbar_y$$=$vbox_y$jscomp$2$$+$top_offset$jscomp$2$$,$h_scrollbar_x$$=$vbox_x$jscomp$2$$+$left_offset$jscomp$2$$,$h_scrollbar_y$$=$vbox_y$jscomp$2$$+$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($vbox__$1$$)+$inv_zoom$jscomp$2$$*-10,$scrollbar_height$$=$vbox_y$jscomp$2$$+$vbox_height$jscomp$2$$-$bottom_offset$jscomp$2$$-$v_scrollbar_y$$,$scrollbar_height__$1$$=function(){var $x__5110__auto__$jscomp$185$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($v_scrolling_QMARK_$$))?
$scrollbar_height_stored$$:$scrollbar_height$$,$y__5111__auto__$jscomp$185$$=$inv_zoom$jscomp$2$$*100;return $x__5110__auto__$jscomp$185$$>$y__5111__auto__$jscomp$185$$?$x__5110__auto__$jscomp$185$$:$y__5111__auto__$jscomp$185$$}(),$scrollbar_width$$=$vbox_x$jscomp$2$$+$vbox_width$jscomp$2$$-$right_offset$jscomp$1$$-$h_scrollbar_x$$,$scrollbar_width__$1$$=function(){var $x__5110__auto__$jscomp$186$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($h_scrolling_QMARK_$$))?$scrollbar_width_stored$$:
$scrollbar_width$$,$y__5111__auto__$jscomp$186$$=$inv_zoom$jscomp$2$$*100;return $x__5110__auto__$jscomp$186$$>$y__5111__auto__$jscomp$186$$?$x__5110__auto__$jscomp$186$$:$y__5111__auto__$jscomp$186$$}(),$h_scrollbar_x__$1_v_scrollbar_y__$1$$=function(){var $x__5110__auto__$jscomp$187$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($v_scrolling_QMARK_$$))?$v_scrollbar_y_stored$$- -($vbox_y$jscomp$2$$-$APP.$rumext$v2$ref_val$$($vbox_y_ref$$)):$v_scrollbar_y$$,$y__5111__auto__$jscomp$187$$=$vbox_y$jscomp$2$$+
$inv_zoom$jscomp$2$$*26;return $x__5110__auto__$jscomp$187$$>$y__5111__auto__$jscomp$187$$?$x__5110__auto__$jscomp$187$$:$y__5111__auto__$jscomp$187$$}(),$v_scrollbar_y__$2$$=$h_scrollbar_x__$1_v_scrollbar_y__$1$$+$scrollbar_height__$1$$>$vbox_y$jscomp$2$$+$vbox_height$jscomp$2$$?$vbox_y$jscomp$2$$+$vbox_height$jscomp$2$$-$scrollbar_height__$1$$:$h_scrollbar_x__$1_v_scrollbar_y__$1$$;$h_scrollbar_x__$1_v_scrollbar_y__$1$$=function(){var $x__5110__auto__$jscomp$188$$=$APP.$cljs$core$truth_$$($APP.$cljs$core$_deref$$($h_scrolling_QMARK_$$))?
$h_scrollbar_x_stored$$- -($vbox_x$jscomp$2$$-$APP.$rumext$v2$ref_val$$($vbox_x_ref$$)):$h_scrollbar_x$$,$y__5111__auto__$jscomp$188$$=$vbox_x$jscomp$2$$+$inv_zoom$jscomp$2$$*26;return $x__5110__auto__$jscomp$188$$>$y__5111__auto__$jscomp$188$$?$x__5110__auto__$jscomp$188$$:$y__5111__auto__$jscomp$188$$}();var $h_scrollbar_x__$2$$=$h_scrollbar_x__$1_v_scrollbar_y__$1$$+$scrollbar_width__$1$$>$vbox_x$jscomp$2$$+$vbox_width$jscomp$2$$?$vbox_x$jscomp$2$$+$vbox_width$jscomp$2$$-$scrollbar_width__$1$$:
$h_scrollbar_x__$1_v_scrollbar_y__$1$$;return(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$Fragment$$,{children:[$APP.$cljs$core$truth_$$($show_v_scroll_QMARK__vbox$jscomp$70$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"v-scroll",fill:"#000000","data-testid":"vertical-scrollbar",children:(0,$APP.$rumext$v2$jsx$$)("rect",{width:$inv_zoom$jscomp$2$$*7,height:$scrollbar_height__$1$$,x:$v_scrollbar_x$$,onPointerUp:$on_pointer_up$jscomp$7$$,style:{stroke:"white",strokeWidth:.15/$zoom$jscomp$150$$},ry:$inv_zoom$jscomp$2$$*
3,rx:$inv_zoom$jscomp$2$$*3,y:$v_scrollbar_y__$2$$,onPointerMove:function($p1__81382_SHARP_$$){return $on_pointer_move$jscomp$15$$($p1__81382_SHARP_$$,$APP.$cljs$cst$1516$y$$)},fillOpacity:.4,onPointerDown:function($p1__81383_SHARP_$$){return $on_pointer_down$jscomp$19$$($p1__81383_SHARP_$$,$APP.$cljs$cst$1516$y$$)}})}):null,$APP.$cljs$core$truth_$$($bottom_padding_props_81386_show_h_scroll_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("g",{className:"h-scroll",fill:"#000000","data-testid":"horizontal-scrollbar",
children:(0,$APP.$rumext$v2$jsx$$)("rect",{width:$scrollbar_width__$1$$,height:$inv_zoom$jscomp$2$$*7,x:$h_scrollbar_x__$2$$,onPointerUp:$on_pointer_up$jscomp$7$$,style:{stroke:"white",strokeWidth:.15/$zoom$jscomp$150$$},ry:$inv_zoom$jscomp$2$$*3,rx:$inv_zoom$jscomp$2$$*3,y:$h_scrollbar_y$$,onPointerMove:function($p1__81384_SHARP_$$){return $on_pointer_move$jscomp$15$$($p1__81384_SHARP_$$,$APP.$cljs$cst$1515$x$$)},fillOpacity:.4,onPointerDown:function($p1__81385_SHARP_$$){return $on_pointer_down$jscomp$19$$($p1__81385_SHARP_$$,
$APP.$cljs$cst$1515$x$$)}})}):null]})});var $app$main$ui$workspace$viewport$snap_points$snap_points_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$){var $zoom$jscomp$172$$=$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$.zoom,$remove_snap$jscomp$2_selected$jscomp$209$$=$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$.selected,$objects$jscomp$839$$=$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$.objects,$layout$jscomp$32$$=$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$.layout,
$page_id$jscomp$462$$=$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$.pageId,$focus$jscomp$24$$=$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$.focus;$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$=$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$.drawing;var $frame_id$jscomp$166_shapes$jscomp$243$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$PersistentVector$EMPTY$$,$APP.$cljs$core$keep$cljs$0core$0IFn$0_invoke$0arity$01$$($APP.$app$common$data$getf$$($objects$jscomp$839$$)),
$remove_snap$jscomp$2_selected$jscomp$209$$),$filter_shapes$jscomp$3$$=$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($remove_snap$jscomp$2_selected$jscomp$209$$,$APP.$cljs$core$mapcat$cljs$0core$0IFn$0_invoke$0arity$01$$(function($p1__81514_SHARP_$$){return $APP.$app$common$files$helpers$get_children_ids$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$839$$,$p1__81514_SHARP_$$)}),$remove_snap$jscomp$2_selected$jscomp$209$$),$remove_snap_base_QMARK_$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout$jscomp$32$$),
$APP.$rumext$v2$adapt$$($filter_shapes$jscomp$3$$),$APP.$rumext$v2$adapt$$($objects$jscomp$839$$),$APP.$rumext$v2$adapt$$($focus$jscomp$24$$)],function(){return $APP.$app$main$snap$make_remove_snap$$($layout$jscomp$32$$,$filter_shapes$jscomp$3$$,$objects$jscomp$839$$,$focus$jscomp$24$$)});$remove_snap$jscomp$2_selected$jscomp$209$$=$APP.$rumext$v2$use_callback$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($remove_snap_base_QMARK_$$)],function($p__81516_type$jscomp$726$$){var $map__81517__$1_or__5025__auto__$jscomp$1421$$=
$APP.$cljs$core$__destructure_map$$($p__81516_type$jscomp$726$$);$p__81516_type$jscomp$726$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81517__$1_or__5025__auto__$jscomp$1421$$,$APP.$cljs$cst$139$type$$);var $grid$jscomp$20$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($map__81517__$1_or__5025__auto__$jscomp$1421$$,$APP.$cljs$cst$1664$grid$$);$map__81517__$1_or__5025__auto__$jscomp$1421$$=$remove_snap_base_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$?$remove_snap_base_QMARK_$$.$cljs$core$IFn$_invoke$arity$1$($map__81517__$1_or__5025__auto__$jscomp$1421$$):
$remove_snap_base_QMARK_$$($map__81517__$1_or__5025__auto__$jscomp$1421$$);return $APP.$cljs$core$truth_$$($map__81517__$1_or__5025__auto__$jscomp$1421$$)?$map__81517__$1_or__5025__auto__$jscomp$1421$$:$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__81516_type$jscomp$726$$,$APP.$cljs$cst$1620$layout$$)&&$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($grid$jscomp$20$$,$APP.$cljs$cst$1912$square$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($p__81516_type$jscomp$726$$,
$APP.$cljs$cst$3916$guide$$)});$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$=$APP.$cljs$core$truth_$$($drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$)?new $APP.$cljs$core$PersistentVector$$(null,1,5,$APP.$cljs$core$PersistentVector$EMPTY_NODE$$,[$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$],null):$frame_id$jscomp$166_shapes$jscomp$243$$;$frame_id$jscomp$166_shapes$jscomp$243$$=$APP.$app$main$snap$snap_frame_id$$($drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$);return $APP.$cljs$core$truth_$$($APP.$app$common$types$shape$layout$any_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$839$$,
$frame_id$jscomp$166_shapes$jscomp$243$$))?null:(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$snap_points$snap_feedback_STAR_$$,{shapes:$drawing$jscomp$4_props_81515_shapes__$1$jscomp$39$$,pageId:$page_id$jscomp$462$$,removeSnap:$remove_snap$jscomp$2_selected$jscomp$209$$,zoom:$zoom$jscomp$172$$})});var $app$main$ui$workspace$viewport$path_actions$pentool_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__pentool-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-pentool"})}),$app$main$ui$workspace$viewport$path_actions$move_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__move-icon main_ui_workspace_viewport_path_actions__pathbar-icon",
height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-move"})}),$app$main$ui$workspace$viewport$path_actions$add_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__add-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-add"})}),$app$main$ui$workspace$viewport$path_actions$remove_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__remove main_ui_workspace_viewport_path_actions__pathbar-icon",
height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-remove"})}),$app$main$ui$workspace$viewport$path_actions$merge_nodes_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__merge-nodes-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-merge-nodes"})}),$app$main$ui$workspace$viewport$path_actions$join_nodes_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__join-nodes-icon main_ui_workspace_viewport_path_actions__pathbar-icon",
height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-join-nodes"})}),$app$main$ui$workspace$viewport$path_actions$separate_nodes_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__separate-nodes-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-separate-nodes"})}),$app$main$ui$workspace$viewport$path_actions$to_corner_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,
className:"main_ui_workspace_viewport_path_actions__to-corner-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-to-corner"})}),$app$main$ui$workspace$viewport$path_actions$to_curve_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__to-curve-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-to-curve"})}),
$app$main$ui$workspace$viewport$path_actions$snap_nodes_icon$$=(0,$APP.$rumext$v2$jsx$$)("svg",{width:500,className:"main_ui_workspace_viewport_path_actions__snap-nodes-icon main_ui_workspace_viewport_path_actions__pathbar-icon",height:500,children:(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-snap-nodes"})});var $app$main$ui$workspace$viewport$widgets$selection_rect_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_81529_zoom$jscomp$175$$){var $data$jscomp$506$$=$props_81529_zoom$jscomp$175$$.data;$props_81529_zoom$jscomp$175$$=$props_81529_zoom$jscomp$175$$.zoom;return $APP.$cljs$core$truth_$$($data$jscomp$506$$)?(0,$APP.$rumext$v2$jsx$$)("rect",{className:"selection-rect",x:$APP.$cljs$cst$1515$x$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$506$$),y:$APP.$cljs$cst$1516$y$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$506$$),
"data-testid":"workspace-selection-rect",width:$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$506$$),height:$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($data$jscomp$506$$),style:{fill:"var(--color-accent-tertiary-muted)",stroke:"var(--color-accent-tertiary)",strokeWidth:1/$props_81529_zoom$jscomp$175$$}}):null}),$app$main$ui$workspace$viewport$widgets$frame_title_STAR_$$,$p1__81530_SHARP_$jscomp$inline_9549$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$((0,$APP.$rumext$v2$forward_ref$$)(function($color$jscomp$210_is_selected$jscomp$15_props_81531$$,
$external_ref$jscomp$4_start_edit$jscomp$1$$){var $is_grid_edition$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.isGridEdition,$is_show_artboard_names$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.isShowArtboardNames,$zoom$jscomp$176$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.zoom,$is_show_id$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.isShowId,$on_frame_select$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.onFrameSelect,$frame$jscomp$105$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.frame,
$on_frame_enter$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.onFrameEnter,$on_frame_leave$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.onFrameLeave;$color$jscomp$210_is_selected$jscomp$15_props_81531$$=$color$jscomp$210_is_selected$jscomp$15_props_81531$$.isSelected;var $workspace_read_only_QMARK_$jscomp$2$$=(0,$APP.$rumext$v2$use_ctx$$)($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),$objects$jscomp$840$$=$APP.$cljs$core$_deref$$($APP.$app$main$refs$workspace_page_objects$$);
$color$jscomp$210_is_selected$jscomp$15_props_81531$$=$APP.$cljs$core$truth_$$($color$jscomp$210_is_selected$jscomp$15_props_81531$$)?$APP.$cljs$core$truth_$$(function(){var $or__5025__auto__$jscomp$1422$$=$APP.$app$common$types$container$in_any_component_QMARK_$$($objects$jscomp$840$$,$frame$jscomp$105$$);return $APP.$cljs$core$truth_$$($or__5025__auto__$jscomp$1422$$)?$or__5025__auto__$jscomp$1422$$:$APP.$app$common$types$component$is_variant_container_QMARK_$$($frame$jscomp$105$$)}())?"var(--assets-component-hightlight)":
"var(--color-accent-tertiary)":"#8f9da3";var $blocked_QMARK_$jscomp$4$$=$APP.$cljs$cst$1628$blocked$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$),$on_pointer_down$jscomp$20$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$)),$APP.$rumext$v2$adapt$$($on_frame_select$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$jscomp$2$$),$APP.$rumext$v2$adapt$$($blocked_QMARK_$jscomp$4$$)],
function($event$jscomp$735$$){var $G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$;if($G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$=$app$util$dom$left_mouse_QMARK_$$($event$jscomp$735$$))$G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$=($G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$=
$APP.$cljs$core$not$$($blocked_QMARK_$jscomp$4$$))?$G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$:$workspace_read_only_QMARK_$jscomp$2$$;return $APP.$cljs$core$truth_$$($G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$)?($APP.$app$util$dom$prevent_default$$($event$jscomp$735$$),$APP.$app$util$dom$stop_propagation$$($event$jscomp$735$$),$G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$),$on_frame_select$$.$cljs$core$IFn$_invoke$arity$2$?$on_frame_select$$.$cljs$core$IFn$_invoke$arity$2$($event$jscomp$735$$,$G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$):$on_frame_select$$($event$jscomp$735$$,$G__81533_JSCompiler_inline_result$jscomp$1970_and__5023__auto__$jscomp$inline_9544_or__5025__auto__$jscomp$inline_9545$$)):null}),$on_context_menu$jscomp$28$$=
$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame$jscomp$105$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$jscomp$2$$)],function($bevent$jscomp$4_event$jscomp$736$$){$bevent$jscomp$4_event$jscomp$736$$=$bevent$jscomp$4_event$jscomp$736$$.nativeEvent;var $position$jscomp$250$$=$APP.$app$util$dom$get_client_position$$($bevent$jscomp$4_event$jscomp$736$$);$APP.$app$util$dom$prevent_default$$($bevent$jscomp$4_event$jscomp$736$$);$APP.$app$util$dom$stop_propagation$$($bevent$jscomp$4_event$jscomp$736$$);
return $APP.$cljs$core$truth_$$($workspace_read_only_QMARK_$jscomp$2$$)?null:$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$show_shape_context_menu$$(new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$1681$position$$,$position$jscomp$250$$,$APP.$cljs$cst$1817$shape$$,$frame$jscomp$105$$],null)))}),$on_pointer_enter$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$)),
$APP.$rumext$v2$adapt$$($on_frame_enter$$)],function(){var $G__81534$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$);return $on_frame_enter$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_enter$$.$cljs$core$IFn$_invoke$arity$1$($G__81534$$):$on_frame_enter$$($G__81534$$)}),$on_pointer_leave$jscomp$16$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$)),$APP.$rumext$v2$adapt$$($on_frame_leave$$)],
function(){var $G__81535$$=$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$);return $on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$($G__81535$$):$on_frame_leave$$($G__81535$$)}),$main_instance_QMARK_$jscomp$6$$=$APP.$app$common$types$component$main_instance_QMARK_$$($frame$jscomp$105$$),$is_variant_QMARK_$jscomp$5$$=$APP.$cljs$cst$2020$is_variant_container$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$),$text_width$jscomp$2$$=
($app$main$ui$workspace$viewport$utils$title_transform_use_width_QMARK_$$($frame$jscomp$105$$)?$APP.$cljs$cst$290$width$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$):$APP.$cljs$cst$1527$height$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$))*$zoom$jscomp$176$$,$show_icon_QMARK_$$=function(){var $and__5023__auto__$jscomp$1008_or__5025__auto__$jscomp$inline_9547$$=$APP.$cljs$cst$2975$use_for_thumbnail$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$);$and__5023__auto__$jscomp$1008_or__5025__auto__$jscomp$inline_9547$$=
$APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1008_or__5025__auto__$jscomp$inline_9547$$)?$and__5023__auto__$jscomp$1008_or__5025__auto__$jscomp$inline_9547$$:$APP.$cljs$core$truth_$$($is_grid_edition$$)?$is_grid_edition$$:$main_instance_QMARK_$jscomp$6$$?$main_instance_QMARK_$jscomp$6$$:$is_variant_QMARK_$jscomp$5$$;return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1008_or__5025__auto__$jscomp$inline_9547$$)?!($text_width$jscomp$2$$<=15):$and__5023__auto__$jscomp$1008_or__5025__auto__$jscomp$inline_9547$$}(),
$text_pos_x$$=$APP.$cljs$core$truth_$$($show_icon_QMARK_$$)?15:0,$edition_STAR_$jscomp$2$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$edition_QMARK_$jscomp$3$$=$APP.$cljs$core$_deref$$($edition_STAR_$jscomp$2$$),$local_ref$jscomp$5_on_key_down$jscomp$30$$=(0,$APP.$rumext$v2$use_ref$$)(),$ref$jscomp$59$$=$APP.$app$common$data$nilv$$.$cljs$core$IFn$_invoke$arity$2$($external_ref$jscomp$4_start_edit$jscomp$1$$,$local_ref$jscomp$5_on_key_down$jscomp$30$$),$frame_id$jscomp$167$$=
$APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$);$external_ref$jscomp$4_start_edit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$167$$),$APP.$rumext$v2$adapt$$($edition_QMARK_$jscomp$3$$),$APP.$rumext$v2$adapt$$($blocked_QMARK_$jscomp$4$$),$APP.$rumext$v2$adapt$$($workspace_read_only_QMARK_$jscomp$2$$)],function(){return $APP.$cljs$core$not$$($blocked_QMARK_$jscomp$4$$)&&$APP.$cljs$core$not$$($workspace_read_only_QMARK_$jscomp$2$$)?
$APP.$cljs$core$not$$($edition_QMARK_$jscomp$3$$)?$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$2$$,!0):$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$start_rename_shape$$($frame_id$jscomp$167$$)):null});var $accept_edit$jscomp$1$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$167$$)],function(){var $name$jscomp$504$$=$APP.$cuerdas$core$trim$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$util$dom$get_value$$($APP.$rumext$v2$ref_val$$($ref$jscomp$59$$)));
$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$2$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$end_rename_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_id$jscomp$167$$,$name$jscomp$504$$));return $on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$167$$):$on_frame_leave$$($frame_id$jscomp$167$$)}),$cancel_edit$jscomp$3$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($frame_id$jscomp$167$$)],
function(){$APP.$cljs$core$reset_BANG_$$($edition_STAR_$jscomp$2$$,!1);$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$end_rename_shape$cljs$0core$0IFn$0_invoke$0arity$02$$($frame_id$jscomp$167$$,null));return $on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$?$on_frame_leave$$.$cljs$core$IFn$_invoke$arity$1$($frame_id$jscomp$167$$):$on_frame_leave$$($frame_id$jscomp$167$$)});$local_ref$jscomp$5_on_key_down$jscomp$30$$=$APP.$rumext$v2$use_fn$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($accept_edit$jscomp$1$$),
$APP.$rumext$v2$adapt$$($cancel_edit$jscomp$3$$)],function($event$jscomp$737$$){$APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$enter_QMARK_$$)($event$jscomp$737$$))&&($accept_edit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$?$accept_edit$jscomp$1$$.$cljs$core$IFn$_invoke$arity$0$():$accept_edit$jscomp$1$$());return $APP.$cljs$core$truth_$$((0,$APP.$app$util$keyboard$esc_QMARK_$$)($event$jscomp$737$$))?$cancel_edit$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$?$cancel_edit$jscomp$3$$.$cljs$core$IFn$_invoke$arity$0$():
$cancel_edit$jscomp$3$$():null});return $APP.$cljs$core$not$$($APP.$cljs$cst$1625$hidden$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$))?(0,$APP.$rumext$v2$jsxs$$)("g",{className:"frame-title",id:"frame-title-"+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$)??""),"data-edit-grid":$is_grid_edition$$,transform:$APP.$app$main$ui$workspace$viewport$utils$title_transform$$($frame$jscomp$105$$,$zoom$jscomp$176$$,$is_grid_edition$$),pointerEvents:$APP.$cljs$core$truth_$$(function(){var $and__5023__auto__$jscomp$1009$$=
$APP.$cljs$cst$1628$blocked$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$);return $APP.$cljs$core$truth_$$($and__5023__auto__$jscomp$1009$$)?$APP.$cljs$core$not$$($workspace_read_only_QMARK_$jscomp$2$$):$and__5023__auto__$jscomp$1009$$}())?"none":null,children:[$APP.$cljs$core$truth_$$($show_icon_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)("svg",{x:0,y:-9,width:12,height:12,style:{stroke:$color$jscomp$210_is_selected$jscomp$15_props_81531$$,fill:"none"},visibility:$APP.$cljs$core$truth_$$($is_show_artboard_names$$)?
"visible":"hidden",className:"workspace-frame-icon",children:$APP.$cljs$core$truth_$$($APP.$cljs$cst$2975$use_for_thumbnail$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$))?(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-boards-thumbnail"}):$APP.$cljs$core$truth_$$($is_grid_edition$$)?(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-grid"}):$main_instance_QMARK_$jscomp$6$$?(0,$APP.$rumext$v2$jsx$$)("use",{href:"#icon-component"}):$APP.$cljs$core$truth_$$($is_variant_QMARK_$jscomp$5$$)?(0,$APP.$rumext$v2$jsx$$)("use",
{href:"#icon-component"}):null}):null,$edition_QMARK_$jscomp$3$$?(0,$APP.$rumext$v2$jsx$$)("foreignObject",{x:$text_pos_x$$,y:-15,width:function(){var $y__5111__auto__$jscomp$191$$=$text_width$jscomp$2$$-$text_pos_x$$;return 0>$y__5111__auto__$jscomp$191$$?0:$y__5111__auto__$jscomp$191$$}(),height:22,style:{fill:$color$jscomp$210_is_selected$jscomp$15_props_81531$$},visibility:$APP.$cljs$core$truth_$$($is_show_artboard_names$$)?"visible":"hidden",className:"main_ui_workspace_viewport_widgets__frame-title-wrapper",
children:(0,$APP.$rumext$v2$jsx$$)("input",{type:"text",style:{color:$color$jscomp$210_is_selected$jscomp$15_props_81531$$},autoFocus:!0,onKeyDown:$local_ref$jscomp$5_on_key_down$jscomp$30$$,ref:$ref$jscomp$59$$,defaultValue:$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$),onBlur:$accept_edit$jscomp$1$$,className:"main_ui_workspace_viewport_widgets__frame-title-label main_ui_workspace_viewport_widgets__frame-title-input"})}):(0,$APP.$rumext$v2$jsx$$)("foreignObject",
{x:$text_pos_x$$,y:-11,width:function(){var $y__5111__auto__$jscomp$192$$=$text_width$jscomp$2$$-$text_pos_x$$;return 0>$y__5111__auto__$jscomp$192$$?0:$y__5111__auto__$jscomp$192$$}(),height:20,style:{fill:$color$jscomp$210_is_selected$jscomp$15_props_81531$$},visibility:$APP.$cljs$core$truth_$$($is_show_artboard_names$$)?"visible":"hidden",className:"main_ui_workspace_viewport_widgets__frame-title-wrapper",children:(0,$APP.$rumext$v2$jsx$$)("div",{onDoubleClick:$external_ref$jscomp$4_start_edit$jscomp$1$$,
className:"main_ui_workspace_viewport_widgets__frame-title-label",children:$APP.$cljs$core$truth_$$($is_show_id$$)?""+($APP.$cljs$cst$266$id$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$)??"")+" - "+($APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$)??""):$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($frame$jscomp$105$$),onContextMenu:$on_context_menu$jscomp$28$$,style:{color:$color$jscomp$210_is_selected$jscomp$15_props_81531$$},ref:$ref$jscomp$59$$,
onPointerDown:$on_pointer_down$jscomp$20$$,onPointerLeave:$on_pointer_leave$jscomp$16$$,onPointerEnter:$on_pointer_enter$jscomp$16$$})})]}):null}));$app$main$ui$workspace$viewport$widgets$frame_title_STAR_$$=$APP.$rumext$v2$deferred$cljs$0core$0IFn$0_invoke$0arity$02$$($p1__81530_SHARP_$jscomp$inline_9549$$,function($f$jscomp$651$$){return(0,$APP.$app$util$timers$request_animation_frame$$)($f$jscomp$651$$)});
var $app$main$ui$workspace$viewport$widgets$frame_titles_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$){var $is_show_artboard_names$jscomp$1$$=$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$.isShowArtboardNames,$zoom$jscomp$177$$=$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$.zoom,$selected$jscomp$210$$=$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$.selected,$on_frame_select$jscomp$1$$=$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$.onFrameSelect,
$on_frame_enter$jscomp$1$$=$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$.onFrameEnter,$objects$jscomp$841$$=$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$.objects,$on_frame_leave$jscomp$1$$=$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$.onFrameLeave,$focus$jscomp$25$$=$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$.focus,$selected__$1$jscomp$20$$=$APP.$cljs$core$truth_$$($selected$jscomp$210$$)?$selected$jscomp$210$$:$APP.$cljs$core$PersistentHashSet$EMPTY$$;$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$=
$APP.$app$common$types$shape_tree$get_frames$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$841$$,new $APP.$cljs$core$PersistentArrayMap$$(null,2,[$APP.$cljs$cst$2092$skip_copies_QMARK_$$,!0,$APP.$cljs$cst$2093$ignore_index_QMARK_$$,!0],null));$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3094$shape_titles$$)?$APP.$cljs$core$into$$.$cljs$core$IFn$_invoke$arity$3$($APP.$cljs$core$set$$($props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$),
$APP.$cljs$core$map$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$common$data$getf$$($objects$jscomp$841$$)),$selected__$1$jscomp$20$$):$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$;var $edition$jscomp$17$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$selected_edition$$),$grid_edition_QMARK_$jscomp$1$$=$APP.$app$common$types$shape$layout$grid_layout_QMARK_$$.$cljs$core$IFn$_invoke$arity$2$($objects$jscomp$841$$,$edition$jscomp$17$$);return(0,$APP.$rumext$v2$jsx$$)("g",{className:"frame-titles blurrable",
children:$APP.$cljs$core$reduce$cljs$0core$0IFn$0_invoke$0arity$03$$(function($out_arr__44092__auto__$jscomp$241$$,$JSCompiler_temp_const$jscomp$1971_p__81537$$){var $JSCompiler_temp$jscomp$1973_map__81538__$1$$=$APP.$cljs$core$__destructure_map$$($JSCompiler_temp_const$jscomp$1971_p__81537$$),$id$jscomp$1061$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1973_map__81538__$1$$,$APP.$cljs$cst$266$id$$),$JSCompiler_temp_const$jscomp$1975_parent_id$jscomp$109$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp$jscomp$1973_map__81538__$1$$,
$APP.$cljs$cst$1624$parent_id$$);$JSCompiler_temp_const$jscomp$1971_p__81537$$=$out_arr__44092__auto__$jscomp$241$$.push;if($APP.$cljs$core$not_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1061$$,$APP.$app$common$uuid$zero$$)&&($APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3094$shape_titles$$)||$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($JSCompiler_temp_const$jscomp$1975_parent_id$jscomp$109$$,$APP.$app$common$uuid$zero$$))&&($APP.$cljs$core$empty_QMARK_$$($focus$jscomp$25$$)||
$APP.$cljs$core$contains_QMARK_$$($focus$jscomp$25$$,$id$jscomp$1061$$))){$JSCompiler_temp_const$jscomp$1975_parent_id$jscomp$109$$=$APP.$app$util$debug$enabled_QMARK_$$($APP.$cljs$cst$3094$shape_titles$$);var $JSCompiler_temp_const$jscomp$1974$$=$APP.$cljs$core$contains_QMARK_$$($selected__$1$jscomp$20$$,$id$jscomp$1061$$),$and__5023__auto__$jscomp$inline_9551$$=$APP.$cljs$core$_EQ_$$.$cljs$core$IFn$_invoke$arity$2$($id$jscomp$1061$$,$edition$jscomp$17$$);$JSCompiler_temp$jscomp$1973_map__81538__$1$$=
(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$viewport$widgets$frame_title_STAR_$$,{onFrameLeave:$on_frame_leave$jscomp$1$$,zoom:$zoom$jscomp$177$$,isShowArtboardNames:$is_show_artboard_names$jscomp$1$$,isShowId:$JSCompiler_temp_const$jscomp$1975_parent_id$jscomp$109$$,onFrameEnter:$on_frame_enter$jscomp$1$$,isSelected:$JSCompiler_temp_const$jscomp$1974$$,isGridEdition:$and__5023__auto__$jscomp$inline_9551$$?$grid_edition_QMARK_$jscomp$1$$:$and__5023__auto__$jscomp$inline_9551$$,frame:$JSCompiler_temp$jscomp$1973_map__81538__$1$$,
onFrameSelect:$on_frame_select$jscomp$1$$},"frame-title-"+($id$jscomp$1061$$??""))}else $JSCompiler_temp$jscomp$1973_map__81538__$1$$=null;$JSCompiler_temp_const$jscomp$1971_p__81537$$.call($out_arr__44092__auto__$jscomp$241$$,$JSCompiler_temp$jscomp$1973_map__81538__$1$$);return $out_arr__44092__auto__$jscomp$241$$},[],$props_81536_shapes$jscomp$244_shapes__$1$jscomp$40$$)})});$APP.$cljs$core$swap_BANG_$$.$cljs$core$IFn$_invoke$arity$2$($APP.$app$main$data$modal$components$$,function($state__44630__auto__$jscomp$53$$){return $APP.$cljs$core$assoc$$.$cljs$core$IFn$_invoke$arity$3$($state__44630__auto__$jscomp$53$$,$cljs$cst$6028$webgl_unavailable$$,$app$main$ui$workspace$webgl_unavailable_modal$webgl_unavailable_modal_STAR_$$)});var $app$main$ui$workspace$workspace_STAR_$$=$APP.$rumext$v2$memo$cljs$0core$0IFn$0_invoke$0arity$01$$(function($layout$jscomp$38_props_81663$$){var $project_id$jscomp$37$$=$layout$jscomp$38_props_81663$$.projectId,$team_id$jscomp$165$$=$layout$jscomp$38_props_81663$$.teamId,$layout_name$$=$layout$jscomp$38_props_81663$$.layoutName,$page_id$jscomp$469_wglobal$jscomp$6$$=$layout$jscomp$38_props_81663$$.pageId,$file_id__$1$jscomp$11$$=$APP.$app$main$ui$hooks$use_equal_memo$$($layout$jscomp$38_props_81663$$.fileId),
$page_id__$1$jscomp$26$$=$APP.$app$main$ui$hooks$use_equal_memo$$($page_id$jscomp$469_wglobal$jscomp$6$$);$layout$jscomp$38_props_81663$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_layout$$);$page_id$jscomp$469_wglobal$jscomp$6$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_global$$);var $permissions$jscomp$40_read_only_QMARK___$1_team$jscomp$71_team_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$165$$)],function(){return $app$main$ui$workspace$make_team_ref$$($team_id$jscomp$165$$)}),
$file$jscomp$189_file_ref$$=$APP.$rumext$v2$use_memo$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id__$1$jscomp$11$$)],function(){return $app$main$ui$workspace$make_file_ref$$($file_id__$1$jscomp$11$$)});$permissions$jscomp$40_read_only_QMARK___$1_team$jscomp$71_team_ref$$=$APP.$rumext$v2$deref$$($permissions$jscomp$40_read_only_QMARK___$1_team$jscomp$71_team_ref$$);$file$jscomp$189_file_ref$$=$APP.$rumext$v2$deref$$($file$jscomp$189_file_ref$$);var $file_loaded_QMARK_$$=$APP.$cljs$core$get$$.$cljs$core$IFn$_invoke$arity$2$($file$jscomp$189_file_ref$$,
$cljs$cst$6035$app_DOT_main_DOT_ui_DOT_workspace_SLASH_has_data$$),$file_name$jscomp$13$$=$APP.$cljs$cst$725$name$$.$cljs$core$IFn$_invoke$arity$1$($file$jscomp$189_file_ref$$);$permissions$jscomp$40_read_only_QMARK___$1_team$jscomp$71_team_ref$$=$APP.$cljs$cst$1728$permissions$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$40_read_only_QMARK___$1_team$jscomp$71_team_ref$$);var $design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$39$$=$APP.$rumext$v2$deref$$($APP.$app$main$refs$workspace_read_only_QMARK_$$);
$permissions$jscomp$40_read_only_QMARK___$1_team$jscomp$71_team_ref$$=$APP.$cljs$core$truth_$$($design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$39$$)?$design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$39$$:$APP.$cljs$core$not$$($APP.$cljs$cst$1601$can_edit$$.$cljs$core$IFn$_invoke$arity$1$($permissions$jscomp$40_read_only_QMARK___$1_team$jscomp$71_team_ref$$));$design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$39$$=$APP.$app$main$features$use_feature$$("design-tokens/v1");var $wasm_renderer_enabled_QMARK_$jscomp$1$$=
$APP.$app$main$features$use_feature$$("render-wasm/v1"),$first_frame_rendered_QMARK_$$=$APP.$rumext$v2$use_state$cljs$0core$0IFn$0_invoke$0arity$01$$(!1),$background_color$jscomp$4$$=$APP.$cljs$cst$3839$background_color$$.$cljs$core$IFn$_invoke$arity$1$($page_id$jscomp$469_wglobal$jscomp$6$$);$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($app$main$data$persistence$initialize_persistence$$(),
$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$plugins$update_plugins_permissions_peek$$()]))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($layout_name$$)],function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($app$main$data$workspace$initialize_workspace_layout$$($layout_name$$))});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_name$jscomp$13$$)],
function(){return $APP.$cljs$core$truth_$$($file_name$jscomp$13$$)?$APP.$app$util$dom$set_html_title$$($APP.$app$util$i18n$tr$$.$cljs$core$IFn$_invoke$arity$variadic$("title.workspace",$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$file_name$jscomp$13$$]))):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($team_id$jscomp$165$$),$APP.$rumext$v2$adapt$$($file_id__$1$jscomp$11$$)],function(){$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$workspace$initialize_workspace$$($team_id$jscomp$165$$,
$file_id__$1$jscomp$11$$));return function(){return $APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$variadic$($APP.$cljs$cst$2545$app_DOT_main_DOT_data_DOT_persistence_SLASH_force_persist$$,$APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$app$main$data$workspace$finalize_workspace$$($team_id$jscomp$165$$,$file_id__$1$jscomp$11$$)]))}});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id__$1$jscomp$11$$),$APP.$rumext$v2$adapt$$($page_id__$1$jscomp$26$$),
$APP.$rumext$v2$adapt$$($file_loaded_QMARK_$$)],function(){return $APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($file_loaded_QMARK_$$)?$APP.$cljs$core$not$$($page_id__$1$jscomp$26$$):$file_loaded_QMARK_$$)?$APP.$app$main$store$emit_BANG_$$.$cljs$core$IFn$_invoke$arity$1$($APP.$app$main$data$common$go_to_workspace$cljs$0core$0IFn$0_invoke$0arity$0variadic$$($APP.$cljs$core$prim_seq$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$cljs$cst$1649$file_id$$,$file_id__$1$jscomp$11$$,$APP.$cljs$cst$2466$app_DOT_main_DOT_router_SLASH_replace$$,
!0]))):null});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([$APP.$rumext$v2$adapt$$($file_id__$1$jscomp$11$$),$APP.$rumext$v2$adapt$$($page_id__$1$jscomp$26$$)],function(){return $APP.$cljs$core$reset_BANG_$$($first_frame_rendered_QMARK_$$,!1)});$APP.$rumext$v2$use_effect$cljs$0core$0IFn$0_invoke$0arity$02$$([],function(){var $listener_key$$=$APP.$goog$events$listen$$($APP.$app$util$globals$document$$,"penpot:wasm:render",function(){return $APP.$cljs$core$reset_BANG_$$($first_frame_rendered_QMARK_$$,
!0)});return function(){return $APP.$goog$events$unlistenByKey$$($listener_key$$)}});return(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_project_id$$),{value:$project_id$jscomp$37$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_file_id$$),{value:$file_id__$1$jscomp$11$$,children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$current_page_id$$),{value:$page_id__$1$jscomp$26$$,
children:(0,$APP.$rumext$v2$jsx$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$design_tokens$$),{value:$design_tokens_QMARK_$jscomp$1_read_only_QMARK_$jscomp$39$$,children:(0,$APP.$rumext$v2$jsxs$$)($APP.$rumext$v2$provider$$($APP.$app$main$ui$context$workspace_read_only_QMARK_$$),{value:$permissions$jscomp$40_read_only_QMARK___$1_team$jscomp$71_team_ref$$,children:[$APP.$rumext$v2$jsx$$($APP.$app$main$ui$modal$modal_container_STAR_$$,{}),(0,$APP.$rumext$v2$jsxs$$)("section",{style:{backgroundColor:$background_color$jscomp$4$$,
touchAction:"none",position:"relative"},className:"main_ui_workspace__workspace",children:[(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$context_menu$context_menu_STAR_$$,{}),$APP.$cljs$core$truth_$$($APP.$cljs$core$truth_$$($file_loaded_QMARK_$$)?$page_id__$1$jscomp$26$$:$file_loaded_QMARK_$$)?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$workspace_inner_STAR_$$,{pageId:$page_id__$1$jscomp$26$$,fileId:$file_id__$1$jscomp$11$$,file:$file$jscomp$189_file_ref$$,wglobal:$page_id$jscomp$469_wglobal$jscomp$6$$,
layout:$layout$jscomp$38_props_81663$$}):null,$APP.$cljs$core$not$$($APP.$cljs$core$truth_$$($file_loaded_QMARK_$$)?$page_id__$1$jscomp$26$$:$file_loaded_QMARK_$$)||$wasm_renderer_enabled_QMARK_$jscomp$1$$&&$APP.$cljs$core$not$$($file_loaded_QMARK_$$)&&$APP.$cljs$core$not$$($APP.$cljs$core$_deref$$($first_frame_rendered_QMARK_$$))?(0,$APP.$rumext$v2$jsx$$)($app$main$ui$workspace$workspace_loader_STAR_$$,{}):null]})]})})})})})});
//# sourceMappingURL=main-workspace.js.map
